@@ -1,13 +1,14 @@
-#!/bin/sh
+#!/bin/bash
 #               GMT ANIMATION 04
-#               $Id: anim_04.sh,v 1.5 2009/03/04 17:42:59 guru Exp $
+#               $Id: anim_04.sh,v 1.7 2011/02/28 00:58:03 remko Exp $
 #
-# Purpose:      Make DVD-res Quicktime movie of NY to Miami flight
+# Purpose:      Make DVD-res MP4 movie of NY to Miami flight
 # GMT progs:    gmtset, gmtmath, psbasemap, pstext, psxy, ps2raster
 # Unix progs:   awk, mkdir, rm, mv, echo, qt_export, cat
 #
 # 1. Initialization
 # 1a) Assign movie parameters
+. ../functions.sh
 . gmt_shell_functions.sh
 REGION=-Rg
 altitude=160.0
@@ -19,7 +20,7 @@ Height=34.0
 px=7.2
 py=4.8
 dpi=100
-name=`basename $0 '.sh'`
+name=../`basename $0 '.sh'`
 
 # Set up flight path
 project -C-73.8333/40.75 -E-80.133/25.75 -G5 -Q > $$.path.d
@@ -47,7 +48,7 @@ while read lon lat dist; do
 done < $$.path.d
 if [ $# -eq 1 ]; then
 	echo "anim_04.sh: Made $frame frames at 480x720 pixels placed in subdirectory frames"
-#	qt_export $$/anim_0_123456.tiff --video=h263,24,100, ${name}_movie.m4v
+	convert $$/anim_0_123456.tiff ${name}_movie.m4v
 fi
 # 4. Clean up temporary files
 gmtset DOTS_PR_INCH 300
