@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *    $Id: blockmedian.c,v 1.63 2009/09/09 23:27:01 guru Exp $
+ *    $Id: blockmedian.c,v 1.73 2011/03/03 21:02:50 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -48,7 +48,7 @@
 int main (int argc, char **argv)
 {
 
-	BOOLEAN	error = FALSE, nofile = TRUE, done = FALSE, first = TRUE, box_and_whisker = FALSE;
+	GMT_LONG	error = FALSE, nofile = TRUE, done = FALSE, first = TRUE, box_and_whisker = FALSE;
 
 	FILE *fp = NULL;
 
@@ -72,9 +72,9 @@ int main (int argc, char **argv)
 	void median_output (struct GRD_HEADER *h, GMT_LONG first_in_cell, GMT_LONG first_in_new_cell, double weight_sum, double *out, 
 		double *extra, GMT_LONG go_quickly, double *quantile, GMT_LONG n_quantiles, struct BLK_DATA *data);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
-	Ctrl = (struct BLOCKMEDIAN_CTRL *) New_Blockmedian_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct BLOCKMEDIAN_CTRL *) New_blockmedian_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	GMT_grd_init (&h, argc, argv, FALSE);
 
@@ -224,7 +224,7 @@ int main (int argc, char **argv)
 
 	h.x_inc = Ctrl->I.xinc;
 	h.y_inc = Ctrl->I.yinc;
-	h.node_offset = Ctrl->F.active;
+	h.node_offset = (int)Ctrl->F.active;
 	GMT_RI_prepare (&h);	/* Ensure -R -I consistency and set nx, ny */
 
 	go_quickly = (Ctrl->Q.active) ? 1 : 0;	
@@ -277,23 +277,26 @@ int main (int argc, char **argv)
 		if (GMT_io.io_header[GMT_IN]) {
 			for (i = 0; i < GMT_io.n_header_recs; i++) {
 				not_used = GMT_fgets (buffer, BUFSIZ, fp);
-				buffer[strlen(buffer)-1] = 0;
-				if (first && GMT_io.io_header[GMT_OUT]) (Ctrl->W.weighted[GMT_OUT] && !(Ctrl->W.weighted[GMT_IN])) ? fprintf (GMT_stdout, "%s weights\n", buffer) : fprintf (GMT_stdout, "%s\n", buffer);
+				GMT_chop (buffer);
+				if (first && GMT_io.io_header[GMT_OUT]) {
+					(Ctrl->W.weighted[GMT_OUT] && !(Ctrl->W.weighted[GMT_IN])) ? sprintf (format, "%s weights\n", buffer) : sprintf (format, "%s\n", buffer);
+					GMT_fputs(format, GMT_stdout);
+				}
 			}
 			first = FALSE;
 		}
 
 		while ((n_fields = GMT_input (fp, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
 
+			n_read++;
+
 			if (GMT_io.status & GMT_IO_MISMATCH) {
-				fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields,  n_expected_fields, n_read);
-				exit (EXIT_FAILURE);
+				fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld (skipped)\n", GMT_program, n_fields,  n_expected_fields, n_read);
+				continue;
 			}
 
 			if (GMT_is_dnan (in[GMT_Z])) continue;	/* Skip when z = NaN */
 
-			n_read++;
-
 			if (GMT_y_is_outside (in[GMT_Y],  wesn[2], wesn[3])) continue;	/* Outside y-range */
 			if (GMT_x_is_outside (&in[GMT_X], wesn[0], wesn[1])) continue;	/* Outside x-range */
 
@@ -397,7 +400,7 @@ int main (int argc, char **argv)
 	GMT_free ((void *)data);
 	GMT_free ((void *)z_tmp);
 
-	Free_Blockmedian_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_blockmedian_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
