@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *    $Id: blockmode.c,v 1.65 2010/01/14 07:15:19 guru Exp $
+ *    $Id: blockmode.c,v 1.72 2011/03/03 21:02:50 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -42,7 +42,7 @@
 
 int main (int argc, char **argv)
 {
-	BOOLEAN	error = FALSE, nofile = TRUE, done = FALSE, first = TRUE, mode_xy;
+	GMT_LONG	error = FALSE, nofile = TRUE, done = FALSE, first = TRUE, mode_xy;
 
 	/* Default value for go_quickly = FALSE for backward compatibility with 3.0  */
 
@@ -64,7 +64,7 @@ int main (int argc, char **argv)
 	
 	double weighted_mode (struct BLK_DATA *d, double wsum, GMT_LONG n, GMT_LONG k);
 	
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct BLOCKMODE_CTRL *) New_blockmode_Ctrl ();	/* Allocate and initialize a new control structure */
 
@@ -205,7 +205,7 @@ int main (int argc, char **argv)
 	mode_xy = !Ctrl->C.active;
 	h.x_inc = Ctrl->I.xinc;
 	h.y_inc = Ctrl->I.yinc;
-	h.node_offset = Ctrl->F.active;
+	h.node_offset = (int)Ctrl->F.active;
 	GMT_RI_prepare (&h);	/* Ensure -R -I consistency and set nx, ny */
 	h.xy_off = 0.5 * h.node_offset;	/* Use to calculate mean location of block */
 
@@ -249,22 +249,25 @@ int main (int argc, char **argv)
 			for (i = 0; i < GMT_io.n_header_recs; i++) {
 				not_used = GMT_fgets (buffer, BUFSIZ, fp);
 				GMT_chop (buffer);
-				if (first && GMT_io.io_header[GMT_OUT]) (Ctrl->W.weighted[GMT_OUT] && !(Ctrl->W.weighted[GMT_IN])) ? fprintf (GMT_stdout, "%s weights\n", buffer) : fprintf (GMT_stdout, "%s\n", buffer);
+				if (first && GMT_io.io_header[GMT_OUT]) {
+					(Ctrl->W.weighted[GMT_OUT] && !(Ctrl->W.weighted[GMT_IN])) ? sprintf (format, "%s weights\n", buffer) : sprintf (format, "%s\n", buffer);
+					GMT_fputs(format, GMT_stdout);
+				}
 			}
 			first = FALSE;
 		}
 
 		while ((n_fields = GMT_input (fp, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
 
+			n_read++;
+
 			if (GMT_io.status & GMT_IO_MISMATCH) {
-				fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields,  n_expected_fields, n_read);
-				exit (EXIT_FAILURE);
+				fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld (skipped)\n", GMT_program, n_fields,  n_expected_fields, n_read);
+				continue;
 			}
 
 			if (GMT_is_dnan (in[GMT_Z])) continue;	/* Skip when z = NaN */
 
-			n_read++;
-
 			if (GMT_y_is_outside (in[GMT_Y],  wesn[2], wesn[3])) continue;	/* Outside y-range */
 			if (GMT_x_is_outside (&in[GMT_X], wesn[0], wesn[1])) continue;	/* Outside x-range */
 
@@ -299,7 +302,7 @@ int main (int argc, char **argv)
 		if (gmtdefs.verbose) fprintf (stderr, "%s: No data points found inside the region; no output produced", GMT_program);
 		exit (EXIT_SUCCESS);
 	}
-	n_lost = n_read - (GMT_LONG)n_pitched;
+	n_lost = n_read - n_pitched;
 	
 	if (gmtdefs.verbose) fprintf(stderr,"%s: N read: %ld N used: %ld N outside_area: %ld\n", GMT_program, n_read, (GMT_LONG)n_pitched, n_lost);
 
