@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdraster.c,v 1.62 2010/01/14 07:15:20 guru Exp $
+ *	$Id: grdraster.c,v 1.67 2011/01/02 20:09:36 guru Exp $
  *
- *    Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *    Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /* grdraster.c -- read a rasterfile and extract a region as a grid file.
@@ -37,11 +37,11 @@
 
 struct GRDRASTER_CTRL {
 	struct G {	/* -G<output_grdfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} G;
 	struct I {	/* -Idx[/dy] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double xinc, yinc;
 	} I;
 };
@@ -54,15 +54,15 @@ struct GRDRASTER_INFO {
 	GMT_LONG	nanset;		/* True if raster uses nanflag to signal NaN  */
 	GMT_LONG	skip;		/* Skip this number of header bytes when opening file  */
 	char	type;
-	BOOLEAN swap_me;	/* TRUE if data set need to be swapped */
-	BOOLEAN geo;		/* TRUE if we believe x/y is lon/lat, FALSE otherwise */
+	GMT_LONG swap_me;	/* TRUE if data set need to be swapped */
+	GMT_LONG geo;		/* TRUE if we believe x/y is lon/lat, FALSE otherwise */
 };
 
 GMT_LONG get_byte_size (char type);
 
 int main (int argc, char **argv)
 {
-	BOOLEAN xyz_out = FALSE;
+	GMT_LONG xyz_out = FALSE;
 
 #if WORDS_BIGENDIAN == 0
 	char my_endian = 'L';	/* This machine is Little endian */
@@ -72,13 +72,13 @@ int main (int argc, char **argv)
 	char	*buffer = NULL, *r_opt = NULL, *tselect = CNULL, match[GRD_REMARK_LEN];
 	unsigned char *ubuffer = NULL;
 	static unsigned char maskset[8] = {128, 64, 32, 16, 8, 4, 2, 1};
-	
+
 	GMT_LONG	i, j, k, ksize = 0, iselect, nselected = 0, imult, jmult, nrasters, ij_offset;
 	GMT_LONG	irasstart, jrasstart, n_nan, iras, jras, ij, ijras, jseek, nmask = 0;
 	GMT_LONG	error = FALSE, firstread, nm;
-	
+
 	float	*grd = NULL, *floatrasrow = NULL;
-	
+
 	double	tol;
 	double	grdlatorigin, grdlonorigin, raslatorigin, raslonorigin;
 	double *x = NULL, y, out[3];
@@ -90,7 +90,7 @@ int main (int argc, char **argv)
 	FILE *fp;
 
 	struct GRDRASTER_CTRL *Ctrl;
-	
+
 	void *New_grdraster_Ctrl (), Free_grdraster_Ctrl (struct GRDRASTER_CTRL *C);
 	void convert_u_row (struct GRDRASTER_INFO ras, float *row, unsigned char *buffer);
 	void convert_c_row (struct GRDRASTER_INFO ras, float *row, char *buffer);
@@ -99,7 +99,7 @@ int main (int argc, char **argv)
 	void convert_l_row (struct GRDRASTER_INFO ras, float *row, int *buffer);
 	GMT_LONG load_rasinfo (struct GRDRASTER_INFO **rasinfo, char endian);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct GRDRASTER_CTRL *)New_grdraster_Ctrl ();	/* Allocate and initialize a new control structure */
 
@@ -122,7 +122,7 @@ int main (int argc, char **argv)
 				case '\0':
 					error += GMT_parse_common_options (argv[i], &h.x_min, &h.x_max, &h.y_min, &h.y_max);
 					break;
-				
+
 				case 'b':
 					error += GMT_parse_b_option (&argv[i][2]);
 					break;
@@ -272,17 +272,17 @@ int main (int argc, char **argv)
 	}
 
 	if (!project_info.region && project_info.projection != GMT_NO_PROJ) {
-	
+
 		GMT_err_fail (GMT_map_setup (h.x_min, h.x_max, h.y_min, h.y_max), "");
-		
+
 		h.x_min = floor (project_info.w / h.x_inc) * h.x_inc;
 		h.x_max = ceil (project_info.e / h.x_inc) * h.x_inc;
 		h.y_min = floor (project_info.s / h.y_inc) * h.y_inc;
 		h.y_max = ceil (project_info.n / h.y_inc) * h.y_inc;
-		
+
 		if (gmtdefs.verbose && rint (h.x_inc * 60.0) == (h.x_inc * 60.0)) {	/* Spacing in even minutes */
 			GMT_LONG w, e, s, n, wm, em, sm, nm;
-			
+
 			w = (GMT_LONG) floor (h.x_min);	wm = (GMT_LONG) irint ((h.x_min - w) * 60.0);
 			e = (GMT_LONG) floor (h.x_max);	em = (GMT_LONG) irint ((h.x_max - e) * 60.0);
 			s = (GMT_LONG) floor (h.y_min);	sm = (GMT_LONG) irint ((h.y_min - s) * 60.0);
@@ -292,7 +292,7 @@ int main (int argc, char **argv)
 		else if (gmtdefs.verbose)
 			fprintf (stderr, "%s: %s -> -R%g/%g/%g/%g\n", GMT_program, r_opt, h.x_min, h.x_max, h.y_min, h.y_max);
 	}
-	
+
 	/* Now Enforce that wesn will fit x_inc, y_inc.  Set nx, ny but reset later based on G or P  */
 	tol = 0.01 * h.x_inc;
 	h.nx = irint((h.x_max - h.x_min)/h.x_inc);
@@ -370,7 +370,7 @@ int main (int argc, char **argv)
 		grd = (float *)GMT_memory(VNULL, (size_t)nm, sizeof(float), GMT_program);
 		ij_offset = h.nx;
 	}
-	
+
 	ksize = get_byte_size (myras.type);
 	if (ksize == 0) {	/* Bits; Need to read the whole thing:  */
 		nmask = (GMT_LONG)ceil (myras.h.nx * myras.h.ny * 0.125);
@@ -382,7 +382,7 @@ int main (int argc, char **argv)
 	}
 
 	/* Now open file and do it:  */
-	
+
 	if ( (fp = fopen(myras.h.remark, "rb") ) == NULL) {
 		fprintf(stderr,"%s ERROR opening %s for read.\n", GMT_program, myras.h.remark);
 		exit (EXIT_FAILURE);
@@ -530,14 +530,14 @@ int main (int argc, char **argv)
 	}
 	else
 		GMT_err_fail (GMT_write_grd (Ctrl->G.file, &h, grd, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), Ctrl->G.file);
-		
+
 	GMT_free ((void *)grd);
 	GMT_free ((void *)rasinfo);
 
 	Free_grdraster_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
-	
+
 	exit (EXIT_SUCCESS);
 }
 
@@ -674,7 +674,7 @@ GMT_LONG	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
 
 	n_alloc = GMT_SMALL_CHUNK;
 	rasinfo = (struct GRDRASTER_INFO *) GMT_memory (VNULL, n_alloc, sizeof (struct GRDRASTER_INFO), GMT_program);
-	
+
 	while (fgets(rasinfo[nfound].h.command, GRD_COMMAND_LEN, fp) ) {
 		if (rasinfo[nfound].h.command[0] == '#') continue;
 		GMT_chop (rasinfo[nfound].h.command);
@@ -697,10 +697,10 @@ GMT_LONG	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
 			fprintf(stderr,"\tFile number conversion error.\n");
 			return(0);
 		}
-		
+
 		strncpy(buf, &rasinfo[nfound].h.command[i], (size_t)j-i);
 		buf[j-i] = '\0';
-		if ( (sscanf(buf, "%ld", &rasinfo[nfound].id) ) != 1) {
+		if ( (sscanf(buf, "%" GMT_LL "d", &rasinfo[nfound].id) ) != 1) {
 			fprintf(stderr,"%s: error reading grdraster.info\n", GMT_program);
 			fprintf(stderr,"\tFile number conversion error.\n");
 			return(0);
@@ -779,7 +779,7 @@ GMT_LONG	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
 			GMT_io.in_col_type[0] = GMT_IS_FLOAT;
 			GMT_io.in_col_type[1] = GMT_IS_FLOAT;
 		}
-			
+
 		if (GMT_parse_common_options(buf, &rasinfo[nfound].h.x_min, &rasinfo[nfound].h.x_max, &rasinfo[nfound].h.y_min, &rasinfo[nfound].h.y_max) ) {
 			fprintf(stderr,"%s: error reading grdraster.info\n", GMT_program);
 			fprintf(stderr,"\t-R string conversion error.\n");
@@ -819,9 +819,9 @@ GMT_LONG	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
 			return(0);
 		}
 		rasinfo[nfound].h.node_offset = (rasinfo[nfound].h.command[i] == 'P') ? 1 : 0;
-		
+
 		/* Check if we have optional G (geographic) or C (Cartesian) that should override the auto test above */
-		
+
 		if (rasinfo[nfound].h.command[i+1] == 'G') {	/* Explicit geographic grid */
 			rasinfo[nfound].geo = TRUE;
 			i++;
@@ -830,7 +830,7 @@ GMT_LONG	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
 			rasinfo[nfound].geo = FALSE;
 			i++;
 		}
-			
+
 		stop_point = i + 1;
 
 		/* Get type  */
@@ -924,14 +924,14 @@ GMT_LONG	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
 		}
 		else {
 			rasinfo[nfound].nanset = 1;
-			if ( (sscanf(buf, "%ld", &rasinfo[nfound].nanflag) ) != 1) {
+			if ( (sscanf(buf, "%" GMT_LL "d", &rasinfo[nfound].nanflag) ) != 1) {
 				fprintf(stderr,"%s: error reading grdraster.info\n", GMT_program);
 				fprintf(stderr,"\tNaN flag conversion error.\n");
 				return(0);
 			}
 		}
 
-		
+
 		/* Get filename:  */
 		i = j+1;
 		while (i < length && (rasinfo[nfound].h.command[i] == ' ' || rasinfo[nfound].h.command[i] == '\t') ) i++;
@@ -985,7 +985,7 @@ GMT_LONG	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
 					return (0);
 			}
 		}
-		
+
 		j = i + 1;
 		while (j < length && (rasinfo[nfound].h.command[j] == ' ' || rasinfo[nfound].h.command[j] == '\t') ) j++;
 
@@ -1009,7 +1009,7 @@ GMT_LONG	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
 					return (0);
 			}
 		}
-		
+
 		/* Get here when all is OK for this line:  */
 		global_lon = 360.0 - (1 - rasinfo[nfound].h.node_offset)*rasinfo[nfound].h.x_inc;
 		lon_tol = 0.01 * rasinfo[nfound].h.x_inc;
@@ -1024,10 +1024,10 @@ GMT_LONG	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
 		rasinfo[nfound].h.command[stop_point] = '\0';
 
 		i = irint( (rasinfo[nfound].h.x_max - rasinfo[nfound].h.x_min)/rasinfo[nfound].h.x_inc);
-		rasinfo[nfound].h.nx = (rasinfo[nfound].h.node_offset) ? i : i + 1;
+		rasinfo[nfound].h.nx = (int)((rasinfo[nfound].h.node_offset) ? i : i + 1);
 		j = irint( (rasinfo[nfound].h.y_max - rasinfo[nfound].h.y_min)/rasinfo[nfound].h.y_inc);
-		rasinfo[nfound].h.ny = (rasinfo[nfound].h.node_offset) ? j : j + 1;
-		
+		rasinfo[nfound].h.ny = (int)((rasinfo[nfound].h.node_offset) ? j : j + 1);
+
 		if ((ksize = get_byte_size (rasinfo[nfound].type)) == 0)
 			expected_size = (off_t)(ceil (GMT_get_nm (rasinfo[nfound].h.nx, rasinfo[nfound].h.ny) * 0.125) + rasinfo[nfound].skip);
 		else
@@ -1040,7 +1040,7 @@ GMT_LONG	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
 			exit (EXIT_FAILURE);
 		}
 		nfound++;
-		
+
 		if ((size_t)nfound == n_alloc) {
 			n_alloc <<= 1;
 			rasinfo = (struct GRDRASTER_INFO *) GMT_memory ((void *)rasinfo, (size_t)n_alloc, sizeof (struct GRDRASTER_INFO), GMT_program);
@@ -1048,7 +1048,7 @@ GMT_LONG	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
 	}
 	fclose (fp);
 	if (nfound > 0) rasinfo = (struct GRDRASTER_INFO *) GMT_memory ((void *)rasinfo, (size_t)nfound, sizeof (struct GRDRASTER_INFO), GMT_program);
-	
+
 	*ras = rasinfo;
 	return (nfound);
 }
@@ -1082,13 +1082,13 @@ GMT_LONG get_byte_size (char type) {
 
 void *New_grdraster_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GRDRASTER_CTRL *C;
-	
+
 	C = (struct GRDRASTER_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDRASTER_CTRL), "New_grdraster_Ctrl");
-	
+
 	return ((void *)C);
 }
 
 void Free_grdraster_Ctrl (struct GRDRASTER_CTRL *C) {	/* Deallocate control structure */
-	if (C->G.file) free ((void *)C->G.file);	
-	GMT_free ((void *)C);	
+	if (C->G.file) free ((void *)C->G.file);
+	GMT_free ((void *)C);
 }
