@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *    $Id: filter1d.c,v 1.61 2010/01/14 07:15:19 guru Exp $
+ *    $Id: filter1d.c,v 1.69 2011/03/03 21:02:50 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -39,41 +39,41 @@
 
 struct FILTER1D_CTRL {
 	struct D {	/* -D<inc> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double inc;
 	} D;
 	struct E {	/* -E */
-		BOOLEAN active;
+		GMT_LONG active;
 	} E;
 	struct F {	/* -F<type><width>[<mode>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		char filter;	/* Character codes for the filter */
 		double width;
 		GMT_LONG mode;
 		char *file;	/* Character codes for the filter */
 	} F;
 	struct I {	/* -I<ignoreval> */
-		BOOLEAN active;	/* TRUE when input values that equal value should be discarded */
+		GMT_LONG active;	/* TRUE when input values that equal value should be discarded */
 		double value;
 	} I;
 	struct L {	/* -L<lackwidth> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double value;
 	} L;
 	struct N {	/* -N<n_cols>/<t_col> */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG col, ncols;
 	} N;
 	struct Q {	/* -Q<factor> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double value;
 	} Q;
 	struct S {	/* -S<symmetry> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double value;
 	} S;
 	struct T {	/* -T[<tmin/tmax/t_inc>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double min, max, inc;
 	} T;
 };
@@ -91,14 +91,14 @@ struct FILTER1D_CTRL {
 #define FILTER1D_CONVOLVE 2		/* If filter_type > FILTER1D_CONVOLVE then a FILTER1D_MEDIAN, FILTER1D_MODE, or EXTREME filter is selected  */
 
 struct FILTER1D_INFO {	/* Control structure for all aspects of the filter setup */
-	BOOLEAN	use_ends;	/* True to start/stop at ends of series instead of 1/2 width inside  */
-	BOOLEAN check_asym;	/* TRUE to test whether the data are asymmetric about the output time  */
-	BOOLEAN check_lack;	/* TRUE to test for lack of data (gap) in the filter window */
-	BOOLEAN check_q;	/* TRUE to test average weight or N in median */
-	BOOLEAN robust;		/* Look for outliers in data when TRUE */
-	BOOLEAN equidist;	/* Data is evenly sampled in t */
-	BOOLEAN out_at_time;	/* TRUE when output is required at evenly spaced intervals */
-	BOOLEAN f_operator;	/* TRUE if custom weights coefficients sum to zero */
+	GMT_LONG	use_ends;	/* True to start/stop at ends of series instead of 1/2 width inside  */
+	GMT_LONG check_asym;	/* TRUE to test whether the data are asymmetric about the output time  */
+	GMT_LONG check_lack;	/* TRUE to test for lack of data (gap) in the filter window */
+	GMT_LONG check_q;	/* TRUE to test average weight or N in median */
+	GMT_LONG robust;		/* Look for outliers in data when TRUE */
+	GMT_LONG equidist;	/* Data is evenly sampled in t */
+	GMT_LONG out_at_time;	/* TRUE when output is required at evenly spaced intervals */
+	GMT_LONG f_operator;	/* TRUE if custom weights coefficients sum to zero */
 
 	GMT_LONG	*n_this_col;		/* Pointer to array of counters [one per column]  */
 	GMT_LONG	*n_left;		/* Pointer to array of counters [one per column]  */
@@ -145,12 +145,12 @@ void allocate_more_work_space (struct FILTER1D_INFO *F);	/* Does just what it sa
 
 int main (int argc, char **argv)
 {
-	BOOLEAN error = FALSE;
+	GMT_LONG error = FALSE;
 	
 	char	c, txt_a[GMT_TEXT_LEN], txt_b[GMT_TEXT_LEN], *not_used = NULL;
 	char	buffer[BUFSIZ];		/* Used to scan input lines  */
 	
-	GMT_LONG	i, n_fields, n_expected_fields;
+	GMT_LONG	i, n_fields, n_expected_fields, n_read;
 	
 	double	last_time, new_time, *in;
 	
@@ -168,7 +168,7 @@ int main (int argc, char **argv)
 	void load_parameters (struct FILTER1D_INFO *C, struct FILTER1D_CTRL *Ctrl);
 	void *New_filter1d_Ctrl (), Free_filter1d_Ctrl (struct FILTER1D_CTRL *C);
 	
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct FILTER1D_CTRL *)New_filter1d_Ctrl ();	/* Allocate and initialize a new control structure */
 
@@ -240,7 +240,7 @@ int main (int argc, char **argv)
 					Ctrl->L.value = atof (&argv[i][2]);
 					break;
 				case 'N':
-					if (sscanf (&argv[i][2], "%ld/%ld", &Ctrl->N.ncols, &Ctrl->N.col) != 2) {
+					if (sscanf (&argv[i][2], "%" GMT_LL "d/%" GMT_LL "d", &Ctrl->N.ncols, &Ctrl->N.col) != 2) {
 						fprintf (stderr, "%s: GMT SYNTAX ERROR -N option:  Syntax is -N<ncol>/<tcol>\n", GMT_program);
 						error++;
 					}
@@ -462,11 +462,11 @@ int main (int argc, char **argv)
 	if (GMT_io.io_header[GMT_IN]) {
 		for (i = 0; i < GMT_io.n_header_recs; i++) {
 			not_used = GMT_fgets (buffer, BUFSIZ, fp_in);
-			if (GMT_io.io_header[GMT_OUT]) fputs (buffer, GMT_stdout);
+			if (GMT_io.io_header[GMT_OUT]) GMT_fputs (buffer, GMT_stdout);
 		}
 	}
 
-	F.n_rows = 0;
+	F.n_rows = n_read = 0;
 	if (F.robust || (F.filter_type == FILTER1D_MEDIAN) ) {
 		for (i = 0; i < F.n_cols; i++) {
 			F.min_loc[i] = DBL_MAX;
@@ -482,9 +482,11 @@ int main (int argc, char **argv)
 
 	while ((n_fields = GMT_input (fp_in, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
 
+		n_read++;
+
 		if (GMT_io.status & GMT_IO_MISMATCH) {
-			fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields,  n_expected_fields, F.n_rows);
-			exit (EXIT_FAILURE);
+			fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld (skipped)\n", GMT_program, n_fields,  n_expected_fields, n_read);
+			continue;
 		}
 
 		for (i = 0; i < F.n_cols; i++) {
@@ -561,7 +563,7 @@ GMT_LONG set_up_filter (struct FILTER1D_INFO *F)
 	GMT_LONG	i, i1, i2;
 	double	t_0, t_1, time, w_sum;
 	char buffer[BUFSIZ];
-	BOOLEAN	normalize = FALSE;
+	GMT_LONG	normalize = FALSE;
 	PFD get_weight[3];		/* Selects desired weight function.  */
 
 	double	boxcar_weight (double radius, double half_width);	/* Returns the weight for a given delta_time  */
@@ -660,15 +662,15 @@ GMT_LONG do_the_filter (struct FILTER1D_INFO *F)
 	GMT_LONG	i_t_output = 0, n_in_filter, n_for_call, n_good_ones;
 	GMT_LONG i_col;
 	double	time, delta_time, *outval, wt, val, med, scl, small;
-	BOOLEAN	*good_one;		/* Pointer to array of logicals [one per column]  */
+	GMT_LONG	*good_one;		/* Pointer to array of logicals [one per column]  */
 	double	*wt_sum;		/* Pointer for array of weight sums [each column]  */
 	double	*data_sum;		/* Pointer for array of data * weight sums [columns]  */
 
-	BOOLEAN	lack_check (struct FILTER1D_INFO *F, GMT_LONG i_col, GMT_LONG left, GMT_LONG right);	/* Tests for lack of data condition  (optional)  */
+	GMT_LONG	lack_check (struct FILTER1D_INFO *F, GMT_LONG i_col, GMT_LONG left, GMT_LONG right);	/* Tests for lack of data condition  (optional)  */
 	void	get_robust_estimates (struct FILTER1D_INFO *F, GMT_LONG j, GMT_LONG n, GMT_LONG both);	/* Does just what it says  */
 
 	outval = (double *)GMT_memory (VNULL, (size_t)F->n_cols, sizeof (double), GMT_program);
-	good_one = (BOOLEAN *) GMT_memory (VNULL, (size_t)F->n_cols, sizeof(BOOLEAN), GMT_program);
+	good_one = (GMT_LONG *) GMT_memory (VNULL, (size_t)F->n_cols, sizeof(GMT_LONG), GMT_program);
 	wt_sum = (double *) GMT_memory (VNULL, (size_t)F->n_cols, sizeof(double), GMT_program);
 	data_sum = (double *) GMT_memory (VNULL, (size_t)F->n_cols, sizeof(double), GMT_program);
 
@@ -924,10 +926,10 @@ void free_space (struct FILTER1D_INFO *F)
 	if (F->n_f_wts) GMT_free ((void *)F->f_wt);
 }
 
-BOOLEAN	lack_check (struct FILTER1D_INFO *F, GMT_LONG i_col, GMT_LONG left, GMT_LONG right)
+GMT_LONG	lack_check (struct FILTER1D_INFO *F, GMT_LONG i_col, GMT_LONG left, GMT_LONG right)
 {
 	GMT_LONG	last_row, this_row;
-	BOOLEAN	lacking = FALSE;
+	GMT_LONG	lacking = FALSE;
 	double	last_t;
 
 	last_row = left;
@@ -952,7 +954,7 @@ BOOLEAN	lack_check (struct FILTER1D_INFO *F, GMT_LONG i_col, GMT_LONG left, GMT_
 void get_robust_estimates (struct FILTER1D_INFO *F, GMT_LONG j, GMT_LONG n, GMT_LONG both)
 {
 	GMT_LONG i, n_smooth;
-	BOOLEAN sort_me = TRUE;
+	GMT_LONG sort_me = TRUE;
 	double	low, high, last, temp;
 
 	if (F->filter_type > FILTER1D_MODE) {
