@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *    $Id: fitcircle.c,v 1.45 2010/01/05 01:15:44 guru Exp $
+ *    $Id: fitcircle.c,v 1.52 2011/03/03 21:02:50 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -64,11 +64,11 @@
 struct FITCIRCLE_CTRL {	/* All control options for this program (except common args) */
 	/* active is TRUE if the option has been activated */
 	struct L {	/* -L[<n>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG norm;	/* 1, 2, or 3 (both) */
 	} L;
 	struct S {	/* -S */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG mode;	/* 0 = find latitude, 1 = use specified latitude */
 		double lat;	/* 0 for great circle */
 	} S;
@@ -80,11 +80,11 @@ struct	FITCIRCLE_DATA {
 
 int main (int argc, char **argv)
 {
-	BOOLEAN	error = FALSE, greenwich = FALSE, allocate;
+	GMT_LONG	error = FALSE, greenwich = FALSE, allocate;
 
 	char	format[BUFSIZ], *not_used = NULL;
 
-	GMT_LONG	imin, imax, nrots, n_fields, n_expected_fields;
+	GMT_LONG	imin, imax, nrots, n_fields, n_expected_fields, n_read;
 	GMT_LONG	i, j, k, n_alloc, n_data, n, np;
 
 	double	lonsum, latsum, *in;
@@ -100,7 +100,7 @@ int main (int argc, char **argv)
 
 	void *New_fitcircle_Ctrl (), Free_fitcircle_Ctrl (struct FITCIRCLE_CTRL *C);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
  	Ctrl = (struct FITCIRCLE_CTRL *) New_fitcircle_Ctrl ();		/* Allocate and initialize defaults in a new control structure */
 
@@ -149,7 +149,7 @@ int main (int argc, char **argv)
 	}
 
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
-		fprintf (stderr, "fitcircle %s - find best-fitting great circle to points on sphere\n\n", GMT_VERSION);
+		fprintf (stderr, "fitcircle %s - Find best-fitting great circle to points on sphere\n\n", GMT_VERSION);
 		fprintf(stderr,"usage:  fitcircle [<input_file>] -L[<n>] [%s] [-S[<lat>]] [-V] [%s]\n", GMT_H_OPT, GMT_t_OPT);
 		fprintf(stderr,"\t[%s] [%s]\n\n", GMT_bi_OPT, GMT_f_OPT);
 
@@ -198,7 +198,7 @@ int main (int argc, char **argv)
 #endif
 	}
 	n_alloc = GMT_CHUNK;
-	n_data = 0;
+	n_data = n_read = 0;
 	lonsum = latsum = 0.0;
 
 	data = (struct FITCIRCLE_DATA *) GMT_memory (VNULL, (size_t)n_alloc, sizeof(struct FITCIRCLE_DATA), GMT_program);
@@ -210,9 +210,11 @@ int main (int argc, char **argv)
 
 	while ((n_fields = GMT_input (fp, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
 
+		n_read++;
+
 		if (GMT_io.status & GMT_IO_MISMATCH) {
-			fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields,  n_expected_fields, n_data);
-			exit (EXIT_FAILURE);
+			fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld (skipped)\n", GMT_program, n_fields,  n_expected_fields, n_data);
+			continue;
 		}
 
 		lonsum += in[GMT_X];
@@ -253,8 +255,8 @@ int main (int argc, char **argv)
 	if (Ctrl->L.norm%2) {
 		GMT_cart_to_geo (&latsum, &lonsum, meanv, TRUE);
 		if (greenwich && lonsum < 0.0) lonsum += 360.0;
-		fprintf (GMT_stdout, format, lonsum, latsum);
-		fprintf (GMT_stdout, "\tL1 Average Position (Fisher's Method)\n");
+		fprintf (stdout, format, lonsum, latsum);
+		fprintf (stdout, "\tL1 Average Position (Fisher's Method)\n");
 
 		cross_sum[0] = cross_sum[1] = cross_sum[2] = 0.0;
 		for (i = 0; i < n_data; i++) {
@@ -275,23 +277,23 @@ int main (int argc, char **argv)
 
 		GMT_cart_to_geo (&latsum, &lonsum, cross_sum, TRUE);
 		if (greenwich && lonsum < 0.0) lonsum += 360.0;
-		fprintf (GMT_stdout, format, lonsum, latsum);
-		fprintf (GMT_stdout, "\tL1 N Hemisphere Great Circle Pole (Cross-Averaged)\n");
+		fprintf (stdout, format, lonsum, latsum);
+		fprintf (stdout, "\tL1 N Hemisphere Great Circle Pole (Cross-Averaged)\n");
 		latsum = -latsum;
 		lonsum = d_atan2d(-cross_sum[1], -cross_sum[0]);
 		if (greenwich && lonsum < 0.0) lonsum += 360.0;
-		fprintf (GMT_stdout, format, lonsum, latsum);
-		fprintf (GMT_stdout, "\tL1 S Hemisphere Great Circle Pole (Cross-Averaged)\n");
+		fprintf (stdout, format, lonsum, latsum);
+		fprintf (stdout, "\tL1 S Hemisphere Great Circle Pole (Cross-Averaged)\n");
 		if (Ctrl->S.active) {
 			if (gmtdefs.verbose) fprintf (stderr,"Fitting small circle using L1 norm.\n");
 			rad = get_small_circle (data, n_data, meanv, gcpole, scpole, 1, work, Ctrl->S.mode, Ctrl->S.lat);
 			if (rad >= 0.0) {
 				GMT_cart_to_geo (&latsum, &lonsum, scpole, TRUE);
 				if (greenwich && lonsum < 0.0) lonsum += 360.0;
-				fprintf (GMT_stdout, format, lonsum, latsum);
-				fprintf (GMT_stdout, "\tL1 Small Circle Pole.  ");
+				fprintf (stdout, format, lonsum, latsum);
+				fprintf (stdout, "\tL1 Small Circle Pole.  ");
 				sprintf(format, "Distance from Pole to L1 Small Circle (degrees):     %s\n", gmtdefs.d_format);
-				fprintf (GMT_stdout, format, rad);
+				fprintf (stdout, format, rad);
 			}
 		}
 	}
@@ -324,8 +326,8 @@ int main (int argc, char **argv)
 			for (i = 0; i < 3; i++) meanv[i] = v[imax*np+i];
 		GMT_cart_to_geo (&latsum, &lonsum, meanv, TRUE);
 		if (greenwich && lonsum < 0.0) lonsum += 360.0;
-		fprintf (GMT_stdout, format, lonsum, latsum);
-		fprintf (GMT_stdout, "\tL2 Average Position (Eigenval Method)\n");
+		fprintf (stdout, format, lonsum, latsum);
+		fprintf (stdout, "\tL2 Average Position (Eigenval Method)\n");
 
 		if (v[imin*np+2] < 0.0)	/* Eigvec is in S Hemisphere  */
 			for (i = 0; i < 3; i++) gcpole[i] = -v[imin*np+i];
@@ -334,13 +336,13 @@ int main (int argc, char **argv)
 
 		GMT_cart_to_geo (&latsum, &lonsum, gcpole, TRUE);
 		if (greenwich && lonsum < 0.0) lonsum += 360.0;
-		fprintf (GMT_stdout, format, lonsum, latsum);
-		fprintf (GMT_stdout, "\tL2 N Hemisphere Great Circle Pole (Eigenval Method)\n");
+		fprintf (stdout, format, lonsum, latsum);
+		fprintf (stdout, "\tL2 N Hemisphere Great Circle Pole (Eigenval Method)\n");
 		latsum = -latsum;
 		lonsum = d_atan2d(-gcpole[1], -gcpole[0]);
 		if (greenwich && lonsum < 0.0) lonsum += 360.0;
-		fprintf (GMT_stdout, format, lonsum, latsum);
-		fprintf (GMT_stdout, "\tL2 S Hemisphere Great Circle Pole (Eigenval Method)\n");
+		fprintf (stdout, format, lonsum, latsum);
+		fprintf (stdout, "\tL2 S Hemisphere Great Circle Pole (Eigenval Method)\n");
 
 		GMT_free ((void *)v);
 		GMT_free ((void *)z);
@@ -354,10 +356,10 @@ int main (int argc, char **argv)
 				/* True when small circle fits better than great circle */
 				GMT_cart_to_geo (&latsum, &lonsum, scpole, TRUE);
 				if (greenwich && lonsum < 0.0) lonsum += 360.0;
-				fprintf (GMT_stdout, format, lonsum, latsum);
-				fprintf (GMT_stdout, "\tL2 Small Circle Pole.  ");
+				fprintf (stdout, format, lonsum, latsum);
+				fprintf (stdout, "\tL2 Small Circle Pole.  ");
 				sprintf(format, "Distance from Pole to L2 Small Circle (degrees):     %s\n", gmtdefs.d_format);
-				fprintf (GMT_stdout, format, rad);
+				fprintf (stdout, format, rad);
 			}
 		}
 	}
