@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_calclock.c,v 1.67 2010/01/05 01:15:44 guru Exp $
+ *	$Id: gmt_calclock.c,v 1.74 2011/03/03 21:02:50 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -35,7 +35,7 @@
 #define GMT_WITH_NO_PS
 #include "gmt.h"
 
-BOOLEAN want_iso = FALSE;	/* Temporary to test compilation.  Delete this.  */
+GMT_LONG want_iso = FALSE;	/* Temporary to test compilation.  Delete this.  */
 
 /* Functions to assemble/disassemble a continuous
 variable (double) and a calendar day (GMT_cal_rd)
@@ -149,7 +149,7 @@ GMT_cal_rd GMT_nth_kday (GMT_LONG n, GMT_LONG kday, GMT_cal_rd date) {
 
 /* Proleptic Gregorian Calendar operations  */
 
-BOOLEAN	GMT_is_gleap (GMT_LONG gyear) {
+GMT_LONG	GMT_is_gleap (GMT_LONG gyear) {
 /*	Given integer proleptic gregorian calendar year,
 	return TRUE if it is a Gregorian leap year; 
 	else return FALSE.  */
@@ -314,7 +314,7 @@ GMT_LONG	GMT_y2_to_y4_yearfix (GMT_LONG y2) {
 	return (y2 + ((y2 >= GMT_Y2K_fix.y2_cutoff) ? GMT_Y2K_fix.y100 : GMT_Y2K_fix.y200));
 }
 
-BOOLEAN	GMT_g_ymd_is_bad (GMT_LONG y, GMT_LONG m, GMT_LONG d) {
+GMT_LONG	GMT_g_ymd_is_bad (GMT_LONG y, GMT_LONG m, GMT_LONG d) {
 
 	/* Check year, month, day values to see if they
 		are an appropriate date in the proleptic
@@ -325,17 +325,18 @@ BOOLEAN	GMT_g_ymd_is_bad (GMT_LONG y, GMT_LONG m, GMT_LONG d) {
 	
 	GMT_LONG	k;
 	
+	
 	if (m < 1 || m > 12 || d < 1) return (TRUE);
 	
 	k = GMT_gmonth_length (y, m);	/* Number of day in the specified month */
-	
+
 	if (d > k) return (TRUE);	/* More days than we've got in this month */
 	
 	return (FALSE);
 }
 
 
-BOOLEAN	GMT_iso_ywd_is_bad (GMT_LONG y, GMT_LONG w, GMT_LONG d) {
+GMT_LONG	GMT_iso_ywd_is_bad (GMT_LONG y, GMT_LONG w, GMT_LONG d) {
 
 	/* Check ISO_year, ISO_week_of_year, ISO_day_of_week
 		values to see if they form a probably
@@ -355,7 +356,7 @@ BOOLEAN	GMT_iso_ywd_is_bad (GMT_LONG y, GMT_LONG w, GMT_LONG d) {
 	return (FALSE);
 }
 
-BOOLEAN	GMT_hms_is_bad (GMT_LONG h, GMT_LONG m, double s) {
+GMT_LONG	GMT_hms_is_bad (GMT_LONG h, GMT_LONG m, double s) {
 
 	/* Check range of hours, min, and seconds.
 		Returns TRUE if it appears something is out of range.
@@ -485,7 +486,7 @@ GMT_LONG	GMT_verify_time_step (GMT_LONG step, char unit) {
 }
 
 
-void	GMT_moment_interval (struct GMT_MOMENT_INTERVAL *p, double dt_in, BOOLEAN init) {
+void	GMT_moment_interval (struct GMT_MOMENT_INTERVAL *p, double dt_in, GMT_LONG init) {
 
 	/*   
 	
@@ -800,7 +801,7 @@ void	GMT_moment_interval (struct GMT_MOMENT_INTERVAL *p, double dt_in, BOOLEAN i
 
 
 
-void	GMT_small_moment_interval (struct GMT_MOMENT_INTERVAL *p, GMT_LONG step_secs, BOOLEAN init) {
+void	GMT_small_moment_interval (struct GMT_MOMENT_INTERVAL *p, GMT_LONG step_secs, GMT_LONG init) {
 
 	/* Called by GMT_moment_interval ().  Get here when p->stuff[0] is initialized and
 		0 < step_secs <= GMT_DAY2SEC_I.  If init, stuff[0] may need to be truncated.  */
@@ -877,7 +878,7 @@ GMT_LONG	GMT_gmonth_length (GMT_LONG year,  GMT_LONG month) {
 	return (k);
 }
 
-void GMT_format_calendar (char *date, char *clock, struct GMT_DATE_IO *D, struct GMT_CLOCK_IO *C, BOOLEAN upper, GMT_LONG kind, double dt)
+void GMT_format_calendar (char *date, char *clock, struct GMT_DATE_IO *D, struct GMT_CLOCK_IO *C, GMT_LONG upper, GMT_LONG kind, double dt)
 {	/* Given the internal time representation dt and the formatting information
 	 * in the D and C structure, write the calendar representation to strings date and clock,
 	 * but skip either string if it is a NULL pointer */
@@ -895,16 +896,16 @@ void GMT_format_calendar (char *date, char *clock, struct GMT_DATE_IO *D, struct
 		/* Now undo Y2K fix to make a 2-digit year here if necessary */
 	
 		if (D->day_of_year) {		/* Using the year and day-of-year as date entries */
-			if (D->item_pos[0] != -1) ival[D->item_pos[0]] = (D->Y2K_year) ? abs(calendar.year) % 100 : calendar.year;
+			if (D->item_pos[0] != -1) ival[D->item_pos[0]] = (D->Y2K_year) ? GMT_abs (calendar.year) % 100 : calendar.year;
 			if (D->item_pos[3] != -1) ival[D->item_pos[3]] = calendar.day_y;
 		}
 		else if (D->iso_calendar) {	/* Using ISO year, week and day-of-week entries. Order is fixed to be y-m-d */
-			ival[0] = (D->Y2K_year) ? abs(calendar.iso_y) % 100 : calendar.iso_y;
+			ival[0] = (D->Y2K_year) ? GMT_abs (calendar.iso_y) % 100 : calendar.iso_y;
 			ival[1] = calendar.iso_w;
 			ival[2] = calendar.iso_d;
 		}
 		else {				/* Gregorian calendar entries */
-			if (D->item_pos[0] != -1) ival[D->item_pos[0]] = (D->Y2K_year) ? abs(calendar.year) % 100 : calendar.year;
+			if (D->item_pos[0] != -1) ival[D->item_pos[0]] = (D->Y2K_year) ? GMT_abs (calendar.year) % 100 : calendar.year;
 			if (D->item_pos[1] != -1) ival[D->item_pos[1]] = calendar.month;
 			if (D->item_pos[2] != -1) ival[D->item_pos[2]] = calendar.day_m;
 		}
@@ -1057,7 +1058,7 @@ GMT_LONG	GMT_read_clock (char *s, double *t) {
 		s[k-j] = '\0';
 		cm = &cm[1];	/* Move beyond colon  */
 	}
-	if ( (sscanf(s, "%ld", &k)) != 1) return (-1);
+	if ( (sscanf(s, "%" GMT_LL "d", &k)) != 1) return (-1);
 	if (k < 0 || k > 24) return (-1);
 	*t = GMT_HR2SEC_I * k;		/* t now has hours (in secs) */
 	
@@ -1070,7 +1071,7 @@ GMT_LONG	GMT_read_clock (char *s, double *t) {
 		cm[k-j] = '\0';
 		cs = &cs[1];
 	}
-	if ( (sscanf(cm, "%ld", &k)) != 1) return (-1);
+	if ( (sscanf(cm, "%" GMT_LL "d", &k)) != 1) return (-1);
 	if (k < 0 || k > 59) return (-1);
 	(*t) += GMT_MIN2SEC_I * k;	/* Now add in minutes (in secs) */
 	
@@ -1115,7 +1116,7 @@ GMT_LONG	GMT_read_cal (char *s, GMT_cal_rd *rd) {
 		s[k-(i+j)] = '\0';
 	}
 	
-	if ( (sscanf (s, "%ld", &itemp1) ) != 1) return (-1);
+	if ( (sscanf (s, "%" GMT_LL "d", &itemp1) ) != 1) return (-1);
 	
 	/* A null value of cj is not an error.  We might have
 		had "1985T" passed to a function and it might
@@ -1138,7 +1139,7 @@ GMT_LONG	GMT_read_cal (char *s, GMT_cal_rd *rd) {
 			k = strlen (cj);
 			cj[k-j] = '\0';
 		}
-		if ( (sscanf (cj, "%ld", &itemp2) ) != 1) return (-1);
+		if ( (sscanf (cj, "%" GMT_LL "d", &itemp2) ) != 1) return (-1);
 		if (itemp2 < 1) return (-1);
 		if (is_iso) {
 			if (itemp2 > 53) return (-1);
@@ -1148,7 +1149,7 @@ GMT_LONG	GMT_read_cal (char *s, GMT_cal_rd *rd) {
 		}
 		if (ck) {
 			/* Read it, skipping the leading hyphen.  */
-			if ( (sscanf (&ck[1], "%ld", &itemp3) ) != 1) return (-1);
+			if ( (sscanf (&ck[1], "%" GMT_LL "d", &itemp3) ) != 1) return (-1);
 			if (itemp3 < 1) return (-1);
 			if (is_iso) {
 				if (itemp3 > 7) return (-1);
@@ -1162,12 +1163,10 @@ GMT_LONG	GMT_read_cal (char *s, GMT_cal_rd *rd) {
 	/* Get here when ready to make a rata die out of 3 itemp values,
 		based on value of is_iso:  */
 	
-	if (is_iso) {
+	if (is_iso)
 		*rd = GMT_rd_from_iywd (itemp1, itemp2, itemp3);
-	}
-	else {
+	else
 		*rd = GMT_rd_from_gymd (itemp1, itemp2, itemp3);
-	}
 	return (0);
 }
 
