@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_cdf.c,v 1.56 2010/01/05 01:15:44 guru Exp $
+ *	$Id: gmt_cdf.c,v 1.61 2011/03/03 21:02:50 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -57,10 +57,11 @@ GMT_LONG GMT_cdf_read_grd_info (struct GRD_HEADER *header)
 
 GMT_LONG GMT_cdf_update_grd_info (struct GRD_HEADER *header)
 {
-	int ncid;
+	int ncid, old_fill_mode;
 	GMT_LONG err;
 	if (!strcmp (header->name,"=")) return (GMT_GRDIO_NC_NO_PIPE);
-	GMT_err_trap (nc_open (header->name, NC_WRITE + NC_NOFILL, &ncid));
+	GMT_err_trap (nc_open (header->name, NC_WRITE, &ncid));
+	GMT_err_trap (nc_set_fill (ncid, NC_NOFILL, &old_fill_mode)); 
 	GMT_err_trap (GMT_cdf_grd_info (ncid, header, 'u'));
 	GMT_err_trap (nc_close (ncid));
 	return (GMT_NOERROR);
@@ -68,10 +69,11 @@ GMT_LONG GMT_cdf_update_grd_info (struct GRD_HEADER *header)
 
 GMT_LONG GMT_cdf_write_grd_info (struct GRD_HEADER *header)
 {
-	int ncid;
+	int ncid, old_fill_mode;
 	GMT_LONG err;
 	if (!strcmp (header->name,"=")) return (GMT_GRDIO_NC_NO_PIPE);
-	GMT_err_trap (nc_create (header->name, NC_CLOBBER + NC_NOFILL, &ncid));
+	GMT_err_trap (nc_create (header->name, NC_CLOBBER, &ncid));
+	GMT_err_trap (nc_set_fill (ncid, NC_NOFILL, &old_fill_mode)); 
 	GMT_err_trap (GMT_cdf_grd_info (ncid, header, 'w'));
 	GMT_err_trap (nc_close (ncid));
 	return (GMT_NOERROR);
@@ -211,7 +213,7 @@ GMT_LONG GMT_cdf_grd_info (int ncid, struct GRD_HEADER *header, char job)
 	return (GMT_NOERROR);
 }
 
-GMT_LONG GMT_cdf_read_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, BOOLEAN complex)
+GMT_LONG GMT_cdf_read_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, GMT_LONG complex)
 {	/* header:	grid structure header
 	 * grid:	array with final grid
 	 * w,e,s,n:	Sub-region to extract  [Use entire file if 0,0,0,0]
@@ -232,7 +234,7 @@ GMT_LONG GMT_cdf_read_grd (struct GRD_HEADER *header, float *grid, double w, dou
 	GMT_LONG i, j, width_in, height_in, i_0_out, inc = 1;
 	GMT_LONG ij, kk, width_out;
 	GMT_LONG *k;
-	BOOLEAN check;
+	GMT_LONG check;
 	float *tmp = VNULL;
 
 	GMT_err_pass (GMT_grd_prep_io (header, &w, &e, &s, &n, &width_in, &height_in, &first_col, &last_col, &first_row, &last_row, &k), header->name);
@@ -277,8 +279,8 @@ GMT_LONG GMT_cdf_read_grd (struct GRD_HEADER *header, float *grid, double w, dou
 		}
 	}
 
-	header->nx = width_in;
-	header->ny = height_in;
+	header->nx = (int)width_in;
+	header->ny = (int)height_in;
 	header->x_min = w;
 	header->x_max = e;
 	header->y_min = s;
@@ -291,7 +293,7 @@ GMT_LONG GMT_cdf_read_grd (struct GRD_HEADER *header, float *grid, double w, dou
 	return (GMT_NOERROR);
 }
 
-GMT_LONG GMT_cdf_write_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, BOOLEAN complex)
+GMT_LONG GMT_cdf_write_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, GMT_LONG complex)
 {	/* header:	grid structure header
 	 * grid:	array with final grid
 	 * w,e,s,n:	Sub-region to write out  [Use entire file if 0,0,0,0]
@@ -302,7 +304,7 @@ GMT_LONG GMT_cdf_write_grd (struct GRD_HEADER *header, float *grid, double w, do
 	 */
 
 	size_t start[1], edge[1];
-	int ncid;
+	int ncid, old_fill_mode;
 	GMT_LONG err;
 	GMT_LONG i, inc = 1, nr_oor = 0;
 	GMT_LONG j, width_out, height_out;
@@ -350,13 +352,14 @@ GMT_LONG GMT_cdf_write_grd (struct GRD_HEADER *header, float *grid, double w, do
 	header->x_max = e;
 	header->y_min = s;
 	header->y_max = n;
-	header->nx = width_out;
-	header->ny = height_out;
+	header->nx = (int)width_out;
+	header->ny = (int)height_out;
 
 	/* Write grid header */
 
 	if (!strcmp (header->name,"=")) return (GMT_GRDIO_NC_NO_PIPE);
-	GMT_err_trap (nc_create (header->name, NC_CLOBBER + NC_NOFILL, &ncid));
+	GMT_err_trap (nc_create (header->name, NC_CLOBBER, &ncid));
+	GMT_err_trap (nc_set_fill (ncid, NC_NOFILL, &old_fill_mode)); 
 	GMT_err_trap (GMT_cdf_grd_info (ncid, header, 'w'));
 
 	/* Set start position for writing grid */
