@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_colors.h,v 1.35 2010/01/05 01:15:44 guru Exp $
+ *	$Id: gmt_colors.h,v 1.38 2011/03/03 21:02:50 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -64,7 +64,7 @@ struct GMT_LUT {
 	int rgb_low[3], rgb_high[3], rgb_diff[3];
 	double hsv_low[3], hsv_high[3], hsv_diff[3];
 	GMT_LONG annot;
-	BOOLEAN skip;
+	GMT_LONG skip;
 	struct GMT_FILL *fill;	/* Use by grdview */
 	char *label;	/* For non-number labels */
 };
@@ -72,7 +72,7 @@ struct GMT_LUT {
 struct GMT_BFN_COLOR {	/* For back-, fore-, and nan-colors */
 	int rgb[3];
 	double hsv[3];
-	BOOLEAN skip;
+	GMT_LONG skip;
 	struct GMT_FILL *fill;
 };
 
@@ -82,14 +82,14 @@ EXTERN_MSC struct GMT_LUT *GMT_lut;
 EXTERN_MSC struct GMT_BFN_COLOR GMT_bfn[3];
 EXTERN_MSC GMT_LONG GMT_n_colors;
 EXTERN_MSC GMT_LONG GMT_cpt_flags;
-EXTERN_MSC BOOLEAN GMT_gray;		/* TRUE if only grayshades are used */
-EXTERN_MSC BOOLEAN GMT_b_and_w;		/* TRUE if only black OR white is used */
-EXTERN_MSC BOOLEAN GMT_continuous;	/* TRUE if colors change continuously within slice */
-EXTERN_MSC BOOLEAN GMT_cpt_pattern;	/* TRUE if cpt file contains any patterns */
-EXTERN_MSC BOOLEAN GMT_cpt_skip;	/* TRUE if current z-slice is to be skipped */
+EXTERN_MSC GMT_LONG GMT_gray;		/* TRUE if only grayshades are used */
+EXTERN_MSC GMT_LONG GMT_b_and_w;		/* TRUE if only black OR white is used */
+EXTERN_MSC GMT_LONG GMT_continuous;	/* TRUE if colors change continuously within slice */
+EXTERN_MSC GMT_LONG GMT_cpt_pattern;	/* TRUE if cpt file contains any patterns */
+EXTERN_MSC GMT_LONG GMT_cpt_skip;	/* TRUE if current z-slice is to be skipped */
 #ifdef GMT_CPT2	
-EXTERN_MSC BOOLEAN GMT_categorical;	/* TRUE if the CPT applies to categorical data */
+EXTERN_MSC GMT_LONG GMT_categorical;	/* TRUE if the CPT applies to categorical data */
 #endif
-EXTERN_MSC void GMT_sample_cpt (double z[], GMT_LONG nz, BOOLEAN continuous, BOOLEAN reverse, GMT_LONG log_mode);
+EXTERN_MSC void GMT_sample_cpt (double z[], GMT_LONG nz, GMT_LONG continuous, GMT_LONG reverse, GMT_LONG log_mode);
 
 #endif /* _GMT_COLORS_H */
