@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_customio.c,v 1.89 2010/01/05 01:15:44 guru Exp $
+ *	$Id: gmt_customio.c,v 1.93 2011/03/03 21:02:50 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it wi1552ll be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -68,8 +68,8 @@ GMT_LONG GMT_native_write_grd_header (FILE *fp, struct GRD_HEADER *header);
 GMT_LONG GMT_native_skip_grd_header (FILE *fp, struct GRD_HEADER *header);
 GMT_LONG GMT_native_read_grd_info (struct GRD_HEADER *header);
 GMT_LONG GMT_native_write_grd_info (struct GRD_HEADER *header);
-GMT_LONG GMT_native_read_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, BOOLEAN complex);
-GMT_LONG GMT_native_write_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, BOOLEAN complex);
+GMT_LONG GMT_native_read_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, GMT_LONG complex);
+GMT_LONG GMT_native_write_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, GMT_LONG complex);
 
 void GMT_grdio_init (void) {
 	GMT_LONG id;
@@ -394,7 +394,7 @@ GMT_LONG GMT_ras_write_grd_info (struct GRD_HEADER *header)
 	return (GMT_NOERROR);
 }
 
-GMT_LONG GMT_ras_read_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, BOOLEAN complex)
+GMT_LONG GMT_ras_read_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, GMT_LONG complex)
 {	/* header:	grid structure header */
 	/* grid:	array with final grid */
 	/* w,e,s,n:	Sub-region to extract  [Use entire file if 0,0,0,0] */
@@ -407,7 +407,7 @@ GMT_LONG GMT_ras_read_grd (struct GRD_HEADER *header, float *grid, double w, dou
 	GMT_LONG i, j, j2, width_in, width_out, height_in, i_0_out, n2;
 	GMT_LONG kk, ij;
 	FILE *fp;
-	BOOLEAN piping = FALSE, check;
+	GMT_LONG piping = FALSE, check;
 	unsigned char *tmp;
 	struct rasterfile h;
 	GMT_LONG *k;
@@ -469,8 +469,8 @@ GMT_LONG GMT_ras_read_grd (struct GRD_HEADER *header, float *grid, double w, dou
 	if (piping) {	/* Skip data by reading it */
 		for (j = last_row + 1; j < header->ny; j++) if (GMT_fread ((void *) tmp, sizeof (unsigned char), (size_t)n2, fp) < (size_t)n2) return (GMT_GRDIO_READ_FAILED);
 	}
-	header->nx = width_in;
-	header->ny = height_in;
+	header->nx = (int)width_in;
+	header->ny = (int)height_in;
 	header->x_min = w;
 	header->x_max = e;
 	header->y_min = s;
@@ -483,7 +483,7 @@ GMT_LONG GMT_ras_read_grd (struct GRD_HEADER *header, float *grid, double w, dou
 	return (GMT_NOERROR);
 }
 
-GMT_LONG GMT_ras_write_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, BOOLEAN complex)
+GMT_LONG GMT_ras_write_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, GMT_LONG complex)
 {	/* header:	grid structure header */
 	/* grid:	array with final grid */
 	/* w,e,s,n:	Sub-region to write  [Use entire file if 0,0,0,0] */
@@ -496,7 +496,7 @@ GMT_LONG GMT_ras_write_grd (struct GRD_HEADER *header, float *grid, double w, do
 	GMT_LONG *k;
 	GMT_LONG kk, ij;
 
-	BOOLEAN check, do_header = TRUE;
+	GMT_LONG check, do_header = TRUE;
 
 	unsigned char *tmp;
 
@@ -591,28 +591,28 @@ GMT_LONG GMT_read_rasheader (FILE *fp, struct rasterfile *h)
 
 		switch (i) {
 			case 0:
-				h->magic = value;
+				h->magic = (int)value;
 				break;
 			case 1:
-				h->width = value;
+				h->width = (int)value;
 				break;
 			case 2:
-				h->height = value;
+				h->height = (int)value;
 				break;
 			case 3:
-				h->depth = value;
+				h->depth = (int)value;
 				break;
 			case 4:
-				h->length = value;
+				h->length = (int)value;
 				break;
 			case 5:
-				h->type = value;
+				h->type = (int)value;
 				break;
 			case 6:
-				h->maptype = value;
+				h->maptype = (int)value;
 				break;
 			case 7:
-				h->maplength = value;
+				h->maplength = (int)value;
 				break;
 		}
 	}
@@ -708,7 +708,7 @@ GMT_LONG GMT_is_native_grid (struct GRD_HEADER *header)
 	if (t_head.nx <= 0 || t_head.ny <= 0) return (GMT_GRDIO_BAD_VAL);		/* Garbage for nx or ny */
 	nm = ((GMT_LONG)t_head.nx) * ((GMT_LONG)t_head.ny);
 	if (nm <= 0) return (GMT_GRDIO_BAD_VAL);		/* Overflow for nx * ny? */
-	item_size = (buf.st_size - GRD_HEADER_SIZE) / nm;	/* Estimate size of elements */
+	item_size = (double)((buf.st_size - GRD_HEADER_SIZE) / nm);	/* Estimate size of elements */
 	size = irint (item_size);
 	if (!GMT_IS_ZERO(item_size - (double)size)) return (GMT_GRDIO_BAD_VAL);	/* Size not an integer */
 	
@@ -744,7 +744,7 @@ GMT_LONG GMT_is_native_grid (struct GRD_HEADER *header)
 	return (header->type);
 }
 
-GMT_LONG GMT_bit_read_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, BOOLEAN complex)
+GMT_LONG GMT_bit_read_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, GMT_LONG complex)
 {	/* header:	grid structure header */
 	/* grid:	array with final grid */
 	/* w,e,s,n:	Sub-region to extract  [Use entire file if 0,0,0,0] */
@@ -758,7 +758,7 @@ GMT_LONG GMT_bit_read_grd (struct GRD_HEADER *header, float *grid, double w, dou
 	GMT_LONG *k;
 	GMT_LONG kk, ij;
 	FILE *fp;
-	BOOLEAN piping = FALSE, check = FALSE;
+	GMT_LONG piping = FALSE, check = FALSE;
 	unsigned int *tmp, ival;
 
 	if (!strcmp (header->name, "=")) {
@@ -813,8 +813,8 @@ GMT_LONG GMT_bit_read_grd (struct GRD_HEADER *header, float *grid, double w, dou
 		for (j = last_row + 1; j < header->ny; j++) if (GMT_fread ((void *) tmp, sizeof (unsigned int), (size_t)mx, fp) < (size_t)mx) return (GMT_GRDIO_READ_FAILED);
 	}
 
-	header->nx = width_in;
-	header->ny = height_in;
+	header->nx = (int)width_in;
+	header->ny = (int)height_in;
 	header->x_min = w;
 	header->x_max = e;
 	header->y_min = s;
@@ -836,7 +836,7 @@ GMT_LONG GMT_bit_read_grd (struct GRD_HEADER *header, float *grid, double w, dou
 	return (GMT_NOERROR);
 }
 
-GMT_LONG GMT_bit_write_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, BOOLEAN complex)
+GMT_LONG GMT_bit_write_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, GMT_LONG complex)
 {	/* header:	grid structure header */
 	/* grid:	array with final grid */
 	/* w,e,s,n:	Sub-region to extract  [Use entire file if 0,0,0,0] */
@@ -850,7 +850,7 @@ GMT_LONG GMT_bit_write_grd (struct GRD_HEADER *header, float *grid, double w, do
 	GMT_LONG j, j2, width_in, width_out, height_out, mx, word, bit, err, inc = 1;
 	GMT_LONG first_col, last_col, first_row, last_row;
 	GMT_LONG kk, ij;
-	BOOLEAN check = FALSE, do_header = TRUE;
+	GMT_LONG check = FALSE, do_header = TRUE;
 	unsigned int *tmp, ival;
 
 	FILE *fp;
@@ -1043,7 +1043,7 @@ GMT_LONG GMT_native_write_grd_info (struct GRD_HEADER *header)
 	return (GMT_NOERROR);
 }
 
-GMT_LONG GMT_native_read_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, BOOLEAN complex)
+GMT_LONG GMT_native_read_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, GMT_LONG complex)
 {	/* header:	grid structure header */
 	/* grid:	array with final grid */
 	/* w,e,s,n:	Sub-region to extract  [Use entire file if 0,0,0,0] */
@@ -1064,8 +1064,8 @@ GMT_LONG GMT_native_read_grd (struct GRD_HEADER *header, float *grid, double w,
 	GMT_LONG kk, ij;
 	GMT_LONG width_out;		/* Width of row as return (may include padding) */
 	FILE *fp;			/* File pointer to data or pipe */
-	BOOLEAN piping = FALSE;		/* TRUE if we read input pipe instead of from file */
-	BOOLEAN check = FALSE;		/* TRUE if nan-proxies are used to signify NaN (for non-floating point types) */
+	GMT_LONG piping = FALSE;		/* TRUE if we read input pipe instead of from file */
+	GMT_LONG check = FALSE;		/* TRUE if nan-proxies are used to signify NaN (for non-floating point types) */
 	void *tmp;			/* Array pointer for reading in rows of data */
 
 	if (!strcmp (header->name, "=")) {
@@ -1125,8 +1125,8 @@ GMT_LONG GMT_native_read_grd (struct GRD_HEADER *header, float *grid, double w,
 		for (j = last_row + 1; j < header->ny; j++) if (GMT_fread (tmp, (size_t)size, (size_t)header->nx, fp) < (size_t)header->nx) return (GMT_GRDIO_READ_FAILED);
 	}
 
-	header->nx = width_in;
-	header->ny = height_in;
+	header->nx = (int)width_in;
+	header->ny = (int)height_in;
 	header->x_min = w;
 	header->x_max = e;
 	header->y_min = s;
@@ -1151,7 +1151,7 @@ GMT_LONG GMT_native_read_grd (struct GRD_HEADER *header, float *grid, double w,
 	return (GMT_NOERROR);
 }
 
-GMT_LONG GMT_native_write_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, BOOLEAN complex)
+GMT_LONG GMT_native_write_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, GMT_LONG complex)
 {	/* header:	grid structure header */
 	/* grid:	array with final grid */
 	/* w,e,s,n:	Sub-region to write out  [Use entire file if 0,0,0,0] */
@@ -1172,8 +1172,8 @@ GMT_LONG GMT_native_write_grd (struct GRD_HEADER *header, float *grid, double w,
 	GMT_LONG width_in;		/* Number of items in one row of the subregion */
 	GMT_LONG ij;
 	FILE *fp;			/* File pointer to data or pipe */
-	BOOLEAN check = FALSE;		/* TRUE if nan-proxies are used to signify NaN (for non-floating point types) */
-	BOOLEAN do_header = TRUE;	/* TRUE if we should write the header first */
+	GMT_LONG check = FALSE;		/* TRUE if nan-proxies are used to signify NaN (for non-floating point types) */
+	GMT_LONG do_header = TRUE;	/* TRUE if we should write the header first */
 	void *tmp;			/* Array pointer for writing in rows of data */
 
 	if (!strcmp (header->name, "=")) {
@@ -1529,7 +1529,7 @@ GMT_LONG GMT_write_srfheader (FILE *fp, struct srf_header6 *h)
 	return (GMT_NOERROR);
 }
 
-GMT_LONG GMT_srf_read_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, BOOLEAN complex)
+GMT_LONG GMT_srf_read_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, GMT_LONG complex)
 {	/* header:     	grid structure header */
 	/* grid:	array with final grid */
 	/* w,e,s,n:	Sub-region to extract  [Use entire file if 0,0,0,0] */
@@ -1550,7 +1550,7 @@ GMT_LONG GMT_srf_read_grd (struct GRD_HEADER *header, float *grid, double w, dou
 	GMT_LONG kk, ij;
 	GMT_LONG width_out;		/* Width of row as return (may include padding) */
 	FILE *fp;			/* File pointer to data or pipe */
-	BOOLEAN piping = FALSE;		/* TRUE if we read input pipe instead of from file */
+	GMT_LONG piping = FALSE;		/* TRUE if we read input pipe instead of from file */
 	void *tmp;			/* Array pointer for reading in rows of data */
 	header->nan_value = 0.1701410e39;	/* Test value in Surfer grids */
 
@@ -1621,8 +1621,8 @@ GMT_LONG GMT_srf_read_grd (struct GRD_HEADER *header, float *grid, double w, dou
 		for (j = last_row + 1; j < header->ny; j++) if (GMT_fread (tmp, size, (size_t)header->nx, fp) < (size_t)header->nx) return (GMT_GRDIO_READ_FAILED);
 	}
 
-	header->nx = width_in;
-	header->ny = height_in;
+	header->nx = (int)width_in;
+	header->ny = (int)height_in;
 	header->x_min = w;
 	header->x_max = e;
 	header->y_min = s;
@@ -1648,7 +1648,7 @@ GMT_LONG GMT_srf_read_grd (struct GRD_HEADER *header, float *grid, double w, dou
 	return (GMT_NOERROR);
 }
 
-GMT_LONG GMT_srf_write_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, BOOLEAN complex)
+GMT_LONG GMT_srf_write_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, GMT_LONG complex)
 {	/* header:	grid structure header */
 	/* grid:	array with final grid */
 	/* w,e,s,n:	Sub-region to write out  [Use entire file if 0,0,0,0] */
@@ -1809,7 +1809,7 @@ GMT_LONG GMT_gdal_write_grd_info (struct GRD_HEADER *header) {
 	return (GMT_NOERROR);
 }
 
-GMT_LONG GMT_gdal_read_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, BOOLEAN complex) {
+GMT_LONG GMT_gdal_read_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, GMT_LONG complex) {
 	/* header:     	grid structure header */
 	/* grid:	array with final grid */
 	/* w,e,s,n:	Sub-region to extract  [Use entire file if 0,0,0,0] */
@@ -1906,7 +1906,7 @@ GMT_LONG GMT_gdal_read_grd (struct GRD_HEADER *header, float *grid, double w, do
 	return (GMT_NOERROR);
 }
 
-GMT_LONG GMT_gdal_write_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, BOOLEAN complex) {
+GMT_LONG GMT_gdal_write_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, GMT_LONG complex) {
 	return (GMT_NOERROR);
 }
 #endif
