@@ -1,4 +1,4 @@
-/*	$Id: gmt_mgg_header2.c,v 1.40 2009/10/05 03:18:09 guru Exp $
+/*	$Id: gmt_mgg_header2.c,v 1.43 2010/10/31 22:29:50 guru Exp $
  *
  *	Code donated by David Divens, NOAA/NGDC
  *	Distributed under the GNU Public License (see LICENSE.TXT for details)
@@ -182,7 +182,7 @@ GMT_LONG GMT_is_mgg2_grid (struct GRD_HEADER *header)
 	if (!strcmp(header->name, "=")) return (GMT_GRDIO_PIPE_CODECHECK);	/* Cannot check on pipes */
 	if ((fp = GMT_fopen(header->name, GMT_io.r_mode)) == NULL) return (GMT_GRDIO_OPEN_FAILED);
 
-	memset(&mggHeader, '\0', sizeof(MGG_GRID_HEADER_2));
+	memset (&mggHeader, 0, sizeof(MGG_GRID_HEADER_2));
 	if (GMT_fread(&mggHeader, sizeof(MGG_GRID_HEADER_2), (size_t)1, fp) != 1) return (GMT_GRDIO_READ_FAILED);
 
 	/* Swap header bytes if necessary; ok is 0|1 if successful and -1 if bad file */
@@ -205,7 +205,7 @@ GMT_LONG mgg2_read_grd_info (struct GRD_HEADER *header)
 	} else if ((fp = GMT_fopen(header->name, GMT_io.r_mode)) == NULL)
 		return (GMT_GRDIO_OPEN_FAILED);
 
-	memset(&mggHeader, '\0', sizeof(MGG_GRID_HEADER_2));
+	memset ((void *)&mggHeader, 0, sizeof(MGG_GRID_HEADER_2));
 	if (GMT_fread(&mggHeader, sizeof(MGG_GRID_HEADER_2), (size_t)1, fp) != 1) return (GMT_GRDIO_READ_FAILED);
 
 	/* Swap header bytes if necessary; ok is 0|1 if successful and -1 if bad file */
@@ -249,7 +249,7 @@ GMT_LONG mgg2_write_grd_info (struct GRD_HEADER *header)
 	return (GMT_NOERROR);
 }
 
-GMT_LONG mgg2_read_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG pad[], BOOLEAN complex)
+GMT_LONG mgg2_read_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG pad[], GMT_LONG complex)
 {
 	MGG_GRID_HEADER_2	mggHeader;
 	FILE  *fp     = NULL;
@@ -260,12 +260,12 @@ GMT_LONG mgg2_read_grd (struct GRD_HEADER *header, float *grid, double w, double
 	GMT_LONG first_col, last_col, first_row, last_row, one_or_zero;
 	GMT_LONG j, j2, width_in, height_in, i_0_out, inc = 1;
 	GMT_LONG i, kk, ij, nm, width_out;
-	BOOLEAN piping = FALSE, geo = FALSE, swap_all = FALSE, is_float = FALSE;
+	GMT_LONG piping = FALSE, geo = FALSE, swap_all = FALSE, is_float = FALSE;
 	double half_or_zero, x, small;
 	long long_offset;	/* For fseek only */
 	
 	if (complex) return (GMT_GRDIO_GRD98_COMPLEX);
-
+	memset ((void *)&mggHeader, 0, sizeof(MGG_GRID_HEADER_2));
 	if (!strcmp (header->name, "=")) {
 		fp = GMT_stdin;
 		piping = TRUE;
@@ -487,8 +487,8 @@ GMT_LONG mgg2_read_grd (struct GRD_HEADER *header, float *grid, double w, double
 		}
 	}
 	
-	header->nx = width_in;
-	header->ny = height_in;
+	header->nx = (int)width_in;
+	header->ny = (int)height_in;
 	header->x_min = w;
 	header->x_max = e;
 	header->y_min = s;
@@ -510,7 +510,7 @@ GMT_LONG mgg2_read_grd (struct GRD_HEADER *header, float *grid, double w, double
 }
 
 	
-GMT_LONG mgg2_write_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, BOOLEAN complex)
+GMT_LONG mgg2_write_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, GMT_LONG complex)
 {
 	MGG_GRID_HEADER_2	mggHeader;
 	int *k;
@@ -519,7 +519,7 @@ GMT_LONG mgg2_write_grd (struct GRD_HEADER *header, float *grid, double w, doubl
 	GMT_LONG first_col, last_col, first_row, last_row;
 	GMT_LONG i, nm, ij, width_in;
 	
-	BOOLEAN geo = FALSE, is_float = FALSE;
+	GMT_LONG geo = FALSE, is_float = FALSE;
 	double half_or_zero, small, x;
 	
 	int  *tLong;
