@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_notunix.h,v 1.31 2010/01/05 01:15:45 guru Exp $
+ *	$Id: gmt_notunix.h,v 1.35 2011/03/03 21:02:50 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -42,9 +42,10 @@
 #define _GMT_NOTUNIX_H
 
 /* A few general comments:
- * NO_LOCK is undefined unless under EMX and _WIN32 where we do NOT want
- * file locking.  Users who do not want file locking because, say, their
- * NFS does not support it should pass the compiler macro -DNO_LOCK.
+ * FLOCK is a pain. If cannot be used under EMX and _WIN32.
+ * Also, users have problems with file locking because their 
+ * NFS does not support it. Only those who are really sure should
+ * activate -DFLOCK.
  */
 
 
@@ -114,9 +115,6 @@
 #define STAT _stat
 
 typedef int mode_t;		/* mode_t not defined under Windows; assumed a signed 4-byte integer */
-#ifdef _WIN64
-typedef __int64 GMT_LONG;		/* A signed 8-byte integer; otherwise set in gmt.h */
-#endif
 
 /* WIN32 versus _WIN32:
  *
@@ -253,7 +251,7 @@ EXTERN_MSC void GMT_setmode (int i_or_o);
 
 #include <io.h>
 
-#define NO_LOCK		/* Do not support file locking */
+#undef FLOCK		/* Do not support file locking */
 #define SET_IO_MODE	/* Need to force binary i/o upon request */
 #define NO_FCNTL	/* fcntl.h does not exist here */
 #define STAT _stat
@@ -273,7 +271,7 @@ EXTERN_MSC void GMT_setmode (int i_or_o);
  
 #ifdef _WIN32	/* Start of NON-UNIX */
 
-#define NO_LOCK		/* Do not support file locking */
+#undef FLOCK		/* Do not support file locking */
 #define SET_IO_MODE	/* Need to force binary i/o upon request */
 
 EXTERN_MSC void GMT_setmode (int i_or_o);
