@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_vector.c,v 1.33 2010/01/05 01:15:46 guru Exp $
+ *	$Id: gmt_vector.c,v 1.37 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -647,7 +647,7 @@ void GMT_cross3v (double *a, double *b, double *c)
 	c[2] = a[0] * b[1] - a[1] * b[0];
 }
 
-void GMT_geo_to_cart (double lat, double lon, double *a, BOOLEAN degrees)
+void GMT_geo_to_cart (double lat, double lon, double *a, GMT_LONG degrees)
 {
 	/* Convert geographic latitude and longitude (lat, lon)
 	   to a 3-vector of unit length (a). If degrees = TRUE,
@@ -665,7 +665,7 @@ void GMT_geo_to_cart (double lat, double lon, double *a, BOOLEAN degrees)
 	a[1] = clat * slon;
 }
 
-void GMT_cart_to_geo (double *lat, double *lon, double *a, BOOLEAN degrees)
+void GMT_cart_to_geo (double *lat, double *lon, double *a, GMT_LONG degrees)
 {
 	/* Convert a 3-vector (a) of unit length into geographic
 	   coordinates (lat, lon). If degrees = TRUE, the output coordinates
@@ -698,8 +698,8 @@ GMT_LONG GMT_fix_up_path (double **a_lon, double **a_lat, GMT_LONG n, double ste
 	 */
       
 	GMT_LONG i, j, n_tmp, n_step = 0, n_alloc = 0;
-	BOOLEAN meridian;
-	double *lon_tmp, *lat_tmp, *old;
+	GMT_LONG meridian;
+	double *lon_tmp = NULL, *lat_tmp = NULL, *old;
 	double a[3], b[3], x[3], *lon, *lat;
 	double c, d, fraction, theta, minlon, maxlon;
 	
