@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: gmtconvert.c,v 1.69 2010/01/05 01:15:46 guru Exp $
+ *	$Id: gmtconvert.c,v 1.79 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -29,36 +29,34 @@
 #define GMT_WITH_NO_PS
 #include "gmt.h"
 
-#define GMTCONVERT_MAX_COL BUFSIZ
-
 struct GMTCONVERT_CTRL {
 	struct A {	/* -A */
-		BOOLEAN active;
+		GMT_LONG active;
 	} A;
 	struct D {	/* -D[<template>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *name;
 	} D;
 	struct E {	/* -E */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG mode;
 	} E;
 	struct F {	/* -F<cols> */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG *col;
 	} F;
 	struct L {	/* -L */
-		BOOLEAN active;
+		GMT_LONG active;
 	} L;
 	struct I {	/* -I */
-		BOOLEAN active;
+		GMT_LONG active;
 	} I;
 	struct N {	/* -N */
-		BOOLEAN active;
+		GMT_LONG active;
 	} N;
 	struct S {	/* -S[~]\"search string\" */
-		BOOLEAN active;
-		BOOLEAN inverse;
+		GMT_LONG active;
+		GMT_LONG inverse;
 		char *pattern;
 	} S;
 };
@@ -69,7 +67,7 @@ int main (int argc, char **argv)
 	GMT_LONG i, j, k, n_total_read = 0, n_hdr_delay = 0, n_out_seg = 0;
 	GMT_LONG n_rev_alloc = 0, n_rev = 0, n_rev_recs = 0, error = 0, n_seg = 0, n_in_seg = 0, n_nan, out_seg;
 	
-	BOOLEAN on, ascii_in_bin_out, match = FALSE;
+	GMT_LONG on, ascii_in_bin_out, match = FALSE;
 
 	double	*in, *out = VNULL, *R_out = (double *)NULL;
 
@@ -81,7 +79,7 @@ int main (int argc, char **argv)
 
 	void *New_gmtconvert_Ctrl (), Free_gmtconvert_Ctrl (struct GMTCONVERT_CTRL *C);
 	
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct GMTCONVERT_CTRL *)New_gmtconvert_Ctrl ();	/* Allocate and initialize a new control structure */
 	
@@ -127,7 +125,7 @@ int main (int argc, char **argv)
 					Ctrl->F.active = TRUE;
 					while ((GMT_strtok (&argv[i][2], ",", &pos, ptr))) {	/* Process all tokens */
 						if (strchr (ptr, '-'))	/* Range of columns given. e.g., 7-9 */
-							sscanf (ptr, "%ld-%ld", &start, &stop);
+							sscanf (ptr, "%" GMT_LL "d-%" GMT_LL "d", &start, &stop);
 						else if (isdigit ((int)ptr[0]))	/* Just a single column, e.g., 13 */
 							start = stop = atoi (ptr);
 						else {				/* Badness! */
@@ -234,9 +232,9 @@ int main (int argc, char **argv)
 	}
 
 	if (Ctrl->A.active) {	/* Do paste and probably cut as well */
-		GMT_LONG *n_expected_fields, *n_fields, all_set = 0;
+		GMT_LONG *n_expected_fields = NULL, *n_fields = NULL, all_set = 0;
 		GMT_LONG n_alloc = GMT_SMALL_CHUNK;
-		double *val;
+		double *val = NULL;
 		FILE **fp = NULL;
 
 		fp = (FILE **) GMT_memory (VNULL, (size_t)n_files, sizeof (FILE *), GMT_program);
@@ -278,12 +276,12 @@ int main (int argc, char **argv)
 						strcat (header, &record_str[1]);
 				}
 				n_total_read ++;
-				if (!GMT_io.binary[GMT_OUT] && GMT_io.io_header[GMT_OUT]) fprintf (GMT_stdout, "%s", header);
+				if (!GMT_io.binary[GMT_OUT] && GMT_io.io_header[GMT_OUT]) GMT_fputs (header, GMT_stdout);
 			}
 		}
 
 		for (k = j = 0; k < n_files; k++) {	/* Get first record from each file */
-			n_expected_fields[k] = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : BUFSIZ; /* BUFSIZ -> Ascii table, must first find the number of fields */
+			n_expected_fields[k] = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : GMT_MAX_COLUMNS; /* GMT_MAX_COLUMNS -> Ascii table, must first find the number of fields */
 			n_fields[k] = GMT_input (fp[k], &n_expected_fields[k], &in);
 			if (! GMT_io.status & GMT_IO_SEGMENT_HEADER) {	/* Good, a data record, update number of cols etc */
 				all_set = 1;
@@ -374,8 +372,8 @@ int main (int argc, char **argv)
 			}
 			while (!GMT_REC_IS_NEW_SEGMENT && !GMT_REC_IS_EOF) {	/* Keep going until FALSE or = 2 segment header */
 				if (GMT_REC_IS_ERROR) {
-					fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields[0], n_expected_fields[0], n_total_read);
-					exit (EXIT_FAILURE);
+					fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld (skipped)\n", GMT_program, n_fields[0], n_expected_fields[0], n_total_read);
+					continue;
 				}
 
 				/* Now shuffle and output the chosen columns */
@@ -415,12 +413,16 @@ int main (int argc, char **argv)
 		}
 
 		for (k = 0; k < n_files; k++) GMT_fclose(fp[k]);
+		GMT_free ((void *)fp);
+		GMT_free ((void *)n_expected_fields);
+		GMT_free ((void *)n_fields);
+		GMT_free ((void *)val);
 
 		if (gmtdefs.verbose) fprintf(stderr, "gmtconvert: %ld records passed (input cols = %ld; output cols = %ld)\n", n_total_read, n_tot_cols, n_out);
 	}
 	else {	/* Just cutting out columns */
 		GMT_LONG n_expected_fields, n_fields, n_args;
-		BOOLEAN nofile = TRUE, done = FALSE;
+		GMT_LONG nofile = TRUE, done = FALSE;
 		FILE *fp = NULL;
 
 		if (GMT_io.binary[GMT_IN] && n_out == 0) {
@@ -459,18 +461,18 @@ int main (int argc, char **argv)
 				for (i = 0; i < GMT_io.n_header_recs; i++) {
 					not_used = GMT_fgets (record_str, BUFSIZ, fp);
 					n_total_read ++;
-					if (!GMT_io.binary[GMT_OUT] && GMT_io.io_header[GMT_OUT]) fputs (record_str, GMT_stdout);
+					if (!GMT_io.binary[GMT_OUT] && GMT_io.io_header[GMT_OUT]) GMT_fputs (record_str, GMT_stdout);
 				}
 			}
 
-			n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : BUFSIZ; /* BUFSIZ -> Ascii table, must first find the number of fields */
+			n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : GMT_MAX_COLUMNS; /* GMT_MAX_COLUMNS -> Ascii table, must first find the number of fields */
 			n_fields = GMT_input (fp, &n_expected_fields, &in);
 			if (GMT_IO_GAP_CHECKING) GMT_write_segmentheader (GMT_stdout, n_out);
 			n_seg = n_in_seg = 0;
 			while (!GMT_REC_IS_EOF) {	/* Not yet EOF */
 
 				while (GMT_REC_IS_NEW_SEGMENT && !GMT_REC_IS_EOF) {
-					if (Ctrl->E.active && (Ctrl->E.mode & 2) && n_in_seg > 0) fprintf (GMT_stdout, "%s", record_str);		/* Previous segments last point */
+					if (Ctrl->E.active && (Ctrl->E.mode & 2) && n_in_seg > 0) GMT_fputs (record_str, GMT_stdout);		/* Previous segments last point */
 					if (Ctrl->S.active) {	/* See if this header has text matching our search string */
 						match = (strstr (GMT_io.segment_header, Ctrl->S.pattern) != NULL);	/* TRUE if we matched */
 						on = (Ctrl->S.inverse == !match);	/* If match then we turn output ON */
@@ -536,7 +538,7 @@ int main (int argc, char **argv)
 						}
 					}
 					else if (Ctrl->E.active) {
-						if (n_in_seg == 0 && (Ctrl->E.mode & 1)) fprintf (GMT_stdout, "%s", GMT_io.current_record);
+						if (n_in_seg == 0 && (Ctrl->E.mode & 1)) GMT_fputs (GMT_io.current_record, GMT_stdout);
 						strcpy (record_str, GMT_io.current_record);
 						n_in_seg++;
 					}
@@ -548,7 +550,7 @@ int main (int argc, char **argv)
 					n_fields = GMT_input (fp, &n_expected_fields, &in);
 				}
 			}
-			if (Ctrl->E.active && (Ctrl->E.mode & 2) && n_in_seg > 0) fprintf (GMT_stdout, "%s", record_str);
+			if (Ctrl->E.active && (Ctrl->E.mode & 2) && n_in_seg > 0) GMT_fputs (record_str, GMT_stdout);
 
 			if (fp != GMT_stdin) GMT_fclose(fp);
 		}
@@ -579,7 +581,7 @@ void *New_gmtconvert_Ctrl () {	/* Allocate and initialize a new control structur
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	
-	C->F.col = (GMT_LONG *) GMT_memory (VNULL, (size_t)GMTCONVERT_MAX_COL, sizeof (GMT_LONG), GMT_program);
+	C->F.col = (GMT_LONG *) GMT_memory (VNULL, (size_t)GMT_MAX_COLUMNS, sizeof (GMT_LONG), GMT_program);
 	
 	return ((void *)C);
 }
