@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: gmtdefaults.c,v 1.35 2010/01/14 17:03:10 guru Exp $
+ *	$Id: gmtdefaults.c,v 1.45 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -31,7 +31,7 @@ int main (int argc, char **argv)
 {
 	GMT_LONG i, get = 0;
 
-	BOOLEAN error = FALSE, get_sys_defaults = FALSE, get_user_defaults = FALSE;
+	GMT_LONG error = FALSE, get_sys_defaults = FALSE, get_user_defaults = FALSE;
 
 	char *path = NULL;
 
@@ -44,7 +44,7 @@ int main (int argc, char **argv)
 	GMT_set_home ();
 	GMT_init_fonts (&GMT_N_FONTS);
 
-	GMT_stdout = stdout;	GMT_stdin = stdin;
+	GMT_begin_io ();
 
 	for (i = 1; !error && i < argc; i++) {
 		if (argv[i][0] != '-') continue;
@@ -103,7 +103,12 @@ int main (int argc, char **argv)
 	else {
 		GMT_getdefpath (get, &path);
 		GMT_getdefaults (path);
+#ifdef WIN32
+		/* We have a "race" condition here. Plain free() crashes Windows but *nix doesn't like GMT_free */
+		GMT_free ((void *)path);
+#else
 		free ((void *)path);
+#endif
 	}
 
 	GMT_putdefaults ("-");
