@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: gmtselect.c,v 1.108 2010/01/05 01:15:46 guru Exp $
+ *	$Id: gmtselect.c,v 1.118 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -64,41 +64,41 @@ struct GMTSELECT_DATA {	/* Used for temporary storage when sorting data on x coo
 struct GMTSELECT_CTRL {	/* All control options for this program (except common args) */
 	/* active is TRUE if the option has been activated */
 	struct A {	/* -A<min_area>[/<min_level>/<max_level>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		struct GMT_SHORE_SELECT info;
 	} A;
 	struct C {	/* [-C[f]<dist>/<ptfile>] */
-		BOOLEAN active;
-		BOOLEAN fast;	/* FALSE for normal distance calculation, TRUE for flat-earth fast calculation */
+		GMT_LONG active;
+		GMT_LONG fast;	/* FALSE for normal distance calculation, TRUE for flat-earth fast calculation */
 		double dist;	/* Radius of influence for each point */
 		char *file;	/* Name of file with points */
 	} C;
 	struct D {	/* -D<resolution> */
-		BOOLEAN active;
-		BOOLEAN force;	/* if TRUE, select next highest level if current set is not avaialble */
+		GMT_LONG active;
+		GMT_LONG force;	/* if TRUE, select next highest level if current set is not avaialble */
 		char set;	/* One of f, h, i, l, c */
 	} D;
 	struct L {	/* -L[p][<dist>/<lfile>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG mode;	/* Controls what happens beyond segment endpoints */
 		double dist;	/* Distance of influence for each line */
 		char *file;	/* Name of file with lines */
 	} L;
 	struct F {	/* -F<polygon> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;	/* Name of file with polygons */
 	} F;
 	struct I {	/* -Icflrsz */
-		BOOLEAN active;
-		BOOLEAN pass[GMTSELECT_N_TESTS];	/* One flag for each setting */
+		GMT_LONG active;
+		GMT_LONG pass[GMTSELECT_N_TESTS];	/* One flag for each setting */
 	} I;
 	struct N {	/* -N<maskvalues>[o] */
-		BOOLEAN active;
-		BOOLEAN edge;	/* TRUE if edges are considere outside */
+		GMT_LONG active;
+		GMT_LONG edge;	/* TRUE if edges are considere outside */
 		GMT_LONG mask[GMTSELECT_N_CLASSES];	/* Mask for each level */
 	} N;
 	struct Z {	/* -Z<min>/<max> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double min;	/* Smallest z-value to pass through */
 		double max;	/* Largest z-value to pass through */
 	} Z;
@@ -109,11 +109,11 @@ int main (int argc, char **argv)
 	GMT_LONG i, j, k, fno, n_files = 0, n_args, err, n_minimum = 2;
 	GMT_LONG n_fields, n_expected_fields, ind, bin, last_bin = -1, n_output = -1;
 	GMT_LONG np[2], base = 3, wd[2], id, this_node, side, is_inside, row, col, pos;
-	GMT_LONG n_read = 0, n_pass = 0;
+	GMT_LONG n_read = 0, n_pass = 0, no_resample = 0;
 
-	BOOLEAN error = FALSE, dry_wet_only = FALSE, long_verbose = FALSE, need_header, shuffle;
-	BOOLEAN cartesian = FALSE, nofile = TRUE, done = FALSE, first = TRUE, inside, plain_xy;
-	BOOLEAN greenwich = FALSE, output_header = FALSE, do_project = FALSE, just_copy_record = FALSE;
+	GMT_LONG error = FALSE, dry_wet_only = FALSE, long_verbose = FALSE, need_header, shuffle;
+	GMT_LONG cartesian = FALSE, nofile = TRUE, done = FALSE, first = TRUE, inside, plain_xy;
+	GMT_LONG greenwich = FALSE, output_header = FALSE, do_project = FALSE, just_copy_record = FALSE;
 
 	double west = 0.0, east = 0.0, south = 0.0, north = 0.0, xx, yy;
 	double *in, west_border = 0.0, east_border = 0.0;
@@ -134,7 +134,7 @@ int main (int argc, char **argv)
 	int compare_x (const void *point_1, const void *point_2);
 	void *New_gmtselect_Ctrl (), Free_gmtselect_Ctrl (struct GMTSELECT_CTRL *C);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct GMTSELECT_CTRL *) New_gmtselect_Ctrl ();		/* Allocate and initialize defaults in a new control structure */
 
@@ -370,7 +370,7 @@ int main (int argc, char **argv)
 	}
         if (GMT_io.binary[GMT_IN] && GMT_io.ncol[GMT_IN] == 0) GMT_io.ncol[GMT_IN] = 2 + Ctrl->Z.active;
         if (GMT_io.binary[GMT_IN] && GMT_io.ncol[GMT_IN] < (2 + Ctrl->Z.active)) {
-                fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data (-bi) must have at least %d columns\n", GMT_program, 2 + Ctrl->Z.active);
+                fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data (-bi) must have at least %ld columns\n", GMT_program, 2 + Ctrl->Z.active);
 		error++;
 	}
 	if (error) exit (EXIT_FAILURE);
@@ -398,7 +398,7 @@ int main (int argc, char **argv)
 	if (project_info.region_supplied) {	/* -R was set directly or indirectly; hence must set -J if not supplied */
 		if (project_info.projection == GMT_NO_PROJ) {	/* -J not specified, set one implicitly */
 			if (GMT_io.in_col_type[0] == GMT_IS_LON) {	/* We know we have geographic data (either via -f or -N) */
-				project_info.degree[0] = project_info.degree[1] = TRUE;
+				project_info.degree[0] = project_info.degree[1] = no_resample = TRUE;
 			}
 			/* Supply dummy linear proj */
 			project_info.projection = project_info.xyz_projection[0] = project_info.xyz_projection[1] = GMT_LINEAR;
@@ -415,6 +415,7 @@ int main (int argc, char **argv)
 			greenwich = (west < 0.0 && east > 0.0);
 		}
 		GMT_err_fail (GMT_map_setup (west, east, south, north), "");
+		if (no_resample) GMT_parallel_straight = GMT_meridian_straight = 2;	/* No resampling along bin boundaries */
 	}
 
 	if (do_project && gmtdefs.verbose) fprintf (stderr, "%s: Warning: -J means all data will be projected before tests are applied\n", GMT_program);
@@ -520,6 +521,7 @@ int main (int argc, char **argv)
 		}
 	}
 	if (Ctrl->F.active) {	/* Initialize polygon structure used in test for polygon in/out test */
+		GMT_io.skip_duplicates = TRUE;
 		GMT_import_table ((void *)Ctrl->F.file, GMT_IS_FILE, &pol, 0.0, greenwich, TRUE, FALSE);
 		if (pol->segment[0]->n_columns < 2) {	/* Trouble */
 			fprintf (stderr, "%s: GMT SYNTAX ERROR -F:  %s does not have at least 2 columns with coordinates\n", GMT_program, Ctrl->F.file);
@@ -534,6 +536,7 @@ int main (int argc, char **argv)
 				}
 			}
 		}
+		GMT_io.skip_duplicates = FALSE;	/* Reset to FALSE */
 	}
 	plain_xy = (do_project || GMT_io.in_col_type[GMT_X] != GMT_IS_LON);
 	
@@ -568,11 +571,11 @@ int main (int argc, char **argv)
 		if (GMT_io.io_header[GMT_IN]) {
 			for (i = 0; i < GMT_io.n_header_recs; i++) {
 				not_used = GMT_fgets (buffer, BUFSIZ, fp);
-				if (first && GMT_io.io_header[GMT_OUT]) fprintf (GMT_stdout, "%s", buffer);
+				if (first && GMT_io.io_header[GMT_OUT]) GMT_fputs (buffer, GMT_stdout);
 			}
 			first = FALSE;
 		}
-		n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : BUFSIZ;
+		n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : GMT_MAX_COLUMNS;
 
 		while ((n_fields = GMT_input (fp, &n_expected_fields, &in)) >= 0 && ! (GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
 
@@ -582,20 +585,21 @@ int main (int argc, char **argv)
 			}
 			if ((GMT_io.status & GMT_IO_EOF)) continue;	/* At EOF */
 
+			n_read++;
+
 			if (!just_copy_record && (GMT_io.status & GMT_IO_MISMATCH)) {
-				fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields,  n_expected_fields, n_read);
-				exit (EXIT_FAILURE);
+				fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld (skipped)\n", GMT_program, n_fields,  n_expected_fields, n_read);
+				continue;
 			}
 
-			n_read++;
 			if (long_verbose && n_read%1000 == 0) fprintf (stderr, "%s: Read %ld records, passed %ld records\r", GMT_program, n_read, n_pass);
 
 			if (n_fields < n_minimum) {
 				if (Ctrl->Z.active)
-					fprintf (stderr, "%s: -Z requires a data file with at least 3 columns; this file only has %ld near line %ld. Exiting.\n", GMT_program, n_fields, n_read);
+					fprintf (stderr, "%s: -Z requires a data file with at least 3 columns; this file only has %ld near line %ld (skipped)\n", GMT_program, n_fields, n_read);
 				else
-					fprintf (stderr, "%s: Data file must have at least 2 columns; this file only has %ld near line %ld. Exiting.\n", GMT_program, n_fields, n_read);
-				exit (EXIT_FAILURE);
+					fprintf (stderr, "%s: Data file must have at least 2 columns; this file only has %ld near line %ld (skipped)\n", GMT_program, n_fields, n_read);
+				continue;
 			}
 
 			if (Ctrl->Z.active) {
@@ -677,7 +681,7 @@ int main (int argc, char **argv)
 						GMT_free_polygons (p[id], np[id]);
 						if (np[id]) GMT_free ((void *)p[id]);
 						np[id] = GMT_assemble_shore (&c, wd[id], TRUE, greenwich, west_border, east_border, &p[id]);
-						np[id] = GMT_prep_polygons (&p[id], np[id], TRUE, step, -1);
+						np[id] = GMT_prep_polygons (&p[id], np[id], !no_resample, step, -1);
 					}
 				}
 
@@ -709,7 +713,7 @@ int main (int argc, char **argv)
 							if (xx < xmin || xx > xmax) continue;
 
 							/* Must compare with polygon */
-
+							
 							if ((side = GMT_non_zero_winding (xx, yy, p[id][k].lon, p[id][k].lat, p[id][k].n)) < is_inside) continue;	/* Outside polygon */
 
 							/* Here, point is inside, we must assign value */
@@ -730,7 +734,7 @@ int main (int argc, char **argv)
 			}
 
 			if (just_copy_record)
-				fprintf (GMT_stdout, "%s", GMT_io.current_record);
+				GMT_fputs (GMT_io.current_record, GMT_stdout);
 			else {
 				if (n_output < 0) n_output = n_expected_fields;
 				GMT_output (GMT_stdout, n_output, in);
