@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *    $Id: grdblend.c,v 1.80 2010/01/14 07:15:19 guru Exp $
+ *    $Id: grdblend.c,v 1.85 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -42,26 +42,26 @@
 
 struct GRDBLEND_CTRL {
 	struct G {	/* -G<grdfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} G;
 	struct I {	/* -Idx[/dy] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double xinc, yinc;
 	} I;
 	struct N {	/* -N<nodata> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double nodata;
 	} N;
 	struct Q {	/* -Q */
-		BOOLEAN active;
+		GMT_LONG active;
 	} Q;
 	struct Z {	/* -Z<scale> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double scale;
 	} Z;
 	struct W {	/* -W */
-		BOOLEAN active;
+		GMT_LONG active;
 	} W;
 };
 
@@ -71,9 +71,9 @@ struct GRDBLEND_INFO {	/* Structure with info about each input grid file */
 	GMT_LONG in_j0, in_j1, out_j0, out_j1;		/* Indices of outer and inner y-coordinates (in output grid coordinates) */
 	GMT_LONG offset;				/* grid offset when the grid extends beyond north */
 	long skip;					/* Byte offset to skip in native binary files */
-	BOOLEAN outside;				/* TRUE if the current output row is outside the range of this grid */
-	BOOLEAN invert;					/* TRUE if weight was given as negative and we want to taper to zero INSIDE the grid region */
-	BOOLEAN open;					/* TRUE if file is currently open */
+	GMT_LONG outside;				/* TRUE if the current output row is outside the range of this grid */
+	GMT_LONG invert;					/* TRUE if weight was given as negative and we want to taper to zero INSIDE the grid region */
+	GMT_LONG open;					/* TRUE if file is currently open */
 	char file[GMT_LONG_TEXT];			/* Name of grid file */
 	double weight, wt_y, wxr, wxl, wyu, wyd;	/* Various weighting factors used for cosine-taper weights */
 	double w_in, e_in, s_in, n_in;			/* Boundaries of inner region */
@@ -87,7 +87,7 @@ int main (int argc, char **argv)
 	double wt_x, w, wt;
 	float *z, no_data_f;
 	char mode[2] = {'w', 'W'};
-	BOOLEAN wrap_x;
+	GMT_LONG wrap_x;
 	FILE *fp = NULL;
 	struct GRDBLEND_INFO *blend = NULL;
 	struct GMT_GRDFILE S;
@@ -97,7 +97,7 @@ int main (int argc, char **argv)
 	GMT_LONG init_blend_job (FILE *fp, struct GRD_HEADER *h, struct GRDBLEND_INFO **blend);
 	void *New_grdblend_Ctrl (), Free_grdblend_Ctrl (struct GRDBLEND_CTRL *C);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct GRDBLEND_CTRL *)New_grdblend_Ctrl ();	/* Allocate and initialize a new control structure */
 	
@@ -434,11 +434,11 @@ GMT_LONG init_blend_job (FILE *fp, struct GRD_HEADER *h, struct GRDBLEND_INFO **
 		if (B[n].out_j0 < 0) {	/* Must skip to first row inside the present -R */
 			type = GMT_grdformats[B[n].G.header.type][0];
 			if (type == 'c')	/* Old-style, 1-D netcdf grid */
-				B[n].offset = B[n].G.header.nx * abs (B[n].out_j0);
+				B[n].offset = B[n].G.header.nx * GMT_abs (B[n].out_j0);
 			else if (type == 'n')	/* New, 2-D netcdf grid */
 				B[n].offset = B[n].out_j0;
 			else
-				B[n].skip = (long)(B[n].G.n_byte * abs (B[n].out_j0));	/* do the fseek when we are ready to read first row */
+				B[n].skip = (long)(B[n].G.n_byte * GMT_abs (B[n].out_j0));	/* do the fseek when we are ready to read first row */
 		}
 
 		/* Allocate space for one entire row */
