@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: grdcontour.c,v 1.147 2010/01/14 07:15:19 guru Exp $
+ *	$Id: grdcontour.c,v 1.157 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -46,58 +46,58 @@
 struct GRDCONTOUR_CTRL {
 	struct GMT_CONTOUR contour;
 	struct A {	/* -A[-|aint][+a<angle>][+c<dx>[/<dy>]][+f<font>][+g<fill>][+j<just>][+l<label>][+o|O|t][+s<size>][+p<pen>][+u<unit>] */
-		BOOLEAN active;
-		BOOLEAN off;
+		GMT_LONG active;
+		GMT_LONG off;
 		double interval;
 	} A;
 	struct C {	/* -C<cont_int> */
-		BOOLEAN active;
-		BOOLEAN cpt;
+		GMT_LONG active;
+		GMT_LONG cpt;
 		char *file;
 		double interval;
 	} C;
 	struct D {	/* -D<dumpfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} D;
 	struct E {	/* -Eazimuth/elevation */
-		BOOLEAN active;
+		GMT_LONG active;
 		double azimuth, elevation;
 	} E;
 	struct F {	/* -F<way> */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG value;
 	} F;
 	struct G {	/* -G[d|f|n|l|L|x|X]<params> */
-		BOOLEAN active;
+		GMT_LONG active;
 	} G;
 	struct L {	/* -L<Low/high> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double low, high;
 	} L;
 	struct Q {	/* -Q<cut> */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG min;
 	} Q;
 	struct S {	/* -S<smooth> */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG value;
 	} S;
 	struct T {	/* -T[+|-][<gap>[c|i|m|p]/<length>[c|i|m|p]][:LH] */
-		BOOLEAN active;
-		BOOLEAN label;
-		BOOLEAN low, high;	/* TRUE to tick low and high locals */
+		GMT_LONG active;
+		GMT_LONG label;
+		GMT_LONG low, high;	/* TRUE to tick low and high locals */
 		double spacing, length;
 		char L_label, H_label;
 	} T;
 	struct W {	/* -W[+]<type><pen> */
-		BOOLEAN active;
-		BOOLEAN color;
+		GMT_LONG active;
+		GMT_LONG color;
 		struct GMT_PEN pen[2];
 	} W;
 	struct Z {	/* -Z[<fact>[/shift>]][p] */
-		BOOLEAN active;
-		BOOLEAN periodic;
+		GMT_LONG active;
+		GMT_LONG periodic;
 		double scale, offset;
 	} Z;
 };
@@ -107,17 +107,17 @@ struct SAVE {
 	double cval;
 	GMT_LONG n;
 	struct GMT_PEN pen;
-	BOOLEAN do_it, high;
+	GMT_LONG do_it, high;
 };
 
 int main (int argc, char **argv)
 {
-	GMT_LONG j, k, c, n_edges, n_alloc = 0, section, n_contours, side, id;
+	GMT_LONG j, k, c, n_edges, n_alloc = 0, section, n_contours, id;
 	GMT_LONG nx, ny, n_save = 0, got, nm, i, n, nn, *edge;
 	
 	int rgb[3];
 
-	BOOLEAN error = FALSE, interior, begin, subset = FALSE;
+	GMT_LONG error = FALSE, interior, begin, subset = FALSE, wrap_check;
 
 	char *grdfile = 0, line[BUFSIZ], *cont_type, *cont_do_tick;
 	char txt_a[GMT_LONG_TEXT], txt_b[GMT_LONG_TEXT];
@@ -134,12 +134,12 @@ int main (int argc, char **argv)
 	struct SAVE *save = NULL;
 	struct GRDCONTOUR_CTRL *Ctrl;
 
-	void sort_and_plot_ticks (struct SAVE *save, GMT_LONG n, struct GRD_HEADER *h, float *grd, double tick_gap, double tick_length, BOOLEAN tick_low, BOOLEAN tick_high, BOOLEAN tick_label, char Llabel, char Hlabel);
+	void sort_and_plot_ticks (struct SAVE *save, GMT_LONG n, struct GRD_HEADER *h, float *grd, double tick_gap, double tick_length, GMT_LONG tick_low, GMT_LONG tick_high, GMT_LONG tick_label, char Llabel, char Hlabel);
 	void GMT_grd_minmax (float *a, struct GRD_HEADER *h, double xyz[2][3]);
 	void adjust_hill_label (struct GMT_CONTOUR *G, struct GRD_HEADER *h, float *z);
 	void *New_grdcontour_Ctrl (), Free_grdcontour_Ctrl (struct GRDCONTOUR_CTRL *C);
 	
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct GRDCONTOUR_CTRL *)New_grdcontour_Ctrl ();	/* Allocate and initialize a new control structure */
 	
@@ -545,7 +545,7 @@ int main (int argc, char **argv)
 			else
 				cont_type[c] = (Ctrl->contour.annot) ? 'A' : 'C';
 			cont_angle[c] = (Ctrl->contour.angle_type == 2) ? Ctrl->contour.label_angle : GMT_d_NaN;
-			cont_do_tick[c] = Ctrl->T.active;
+			cont_do_tick[c] = (char)Ctrl->T.active;
 			c++;
 		}
 		contour[c] = GMT_lut[GMT_n_colors-1].z_high;
@@ -556,7 +556,7 @@ int main (int argc, char **argv)
 		else
 			cont_type[c] = (Ctrl->contour.annot) ? 'A' : 'C';
 		cont_angle[c] = (Ctrl->contour.angle_type == 2) ? Ctrl->contour.label_angle : GMT_d_NaN;
-		cont_do_tick[c] = Ctrl->T.active;
+		cont_do_tick[c] = (char)Ctrl->T.active;
 		n_contours = c + 1;
 	}
 	else if (Ctrl->C.file) {	/* read contour info from file */
@@ -595,7 +595,7 @@ int main (int argc, char **argv)
 			if (Ctrl->contour.annot && (contour[n_contours] - aval) > GMT_SMALL) aval += Ctrl->A.interval;
 			cont_type[n_contours] = (fabs (contour[n_contours] - aval) < GMT_SMALL) ? 'A' : 'C';
 			cont_angle[n_contours] = (Ctrl->contour.angle_type == 2) ? Ctrl->contour.label_angle : GMT_d_NaN;
-			cont_do_tick[n_contours] = Ctrl->T.active;
+			cont_do_tick[n_contours] = (char)Ctrl->T.active;
 		}
 	}
 	if (GMT_z_periodic && n_contours > 1 && fabs (contour[n_contours-1] - contour[0] - 360.0) < GMT_SMALL) {	/* Get rid of redundant contour */
@@ -634,7 +634,8 @@ int main (int argc, char **argv)
 	n_edges = header.ny * (int )ceil (header.nx / 16.0);
 	edge = (GMT_LONG *) GMT_memory (VNULL, (size_t)n_edges, sizeof (GMT_LONG), GMT_program);
 
-
+	wrap_check = (GMT_io.in_col_type[0] == GMT_IS_LON && (fabs (header.x_max - header.x_min - 360.0) < GMT_SMALL));
+	
 	GMT_plotinit (argc, argv);
 	if (project_info.three_D) ps_transrotate (-z_project.xmin, -z_project.ymin, 0.0);
 
@@ -666,51 +667,52 @@ int main (int argc, char **argv)
 			if (!Ctrl->contour.got_font_rgb && Ctrl->contour.curved_text) memcpy ((void *)&Ctrl->contour.font_rgb, (void *)rgb, (size_t)(3 * sizeof (int)));
 		}
 
-		side = 0;
-		begin = TRUE;
 		n_alloc = 0;
-		while (side <= GMT_LAST_CONTOUR_SIDE) {
-			while ((n = GMT_contours (grd, &header, Ctrl->S.value, gmtdefs.interpolant, Ctrl->F.value, &side, edge, begin, &x, &y)) > 0) {
+		begin = TRUE;
+		while ((n = GMT_contours (grd, &header, Ctrl->S.value, gmtdefs.interpolant, Ctrl->F.value, edge, &begin, &x, &y)) > 0) {
 
-				if (fabs (x[0] - x[n-1]) < small_x && fabs (y[0] - y[n-1]) < small_y) {
-					interior = TRUE;
-					x[n-1] = x[0];	y[n-1] = y[0];	/* Ensure exact closure */
-				}
-				else
-					interior = FALSE;
-
-				if (!interior || n >= Ctrl->Q.min) {
-					if (Ctrl->D.active) GMT_dump_contour (x, y, n, cval, section, interior, Ctrl->D.file);
-					if ((nn = GMT_clip_to_map (x, y, n, &xp, &yp))) {	/* Lines inside the region */
-						/* From here on, xp/yp are map inches */
-						if (cont_type[c] == 'A' || cont_type[c] == 'a') {	/* Annotated contours */
-							GMT_get_format (cval, Ctrl->contour.unit, CNULL, format);
-							sprintf (cont_label, format, cval);
-						}
-						else
-							cont_label[0] = (char)0;
-						if (cont_do_tick[c] && interior) {
-							if (n_save == n_alloc) n_alloc = GMT_alloc_memory ((void **)&save, n_save, n_alloc, sizeof (struct SAVE), GMT_program);
-							(void)GMT_alloc_memory2 ((void **)&save[n_save].x, (void **)&save[n_save].y, nn, 0, sizeof (double), GMT_program);
-							memcpy ((void *)save[n_save].x, (void *)xp, (size_t)(nn * sizeof (double)));
-							memcpy ((void *)save[n_save].y, (void *)yp, (size_t)(nn * sizeof (double)));
-							save[n_save].n = nn;
-							memcpy ((void *)&save[n_save].pen, (void *)&Ctrl->W.pen[id], sizeof (struct GMT_PEN));
-							save[n_save].do_it = TRUE;
-							save[n_save].cval = cval;
-							n_save++;
-						}
-						GMT_hold_contour (&xp, &yp, nn, cval, cont_label, cont_type[c], cont_angle[c], interior, &Ctrl->contour);
-						GMT_free ((void *)xp);
-						GMT_free ((void *)yp);
-					}
-					section++;
-				}
-				begin = FALSE;
-				GMT_free ((void *)x);
-				GMT_free ((void *)y);
+			if (fabs (x[0] - x[n-1]) < small_x && fabs (y[0] - y[n-1]) < small_y) {
+				interior = 3;
+				x[n-1] = x[0];	y[n-1] = y[0];	/* Ensure exact closure */
 			}
-			begin = FALSE;
+#ifdef EXPERIMENT	
+			else if (wrap_check) {
+				if (fabs (x[0] - header.x_min) < GMT_SMALL && fabs (x[n-1] - header.x_min) < GMT_SMALL) interior = 2;
+				else if (fabs (x[0] - header.x_max) < GMT_SMALL && fabs (x[n-1] - header.x_max) < GMT_SMALL) interior = 1;
+			}
+#endif
+			else
+				interior = FALSE;
+
+			if (!interior || n >= Ctrl->Q.min) {
+				if (Ctrl->D.active) GMT_dump_contour (x, y, n, cval, section, interior, Ctrl->D.file);
+				if ((nn = GMT_clip_to_map (x, y, n, &xp, &yp))) {	/* Lines inside the region */
+					/* From here on, xp/yp are map inches */
+					if (cont_type[c] == 'A' || cont_type[c] == 'a') {	/* Annotated contours */
+						GMT_get_format (cval, Ctrl->contour.unit, CNULL, format);
+						sprintf (cont_label, format, cval);
+					}
+					else
+						cont_label[0] = (char)0;
+					if (cont_do_tick[c] && interior) {
+						if (n_save == n_alloc) n_alloc = GMT_alloc_memory ((void **)&save, n_save, n_alloc, sizeof (struct SAVE), GMT_program);
+						(void)GMT_alloc_memory2 ((void **)&save[n_save].x, (void **)&save[n_save].y, nn, 0, sizeof (double), GMT_program);
+						memcpy ((void *)save[n_save].x, (void *)xp, (size_t)(nn * sizeof (double)));
+						memcpy ((void *)save[n_save].y, (void *)yp, (size_t)(nn * sizeof (double)));
+						save[n_save].n = nn;
+						memcpy ((void *)&save[n_save].pen, (void *)&Ctrl->W.pen[id], sizeof (struct GMT_PEN));
+						save[n_save].do_it = interior;
+						save[n_save].cval = cval;
+						n_save++;
+					}
+					GMT_hold_contour (&xp, &yp, nn, cval, cont_label, cont_type[c], cont_angle[c], interior, &Ctrl->contour);
+					GMT_free ((void *)xp);
+					GMT_free ((void *)yp);
+				}
+				section++;
+			}
+			GMT_free ((void *)x);
+			GMT_free ((void *)y);
 		}
 	}
 
@@ -760,13 +762,15 @@ int main (int argc, char **argv)
 	exit (EXIT_SUCCESS);
 }
 
-void sort_and_plot_ticks (struct SAVE *save, GMT_LONG n, struct GRD_HEADER *h, float *grd, double tick_gap, double tick_length, BOOLEAN tick_low, BOOLEAN tick_high, BOOLEAN tick_label, char Llabel, char Hlabel)
+void sort_and_plot_ticks (struct SAVE *save, GMT_LONG n, struct GRD_HEADER *h, float *grd, double tick_gap, double tick_length, GMT_LONG tick_low, GMT_LONG tick_high, GMT_LONG tick_label, char Llabel, char Hlabel)
 {
 	GMT_LONG np, i, j, inside, ix, iy, done, n_ticks, stop;
 	double x0, y0, add, sign, dx, dy, x_back, y_back, x_front, y_front;
-	double xmin, xmax, ymin, ymax, x_mean = 0.0, y_mean = 0.0, inc, dist, a, small, this_lon, this_lat, sa, ca, *s;
+	double xmin, xmax, ymin, ymax, x_mean = 0.0, y_mean = 0.0, inc, dist, a, small, this_lon, this_lat, L, sa, ca, *s;
 	char txt[2][2];
-
+#ifdef EXPERIMENT	
+	GMT_LONG k, m, reverse;
+#endif
 	/* The x/y coordinates in SAVE are now all projected to map inches */
 
 	small = 0.1 * project_info.xmax / h->nx;
@@ -775,9 +779,55 @@ void sort_and_plot_ticks (struct SAVE *save, GMT_LONG n, struct GRD_HEADER *h, f
 		txt[1][0] = Hlabel;	txt[1][1] = 0;
 	}
 
+	for (i = 0; i < n; i++) {	/* Look for tiny closed contours around a single node == cval */
+		for (j = 1, L = 0.0; j < save[i].n; j++) L += hypot (save[i].x[j]-save[i].x[j-1], save[i].y[j]-save[i].y[j-1]);
+		if (L < GMT_SMALL) {	/* This is a tiny closed contour; Mark as invalid */
+			save[i].do_it = FALSE;
+			continue;
+		}
+	}
+
+#ifdef EXPERIMENT	
+	/* Reconnect closed contours split at a periodic boundary */
+	
+	for (i = 0; i < n; i++) {	/* For all or these "closed" contours */
+		if (save[i].do_it == 3) continue;	/* This one is fully closed already */
+		for (j = i + 1; j < n; j++) {	/* Compare to all other "closed" contours */
+			if (save[j].do_it == 3) continue;	/* This one is also fully closed */
+			if (save[i].cval != save[j].cval) continue;	/* Not the same contour level */
+			if (!(save[i].do_it + save[j].do_it) == 3) continue;	/* Not west + east split contours */
+			/* OK, found a matching pair; now see if they are projected to be next to each other */
+			np = save[i].n;
+			if (fabs (save[i].x[0] - save[j].x[0]) < SMALL && fabs (save[i].y[0] - save[j].y[0]) < SMALL)
+				reverse = TRUE;
+			else if (fabs (save[i].x[np-1] - save[j].x[0]) < SMALL && fabs (save[i].y[np-1] - save[j].y[0]) < SMALL)
+				reverse = FALSE;
+			else
+				continue;	/* No match */
+			/* Here we append west to east segment */
+			save[i].x = (double *) GMT_memory ((void *)save[i].x, (size_t)(np+save[j].n), sizeof (double), GMT_program);
+			save[i].y = (double *) GMT_memory ((void *)save[i].y, (size_t)(np+save[j].n), sizeof (double), GMT_program);
+			if (reverse) {
+				for (k = np, m = save[j].n-1; m >= 0; k++, m--) {
+					save[i].x[k] = save[j].x[m];
+					save[i].y[k] = save[j].y[m];
+				}
+			}
+			else {
+				memcpy ((void *)&save[i].x[np], (void *)save[j].x, save[j].n * sizeof (double));
+				memcpy ((void *)&save[i].y[np], (void *)save[j].y, save[j].n * sizeof (double));
+			}
+			save[i].n += save[j].n;
+			save[i].do_it = 3;
+			save[j].do_it = FALSE;
+		}
+	}
+#endif
+	
 	for (i = 0; i < n; i++) {	/* Mark polygons that have other polygons inside them */
 		np = save[i].n;
-		for (j = 0; save[i].do_it && j < n; j++) {
+		for (j = 0; save[i].do_it == 3 && j < n; j++) {
+			if (!save[j].do_it) continue;	/* No point checking contours that either have others inside or are invalid */
 			inside = GMT_non_zero_winding (save[j].x[0], save[j].y[0], save[i].x, save[i].y, (GMT_LONG)np);
 			if (inside == 2) save[i].do_it = FALSE;
 		}
@@ -855,6 +905,7 @@ void sort_and_plot_ticks (struct SAVE *save, GMT_LONG n, struct GRD_HEADER *h, f
 			GMT_free ((void *)s);
 			continue;
 		}
+		GMT_setpen (&save[i].pen);
 		inc = s[np-1] / n_ticks;
 		if (tick_label) {
 			x_mean /= np;
@@ -867,7 +918,6 @@ void sort_and_plot_ticks (struct SAVE *save, GMT_LONG n, struct GRD_HEADER *h, f
 		dist = 0.0;
 		j = 0;
 		add = sign * ((save[i].high) ? -1.0 : 1.0);
-		GMT_setpen (&save[i].pen);
 		while (j < np-1) {
 			x_front = save[i].x[j+1];
 			y_front = save[i].y[j+1];
