@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: grdcut.c,v 1.45 2010/01/05 01:15:46 guru Exp $
+ *	$Id: grdcut.c,v 1.49 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -30,11 +30,11 @@
 
 struct GRDCUT_CTRL {
 	struct G {	/* -G<output_grdfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} G;
 	struct Z {	/* -Z[min/max] */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG mode;	/* 1 means NaN */
 		double min, max;
 	} Z;
@@ -45,7 +45,7 @@ struct GRDCUT_CTRL {
 
 int main (int argc, char **argv)
 {
-	BOOLEAN	error = FALSE;
+	GMT_LONG	error = FALSE;
 
 	GMT_LONG	i, k, nx_old, ny_old, nx_new, ny_new, one_or_zero;
 	
@@ -63,7 +63,7 @@ int main (int argc, char **argv)
 
 	void *New_grdcut_Ctrl (), Free_grdcut_Ctrl (struct GRDCUT_CTRL *C);
 	
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct GRDCUT_CTRL *) New_grdcut_Ctrl ();	/* Allocate and initialize a new control structure */
 
