@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: grdfft.c,v 1.50 2010/01/05 01:15:46 guru Exp $
+ *	$Id: grdfft.c,v 1.57 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -46,50 +46,50 @@ struct GRDFFT_CTRL {
 	double	*par;
 
 	struct A {	/* -A<azimuth> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double value;
 	} A;
 	struct C {	/* -C<zlevel> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double value;
 	} C;
 	struct D {	/* -D[<scale>|g] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double value;
 	} D;
 	struct E {	/* -E[x_or_y][w] */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG mode;
 	} E;
 	struct F {	/* -F[x_or_y]<lc>/<lp>/<hp>/<hc> or -F[x_or_y]<lo>/<hi> */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG mode;
 		double lc, lp, hp, hc;
 	} F;
 	struct G {	/* -G<outfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} G;
 	struct I {	/* -I[<scale>|g] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double value;
 	} I;
 	struct L {	/* -L */
-		BOOLEAN active;
+		GMT_LONG active;
 	} L;
 	struct M {	/* -M */
-		BOOLEAN active;
+		GMT_LONG active;
 	} M;
 	struct N {	/* -N<stuff> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double value;
 	} N;
 	struct S {	/* -S<scale> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double value;
 	} S;
 	struct T {	/* -T<te/rl/rm/rw/ri> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double te, rhol, rhom, rhow, rhoi;
 	} T;
 };
@@ -116,7 +116,7 @@ struct GRDFFT_CTRL {
 GMT_LONG	narray[2];
 GMT_LONG	i, j, k, n, nx2 = 0, ny2 = 0, ndatac, i_data_start, j_data_start;
 
-BOOLEAN	map_units = FALSE, force_narray = FALSE, suggest_narray = FALSE, leave_trend_alone = FALSE, n_user_set = FALSE;
+GMT_LONG	map_units = FALSE, force_narray = FALSE, suggest_narray = FALSE, leave_trend_alone = FALSE, n_user_set = FALSE;
 
 double	data_var, data2_var, delta_kx, delta_ky;
 double	a[3];	/* Plane fitting coefficients  */
@@ -161,7 +161,7 @@ int main (int argc, char **argv)
 {
 	GMT_LONG op_count = 0, par_count = 0, filter_type = 0;
 
-	BOOLEAN error = FALSE, stop, give_wavelength = FALSE;
+	GMT_LONG error = FALSE, stop, give_wavelength = FALSE;
 	struct GRDFFT_CTRL *Ctrl;
 	GMT_LONG parse_f_string (char *c), count_slashes (char *txt);
 	void read_data(struct GRDFFT_CTRL *Ctrl, int argc, char **argv);
@@ -171,7 +171,7 @@ int main (int argc, char **argv)
 
 	void *New_grdfft_Ctrl (), Free_grdfft_Ctrl (struct GRDFFT_CTRL *C);
 	
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct GRDFFT_CTRL *) New_grdfft_Ctrl ();	/* Allocate and initialize a new control structure */
 
@@ -307,7 +307,7 @@ int main (int argc, char **argv)
 					else if (argv[i][2] == 'q' || argv[i][2] == 'Q')
 						suggest_narray = TRUE;
 					else {
-	                                        sscanf(&argv[i][2], "%ld/%ld", &nx2, &ny2);
+	                                        sscanf(&argv[i][2], "%" GMT_LL "d/%" GMT_LL "d", &nx2, &ny2);
 						n_user_set = TRUE;
 					}
                                         break;
@@ -1024,7 +1024,7 @@ void do_spectrum (double *par, GMT_LONG give_wavelength)
 	GMT_LONG	k, nk, nused, ifreq;
 	double	delta_k, r_delta_k, freq, *power, eps_pow;
 	PFD	get_k;
-	char	format[GMT_TEXT_LEN];
+	char	format[GMT_TEXT_LEN], buffer[GMT_LONG_TEXT];
 	/*  Added by WHFS in version 3.001 to normalize power  :  */
 	double	powfactor;
 
@@ -1079,7 +1079,8 @@ void do_spectrum (double *par, GMT_LONG give_wavelength)
 		freq = (k + 1) * delta_k;
 		if (give_wavelength) freq = 1.0/freq;
 		power[k] *= powfactor;
-		fprintf (GMT_stdout, format, freq, power[k], eps_pow * power[k]);
+		sprintf (buffer, format, freq, power[k], eps_pow * power[k]);
+		GMT_fputs (buffer, GMT_stdout);
 	}
 }
 
