@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: grdfilter.c,v 1.76 2010/01/05 01:15:46 guru Exp $
+ *	$Id: grdfilter.c,v 1.81 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -46,30 +46,30 @@
 
 struct GRDFILTER_CTRL {
 	struct D {	/* -D<distflag> */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG mode;
 	} D;
 	struct F {	/* <type>[-]<filter_width>[<mode>] */
-		BOOLEAN active;
-		BOOLEAN highpass;
+		GMT_LONG active;
+		GMT_LONG highpass;
 		char filter;	/* Character codes for the filter */
 		double width;
 		GMT_LONG mode;
 	} F;
 	struct G {	/* -G<file> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} G;
 	struct I {	/* -Idx[/dy] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double xinc, yinc;
 	} I;
 	struct N {	/* -Np|i|r */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG mode;	/* 0 is default (i), 1 is replace (r), 2 is preserve (p) */
 	} N;
 	struct T {	/* -T */
-		BOOLEAN active;
+		GMT_LONG active;
 	} T;
 };
 
@@ -111,9 +111,9 @@ int main (int argc, char **argv)
 	GMT_LONG *i_origin;
 
 
-	BOOLEAN	error, new_range, fast_way, slow = FALSE, same_grid = FALSE;
-	BOOLEAN wrap_case_x = FALSE, wrap_case_y = FALSE, pole_check = FALSE;
-	BOOLEAN full_360, full_180, duplicate_check, i_west_used, i_east_used, row_ok;
+	GMT_LONG	error, new_range, fast_way, slow = FALSE, same_grid = FALSE;
+	GMT_LONG wrap_case_x = FALSE, wrap_case_y = FALSE, pole_check = FALSE;
+	GMT_LONG full_360, full_180, duplicate_check, i_west_used, i_east_used, row_ok;
 
 	float	*input, *output;
 
@@ -140,7 +140,7 @@ int main (int argc, char **argv)
 	double SphericalRadius (double x0, double y0, double x1, double y1, double par[]);
 	void *New_grdfilter_Ctrl (), Free_grdfilter_Ctrl (struct GRDFILTER_CTRL *C);
 	
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct GRDFILTER_CTRL *)New_grdfilter_Ctrl ();	/* Allocate and initialize a new control structure */
 	
@@ -429,11 +429,15 @@ int main (int argc, char **argv)
 			x_scale = project_info.KM_PR_DEG * cosd (0.5 * (north_new + south_new));
 			y_scale = project_info.KM_PR_DEG;
 			F.radius_func = FlatEarthRadius;
+			if (full_360) wrap_case_x = TRUE;		/* For periodic boundaries */
+			if (full_180) wrap_case_y = wrap_case_x;	/* For spherical caps */
 			break;
 		case 3:	/* Flat Earth Cartesian distances, xscale reset for each latitude */
 			x_scale = project_info.KM_PR_DEG * ((fabs (south_new) > north_new) ? cosd (south_new) : cosd (north_new));
 			y_scale = project_info.KM_PR_DEG;
 			F.radius_func = FlatEarthRadius;
+			if (full_360) wrap_case_x = TRUE;		/* For periodic boundaries */
+			if (full_180) wrap_case_y = wrap_case_x;	/* For spherical caps */
 			break;
 		case 4:	/* Great circle distances */
 			x_scale = 0.0;
@@ -448,7 +452,7 @@ int main (int argc, char **argv)
 			merc_range = LAT2IMG (max_lat + (0.5 * Ctrl->F.width / project_info.KM_PR_DEG)) - LAT2IMG (max_lat);
 			x_scale = y_scale = 0.5 * Ctrl->F.width / merc_range;
 			F.radius_func = SphericalRadius;
-			if (full_360) wrap_case_x = TRUE;		/* For spherical filtering */
+			if (full_360) wrap_case_x = TRUE;		/* For spherical filtering; there is no polar caps in img files */
 			break;
 	}
 			
@@ -692,8 +696,8 @@ int main (int argc, char **argv)
 	if (n_nan && gmtdefs.verbose) fprintf (stderr, "%s: Unable to estimate value at %ld nodes, set to NaN\n", GMT_program, n_nan);
 	if (GMT_n_multiples > 0 && gmtdefs.verbose) fprintf (stderr, "%s: WARNING: %ld multiple modes found\n", GMT_program, GMT_n_multiples);
 
-	h.nx = nx_out;
-	h.ny = ny_out;
+	h.nx = (int)nx_out;
+	h.ny = (int)ny_out;
 	h.x_min = west_new;
 	h.x_max = east_new;
 	h.y_min = south_new;
