@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: grdgradient.c,v 1.51 2010/01/05 01:15:46 guru Exp $
+ *	$Id: grdgradient.c,v 1.57 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -49,38 +49,38 @@
 
 struct GRDGRADIENT_CTRL {
 	struct A {	/* -A<azim>[/<azim2>] */
-		BOOLEAN active;
-		BOOLEAN two;
+		GMT_LONG active;
+		GMT_LONG two;
 		double azimuth[2];
 	} A;
 	struct D {	/* -D[a][o][n] */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG mode;
 	} D;
 	struct E {	/* -E[s|p]<azim>/<elev[ambient/diffuse/specular/shine]> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double azimuth, elevation;
 		double ambient, diffuse, specular, shine;
 		GMT_LONG mode;
 	} E;
 	struct G {	/* -G<file> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} G;
 	struct L {	/* -L<flag> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char mode[4];
 	} L;
 	struct M {	/* -M */
-		BOOLEAN active;
+		GMT_LONG active;
 	} M;
 	struct N {	/* -N[t_or_e][<amp>[/<sigma>[/<offset>]]] */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG mode;
 		double norm, sigma, offset;
 	} N;
 	struct S {	/* -S<slopefile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} S;
 };
@@ -91,7 +91,7 @@ int main (int argc, char **argv)
 {
 	char	*infile = CNULL, format[BUFSIZ], ptr[BUFSIZ];
 	
-	BOOLEAN	error = FALSE, sigma_set = FALSE, offset_set = FALSE, bad;
+	GMT_LONG	error = FALSE, sigma_set = FALSE, offset_set = FALSE, bad;
 	
 	GMT_LONG pos, p[4], entry, mx, my;
 	
@@ -112,7 +112,7 @@ int main (int argc, char **argv)
 	double specular (double nx, double ny, double nz, double *s);
 	void *New_grdgradient_Ctrl (), Free_grdgradient_Ctrl (struct GRDGRADIENT_CTRL *C);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct GRDGRADIENT_CTRL *)New_grdgradient_Ctrl ();	/* Allocate and initialize a new control structure */
 	
@@ -155,7 +155,7 @@ int main (int argc, char **argv)
 								Ctrl->D.mode |= 4;
 								break;
 							default:
-								fprintf (stderr, "%s: GMT SYNTAX ERROR -S option:  Unrecognized modifier\n", GMT_program);
+								fprintf (stderr, "%s: GMT SYNTAX ERROR -D option:  Unrecognized modifier\n", GMT_program);
 								error++;
 								break;
 						}
@@ -304,7 +304,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -S option:  Must specify output file\n", GMT_program);
 		error++;
 	}
-	if (!Ctrl->G.file) {
+	if (!Ctrl->G.file && !Ctrl->S.active) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -G option:  Must specify output file\n", GMT_program);
 		error++;
 	}
@@ -590,7 +590,8 @@ int main (int argc, char **argv)
 
 	GMT_pad[0] = GMT_pad[1] = GMT_pad[2] = GMT_pad[3] = 0;	/* Because of the shift */
 
-	GMT_err_fail (GMT_write_grd (Ctrl->G.file, &header, data, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), Ctrl->G.file);
+	if (Ctrl->G.active)
+		GMT_err_fail (GMT_write_grd (Ctrl->G.file, &header, data, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), Ctrl->G.file);
 
 	GMT_free ((void *) data);
 
