@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: grdimage.c,v 1.109 2009/09/18 04:14:34 guru Exp $
+ *	$Id: grdimage.c,v 1.117 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -34,41 +34,41 @@
 
 struct GRDIMAGE_CTRL {
 	struct C {	/* -C<cptfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} C;
 #ifdef USE_GDAL
 	struct D {	/* -D to read gdal file */
-		BOOLEAN active;
-		BOOLEAN mode;	/* Use info of -R option to reference image */
+		GMT_LONG active;
+		GMT_LONG mode;	/* Use info of -R option to reference image */
 	} D;
 #endif
 	struct E {	/* -Ei|<dpi> */
-		BOOLEAN active;
-		BOOLEAN device_dpi;
+		GMT_LONG active;
+		GMT_LONG device_dpi;
 		GMT_LONG dpi;
 	} E;
 	struct G {	/* -G[f|b]<rgb> */
-		BOOLEAN active;
+		GMT_LONG active;
 		int f_rgb[3];
 		int b_rgb[3];
 	} G;
 	struct I {	/* -I<intensfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} I;
 	struct M {	/* -M */
-		BOOLEAN active;
+		GMT_LONG active;
 	} M;
 	struct N {	/* -N */
-		BOOLEAN active;
+		GMT_LONG active;
 	} N;
 	struct Q {	/* -Q */
-		BOOLEAN active;
+		GMT_LONG active;
 	} Q;
 	struct S {	/* -S[-]b|c|l|n[/<threshold>] */
-		BOOLEAN active;
-		BOOLEAN antialias;
+		GMT_LONG active;
+		GMT_LONG antialias;
 		GMT_LONG interpolant;
 		double threshold;
 	} S;
@@ -76,13 +76,13 @@ struct GRDIMAGE_CTRL {
 
 int main (int argc, char **argv)
 {
-	BOOLEAN error = FALSE, do_rgb = FALSE, done, need_to_project, normal_x, normal_y, resampled = FALSE;
+	GMT_LONG error = FALSE, do_rgb = FALSE, done, need_to_project, normal_x, normal_y, resampled = FALSE;
 
 	unsigned char *bitimage_8 = NULL, *bitimage_24 = NULL, *rgb_used = NULL;
 
 	char *grdfile[3], *c_method[2] = {"colorimage", "colortiles",};
 
-	GMT_LONG i, j, k, byte, nx_f, ny_f, nx, ny, nx_proj = 0, ny_proj = 0, index, grid_type = 0, n_grids = 0;
+	GMT_LONG i, j, k, byte, nx, ny, nx_proj = 0, ny_proj = 0, index, grid_type = 0, n_grids = 0;
 	GMT_LONG PS_colormask_off = 0, PS_colormask, PS_interpolate, nm, nm2 = 0, node, kk;
 	int rgb[3], try;
 	
@@ -96,18 +96,18 @@ int main (int argc, char **argv)
 	struct GRDIMAGE_CTRL *Ctrl;
 
 #ifdef USE_GDAL
-	BOOLEAN do_indexed = FALSE;
+	GMT_LONG do_indexed = FALSE;
 	unsigned char *r_table = NULL, *g_table = NULL, *b_table = NULL;
 	struct GDALREAD_CTRL *to_gdalread;
 	struct GD_CTRL *from_gdalread;
 #endif
 
 	void GMT_set_proj_limits (struct GRD_HEADER *r, struct GRD_HEADER *g);
-	void *New_Grdimage_Ctrl (), Free_Grdimage_Ctrl (struct GRDIMAGE_CTRL *C);
+	void *New_grdimage_Ctrl (), Free_grdimage_Ctrl (struct GRDIMAGE_CTRL *C);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
-	Ctrl = (struct GRDIMAGE_CTRL *)New_Grdimage_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct GRDIMAGE_CTRL *)New_grdimage_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	grdfile[0] = grdfile[1] = grdfile[2] = CNULL;
 	west = east = south = north = 0.0;
@@ -354,8 +354,8 @@ int main (int argc, char **argv)
 		}
 
 		/* Allocate new control structures */
-		to_gdalread = (struct GDALREAD_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GDALREAD_CTRL), "New_Gdalread_Ctrl");
-		from_gdalread = (struct GD_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GD_CTRL), "New_Gd_Ctrl");
+		to_gdalread = (struct GDALREAD_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GDALREAD_CTRL), "New_gdalread_Ctrl");
+		from_gdalread = (struct GD_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GD_CTRL), "New_gd_Ctrl");
 		to_gdalread->F.active = 1;
 
 		if (project_info.region_supplied && !Ctrl->D.mode) {
@@ -491,14 +491,11 @@ int main (int argc, char **argv)
 		GMT_plotinit (argc, argv);
 		GMT_map_basemap ();
 		GMT_plotend ();
-		Free_Grdimage_Ctrl (Ctrl);	/* Deallocate control structure */
+		Free_grdimage_Ctrl (Ctrl);	/* Deallocate control structure */
 		GMT_end (argc, argv);
 		exit (EXIT_SUCCESS);
 	}
 
-	nx_f = g_head[0].nx;
-	ny_f = g_head[0].ny;
-
 	nx = GMT_get_n (data_west, data_east, g_head[0].x_inc, g_head[0].node_offset);
 	ny = GMT_get_n (data_south, data_north, g_head[0].y_inc, g_head[0].node_offset);
 
@@ -554,13 +551,13 @@ int main (int argc, char **argv)
 
 		GMT_err_fail (GMT_read_grd_info (Ctrl->I.file, &i_head), Ctrl->I.file);
 
-		if (i_head.nx != nx_f || i_head.ny != ny_f) {
-			fprintf (stderr, "%s: Intensity file has improper dimensions!\n", GMT_program);
-			exit (EXIT_FAILURE);
-		}
 		tmp2 = (float *) GMT_memory (VNULL, (size_t)nm, sizeof (float), GMT_program);
 
 		GMT_err_fail (GMT_read_grd (Ctrl->I.file, &i_head, tmp2, data_west, data_east, data_south, data_north, GMT_pad, FALSE), Ctrl->I.file);
+		if (i_head.nx != g_head[0].nx || i_head.ny != g_head[0].ny) {
+			fprintf (stderr, "%s: Intensity file has improper dimensions!\n", GMT_program);
+			exit (EXIT_FAILURE);
+		}
 	}
 
 	for (i = 0; i < n_grids; i++) GMT_set_proj_limits (&r_head[i], &g_head[i]);
@@ -787,7 +784,7 @@ int main (int argc, char **argv)
 
 	GMT_plotend ();
 
-	Free_Grdimage_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_grdimage_Ctrl (Ctrl);	/* Deallocate control structure */
 
 #ifdef USE_GDAL
 	if (Ctrl->D.active) {
@@ -817,7 +814,7 @@ void GMT_set_proj_limits (struct GRD_HEADER *r, struct GRD_HEADER *g)
 	 * if GMT_grdproject_init is called at a later stage */
 
 	GMT_LONG i, j;
-	BOOLEAN all_lats = FALSE, all_lons = FALSE;
+	GMT_LONG all_lats = FALSE, all_lons = FALSE;
 	double lon, lat, x, y;
 
 	r->nx = g->nx;
@@ -871,10 +868,10 @@ void GMT_set_proj_limits (struct GRD_HEADER *r, struct GRD_HEADER *g)
 	}
 }
 
-void *New_Grdimage_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_grdimage_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GRDIMAGE_CTRL *C;
 
-	C = (struct GRDIMAGE_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDIMAGE_CTRL), "New_Grdimage_Ctrl");
+	C = (struct GRDIMAGE_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDIMAGE_CTRL), "New_grdimage_Ctrl");
 
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 
@@ -885,7 +882,7 @@ void *New_Grdimage_Ctrl () {	/* Allocate and initialize a new control structure
 	return ((void *)C);
 }
 
-void Free_Grdimage_Ctrl (struct GRDIMAGE_CTRL *C) {	/* Deallocate control structure */
+void Free_grdimage_Ctrl (struct GRDIMAGE_CTRL *C) {	/* Deallocate control structure */
 	if (C->C.file) free ((void *)C->C.file);
 	if (C->I.file) free ((void *)C->I.file);
 	GMT_free ((void *)C);
