@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: grdinfo.c,v 1.64 2010/01/05 01:15:46 guru Exp $
+ *	$Id: grdinfo.c,v 1.71 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -30,32 +30,32 @@
 
 struct GRDINFO_CTRL {
 	struct C {	/* -C */
-		BOOLEAN active;
+		GMT_LONG active;
 	} C;
 	struct F {	/* -F */
-		BOOLEAN active;
+		GMT_LONG active;
 	} F;
 	struct I {	/* -Idx[/dy] */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG status;
 		double xinc, yinc;
 	} I;
 	struct M {	/* -M */
-		BOOLEAN active;
+		GMT_LONG active;
 	} M;
 	struct L {	/* -L[1|2] */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG norm;
 	} L;
 	struct T {	/* -T<dz> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double inc;
 	} T;
 };
 
 int main (int argc, char **argv)
 {
-	BOOLEAN error = FALSE, slow = FALSE;
+	GMT_LONG error = FALSE, slow = FALSE;
 
 	GMT_LONG nfiles = 0, k, i, n_grds = 0, col, row;
 	GMT_LONG nm = 0, n_nan = 0, n = 0, ij, ij_min, ij_max;
@@ -66,7 +66,7 @@ int main (int argc, char **argv)
 	double global_xmin, global_xmax, global_ymin, global_ymax, global_zmin, global_zmax;
 	double mean = 0.0, median = 0.0, sum2 = 0.0, stdev = 0.0, scale = 0.0, rms = 0.0, x;
 
-	char format[BUFSIZ], text[GMT_TEXT_LEN];
+	char format[BUFSIZ], text[GMT_TEXT_LEN], buffer[BUFSIZ];
 	char *type[2] = { "Gridline", "Pixel"};
 
 	struct GRD_HEADER grd;
@@ -74,7 +74,7 @@ int main (int argc, char **argv)
 
 	void *New_grdinfo_Ctrl (), Free_grdinfo_Ctrl (struct GRDINFO_CTRL *C);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct GRDINFO_CTRL *)New_grdinfo_Ctrl ();	/* Allocate and initialize a new control structure */
 
@@ -262,154 +262,152 @@ int main (int argc, char **argv)
 		/* OK, time to report results */
 
 		if (Ctrl->I.active && Ctrl->I.status == 1) {
-			fprintf (GMT_stdout, "-R");
-			GMT_ascii_output_one (GMT_stdout, grd.x_min, 0);	fprintf (GMT_stdout, "/");	GMT_ascii_output_one (GMT_stdout, grd.x_max, 0);	fprintf (GMT_stdout, "/");
-			GMT_ascii_output_one (GMT_stdout, grd.y_min, 1);	fprintf (GMT_stdout, "/");	GMT_ascii_output_one (GMT_stdout, grd.y_max, 1);	fprintf (GMT_stdout, "\n");
+			GMT_fputs ("-R", GMT_stdout);
+			GMT_ascii_output_one (GMT_stdout, grd.x_min, 0);	GMT_fputs ("/", GMT_stdout);
+			GMT_ascii_output_one (GMT_stdout, grd.x_max, 0);	GMT_fputs ("/", GMT_stdout);
+			GMT_ascii_output_one (GMT_stdout, grd.y_min, 1);	GMT_fputs ("/", GMT_stdout);
+			GMT_ascii_output_one (GMT_stdout, grd.y_max, 1);	GMT_fputs ("\n", GMT_stdout);
 		} else if (Ctrl->I.active && Ctrl->I.status == 0) {
-			fprintf (GMT_stdout, "-I");
-			GMT_ascii_output_one (GMT_stdout, grd.x_inc, 2);	fprintf (GMT_stdout, "/");
+			GMT_fputs ("-I", GMT_stdout);
+			GMT_ascii_output_one (GMT_stdout, grd.x_inc, 2);	GMT_fputs ("/", GMT_stdout);
 			GMT_ascii_output_one (GMT_stdout, grd.y_inc, 2);
-			fprintf (GMT_stdout, "\n");
+			GMT_fputs ("\n", GMT_stdout);
 		} else if (Ctrl->C.active && !Ctrl->I.active) {
-			fprintf (GMT_stdout, "%s\t", grd.name);
-			GMT_ascii_output_one (GMT_stdout, grd.x_min, 0);	fprintf (GMT_stdout, "\t");	GMT_ascii_output_one (GMT_stdout, grd.x_max, 0);	fprintf (GMT_stdout, "\t");
-			GMT_ascii_output_one (GMT_stdout, grd.y_min, 1);	fprintf (GMT_stdout, "\t");	GMT_ascii_output_one (GMT_stdout, grd.y_max, 1);	fprintf (GMT_stdout, "\t");
-			GMT_ascii_output_one (GMT_stdout, grd.z_min, 2);	fprintf (GMT_stdout, "\t");	GMT_ascii_output_one (GMT_stdout, grd.z_max, 2);	fprintf (GMT_stdout, "\t");
+			sprintf (buffer, "%s\t", grd.name);			GMT_fputs (buffer, GMT_stdout);
+			GMT_ascii_output_one (GMT_stdout, grd.x_min, 0);	GMT_fputs ("\t", GMT_stdout);
+			GMT_ascii_output_one (GMT_stdout, grd.x_max, 0);	GMT_fputs ("\t", GMT_stdout);
+			GMT_ascii_output_one (GMT_stdout, grd.y_min, 1);	GMT_fputs ("\t", GMT_stdout);
+			GMT_ascii_output_one (GMT_stdout, grd.y_max, 1);	GMT_fputs ("\t", GMT_stdout);
+			GMT_ascii_output_one (GMT_stdout, grd.z_min, 2);	GMT_fputs ("\t", GMT_stdout);
+			GMT_ascii_output_one (GMT_stdout, grd.z_max, 2);	GMT_fputs ("\t", GMT_stdout);
 			GMT_ascii_format_one (text, grd.x_inc, GMT_io.out_col_type[0]);
 			if (isalpha ((int)text[strlen(text)-1])) text[strlen(text)-1] = '\0';	/* Chop of trailing WESN flag here */
-			fprintf (GMT_stdout, "%s\t", text);
+			GMT_fputs (text, GMT_stdout);	GMT_fputs ("\t", GMT_stdout);
 			GMT_ascii_format_one (text, grd.y_inc, GMT_io.out_col_type[1]);
 			if (isalpha ((int)text[strlen(text)-1])) text[strlen(text)-1] = '\0';	/* Chop of trailing WESN flag here */
-			fprintf (GMT_stdout, "%s\t", text);
-			GMT_ascii_output_one (GMT_stdout, (double)grd.nx, 2);	fprintf (GMT_stdout, "\t");	GMT_ascii_output_one (GMT_stdout, (double)grd.ny, 2);
+			GMT_fputs (text, GMT_stdout);	GMT_fputs ("\t", GMT_stdout);
+			GMT_ascii_output_one (GMT_stdout, (double)grd.nx, 2);	GMT_fputs ("\t", GMT_stdout);	GMT_ascii_output_one (GMT_stdout, (double)grd.ny, 2);
 
 			if (Ctrl->M.active) {
-				fprintf (GMT_stdout, "\t");	GMT_ascii_output_one (GMT_stdout, x_min, 0);
-				fprintf (GMT_stdout, "\t");	GMT_ascii_output_one (GMT_stdout, y_min, 1);
-				fprintf (GMT_stdout, "\t");	GMT_ascii_output_one (GMT_stdout, x_max, 0);
-				fprintf (GMT_stdout, "\t");	GMT_ascii_output_one (GMT_stdout, y_max, 1);
+				GMT_fputs ("\t", GMT_stdout);	GMT_ascii_output_one (GMT_stdout, x_min, 0);
+				GMT_fputs ("\t", GMT_stdout);	GMT_ascii_output_one (GMT_stdout, y_min, 1);
+				GMT_fputs ("\t", GMT_stdout);	GMT_ascii_output_one (GMT_stdout, x_max, 0);
+				GMT_fputs ("\t", GMT_stdout);	GMT_ascii_output_one (GMT_stdout, y_max, 1);
 			}
 			if (Ctrl->L.norm & 1) {
-				fprintf (GMT_stdout, "\t");	GMT_ascii_output_one (GMT_stdout, median, 2);
-				fprintf (GMT_stdout, "\t");	GMT_ascii_output_one (GMT_stdout, scale, 2);
+				GMT_fputs ("\t", GMT_stdout);	GMT_ascii_output_one (GMT_stdout, median, 2);
+				GMT_fputs ("\t", GMT_stdout);	GMT_ascii_output_one (GMT_stdout, scale, 2);
 			}
 			if (Ctrl->L.norm & 2) {
-				fprintf (GMT_stdout, "\t");	GMT_ascii_output_one (GMT_stdout, mean, 2);
-				fprintf (GMT_stdout, "\t");	GMT_ascii_output_one (GMT_stdout, stdev, 2);
-				fprintf (GMT_stdout, "\t");	GMT_ascii_output_one (GMT_stdout, rms, 2);
+				GMT_fputs ("\t", GMT_stdout);	GMT_ascii_output_one (GMT_stdout, mean, 2);
+				GMT_fputs ("\t", GMT_stdout);	GMT_ascii_output_one (GMT_stdout, stdev, 2);
+				GMT_fputs ("\t", GMT_stdout);	GMT_ascii_output_one (GMT_stdout, rms, 2);
 			}
-			if (Ctrl->M.active) {
-				fprintf (GMT_stdout, "\t");
-				PRINT_SIZE_T (GMT_stdout, n_nan);
-			}
-			fprintf (GMT_stdout, "\n");
+			if (Ctrl->M.active) {sprintf (buffer, "\t%d", (int)n_nan);	GMT_fputs(buffer, GMT_stdout);}
+			GMT_fputs ("\n", GMT_stdout);
 		}
 		else if (!(Ctrl->T.active || (Ctrl->I.active && Ctrl->I.status == 2))) {
-			fprintf (GMT_stdout, "%s: Title: %s\n", grd.name, grd.title);
-			fprintf (GMT_stdout, "%s: Command: %s\n", grd.name, grd.command);
-			fprintf (GMT_stdout, "%s: Remark: %s\n", grd.name, grd.remark);
+			sprintf (buffer, "%s: Title: %s\n", grd.name, grd.title);	GMT_fputs(buffer, GMT_stdout);
+			sprintf (buffer, "%s: Command: %s\n", grd.name, grd.command);	GMT_fputs(buffer, GMT_stdout);
+			sprintf (buffer, "%s: Remark: %s\n", grd.name, grd.remark);	GMT_fputs(buffer, GMT_stdout);
 			if (grd.node_offset == 0 || grd.node_offset == 1)
-				fprintf (GMT_stdout, "%s: %s node registration used\n", grd.name, type[grd.node_offset]);
+				{sprintf (buffer, "%s: %s node registration used\n", grd.name, type[grd.node_offset]);	GMT_fputs(buffer, GMT_stdout);}
 			else
-				fprintf (GMT_stdout, "%s: Unknown registration! Probably not a GMT grid\n", grd.name);
+				{sprintf (buffer, "%s: Unknown registration! Probably not a GMT grid\n", grd.name);	GMT_fputs(buffer, GMT_stdout);}
 			if (grd.type >= 0 && grd.type < N_GRD_TYPES)
-				fprintf (GMT_stdout, "%s: Grid file format: %c%c (# %ld) %s\n", grd.name, (int)GMT_grdformats[grd.type][0], (int)GMT_grdformats[grd.type][1], grd.type, GMT_grd_type[grd.type-1]);
+				{sprintf (buffer, "%s: Grid file format: %c%c (# %ld) %s\n", grd.name, (int)GMT_grdformats[grd.type][0], (int)GMT_grdformats[grd.type][1], grd.type, GMT_grd_type[grd.type-1]);	GMT_fputs(buffer, GMT_stdout);}
 			else
-				fprintf (GMT_stdout, "%s: Unrecognized grid file format! Probably not a GMT grid\n", grd.name);
+				{sprintf (buffer, "%s: Unrecognized grid file format! Probably not a GMT grid\n", grd.name);	GMT_fputs(buffer, GMT_stdout);}
 			if (Ctrl->F.active) {
 				if ((fabs (grd.x_min) < 500.0) && (fabs (grd.x_max) < 500.0) && (fabs (grd.y_min) < 500.0) && (fabs (grd.y_max) < 500.0)) {
-					fprintf (GMT_stdout, "%s: x_min: %.7f\n", grd.name, grd.x_min);
-					fprintf (GMT_stdout, "%s: x_max: %.7f\n", grd.name, grd.x_max);
-					fprintf (GMT_stdout, "%s: x_inc: %.7f\n", grd.name, grd.x_inc);
-					fprintf (GMT_stdout, "%s: name: %s\n", grd.name, grd.x_units);
-					fprintf (GMT_stdout, "%s: nx: %d\n", grd.name, grd.nx);
-					fprintf (GMT_stdout, "%s: y_min: %.7f\n", grd.name, grd.y_min);
-					fprintf (GMT_stdout, "%s: y_max: %.7f\n", grd.name, grd.y_max);
-					fprintf (GMT_stdout, "%s: y_inc: %.7f\n", grd.name, grd.y_inc);
-					fprintf (GMT_stdout, "%s: name: %s\n", grd.name, grd.y_units);
-					fprintf (GMT_stdout, "%s: ny: %d\n", grd.name, grd.ny);
+					sprintf (buffer, "%s: x_min: %.7f\n", grd.name, grd.x_min);	GMT_fputs(buffer, GMT_stdout);
+					sprintf (buffer, "%s: x_max: %.7f\n", grd.name, grd.x_max);	GMT_fputs(buffer, GMT_stdout);
+					sprintf (buffer, "%s: x_inc: %.7f\n", grd.name, grd.x_inc);	GMT_fputs(buffer, GMT_stdout);
+					sprintf (buffer, "%s: name: %s\n", grd.name, grd.x_units);	GMT_fputs(buffer, GMT_stdout);
+					sprintf (buffer, "%s: nx: %d\n", grd.name, grd.nx);		GMT_fputs(buffer, GMT_stdout);
+					sprintf (buffer, "%s: y_min: %.7f\n", grd.name, grd.y_min);	GMT_fputs(buffer, GMT_stdout);
+					sprintf (buffer, "%s: y_max: %.7f\n", grd.name, grd.y_max);	GMT_fputs(buffer, GMT_stdout);
+					sprintf (buffer, "%s: y_inc: %.7f\n", grd.name, grd.y_inc);	GMT_fputs(buffer, GMT_stdout);
+					sprintf (buffer, "%s: name: %s\n", grd.name, grd.y_units);	GMT_fputs(buffer, GMT_stdout);
+					sprintf (buffer, "%s: ny: %d\n", grd.name, grd.ny);		GMT_fputs(buffer, GMT_stdout);
 				}
 				else {
-					fprintf (GMT_stdout, "%s: x_min: %.2f\n", grd.name, grd.x_min);
-					fprintf (GMT_stdout, "%s: x_max: %.2f\n", grd.name, grd.x_max);
-					fprintf (GMT_stdout, "%s: x_inc: %.2f\n", grd.name, grd.x_inc);
-					fprintf (GMT_stdout, "%s: name: %s\n", grd.name, grd.x_units);
-					fprintf (GMT_stdout, "%s: nx: %d\n", grd.name, grd.nx);
-					fprintf (GMT_stdout, "%s: y_min: %.2f\n", grd.name, grd.y_min);
-					fprintf (GMT_stdout, "%s: y_max: %.2f\n", grd.name, grd.y_max);
-					fprintf (GMT_stdout, "%s: y_inc: %.2f\n", grd.name, grd.y_inc);
-					fprintf (GMT_stdout, "%s: name: %s\n", grd.name, grd.y_units);
-					fprintf (GMT_stdout, "%s: ny: %d\n", grd.name, grd.ny);
+					sprintf (buffer, "%s: x_min: %.2f\n", grd.name, grd.x_min);	GMT_fputs(buffer, GMT_stdout);
+					sprintf (buffer, "%s: x_max: %.2f\n", grd.name, grd.x_max);	GMT_fputs(buffer, GMT_stdout);
+					sprintf (buffer, "%s: x_inc: %.2f\n", grd.name, grd.x_inc);	GMT_fputs(buffer, GMT_stdout);
+					sprintf (buffer, "%s: name: %s\n", grd.name, grd.x_units);	GMT_fputs(buffer, GMT_stdout);
+					sprintf (buffer, "%s: nx: %d\n", grd.name, grd.nx);		GMT_fputs(buffer, GMT_stdout);
+					sprintf (buffer, "%s: y_min: %.2f\n", grd.name, grd.y_min);	GMT_fputs(buffer, GMT_stdout);
+					sprintf (buffer, "%s: y_max: %.2f\n", grd.name, grd.y_max);	GMT_fputs(buffer, GMT_stdout);
+					sprintf (buffer, "%s: y_inc: %.2f\n", grd.name, grd.y_inc);	GMT_fputs(buffer, GMT_stdout);
+					sprintf (buffer, "%s: name: %s\n", grd.name, grd.y_units);	GMT_fputs(buffer, GMT_stdout);
+					sprintf (buffer, "%s: ny: %d\n", grd.name, grd.ny);		GMT_fputs(buffer, GMT_stdout);
 				}
 			}
 			else {
 				GMT_ascii_format_one (text, grd.x_inc, GMT_io.out_col_type[0]);
 				if (isalpha ((int)text[strlen(text)-1])) text[strlen(text)-1] = '\0';	/* Chop of trailing WESN flag here */
-				fprintf (GMT_stdout, "%s: x_min: ", grd.name);
+				sprintf (buffer, "%s: x_min: ", grd.name);			GMT_fputs(buffer, GMT_stdout);
 				GMT_ascii_output_one (GMT_stdout, grd.x_min, 0);
-				fprintf (GMT_stdout, " x_max: ");
+				GMT_fputs (" x_max: ", GMT_stdout);
 				GMT_ascii_output_one (GMT_stdout, grd.x_max, 0);
-				fprintf (GMT_stdout, " x_inc: %s", text);
-				fprintf (GMT_stdout, " name: %s nx: %d\n", grd.x_units, grd.nx);
-				fprintf (GMT_stdout, "%s: y_min: ", grd.name);
+				sprintf (buffer, " x_inc: %s", text);				GMT_fputs(buffer, GMT_stdout);
+				sprintf (buffer, " name: %s nx: %d\n", grd.x_units, grd.nx);	GMT_fputs(buffer, GMT_stdout);
+				sprintf (buffer, "%s: y_min: ", grd.name);			GMT_fputs(buffer, GMT_stdout);
 				GMT_ascii_output_one (GMT_stdout, grd.y_min, 1);
-				fprintf (GMT_stdout, " y_max: ");
+				GMT_fputs (" y_max: ", GMT_stdout);
 				GMT_ascii_output_one (GMT_stdout, grd.y_max, 1);
 				GMT_ascii_format_one (text, grd.y_inc, GMT_io.out_col_type[1]);
 				if (isalpha ((int)text[strlen(text)-1])) text[strlen(text)-1] = '\0';	/* Chop of trailing WESN flag here */
-				fprintf (GMT_stdout, " y_inc: %s", text);
-				fprintf (GMT_stdout, " name: %s ny: %d\n", grd.y_units, grd.ny);
+				sprintf (buffer, " y_inc: %s", text);				GMT_fputs(buffer, GMT_stdout);
+				sprintf (buffer, " name: %s ny: %d\n", grd.y_units, grd.ny);	GMT_fputs(buffer, GMT_stdout);
 			}
 
 			if (Ctrl->M.active) {
 				if (z_min == -DBL_MAX) z_min = GMT_d_NaN;
 				if (z_max == +DBL_MAX) z_max = GMT_d_NaN;
-				fprintf (GMT_stdout, "%s: z_min: ", grd.name);
+				sprintf (buffer, "%s: z_min: ", grd.name);	GMT_fputs(buffer, GMT_stdout);
 				GMT_ascii_output_one (GMT_stdout, z_min, 2);
-				fprintf (GMT_stdout, " at x = ");
+				GMT_fputs (" at x = ", GMT_stdout);
 				GMT_ascii_output_one (GMT_stdout, x_min, 0);
-				fprintf (GMT_stdout, " y = ");
+				GMT_fputs (" y = ", GMT_stdout);
 				GMT_ascii_output_one (GMT_stdout, y_min, 1);
-				fprintf (GMT_stdout, " z_max: ");
+				GMT_fputs (" z_max: ", GMT_stdout);
 				GMT_ascii_output_one (GMT_stdout, z_max, 2);
-				fprintf (GMT_stdout, " at x = ");
+				GMT_fputs (" at x = ", GMT_stdout);
 				GMT_ascii_output_one (GMT_stdout, x_max, 0);
-				fprintf (GMT_stdout, " y = ");
+				GMT_fputs (" y = ", GMT_stdout);
 				GMT_ascii_output_one (GMT_stdout, y_max, 1);
-				fprintf (GMT_stdout, "\n");
+				GMT_fputs ("\n", GMT_stdout);
 			}
 			else if (Ctrl->F.active) {
-				fprintf (GMT_stdout, "%s: zmin: %g\n", grd.name, grd.z_min);
-				fprintf (GMT_stdout, "%s: zmax: %g\n", grd.name, grd.z_max);
-			 	fprintf (GMT_stdout, "%s: name: %s\n", grd.name, grd.z_units);
+				sprintf (buffer, "%s: zmin: %g\n", grd.name, grd.z_min);	GMT_fputs(buffer, GMT_stdout);
+				sprintf (buffer, "%s: zmax: %g\n", grd.name, grd.z_max);	GMT_fputs(buffer, GMT_stdout);
+			 	sprintf (buffer, "%s: name: %s\n", grd.name, grd.z_units);	GMT_fputs(buffer, GMT_stdout);
 			}
 			else {
-				fprintf (GMT_stdout, "%s: z_min: ", grd.name);
+				sprintf (buffer, "%s: z_min: ", grd.name);	GMT_fputs(buffer, GMT_stdout);
 				GMT_ascii_output_one (GMT_stdout, grd.z_min, 2);
-				fprintf (GMT_stdout, " z_max: ");
+				GMT_fputs (" z_max: ", GMT_stdout);
 				GMT_ascii_output_one (GMT_stdout, grd.z_max, 2);
-				fprintf (GMT_stdout, " name: %s\n", grd.z_units);
+				sprintf (buffer, " name: %s\n", grd.z_units);	GMT_fputs(buffer, GMT_stdout);
 			}
 
 			GMT_ascii_format_one (text, grd.z_add_offset, GMT_io.out_col_type[2]);
 			if (isalpha ((int)text[strlen(text)-1])) text[strlen(text)-1] = '\0';	/* Chop of trailing WESN flag here */
 			sprintf (format, "%s: scale_factor: %s add_offset: %%s\n", grd.name, gmtdefs.d_format);
-			fprintf (GMT_stdout, format, grd.z_scale_factor, text);
-			if (n_nan) {
-				fprintf (GMT_stdout, "%s: ", grd.name);
-				PRINT_SIZE_T (GMT_stdout, n_nan);
-				fprintf (GMT_stdout, " nodes set to NaN\n");
-			}
+			sprintf (buffer, format, grd.z_scale_factor, text);	GMT_fputs(buffer, GMT_stdout);
+			if (n_nan) fprintf (stdout, "%s: %ld nodes set to NaN\n", grd.name, n_nan);
 			if (Ctrl->L.norm & 1) {
-				fprintf (GMT_stdout, "%s: median: ", grd.name);	GMT_ascii_output_one (GMT_stdout, median, 2);
-				fprintf (GMT_stdout, " scale: ");		GMT_ascii_output_one (GMT_stdout, scale, 2);
-				fprintf (GMT_stdout, "\n");
+				sprintf (buffer, "%s: median: ", grd.name);	GMT_fputs(buffer, GMT_stdout);	GMT_ascii_output_one (GMT_stdout, median, 2);
+				GMT_fputs (" scale: ", GMT_stdout);		GMT_ascii_output_one (GMT_stdout, scale, 2);
+				GMT_fputs ("\n", GMT_stdout);
 			}
 			if (Ctrl->L.norm & 2) {
-				fprintf (GMT_stdout, "%s: mean: ", grd.name);	GMT_ascii_output_one (GMT_stdout, mean, 2);
-				fprintf (GMT_stdout, " stdev: ");		GMT_ascii_output_one (GMT_stdout, stdev, 2);
-				fprintf (GMT_stdout, " rms: ");			GMT_ascii_output_one (GMT_stdout, rms, 2);
-				fprintf (GMT_stdout, "\n");
+				sprintf (buffer, "%s: mean: ", grd.name);	GMT_fputs(buffer, GMT_stdout);	GMT_ascii_output_one (GMT_stdout, mean, 2);
+				GMT_fputs (" stdev: ", GMT_stdout);		GMT_ascii_output_one (GMT_stdout, stdev, 2);
+				GMT_fputs (" rms: ", GMT_stdout);		GMT_ascii_output_one (GMT_stdout, rms, 2);
+				GMT_fputs ("\n", GMT_stdout);
 			}
 		}
 		else {
@@ -430,35 +428,35 @@ int main (int argc, char **argv)
 		global_xmax = ceil  (global_xmax / Ctrl->I.xinc) * Ctrl->I.xinc;
 		global_ymin = floor (global_ymin / Ctrl->I.yinc) * Ctrl->I.yinc;
 		global_ymax = ceil  (global_ymax / Ctrl->I.yinc) * Ctrl->I.yinc;
-		fprintf (GMT_stdout, "%ld\t", n_grds);
-		GMT_ascii_output_one (GMT_stdout, global_xmin, 0);	fputc ('\t', GMT_stdout);
-		GMT_ascii_output_one (GMT_stdout, global_xmax, 0);	fputc ('\t', GMT_stdout);
-		GMT_ascii_output_one (GMT_stdout, global_ymin, 1);	fputc ('\t', GMT_stdout);
-		GMT_ascii_output_one (GMT_stdout, global_ymax, 1);	fputc ('\t', GMT_stdout);
-		GMT_ascii_output_one (GMT_stdout, global_zmin, 1);	fputc ('\t', GMT_stdout);
-		GMT_ascii_output_one (GMT_stdout, global_zmax, 1);	fputc ('\n', GMT_stdout);
+		sprintf (buffer, "%d\t", (int)n_grds);	GMT_fputs(buffer, GMT_stdout);
+		GMT_ascii_output_one (GMT_stdout, global_xmin, 0);	GMT_fputs ("\t", GMT_stdout);
+		GMT_ascii_output_one (GMT_stdout, global_xmax, 0);	GMT_fputs ("\t", GMT_stdout);
+		GMT_ascii_output_one (GMT_stdout, global_ymin, 1);	GMT_fputs ("\t", GMT_stdout);
+		GMT_ascii_output_one (GMT_stdout, global_ymax, 1);	GMT_fputs ("\t", GMT_stdout);
+		GMT_ascii_output_one (GMT_stdout, global_zmin, 1);	GMT_fputs ("\t", GMT_stdout);
+		GMT_ascii_output_one (GMT_stdout, global_zmax, 1);	GMT_fputs ("\n", GMT_stdout);
 	}
 	else if (Ctrl->T.active) {
 		global_zmin = floor (global_zmin / Ctrl->T.inc) * Ctrl->T.inc;
 		global_zmax = ceil  (global_zmax / Ctrl->T.inc) * Ctrl->T.inc;
-		fprintf (GMT_stdout, "-T");
+		GMT_fputs ("-T", GMT_stdout);
 		GMT_ascii_output_one (GMT_stdout, global_zmin, 2);
-		fprintf (GMT_stdout, "/");
+		GMT_fputs ("/", GMT_stdout);
 		GMT_ascii_output_one (GMT_stdout, global_zmax, 2);
-		fprintf (GMT_stdout, "/");
+		GMT_fputs ("/", GMT_stdout);
 		GMT_ascii_output_one (GMT_stdout, Ctrl->T.inc, 2);
-		fprintf (GMT_stdout, "\n");
+		GMT_fputs ("\n", GMT_stdout);
 	}
 	else if ((Ctrl->I.active && Ctrl->I.status == 2)) {
 		global_xmin = floor (global_xmin / Ctrl->I.xinc) * Ctrl->I.xinc;
 		global_xmax = ceil  (global_xmax / Ctrl->I.xinc) * Ctrl->I.xinc;
 		global_ymin = floor (global_ymin / Ctrl->I.yinc) * Ctrl->I.yinc;
 		global_ymax = ceil  (global_ymax / Ctrl->I.yinc) * Ctrl->I.yinc;
-		fprintf (GMT_stdout, "-R");
-		GMT_ascii_output_one (GMT_stdout, global_xmin, 0);	fputc ('/', GMT_stdout);
-		GMT_ascii_output_one (GMT_stdout, global_xmax, 0);	fputc ('/', GMT_stdout);
-		GMT_ascii_output_one (GMT_stdout, global_ymin, 1);	fputc ('/', GMT_stdout);
-		GMT_ascii_output_one (GMT_stdout, global_ymax, 1);	fputc ('\n', GMT_stdout);
+		GMT_fputs ("-R", GMT_stdout);
+		GMT_ascii_output_one (GMT_stdout, global_xmin, 0);	GMT_fputs ("/", GMT_stdout);
+		GMT_ascii_output_one (GMT_stdout, global_xmax, 0);	GMT_fputs ("/", GMT_stdout);
+		GMT_ascii_output_one (GMT_stdout, global_ymin, 1);	GMT_fputs ("/", GMT_stdout);
+		GMT_ascii_output_one (GMT_stdout, global_ymax, 1);	GMT_fputs ("\n", GMT_stdout);
 	}
 
 	GMT_free ((void *)a);
