@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: grdlandmask.c,v 1.56 2010/01/05 01:15:46 guru Exp $
+ *	$Id: grdlandmask.c,v 1.61 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -37,36 +37,36 @@
 struct GRDLANDMASK_CTRL {	/* All control options for this program (except common args) */
 	/* ctive is TRUE if the option has been activated */
 	struct A {	/* -A<min_area>[/<min_level>/<max_level>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		struct GMT_SHORE_SELECT info;
 	} A;
 	struct D {	/* -D<resolution> */
-		BOOLEAN active;
-		BOOLEAN force;	/* if TRUE, select next highest level if current set is not avaialble */
+		GMT_LONG active;
+		GMT_LONG force;	/* if TRUE, select next highest level if current set is not avaialble */
 		char set;	/* One of f, h, i, l, c */
 	} D;
 	struct F {	/* -F */
-		BOOLEAN active;
+		GMT_LONG active;
 	} F;
 	struct G {	/* -G<maskfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} G;
 	struct I {	/* -Idx[/dy] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double xinc, yinc;
 	} I;
 	struct N {	/* -N<maskvalues>[o] */
-		BOOLEAN active;
-		BOOLEAN edge;	/* TRUE if edges are considere outside */
+		GMT_LONG active;
+		GMT_LONG edge;	/* TRUE if edges are considere outside */
 		double mask[GRDLANDMASK_N_CLASSES];	/* values for each level */
 	} N;
 };
 
 int main (int argc, char **argv)
 {
-	BOOLEAN	error = FALSE, dry_wet_only = FALSE, greenwich = FALSE;
-	BOOLEAN temp_shift = FALSE, wrap, used_polygons;
+	GMT_LONG	error = FALSE, dry_wet_only = FALSE, greenwich = FALSE;
+	GMT_LONG temp_shift = FALSE, wrap, used_polygons;
 
 	char line[GMT_LONG_TEXT], ptr[BUFSIZ];
 	char *shore_resolution[5] = {"full", "high", "intermediate", "low", "crude"};
@@ -86,7 +86,7 @@ int main (int argc, char **argv)
 
 	void *New_grdlandmask_Ctrl (), Free_grdlandmask_Ctrl (struct GRDLANDMASK_CTRL *C);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct GRDLANDMASK_CTRL *) New_grdlandmask_Ctrl ();		/* Allocate and initialize defaults in a new control structure */
 
@@ -207,7 +207,7 @@ int main (int argc, char **argv)
 
 	header.x_inc = Ctrl->I.xinc;
 	header.y_inc = Ctrl->I.yinc;
-	header.node_offset = Ctrl->F.active;
+	header.node_offset = (int)Ctrl->F.active;
 	
 	GMT_RI_prepare (&header);	/* Ensure -R -I consistency and set nx, ny */
 
@@ -271,6 +271,7 @@ int main (int argc, char **argv)
 
 	GMT_parse_J_option ("x1d");	/* Fake linear projection */
 	GMT_err_fail (GMT_map_setup (header.x_min, header.x_max, header.y_min, header.y_max), "");
+	GMT_parallel_straight = GMT_meridian_straight = 2;	/* No resampling along bin boundaries */
 	wrap = GMT_360_RANGE (header.x_max, header.x_min);
 	
 	/* Fill out gridnode coordinates and apply the implicit linear projection */
@@ -351,9 +352,6 @@ int main (int argc, char **argv)
 			k = INT_MAX;	/* Initialize to outside range of levels (4 is highest) */
 			/* Visit each of the 4 nodes, test if it is inside -R, and if so update lowest level found so far */
 
-if (c.lon_sw == 179.0 && c.lat_sw == -80.0) {
-	k = INT_MAX;
-}
 			if (!GMT_map_outside (c.lon_sw, c.lat_sw)) k = MIN (k, c.node_level[0]);			/* SW */
 			if (!GMT_map_outside (c.lon_sw + c.bsize, c.lat_sw)) k = MIN (k, c.node_level[1]);		/* SE */
 			if (!GMT_map_outside (c.lon_sw + c.bsize, c.lat_sw - c.bsize)) k = MIN (k, c.node_level[2]);	/* NE */
