@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: grdmask.c,v 1.80 2010/01/05 01:15:46 guru Exp $
+ *	$Id: grdmask.c,v 1.89 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -42,27 +42,27 @@
 
 struct GRDMASK_CTRL {
 	struct A {	/* -A[m|p|step] */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG mode;
 		double step;
 	} A;
 	struct F {	/* -F */
-		BOOLEAN active;
+		GMT_LONG active;
 	} F;
 	struct G {	/* -G<maskfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} G;
 	struct I {	/* -Idx[/dy] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double xinc, yinc;
 	} I;
 	struct N {	/* -N<maskvalues> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double mask[GRDMASK_N_CLASSES];	/* values for each level */
 	} N;
 	struct S {	/* -S<radius>[m|c|k|K] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double radius;
 		char unit;
 	} S;
@@ -70,7 +70,7 @@ struct GRDMASK_CTRL {
 
 int main (int argc, char **argv)
 {
-	BOOLEAN	error = FALSE, done, nofile = TRUE, periodic = FALSE, resample = FALSE;
+	GMT_LONG	error = FALSE, done, nofile = TRUE, periodic = FALSE, resample = FALSE;
 
 	char line[BUFSIZ], ptr[BUFSIZ], *not_used = NULL;
 
@@ -81,7 +81,7 @@ int main (int argc, char **argv)
 
 	float *data;
 
-	double	*x, *y, xx, yy, xmin, xmax, ymin, ymax, lon_sum, lat_sum, dlon, step;
+	double	*x, *y, xx, yy, xmin, xmax, ymin, ymax, lon_sum, lat_sum, dlon;
 	double distance, shrink = 1.0, idx, idy, x0, y0, *in;
 	double xmin1, xmin2, xmax1, xmax2, lon_w;
 
@@ -93,7 +93,7 @@ int main (int argc, char **argv)
 	
 	void *New_grdmask_Ctrl (), Free_grdmask_Ctrl (struct GRDMASK_CTRL *C);
 	
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct GRDMASK_CTRL *)New_grdmask_Ctrl ();	/* Allocate and initialize a new control structure */
 
@@ -247,7 +247,7 @@ int main (int argc, char **argv)
 	if (Ctrl->S.unit == 'k') distance_flag = 1;
 	if (Ctrl->S.unit == 'K') distance_flag = 2;
 
-	header.node_offset = Ctrl->F.active;
+	header.node_offset = (int)Ctrl->F.active;
 	header.x_inc = Ctrl->I.xinc;
 	header.y_inc = Ctrl->I.yinc;
 	GMT_RI_prepare (&header);	/* Ensure -R -I consistency and set nx, ny */
@@ -283,9 +283,7 @@ int main (int argc, char **argv)
 		dj = (GMT_LONG)ceil (Ctrl->S.radius * idy);
 	}
 	periodic = (GMT_io.in_col_type[GMT_X] == GMT_IS_LON);	/* Dealing with geographic coordinates */
-	resample = (!Ctrl->A.active && periodic);
-	/* Maximum step size (in degrees) used for interpolation of line segments along great circles (when requested) */
-	step = Ctrl->A.step / project_info.x_scale / project_info.M_PR_DEG;
+	resample = ((!Ctrl->A.active || Ctrl->A.mode) && periodic);
 	if (distance_flag == 2 && !GMT_IS_SPHERICAL) distance_flag = 3;	/* Use geodesics */
 
 	switch (distance_flag) {	/* Take different action depending on how we want distances calculated */
@@ -321,6 +319,7 @@ int main (int argc, char **argv)
 
 	done = FALSE;
 	n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : 2;
+	GMT_io.skip_duplicates = TRUE;	/* The inonout algorithm assumes no duplicates */
 
 	for (fno = 1; !done && fno < n_args; fno++) {	/* Loop over all input files */
 		if (!nofile && argv[fno][0] == '-') continue;
@@ -355,9 +354,10 @@ int main (int argc, char **argv)
 			lon_sum = lat_sum = 0.0;
 
 			while (!(GMT_io.status & (GMT_IO_SEGMENT_HEADER | GMT_IO_EOF))) {	/* Keep going until FALSE  */
+				n_read++;
 				if (GMT_io.status & GMT_IO_MISMATCH) {
-					fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields,  n_expected_fields, n_read);
-					exit (EXIT_FAILURE);
+					fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld (skipped)\n", GMT_program, n_fields,  n_expected_fields, n_read);
+					continue;
 				}
 				x[n_path] = in[GMT_X];
 				y[n_path] = in[GMT_Y];
@@ -418,13 +418,8 @@ int main (int argc, char **argv)
 			if (Ctrl->S.active) {	/* Assign 'inside' to nodes within given distance of data constrains */
 				for (k = 0; k < n_path; k++) {
 
-					if (y[k] < header.y_min || y[k] > header.y_max) continue;
-					if (periodic) {	/* Make sure we are not off by 360 somewhere */
-						x[k] -= 360.0;
-						while (x[k] < header.x_min) x[k] += 360.0;
-						if (x[k] > header.x_max) continue;
-					}
-					else if (x[k] < header.x_min || x[k] > header.x_max) continue;
+					if (GMT_y_is_outside (y[k], header.y_min, header.y_max)) continue;	/* Outside y-range */
+					if (GMT_x_is_outside (&x[k], header.x_min, header.x_max)) continue;	/* Outside x-range (or longitude) */
 
 					/* OK, this point is within bounds, but may be exactly on the border */
 
@@ -449,7 +444,7 @@ int main (int argc, char **argv)
 					}
 				}
 			}
-			else {	/* assign 'inside' to nodes if they are inside given polygon */
+			else if (n_path) {	/* assign 'inside' to nodes if they are inside given polygon */
 				dlon = x[n_path-1] - x[0];
 				if (periodic && fabs(dlon) == 360.0) dlon = 0.0;
 				if (!(y[n_path-1] == y[0] && dlon == 0.0)) {	/* Explicitly close the polygon */
@@ -462,9 +457,12 @@ int main (int argc, char **argv)
 						lon_sum += dlon;
 					}
 				}
-
+				if (n_path < 3) {	/* Cannot be a polygon; skip */
+					if (gmtdefs.verbose) fprintf (stderr, "%s: Polygon %ld only had %ld points; skipped\r", GMT_program, n_pol, n_path);
+					continue;
+				}
 				if (resample) {
-					n_path = GMT_fix_up_path (&x, &y, n_path, step, Ctrl->A.mode);
+					n_path = GMT_fix_up_path (&x, &y, n_path, Ctrl->A.step, Ctrl->A.mode);
 					n_alloc = n_path;	/* Since it got reset */
 				}
 
@@ -526,6 +524,7 @@ int main (int argc, char **argv)
 
 		if (fp != GMT_stdin) GMT_fclose (fp);
 	}
+	GMT_io.skip_duplicates = FALSE;	/* Reset to FALSE */
 
 	GMT_err_fail (GMT_write_grd (Ctrl->G.file, &header, data, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), Ctrl->G.file);
 
@@ -549,7 +548,7 @@ void *New_grdmask_Ctrl () {	/* Allocate and initialize a new control structure *
 	C = (struct GRDMASK_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDMASK_CTRL), "New_grdmask_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
-	C->A.step = gmtdefs.line_step;
+	C->A.step = 0.1;	/* In degrees */
 	C->N.mask[GRDMASK_INSIDE] = 1.0;			/* Default inside value */
 	return ((void *)C);
 }
