@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: grdpaste.c,v 1.29 2010/01/05 01:15:46 guru Exp $
+ *	$Id: grdpaste.c,v 1.34 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -32,14 +32,14 @@
 
 struct GRDPASTE_CTRL {
 	struct G {	/* -G<output_grdfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} G;
 };
 
 int main (int argc, char **argv)
 {
-	BOOLEAN	error = FALSE;
+	GMT_LONG	error = FALSE;
 
 	char *grd_a, *grd_b, format[BUFSIZ];
 
@@ -49,14 +49,14 @@ int main (int argc, char **argv)
 
 	float	*c;
 
-	double x_noise, y_noise;
+	double x_noise, y_noise, w, e;
 
 	struct GRD_HEADER ha, hb, hc;
 	struct GRDPASTE_CTRL *Ctrl;
 
 	void *New_grdpaste_Ctrl (), Free_grdpaste_Ctrl (struct GRDPASTE_CTRL *C);
 	
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct GRDPASTE_CTRL *) New_grdpaste_Ctrl ();	/* Allocate and initialize a new control structure */
 
@@ -70,6 +70,7 @@ int main (int argc, char **argv)
 				/* Common parameters */
 
 				case 'V':
+				case 'f':
 				case '\0':
 					error += GMT_parse_common_options (argv[i], 0, 0, 0, 0);
 					break;
@@ -102,7 +103,7 @@ int main (int argc, char **argv)
 
 	if (GMT_give_synopsis_and_exit || argc == 1) {
 		fprintf (stderr,"grdpaste %s - Join two grid files along common edge\n\n", GMT_VERSION);
-		fprintf (stderr, "usage: grdpaste <file_a> <file_b> -G<outfile> [-V]\n\n");
+		fprintf (stderr, "usage: grdpaste <file_a> <file_b> -G<outfile> [-V] [%s]\n\n", GMT_f_OPT);
 
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
@@ -112,6 +113,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "	 Use grdcut and/or grdsample to adjust files as necessary.\n");
 		fprintf (stderr, "\n\tOPTIONS:\n");
 		GMT_explain_option ('V');
+		GMT_explain_option ('f');
 		exit (EXIT_FAILURE);
 	}
 
@@ -153,12 +155,21 @@ int main (int argc, char **argv)
 	x_noise = GMT_SMALL * hc.x_inc;
 	y_noise = GMT_SMALL * hc.y_inc;
 
+	w = hb.x_min;	e = hb.x_max;	/* Get copies */
+	if (GMT_io.in_col_type[GMT_IN] == GMT_IS_LON) {	/* Must be careful in determining a match */
+		w -= 360.0;	e -= 360.0;	/* Wind to left first */
+		while ((ha.x_min - w) > x_noise) {	/* Wind back to match grid A if possible */
+			w += 360.0;
+			e += 360.0;
+		}
+		hb.x_min = w;	hb.x_max = e;	/* Possibly update lon range */
+	}
 	if ( fabs (ha.x_min - hb.x_min) < x_noise && fabs (ha.x_max - hb.x_max) < x_noise ) {
 
 		if (fabs (ha.y_max - hb.y_min) < y_noise) {
 			way = 1;
 			hc.nx = ha.nx;
-			hc.ny = ha.ny + hb.ny - one_or_zero;
+			hc.ny = (int)(ha.ny + hb.ny - one_or_zero);
 			hc.x_min = ha.x_min;
 			hc.x_max = ha.x_max;
 			hc.y_min = ha.y_min;
@@ -167,7 +178,7 @@ int main (int argc, char **argv)
 		else if (fabs (ha.y_min - hb.y_max) < y_noise) {
 			way = 2;
 			hc.nx = ha.nx;
-			hc.ny = ha.ny + hb.ny - one_or_zero;
+			hc.ny = (int)(ha.ny + hb.ny - one_or_zero);
 			hc.x_min = ha.x_min;
 			hc.x_max = ha.x_max;
 			hc.y_min = hb.y_min;
@@ -182,7 +193,7 @@ int main (int argc, char **argv)
 
 		if (fabs (ha.x_min - hb.x_max) < x_noise) {
 			way = 3;
-			hc.nx = ha.nx + hb.nx - one_or_zero;
+			hc.nx = (int)(ha.nx + hb.nx - one_or_zero);
 			hc.ny = ha.ny;
 			hc.x_min = hb.x_min;
 			hc.x_max = ha.x_max;
@@ -191,7 +202,7 @@ int main (int argc, char **argv)
 		}
 		else if (fabs (ha.x_max - hb.x_min) < x_noise) {
 			way = 4;
-			hc.nx = ha.nx + hb.nx - one_or_zero;
+			hc.nx = (int)(ha.nx + hb.nx - one_or_zero);
 			hc.ny = ha.ny;
 			hc.x_min = ha.x_min;
 			hc.x_max = hb.x_max;
@@ -208,6 +219,10 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
+	if (GMT_io.in_col_type[GMT_IN] == GMT_IS_LON && hc.x_max > 360.0) {	/* Take out 360.0 */
+		hc.x_min -= 360.0;
+		hc.x_max -= 360.0;
+	}
 	/* Now we can do it  */
 
 	sprintf (format, "%%s: \t%s\t%s\t%s\t%s\t%s\t%s\t%%ld\t%%ld\n", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
@@ -252,6 +267,7 @@ int main (int argc, char **argv)
 	}
 
 	GMT_pad[0] = GMT_pad[1] = GMT_pad[2] = GMT_pad[3] = 0;
+	
 	GMT_err_fail (GMT_write_grd (Ctrl->G.file, &hc, c, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), Ctrl->G.file);
 
 	GMT_free ((void *) c);
