@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: grdproject.c,v 1.51 2010/01/05 01:15:46 guru Exp $
+ *	$Id: grdproject.c,v 1.60 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -31,42 +31,42 @@
 
 struct GRDPROJECT_CTRL {
 	struct A {	/* -A[k|m|n|i|c|p] */
-		BOOLEAN active;
+		GMT_LONG active;
 		char unit;
 	} A;
 	struct C {	/* -C[<dx/dy>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double easting, northing;
 	} C;
 	struct D {	/* -Ddx[/dy] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double xinc, yinc;
 	} D;
 	struct E {	/* -E<dpi> */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG dpi;
 	} E;
 	struct F {	/* -F */
-		BOOLEAN active;
+		GMT_LONG active;
 	} F;
 	struct G {	/* -G */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} G;
 	struct I {	/* -I */
-		BOOLEAN active;
+		GMT_LONG active;
 	} I;
 	struct M {	/* -Mc|i|m */
-		BOOLEAN active;
+		GMT_LONG active;
 		char unit;
 	} M;
 	struct N {	/* -N<nx/ny> */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG nx, ny;
 	} N;
 	struct S {	/* -S[-]b|c|l|n[/<threshold>] */
-		BOOLEAN active;
-		BOOLEAN antialias;
+		GMT_LONG active;
+		GMT_LONG antialias;
 		GMT_LONG interpolant;
 		double threshold;
 	} S;
@@ -74,7 +74,7 @@ struct GRDPROJECT_CTRL {
 
 int main (int argc, char **argv)
 {
-	BOOLEAN error = FALSE, set_n = FALSE, shift_xy = FALSE, offset;
+	GMT_LONG error = FALSE, set_n = FALSE, shift_xy = FALSE, offset;
 
 	char *infile, format[BUFSIZ], unit_name[GRD_UNIT_LEN], scale_unit_name[GRD_UNIT_LEN];
 
@@ -93,7 +93,7 @@ int main (int argc, char **argv)
 
 	void *New_grdproject_Ctrl (), Free_grdproject_Ctrl (struct GRDPROJECT_CTRL *C);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct GRDPROJECT_CTRL *)New_grdproject_Ctrl ();	/* Allocate and initialize a new control structure */
 	
@@ -153,7 +153,7 @@ int main (int argc, char **argv)
 					Ctrl->M.unit = argv[i][2];
 					break;
 				case 'N':
-					sscanf (&argv[i][2], "%ld/%ld", &Ctrl->N.nx, &Ctrl->N.ny);
+					sscanf (&argv[i][2], "%" GMT_LL "d/%" GMT_LL "d", &Ctrl->N.nx, &Ctrl->N.ny);
 					if (Ctrl->N.ny == 0) Ctrl->N.ny = Ctrl->N.nx;
 					Ctrl->N.active = TRUE;
 					break;
@@ -277,10 +277,20 @@ int main (int argc, char **argv)
 	unit = GMT_check_scalingopt ('A', Ctrl->A.unit, scale_unit_name);
 	GMT_init_scales (unit, &fwd_scale, &inv_scale, &inch_to_unit, &unit_to_inch, unit_name);
 
+	if (Ctrl->I.active) {	/* Must flip the column types since in is Cartesian and out is geographic */
+		GMT_io.out_col_type[0] = GMT_IS_LON;	GMT_io.out_col_type[1] = GMT_IS_LAT;	/* Inverse projection expects x,y and gives lon, lat */
+		GMT_io.in_col_type[0] = GMT_io.in_col_type[1] = GMT_IS_FLOAT;
+		project_info.degree[0] = project_info.degree[1] = FALSE;
+	}
+
 	if (!project_info.region_supplied) {
 		double ww, ee, ss, nn;
 		char opt_R[BUFSIZ];
 		struct GRD_HEADER head;
+		if (project_info.utm_hemisphere == 0) {
+			fprintf (stderr, "%s: GMT SYNTAX ERROR -J option: When -R is not provided you have to specify the hemisphere\n", GMT_program);
+			exit (EXIT_FAILURE);
+		}
 		GMT_err_fail (GMT_read_grd_info (infile, &head), infile);
 		w = head.x_min;		e = head.x_max;
 		s = head.y_min;		n = head.y_max;
@@ -293,20 +303,25 @@ int main (int argc, char **argv)
 			double x_c, y_c, lon_t, lat_t;
 			/* Obtain a first crude estimation of the good -R */
 			x_c = (w + e) / 2.; 		/* mid point of projected coords */
-			y_c = (s + n) / 2.; 
+			y_c = (s + n) / 2.;
+			if (project_info.projection == GMT_UTM && !project_info.north_pole && y_c > 0) y_c *= -1;
 			if (y_c > 0)
-				GMT_parse_common_options ("-R-180/180/0/80", &ww, &ee, &ss, &nn);
+				GMT_parse_R_option ("-R-180/180/0/80", &ww, &ee, &ss, &nn);
 			else
 				GMT_parse_R_option ("-R-180/180/-80/0", &ww, &ee, &ss, &nn);
+			if (project_info.projection == GMT_UTM && !project_info.north_pole && y_c < 0) y_c *= -1;	/* Undo the *-1 (only for the UTM case) */
 			if (shift_xy) {
 				x_c -= Ctrl->C.easting;
-				x_c -= Ctrl->C.northing;
+				y_c -= Ctrl->C.northing;
 			}
 			/* Convert from 1:1 scale */ 
 			if (unit) {
 				x_c *= fwd_scale;
 				y_c *= fwd_scale;
 			}
+
+			GMT_err_fail (GMT_map_setup (ww, ee, ss, nn), "");
+
 			x_c *= project_info.x_scale;
 			y_c *= project_info.y_scale;
 
@@ -314,11 +329,11 @@ int main (int argc, char **argv)
 				x_c += project_info.x0;
 				y_c += project_info.y0;
 			}
-			GMT_err_fail (GMT_map_setup (ww, ee, ss, nn), "");
 			GMT_xy_to_geo (&lon_t, &lat_t, x_c, y_c);
 			sprintf (opt_R, "-R%.12f/%.12f/%.12f/%.12f", lon_t-1, lon_t+1, lat_t-1, lat_t+1);
 			if (gmtdefs.verbose) fprintf (stderr, "First opt_R\t %s\t%g\t%g\n", opt_R, x_c, y_c);
-			GMT_parse_common_options (opt_R, &ww, &ee, &ss, &nn);
+			GMT_parse_R_option (opt_R, &ww, &ee, &ss, &nn);
+			project_info.region = 0;	/* We need to reset this to not fall into non-wanted branch deeper down */
 			GMT_err_fail (GMT_map_setup (ww, ee, ss, nn), "");
 
 			/* Finally obtain the good limits */
@@ -455,6 +470,8 @@ int main (int argc, char **argv)
 		GMT_grd_project (rect, &r_head, geo, &g_head, &edgeinfo, Ctrl->S.antialias, Ctrl->S.interpolant, Ctrl->S.threshold, TRUE);
 
 		GMT_pad[0] = GMT_pad[1] = GMT_pad[2] = GMT_pad[3] = 0;
+		sprintf (g_head.x_units, "longitude [degrees_east]");
+		sprintf (g_head.y_units, "latitude [degrees_north]");
 		GMT_err_fail (GMT_write_grd (Ctrl->G.file, &g_head, geo, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), Ctrl->G.file);
 	}
 	else {	/* Forward projection from geographical to rectangular grid */
@@ -542,6 +559,8 @@ int main (int argc, char **argv)
 		/* rect xy values are here in GMT projected units chosen by user */
 
 		GMT_pad[0] = GMT_pad[1] = GMT_pad[2] = GMT_pad[3] = 0;
+		strcpy (r_head.x_units, unit_name);
+		strcpy (r_head.y_units, unit_name);
 		GMT_err_fail (GMT_write_grd (Ctrl->G.file, &r_head, rect, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), Ctrl->G.file);
 	}
 
