@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: grdreformat.c,v 1.54 2010/01/05 01:15:46 guru Exp $
+ *	$Id: grdreformat.c,v 1.59 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -19,7 +19,7 @@
  * grdreformat.c reads a grid file in one format and outputs it in another
  *
  * Author:	Paul Wessel
- * Date:	3-JAN-1991-2010
+ * Date:	3-JAN-1991-2011
  * Version:	4
  */
 
@@ -27,16 +27,16 @@
 
 struct GRDREFORMAT_CTRL {
 	struct N {	/* -N */
-		BOOLEAN active;
+		GMT_LONG active;
 	} N;
 };
 
 int main (int argc, char **argv)
 {
 #include "grdreformat.h"	/* Defines N_GRDTXT_LINES and char *grd_formats[N_GRDTXT_LINES] array used in usage message */
-	BOOLEAN error = FALSE, global = FALSE;
+	GMT_LONG error = FALSE, global = FALSE, no_header;
 
-	GMT_LONG i, nfiles = 0, nx, ny, no_header, type[2];
+	GMT_LONG i, nfiles = 0, nx, ny, type[2];
 
 	size_t nm;
 	
@@ -51,7 +51,7 @@ int main (int argc, char **argv)
 
 	void *New_grdreformat_Ctrl (), Free_grdreformat_Ctrl (struct GRDREFORMAT_CTRL *C);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct GRDREFORMAT_CTRL *)New_grdreformat_Ctrl ();	/* Allocate and initialize a new control structure */
 	
