@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: grdtrack.c,v 1.75 2010/01/14 07:15:19 guru Exp $
+ *	$Id: grdtrack.c,v 1.87 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -45,32 +45,32 @@
 
 struct GRDTRACK_CTRL {
 	struct G {	/* -G<grdfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 		double scale, lat;
 		GMT_LONG mode;
 		GMT_LONG type;	/*HIDDEN */
 	} G;
 	struct L {	/* -L<flag> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char mode[4];
 	} L;
 	struct Q {	/* -Q[b|c|l|n][[/]<threshold>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG interpolant;
 		double threshold;
 	} Q;
 	struct S {	/* -S */
-		BOOLEAN active;
+		GMT_LONG active;
 	} S;
 	struct Z {	/* -Z */
-		BOOLEAN active;
+		GMT_LONG active;
 	} Z;
 };
 
 int main (int argc, char **argv)
 {
-	BOOLEAN error = FALSE, pure_ascii = FALSE;
+	GMT_LONG error = FALSE, pure_ascii = FALSE;
 
 	char line[BUFSIZ], *not_used = NULL;
 
@@ -91,7 +91,7 @@ int main (int argc, char **argv)
 
 	void *New_grdtrack_Ctrl (), Free_grdtrack_Ctrl (struct GRDTRACK_CTRL *C);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct GRDTRACK_CTRL *) New_grdtrack_Ctrl ();	/* Allocate and initialize a new control structure */
 	
@@ -124,7 +124,7 @@ int main (int argc, char **argv)
 				case 'G':
 					Ctrl->G.active = TRUE;
 					if (strchr (argv[i], ',') && !strchr (argv[i], '?')) {	/* IMG grid file with required parameters */
-						if ((j = sscanf (&argv[i][2], "%[^,],%lf,%ld,%lf", line, &Ctrl->G.scale, &Ctrl->G.mode, &Ctrl->G.lat)) < 3) {
+						if ((j = sscanf (&argv[i][2], "%[^,],%lf,%" GMT_LL "d,%lf", line, &Ctrl->G.scale, &Ctrl->G.mode, &Ctrl->G.lat)) < 3) {
 							fprintf (stderr, "%s: SYNTAX ERROR -G option: Give imgfile, scale, mode [and optionally max_lat]\n", GMT_program);
 							error = TRUE;
 						}
@@ -141,10 +141,10 @@ int main (int argc, char **argv)
 						strncpy (Ctrl->L.mode, &argv[i][2], (size_t)4);
 					}
 					else {
-						GMT_io.in_col_type[0] = GMT_io.out_col_type[0] = GMT_IS_LON;
-						GMT_io.in_col_type[1] = GMT_io.out_col_type[1] = GMT_IS_LAT;
+						GMT_io.in_col_type[GMT->common->t.active] = GMT_io.out_col_type[GMT->common->t.active] = GMT_IS_LON;
+						GMT_io.in_col_type[1-GMT->common->t.active] = GMT_io.out_col_type[1-GMT->common->t.active] = GMT_IS_LAT;
+						fprintf (stderr, "%s: Option -L with no argument is obsolete (but is processed correctly).  Please use -f instead\n", GMT_program);
 					}
-					fprintf (stderr, "%s: Option -L is obsolete (but is processed correctly).  Please use -f instead\n", GMT_program);
 					break;
 				case 'N':	/* Backwards compatible */
 					Ctrl->Q.interpolant = BCR_NEARNEIGHBOR;
@@ -300,6 +300,9 @@ int main (int argc, char **argv)
 			south = grd.y_min;
 			north = grd.y_max;
 		}
+		else	/* Make sure the subset fits the grid layout */
+			GMT_err_pass (GMT_adjust_loose_wesn (&west, &east, &south, &north, &grd), grd.name);
+		
 		nx = GMT_get_n (west, east, grd.x_inc, grd.node_offset);
 		ny = GMT_get_n (south, north, grd.y_inc, grd.node_offset);
 		mx = nx + 4;	my = ny + 4;
@@ -333,20 +336,22 @@ int main (int argc, char **argv)
 	if (GMT_io.io_header[GMT_IN]) {	/* First echo headers, if any */
 		for (i = 0; i < GMT_io.n_header_recs - 1; i++) {
 			not_used = GMT_fgets (line, BUFSIZ, fp);
-			if (!GMT_io.binary[GMT_OUT] && GMT_io.io_header[GMT_OUT]) fprintf (GMT_stdout, "%s", line);
+			if (!GMT_io.binary[GMT_OUT] && GMT_io.io_header[GMT_OUT]) fprintf (stdout, "%s", line);
 		}
 		not_used = GMT_fgets (line, BUFSIZ, fp);
 		GMT_chop (line);
-		if (!GMT_io.binary[GMT_OUT] && GMT_io.io_header[GMT_OUT]) fprintf (GMT_stdout, "%s\tsample\n", line);
+		if (!GMT_io.binary[GMT_OUT] && GMT_io.io_header[GMT_OUT]) fprintf (stdout, "%s\tsample\n", line);
 	}
 
 	ix = (gmtdefs.xy_toggle[GMT_OUT]);	iy = 1 - ix;	/* These are used for output purposes only */
-	n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : BUFSIZ;
+	n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : GMT_MAX_COLUMNS;
 	memset ((void *)line, 0, (size_t)BUFSIZ);
 	if (Ctrl->Z.active) GMT_io.out_col_type[0] = GMT_IS_FLOAT;	/* Since we are outputting z in the longitude column */
 
 	while ((n_fields = GMT_input (fp, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {
 
+		n_read++;
+
 		while (GMT_io.status & GMT_IO_SEGMENT_HEADER) {
 			GMT_write_segmentheader (GMT_stdout, n_expected_fields);
 			n_fields = GMT_input (fp,  &n_expected_fields, &in);
@@ -354,13 +359,11 @@ int main (int argc, char **argv)
 		if ((GMT_io.status & GMT_IO_EOF)) continue;	/* At EOF */
 
 		if ((GMT_io.status & GMT_IO_MISMATCH) && n_fields < 2) {
-			fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields, n_expected_fields, n_read);
-			exit (EXIT_FAILURE);
+			fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld (skipped)\n", GMT_program, n_fields, n_expected_fields, n_read);
+			continue;
 		}
 		if (n_output == 0) n_output = n_expected_fields + 1;
 
-		n_read++;
-
 		if (Ctrl->G.type == 1) {	/* Mercator IMG grid - get Mercator coordinates x,y */
 			GMT_geo_to_xy (in[GMT_X], in[GMT_Y], &x, &y);
 			if (x > grd.x_max) x -= 360.0;
@@ -405,10 +408,10 @@ int main (int argc, char **argv)
 			/* First get rid of any commas that may cause grief */
 			for (i = 0; GMT_io.current_record[i]; i++) if (GMT_io.current_record[i] == ',') GMT_io.current_record[i] = ' ';
 			sscanf (GMT_io.current_record, "%*s %*s %[^\n]", line);
-			GMT_ascii_output_one (GMT_stdout, in[ix], ix);	fprintf (GMT_stdout, "\t");
-			GMT_ascii_output_one (GMT_stdout, in[iy], iy);	fprintf (GMT_stdout, "\t");
-			fprintf (GMT_stdout, "%s\t", line);
-			GMT_ascii_output_one (GMT_stdout, value, 2);	fprintf (GMT_stdout, "\n");
+			GMT_ascii_output_one (GMT_stdout, in[ix], ix);	GMT_fputs ("\t", GMT_stdout);
+			GMT_ascii_output_one (GMT_stdout, in[iy], iy);	GMT_fputs ("\t", GMT_stdout);
+			GMT_fputs (line, GMT_stdout);			GMT_fputs ("\t", GMT_stdout); 
+			GMT_ascii_output_one (GMT_stdout, value, 2);	GMT_fputs ("\n", GMT_stdout);
 		}
 		else {	/* Simply copy other columns, append value, and output */
 			for (i = 0; i < n_expected_fields; i++) out[i] = in[i];
