@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: grdtrend.c,v 1.38 2010/01/05 01:15:46 guru Exp $
+ *	$Id: grdtrend.c,v 1.42 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -86,27 +86,27 @@ are conveniently sized near 0 or 1.
 struct GRDTREND_CTRL {	/* All control options for this program (except common args) */
 	/* ctive is TRUE if the option has been activated */
 	struct D {	/* -D<diffgrid> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} D;
 	struct N {	/* -N[r]<n_model> */
-		BOOLEAN active;
-		BOOLEAN robust;
+		GMT_LONG active;
+		GMT_LONG robust;
 		GMT_LONG value;
 	} N;
 	struct T {	/* -T<trend.grd> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} T;
 	struct W {	/* -W<weight.grd> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} W;
 };
 
 int main(int argc, char **argv)
 {
-	BOOLEAN	error = FALSE, trivial, weighted;
+	GMT_LONG	error = FALSE, trivial, weighted;
 
 	char	*i_filename = NULL, format[BUFSIZ];
 
@@ -142,7 +142,7 @@ int main(int argc, char **argv)
 
 /* Execution begins here with loop over arguments:  */
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct GRDTREND_CTRL *) New_grdtrend_Ctrl ();		/* Allocate and initialize defaults in a new control structure */
 
@@ -623,7 +623,7 @@ void load_gtg_and_gtd (float *data, GMT_LONG nx, GMT_LONG ny, double *xval, doub
 
 /* Now if !weighted, use more accurate sum for gtg[0], and set symmetry:  */
 
-	if (!weighted) gtg[0] = n_used;
+	if (!weighted) gtg[0] = (double)n_used;
 
 	for (k = 0; k < n_model; k++) {
 		for (l = 0; l < k; l++) gtg[l + k*n_model] = gtg[k + l*n_model];
