@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: grdvector.c,v 1.60 2010/01/05 01:15:46 guru Exp $
+ *	$Id: grdvector.c,v 1.64 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -34,45 +34,45 @@
 
 struct GRDVECTOR_CTRL {
 	struct A {	/* -A */
-		BOOLEAN active;
+		GMT_LONG active;
 	} A;
 	struct C {	/* -C<cpt> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} C;
 	struct E {	/* -E */
-		BOOLEAN active;
+		GMT_LONG active;
 	} E;
 	struct G {	/* -G<fill> */
-		BOOLEAN active;
+		GMT_LONG active;
 		struct GMT_FILL fill;
 	} G;
 	struct I {	/* -Idx[/dy] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double xinc, yinc;
 	} I;
 	struct N {	/* -N */
-		BOOLEAN active;
+		GMT_LONG active;
 	} N;
 	struct Q {	/* -Q<params> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double width, length, thickness, norm;
 	} Q;
 	struct S {	/* -S[l]<scale>][<unit>] */
-		BOOLEAN active;
-		BOOLEAN constant;
+		GMT_LONG active;
+		GMT_LONG constant;
 		char unit;
 		double factor;
 	} S;
 	struct T {	/* -T */
-		BOOLEAN active;
+		GMT_LONG active;
 	} T;
 	struct W {	/* -W<pen> */
-		BOOLEAN active;
+		GMT_LONG active;
 		struct GMT_PEN pen;
 	} W;
 	struct Z {	/* -Z */
-		BOOLEAN active;
+		GMT_LONG active;
 	} Z;
 };
 
@@ -82,7 +82,7 @@ int main (int argc, char **argv)
 
 	GMT_LONG ij, nm;
 	
-	BOOLEAN shrink_properties = FALSE, error = FALSE;
+	GMT_LONG shrink_properties = FALSE, error = FALSE;
 
 	char *file[2], txt_a[GMT_LONG_TEXT], txt_b[GMT_LONG_TEXT], txt_c[GMT_LONG_TEXT];
 
@@ -97,7 +97,7 @@ int main (int argc, char **argv)
 
 	void *New_grdvector_Ctrl (), Free_grdvector_Ctrl (struct GRDVECTOR_CTRL *C);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct GRDVECTOR_CTRL *)New_grdvector_Ctrl ();	/* Allocate and initialize a new control structure */
 	
