@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: grdvolume.c,v 1.47 2009/09/09 23:27:03 guru Exp $
+ *	$Id: grdvolume.c,v 1.54 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -31,22 +31,22 @@
 
 struct GRDVOLUME_CTRL {
 	struct C {	/* -C */
-		BOOLEAN active;
+		GMT_LONG active;
 		double low, high, inc;
 	} C;
 	struct L {	/* -L<base> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double value;
 	} L;
 	struct S {	/* -S */
-		BOOLEAN active;
+		GMT_LONG active;
 		char unit;
 	} S;
 	struct T {	/* -T */
-		BOOLEAN active;
+		GMT_LONG active;
 	} T;
 	struct Z {	/* Z<fact>[/<shift>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double scale, offset;
 	} Z;
 };
@@ -56,7 +56,7 @@ double vol_prism_frac_y (float *z, GMT_LONG ij, GMT_LONG nx, double y0, double y
 
 int main (int argc, char **argv)
 {
-	BOOLEAN error = FALSE, full = FALSE, bad, cut[4];
+	GMT_LONG error = FALSE, full = FALSE, bad, cut[4];
 
 	char *grdfile = CNULL, format[BUFSIZ];
 
@@ -72,18 +72,18 @@ int main (int argc, char **argv)
 
 	struct GRD_HEADER grd;
 
-	void SW_triangle (float f[], GMT_LONG ij, GMT_LONG nx, BOOLEAN triangle, double *dv, double *da);
-	void NE_triangle (float f[], GMT_LONG ij, GMT_LONG nx, BOOLEAN triangle, double *dv, double *da);
-	void SE_triangle (float f[], GMT_LONG ij, GMT_LONG nx, BOOLEAN triangle, double *dv, double *da);
-	void NW_triangle (float f[], GMT_LONG ij, GMT_LONG nx, BOOLEAN triangle, double *dv, double *da);
-	void NS_trapezoid (float f[], GMT_LONG ij, GMT_LONG nx, BOOLEAN right, double *dv, double *da);
-	void EW_trapezoid (float f[], GMT_LONG ij, GMT_LONG nx, BOOLEAN top, double *dv, double *da);
+	void SW_triangle (float f[], GMT_LONG ij, GMT_LONG nx, GMT_LONG triangle, double *dv, double *da);
+	void NE_triangle (float f[], GMT_LONG ij, GMT_LONG nx, GMT_LONG triangle, double *dv, double *da);
+	void SE_triangle (float f[], GMT_LONG ij, GMT_LONG nx, GMT_LONG triangle, double *dv, double *da);
+	void NW_triangle (float f[], GMT_LONG ij, GMT_LONG nx, GMT_LONG triangle, double *dv, double *da);
+	void NS_trapezoid (float f[], GMT_LONG ij, GMT_LONG nx, GMT_LONG right, double *dv, double *da);
+	void EW_trapezoid (float f[], GMT_LONG ij, GMT_LONG nx, GMT_LONG top, double *dv, double *da);
 	GMT_LONG ors_find_kink (double y[], GMT_LONG n, GMT_LONG mode);
-	void *New_Grdvolume_Ctrl (), Free_Grdvolume_Ctrl (struct GRDVOLUME_CTRL *C);
+	void *New_grdvolume_Ctrl (), Free_grdvolume_Ctrl (struct GRDVOLUME_CTRL *C);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
-	Ctrl = (struct GRDVOLUME_CTRL *) New_Grdvolume_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct GRDVOLUME_CTRL *) New_grdvolume_Ctrl ();	/* Allocate and initialize a new control structure */
 	
 	west = east = south = north = 0.0;
 
@@ -370,15 +370,15 @@ int main (int argc, char **argv)
 
 	if (full) {
 		sprintf (format, "%s\t%s\t%s\t%s\n", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
-		for (c = 0; c < n_contours; c++) fprintf (GMT_stdout, format, Ctrl->C.low + c * Ctrl->C.inc, area[c], vol[c], height[c]);
+		for (c = 0; c < n_contours; c++) fprintf (stdout, format, Ctrl->C.low + c * Ctrl->C.inc, area[c], vol[c], height[c]);
 	}
 	else if (Ctrl->C.active) {
         	sprintf (format, "%s\t%s\t%s\t%s\n", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
-		fprintf (GMT_stdout, format, Ctrl->C.low + c * Ctrl->C.inc, area[c], vol[c], height[c]);
+		fprintf (stdout, format, Ctrl->C.low + c * Ctrl->C.inc, area[c], vol[c], height[c]);
 	}
 	else {
         	sprintf (format, "%s\t%s\t%s\n", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
-		fprintf (GMT_stdout, format, area[c], vol[c], height[c]);
+		fprintf (stdout, format, area[c], vol[c], height[c]);
 	}
 
 	GMT_free ((void *)f);
@@ -386,14 +386,14 @@ int main (int argc, char **argv)
 	GMT_free ((void *)vol);
 	GMT_free ((void *)height);
 
-	Free_Grdvolume_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_grdvolume_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
 
-void SW_triangle (float f[], GMT_LONG ij, GMT_LONG nx, BOOLEAN triangle, double *dv, double *da)
+void SW_triangle (float f[], GMT_LONG ij, GMT_LONG nx, GMT_LONG triangle, double *dv, double *da)
 {	/* Calculates area of a SW-corner triangle */
 	/* triangle = TRUE gets triangle, FALSE gives the complementary area */
 	double x1, y0, frac;
@@ -411,7 +411,7 @@ void SW_triangle (float f[], GMT_LONG ij, GMT_LONG nx, BOOLEAN triangle, double
 	}
 }
 
-void NE_triangle (float f[], GMT_LONG ij, GMT_LONG nx, BOOLEAN triangle, double *dv, double *da)
+void NE_triangle (float f[], GMT_LONG ij, GMT_LONG nx, GMT_LONG triangle, double *dv, double *da)
 {	/* Calculates area of a NE-corner triangle */
 	/* triangle = TRUE gets triangle, FALSE gives the complementary area */
 	double x0, y1, a, x0_1, y1_1, frac = 0.0;
@@ -434,7 +434,7 @@ void NE_triangle (float f[], GMT_LONG ij, GMT_LONG nx, BOOLEAN triangle, double
 	}
 }
 
-void SE_triangle (float f[], GMT_LONG ij, GMT_LONG nx, BOOLEAN triangle, double *dv, double *da)
+void SE_triangle (float f[], GMT_LONG ij, GMT_LONG nx, GMT_LONG triangle, double *dv, double *da)
 {	/* Calculates area of a SE-corner triangle */
 	/* triangle = TRUE gets triangle, FALSE gives the complementary area */
 	double x0, y1, c, x0_1, frac = 0.0;
@@ -456,7 +456,7 @@ void SE_triangle (float f[], GMT_LONG ij, GMT_LONG nx, BOOLEAN triangle, double
 	}
 }
 
-void NW_triangle (float f[], GMT_LONG ij, GMT_LONG nx, BOOLEAN triangle, double *dv, double *da)
+void NW_triangle (float f[], GMT_LONG ij, GMT_LONG nx, GMT_LONG triangle, double *dv, double *da)
 {	/* Calculates area of a NW-corner triangle */
 	/* triangle = TRUE gets triangle, FALSE gives the complementary area */
 	double x1, y0, y0_1, frac;
@@ -475,7 +475,7 @@ void NW_triangle (float f[], GMT_LONG ij, GMT_LONG nx, BOOLEAN triangle, double
 	}
 }
 
-void NS_trapezoid (float f[], GMT_LONG ij, GMT_LONG nx, BOOLEAN right, double *dv, double *da)
+void NS_trapezoid (float f[], GMT_LONG ij, GMT_LONG nx, GMT_LONG right, double *dv, double *da)
 {	/* Calculates area of a NS trapezoid */
 	/* right = TRUE gets the right trapezoid, FALSE gets the left */
 	double x0, x1;
@@ -492,7 +492,7 @@ void NS_trapezoid (float f[], GMT_LONG ij, GMT_LONG nx, BOOLEAN right, double *d
 	}
 }
 
-void EW_trapezoid (float f[], GMT_LONG ij, GMT_LONG nx, BOOLEAN top, double *dv, double *da)
+void EW_trapezoid (float f[], GMT_LONG ij, GMT_LONG nx, GMT_LONG top, double *dv, double *da)
 {	/* Calculates area of a EW trapezoid */
 	/* top = TRUE gets the top trapezoid, FALSE gets the bottom */
 	double y0, y1;
@@ -615,10 +615,10 @@ double median3 (double x[])
 	}
 }
 
-void *New_Grdvolume_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_grdvolume_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GRDVOLUME_CTRL *C;
 	
-	C = (struct GRDVOLUME_CTRL *) GMT_memory (VNULL, 1, sizeof (struct GRDVOLUME_CTRL), "New_Grdvolume_Ctrl");
+	C = (struct GRDVOLUME_CTRL *) GMT_memory (VNULL, 1, sizeof (struct GRDVOLUME_CTRL), "New_grdvolume_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->L.value = GMT_d_NaN;
@@ -626,6 +626,6 @@ void *New_Grdvolume_Ctrl () {	/* Allocate and initialize a new control structure
 	return ((void *)C);
 }
 
-void  Free_Grdvolume_Ctrl (struct GRDVOLUME_CTRL *C) {	/* Deallocate control structure */
+void  Free_grdvolume_Ctrl (struct GRDVOLUME_CTRL *C) {	/* Deallocate control structure */
 	GMT_free ((void *)C);	
 }
