@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: greenspline.c,v 1.46 2010/01/05 01:15:46 guru Exp $
+ *	$Id: greenspline.c,v 1.52 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 2008-2010 by P. Wessel
+ *	Copyright (c) 2008-2011 by P. Wessel
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -71,50 +71,50 @@ typedef double REAL;	/* Change this to float and recompile if you only want sing
 
 struct GREENSPLINE_CTRL {
 	struct A {	/* -A<gradientfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG mode;	/* 0 = azimuths, 1 = directions, 2 = dx,dy components, 3 = dx, dy, dz components */
 		char *file;
 	} A	;
 	struct C {	/* -C<cutoff> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double value;
 		char *file;
 	} C;
 	struct D {	/* -D<distflag> */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG mode;
 	} D;
 	struct F {	/* -F */
-		BOOLEAN active;
+		GMT_LONG active;
 	} F;
 	struct G {	/* -G<output_grdfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} G;
 	struct I {	/* -Idx[/dy[/dz]] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double inc[3];
 	} I;
 	struct L {	/* -L */
-		BOOLEAN active;
+		GMT_LONG active;
 	} L;
 	struct N {	/* -N<outputnode_file> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} N;
 	struct Q {	/* -Qdaz */
-		BOOLEAN active;
+		GMT_LONG active;
 		double az;
 		double dir[3];
 	} Q;
 	struct S {	/* -S<mode>[/args] */
-		BOOLEAN active, fast;
+		GMT_LONG active, fast;
 		GMT_LONG mode;
 		double value[2];
 		char *arg;
 	} S;
 	struct T {	/* -T<mask_grdfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} T;
 };
@@ -154,16 +154,16 @@ static void Ccot (double Z[], double cotZ[])
 	A[1] += 1.0;	B[0] -= 1.0;	B[1] = -A[0];
 	Cdiv (A, B, cotZ);
 }
-void GMT_check_lattice_cpy (struct GMT_GRD_INFO *info, double *x_inc, double *y_inc, BOOLEAN *pixel, BOOLEAN *active);
+void GMT_check_lattice_cpy (struct GMT_GRD_INFO *info, double *x_inc, double *y_inc, GMT_LONG *pixel, GMT_LONG *active);
 
 PFD GMT_azimuth_func;
 
 int main (int argc, char **argv)
 {
-	GMT_LONG i, j, k, p, ii, n, m, nm, fno, n_files = 0, n_fields, n_args, dimension = 0;
+	GMT_LONG i, j, k, p, ii, n, m, nm, fno, n_files = 0, n_fields, n_read, n_args, dimension = 0;
 	GMT_LONG error = 0, n_expected_fields, normalize = 1, unit = 0, n_items;
 	GMT_LONG old_n_alloc, n_alloc, ij, ji, nxy, n_ok = 0;
-	BOOLEAN do_grid, done, nofile = TRUE;
+	GMT_LONG do_grid, done, nofile = TRUE;
 	char line[BUFSIZ];
 	char *method[N_METHODS] = {"minimum curvature Cartesian spline [1-D]",
 		"minimum curvature Cartesian spline [2-D]",
@@ -210,7 +210,7 @@ int main (int argc, char **argv)
 	double spline2d_lookup (double x, double par[], double *y);
 	double spline2d_Wessel_Becker_lookup (double x, double par[], double *z);
 	double gradspline2d_Wessel_Becker_lookup (double x, double par[], double *z);
-	void spline2d_Wessel_Becker_init (double par[], double *z, double *g, BOOLEAN grad);
+	void spline2d_Wessel_Becker_init (double par[], double *z, double *g, GMT_LONG grad);
 	double spline3d_sandwell (double r, double par[], double *G);
 	double spline3d_Wessel_Bercovici (double r, double par[], double *G);
 	double spline3d_Mitasova_Mitas (double r, double par[], double *G);
@@ -220,11 +220,11 @@ int main (int argc, char **argv)
 	double undo_normalization (double *X, double q, GMT_LONG mode, double *coeff);
 	void do_normalization (double **X, double *obs, GMT_LONG n, GMT_LONG mode, double *coeff);
 	double get_radius (double *X0, double *X1, GMT_LONG dim);
-	double get_dircosine (double *D, double *X0, double *X1, GMT_LONG dim, BOOLEAN baz);
+	double get_dircosine (double *D, double *X0, double *X1, GMT_LONG dim, GMT_LONG baz);
 	
 	PFD G = NULL, dGdr = NULL;
 	
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct GREENSPLINE_CTRL *)New_greenspline_Ctrl ();	/* Allocate and initialize a new control structure */
 
@@ -485,7 +485,11 @@ int main (int argc, char **argv)
 		GMT_explain_option ('.');
 		exit (EXIT_FAILURE);
 	}
-	
+
+	if (! (project_info.region_supplied || Ctrl->N.active || Ctrl->T.active)) {
+		fprintf (stderr, "%s: GMT SYNTAX ERROR.  No output locations specified (use either [-R -I], -N, or -T)\n", GMT_program);
+		error++;
+	}
 	dimension = (Ctrl->D.mode == 0) ? 1 : ((Ctrl->D.mode == 5) ? 3 : 2);
 	if (info.active && dimension != 2) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR.  The -R<gridfile> option only applies to 2-D gridding\n", GMT_program);
@@ -612,7 +616,7 @@ int main (int argc, char **argv)
 	for (k = 0; k < n_alloc; k++) X[k] = (double *) GMT_memory (VNULL, dimension, sizeof (double), GMT_program);
 	obs = (double *) GMT_memory (VNULL, (size_t)n_alloc, sizeof (double), GMT_program);
 
-	n = m = 0;
+	n = m = n_read = 0;
 	for (fno = 1; !done && fno < n_args; fno++) {	/* Loop over input files, if any */
 		if (!nofile && argv[fno][0] == '-') continue;
 
@@ -634,9 +638,11 @@ int main (int argc, char **argv)
 
 		while ((n_fields = GMT_input (fp, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
 
+			n_read++;
+
 			if (GMT_io.status & GMT_IO_MISMATCH) {
-				fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields, n_expected_fields, n);
-				exit (EXIT_FAILURE);
+				fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld (skipped)\n", GMT_program, n_fields, n_expected_fields, n_read);
+				continue;
 			}
 
 			for (k = 0; k < dimension; k++) X[n][k] = in[k];
@@ -773,7 +779,7 @@ int main (int argc, char **argv)
 		GMT_import_table ((void *)Ctrl->N.file, GMT_IS_FILE, &T, 0.0, FALSE, FALSE, FALSE);
 	}
 	else {	/* Fill in an equidistant output table or grid */
-		h.node_offset = Ctrl->F.active;
+		h.node_offset = (int)Ctrl->F.active;
 		h.x_inc = Ctrl->I.inc[GMT_X];
 		Z.nz = h.ny = 1;	/* So that output logic will work for lower dimensions */
 		if (dimension > 1) {
@@ -1466,7 +1472,7 @@ double gradspline2d_Wessel_Becker_lookup (double x, double par[], double *y)
 	return (spline2d_lookup (x, par, y));
 }
 
-void spline2d_Wessel_Becker_init (double par[], double *z, double *g, BOOLEAN grad)
+void spline2d_Wessel_Becker_init (double par[], double *z, double *g, GMT_LONG grad)
 {
 	int i, nx;
 	double x;
@@ -2180,7 +2186,7 @@ double get_radius (double *X0, double *X1, GMT_LONG dim)
 	return (r);
 }
 
-double get_dircosine (double *D, double *X0, double *X1, GMT_LONG dim, BOOLEAN baz)
+double get_dircosine (double *D, double *X0, double *X1, GMT_LONG dim, GMT_LONG baz)
 {
 	/* D, the directional cosines of the observed gradient:
 	 * X0: Observation point.
@@ -2209,7 +2215,7 @@ double get_dircosine (double *D, double *X0, double *X1, GMT_LONG dim, BOOLEAN b
 	return (C);
 }
 
-void GMT_check_lattice_cpy (struct GMT_GRD_INFO *info, double *x_inc, double *y_inc, BOOLEAN *pixel, BOOLEAN *active)
+void GMT_check_lattice_cpy (struct GMT_GRD_INFO *info, double *x_inc, double *y_inc, GMT_LONG *pixel, GMT_LONG *active)
 {	/* Uses provided settings to initialize the lattice settings from
 	 * the -R<grdfile> if it was given; else it does nothing.
 	 */
