@@ -1,6 +1,6 @@
-/* $Id: img2mercgrd.c,v 1.35 2010/01/05 01:15:48 guru Exp $
+/* $Id: img2mercgrd.c,v 1.38 2011/01/02 20:09:36 guru Exp $
  *
- * Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ * Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  * See LICENSE.TXT file for copying and redistribution conditions.
  *
  * img2mercgrd.c
@@ -58,34 +58,34 @@
 struct IMG2MERCGRD_CTRL {
 	char *file;	/* Input file name */
 	struct C {	/* -C */
-		BOOLEAN active;
+		GMT_LONG active;
 	} C;
 	struct D {	/* -D[<minlat>/<maxlat>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double min, max;
 	} D;
 	struct G {	/* -G<output_grdfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} G;
 	struct N {	/* -N<ave> */
-		BOOLEAN active;
+		GMT_LONG active;
 		int value;
 	} N;
 	struct S {	/* -S<scale> 	(use 0.1 for grav,curv,north,east files.) */
-		BOOLEAN active;
+		GMT_LONG active;
 		double value;
 	} S;
 	struct T {	/* -T<type> */
-		BOOLEAN active;
+		GMT_LONG active;
 		int value;
 	} T;
 	struct W {	/* -W<maxlon> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double value;
 	} W;
 	struct m {	/* -m<minutes> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double value;
 	} m;
 };
@@ -112,7 +112,7 @@ int main (int argc, char **argv)
 	
 	void *New_img2mercgrd_Ctrl (), Free_img2mercgrd_Ctrl (struct IMG2MERCGRD_CTRL *C);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 	
 	Ctrl = (struct IMG2MERCGRD_CTRL *)New_img2mercgrd_Ctrl ();	/* Allocate and initialize a new control structure */
 
@@ -321,7 +321,7 @@ int main (int argc, char **argv)
 	jinstart = navg * (int)floor (GMT_img_lat_to_ypix (north, &imgcoord) / navg);
 	jinstop  = navg * (int)ceil  (GMT_img_lat_to_ypix (south, &imgcoord) / navg);
 	/* jinstart <= jinputrow < jinstop  */
-	h.ny = (jinstop - jinstart) / navg;
+	h.ny = (int)((jinstop - jinstart) / navg);
 	north = GMT_img_ypix_to_lat ((double)jinstart, &imgcoord);
 	south = GMT_img_ypix_to_lat ((double)jinstop,  &imgcoord);
 
@@ -331,7 +331,7 @@ int main (int argc, char **argv)
 	/* Reset left and right edges of user area:  */
 	west = iinstart * dx;
 	east = iinstop  * dx;
-	h.nx = (iinstop - iinstart) / navg;
+	h.nx = (int)((iinstop - iinstart) / navg);
 
 	if (gmtdefs.verbose) {
 		fprintf(stderr, "%s:  To fit [averaged] input, your %s is adjusted to -R%.12g/%.12g/%.12g/%.12g\n",
@@ -448,7 +448,7 @@ int main (int argc, char **argv)
 					for (k = 0, kk = kstart; k < navgsq; k++, kk++) {
 						tempint = (int)row[ix[kk]];
 						if (Ctrl->T.value) {
-							if ( ( (abs(tempint))%2) != 0) {
+							if ( ( (GMT_abs(tempint))%2) != 0) {
 								csum += 1.0;
 								tempint--;
 							}
@@ -460,7 +460,7 @@ int main (int argc, char **argv)
 				}
 				else {
 					tempint = (int)row[ix[iout]];
-					if (Ctrl->T.value && abs(tempint)%2 != 0) {
+					if (Ctrl->T.value && GMT_abs(tempint)%2 != 0) {
 						csum = 1.0;
 						tempint--;
 					}
