@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *    $Id: psmeca.c,v 1.51 2010/01/05 01:15:48 guru Exp $
+ *    $Id: psmeca.c,v 1.60 2011/01/02 20:09:36 guru Exp $
  *
- *    Copyright (c) 1996-2010 by G. Patau
+ *    Copyright (c) 1996-2011 by G. Patau
  *    Distributed under the GNU Public Licence
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
@@ -44,21 +44,21 @@ int main (int argc, char **argv)
     GMT_LONG     n_args;
     GMT_LONG     n_rec = 0;
 
-    BOOLEAN    outline = FALSE, p_outline = FALSE, t_outline = FALSE;
-    BOOLEAN    error = FALSE, nofile = TRUE;
-    BOOLEAN    done, get_rgb = FALSE, no_size_needed;
-    BOOLEAN    read_cmt = FALSE, read_aki = FALSE, read_planes = FALSE;
-    BOOLEAN    read_tensor = FALSE, plot_dc = FALSE, plot_zerotrace = FALSE;
-    BOOLEAN    read_axis = FALSE;
-    BOOLEAN    read_change_position = FALSE;
-    BOOLEAN    transparence = FALSE, one_size = FALSE, no_label = FALSE;
-    BOOLEAN    plot_axis = FALSE, tr_zerotrace = FALSE;
-    BOOLEAN    skip_if_outside = TRUE;
-    BOOLEAN    def_lpen = FALSE, def_cpen = FALSE, def_tr_pen = FALSE;
-    BOOLEAN    def_ppen = FALSE, def_tpen = FALSE, def_tz_pen = FALSE;
-    BOOLEAN    def_pfill = FALSE, def_tfill = FALSE;
-    BOOLEAN    draw_box = FALSE;
-    BOOLEAN    transparence_old = FALSE, not_defined = FALSE;
+    GMT_LONG    outline = FALSE, p_outline = FALSE, t_outline = FALSE;
+    GMT_LONG    error = FALSE, nofile = TRUE;
+    GMT_LONG    done, get_rgb = FALSE, no_size_needed;
+    GMT_LONG    read_cmt = FALSE, read_aki = FALSE, read_planes = FALSE;
+    GMT_LONG    read_tensor = FALSE, plot_dc = FALSE, plot_zerotrace = FALSE;
+    GMT_LONG    read_axis = FALSE;
+    GMT_LONG    read_change_position = FALSE;
+    GMT_LONG    transparence = FALSE, one_size = FALSE, no_label = FALSE;
+    GMT_LONG    plot_axis = FALSE, tr_zerotrace = FALSE;
+    GMT_LONG    skip_if_outside = TRUE;
+    GMT_LONG    def_lpen = FALSE, def_cpen = FALSE, def_tr_pen = FALSE;
+    GMT_LONG    def_ppen = FALSE, def_tpen = FALSE, def_tz_pen = FALSE;
+    GMT_LONG    def_pfill = FALSE, def_tfill = FALSE;
+    GMT_LONG    draw_box = FALSE;
+    GMT_LONG    transparence_old = FALSE, not_defined = FALSE;
     
     double xy[2], xynew[2], west = 0.0, east = 0.0, south = 0.0, north = 0.0;
     double plot_x, plot_y, scale = 0.0;
@@ -99,7 +99,7 @@ int main (int argc, char **argv)
     char P_sym_type = 0, T_sym_type = 0;
     GMT_LONG P_sym = 0, T_sym = 0;
 
-    argc = GMT_begin (argc, argv);
+    argc = (int)GMT_begin (argc, argv);
     
     GMT_init_pen (&pen, GMT_PENWIDTH);
     GMT_init_pen (&lpen, GMT_PENWIDTH);
@@ -251,7 +251,7 @@ int main (int argc, char **argv)
                     break;
                 case 'T':
                     transparence = TRUE;
-                    sscanf (&argv[i][2], "%ld",&n_plane);
+                    sscanf (&argv[i][2], "%" GMT_LL "d",&n_plane);
                     if (strlen(argv[i]) > 4) { /* Set transparent attributes */
                         def_tr_pen = TRUE;
                         if (GMT_getpen (&argv[i][4], &tr_pen)) {
@@ -288,7 +288,6 @@ int main (int argc, char **argv)
                         T_sym_type = 'c';
                     }
                     else {
-                        a_size = GMT_convert_units (txt_a, GMT_INCH);
                         strcpy(txt_a, &argv[i][3]);
                         n=0;
 			while (txt_a[n] && txt_a[n] != '/') n++;
@@ -443,7 +442,7 @@ int main (int argc, char **argv)
     if (argc == 1 || GMT_give_synopsis_and_exit || error) {   /* Display usage */
         fprintf (stderr,"psmeca %s - Plot seismological symbols on maps\n\n", GMT_VERSION);
         fprintf (stderr,"usage: psmeca <infiles> %s %s\n", GMT_J_OPT, GMT_Rgeo_OPT);
-        fprintf (stderr, "   -S<symbol><scale>[/fontsize[/justify/offset/angle/form]]\n");
+        fprintf (stderr, "   -S<format><scale>[/fontsize[/justify/offset/angle/form]]\n");
         fprintf (stderr, "   [%s] [-C[<pen>][P<pointsize>]]\n", GMT_B_OPT);
         fprintf (stderr, "   [-Ddepmin/depmax] [-E<fill>] [-G<fill>]\n");
         fprintf (stderr, "   [%s] [-K] [-L<pen>] [-M] [-N] [-O] [-P] [-r]\n", GMT_Ho_OPT);
@@ -455,7 +454,7 @@ int main (int argc, char **argv)
         
         if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
         
-        fprintf (stderr, "    <infiles> is one or more files.  If no, read standard input\n");
+        fprintf (stderr, "    <infiles> is one or more files. If no files are given, read standard input\n");
         GMT_explain_option ('j');
         GMT_explain_option ('R');
         GMT_explain_option ('b');
@@ -478,27 +477,27 @@ int main (int argc, char **argv)
         fprintf (stderr, "        -r draw a box around text.\n");
         fprintf (stderr, "        -S Select format type and symbol size (in %s).\n", GMT_unit_names[gmtdefs.measure_unit]);
         fprintf (stderr, "           Choose format between\n");
-        fprintf (stderr, "         (c) Focal mechanisms in CMT convention\n");
+        fprintf (stderr, "         (c) Focal mechanisms in Harvard CMT convention\n");
         fprintf (stderr, "             X, Y, depth, strike1, dip1, rake1, strike2, dip2, rake2, moment, newX, newY, event_title\n");
         fprintf (stderr, "             with moment in 2 columns : mantiss and exponent corresponding to seismic moment in dynes-cm\n");
-        fprintf (stderr, "         (a) Focal mechanism in AKI & RICHARD's convention:\n");
+        fprintf (stderr, "         (a) Focal mechanism in Aki & Richard's convention:\n");
         fprintf (stderr, "             X, Y, depth, strike, dip, rake, mag, newX, newY, event_title\n");
         fprintf (stderr, "         (p) Focal mechanism defined with\n");
         fprintf (stderr, "             X, Y, depth, strike1, dip1, strike2, fault, mag, newX, newY, event_title\n");
         fprintf (stderr, "             fault = -1/+1 for a normal/inverse fault\n");
-        fprintf (stderr, "         (m) Moment tensor\n");
+        fprintf (stderr, "         (m) Sesmic moment tensor (Harvard CMT, with zero trace)\n");
         fprintf (stderr, "             X, Y, depth, mrr, mtt, mff, mrt, mrf, mtf, exp, newX, newY, event_title\n");
-        fprintf (stderr, "         (z) Zero trace moment tensor\n");
+        fprintf (stderr, "         (z) Anisotropic part of seismic moment tensor (Harvard CMT, with zero trace)\n");
+        fprintf (stderr, "             X, Y, depth, mrr, mtt, mff, mrt, mrf, mtf, exp, event_title\n");
+        fprintf (stderr, "         (d) Best double couple defined from seismic moment tensor (Harvard CMT, with zero trace)\n");
         fprintf (stderr, "             X, Y, depth, mrr, mtt, mff, mrt, mrf, mtf, exp, newX, newY, event_title\n");
-        fprintf (stderr, "         (d) Best double couple defined from moment tensor\n");
-        fprintf (stderr, "             X, Y, depth, mrr, mtt, mff, mrt, mrf, mtf, exp, newX, newY, event_title\n");
-        fprintf (stderr, "         (x) Axis (Harvard CMT)\n");
+        fprintf (stderr, "         (x) Principal axis\n");
         fprintf (stderr, "             X, Y, depth, T_value, T_azim, T_plunge, N_value, N_azim, N_plunge\n");
         fprintf (stderr, "             P_value, P_azim, P_plunge, exp, newX, newY, event_title\n");
-        fprintf (stderr, "         (t) Zero trace moment tensor defined from axis\n");
+        fprintf (stderr, "         (t) Zero trace moment tensor defined from principal axis\n");
         fprintf (stderr, "             X, Y, depth, T_value, T_azim, T_plunge, N_value, N_azim, N_plunge\n");
         fprintf (stderr, "             P_value, P_azim, P_plunge, exp, newX, newY, event_title\n");
-        fprintf (stderr, "         (y) Best double couple defined from axis\n");
+        fprintf (stderr, "         (y) Best double couple defined from principal axis\n");
         fprintf (stderr, "             X, Y, depth, T_value, T_azim, T_plunge, N_value, N_azim, N_plunge\n");
         fprintf (stderr, "             P_value, P_azim, P_plunge, exp, newX, newY, event_title\n");
         fprintf (stderr, "         Use -o option for old (psvelomeca) format (not depth in third column)\n");
@@ -622,7 +621,7 @@ int main (int argc, char **argv)
             
             if (skip_if_outside) {
                 GMT_map_outside (xy[0], xy[1]);
-                if ( abs (GMT_x_status_new) > 1 || abs (GMT_y_status_new) > 1) continue;
+                if (GMT_abs (GMT_x_status_new) > 1 || GMT_abs (GMT_y_status_new) > 1) continue;
             }
 
 	    /* In new (psmeca) input format, third column is depth.
@@ -719,6 +718,8 @@ Definition of scalar moment.
 
 	    else if (read_tensor) {
                 for (i=2+new, n=0; i<8+new; i++, n++) mt.f[n] = atof(col[i]);
+		/* if (mt.f[0] + mt.f[1] + mt.f[2] < GMT_SMALL)		What is SMALL here??
+			fprintf (stderr, "psmeca WARNING: Found mechanism with zero trace != 0\n"); */
                 mt.expo = atoi(col[i]);
 /*
 F. A. Dahlen and Jeroen Tromp, Theoretical Seismology, Princeton, 1998, p.167.
