@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *    $Id: psvelo.c,v 1.37 2010/01/05 01:15:48 guru Exp $
+ *    $Id: psvelo.c,v 1.41 2011/01/02 20:09:36 guru Exp $
  *
- *    Copyright (c) 1996-2010 by G. Patau
+ *    Copyright (c) 1996-2011 by G. Patau
  *    Distributed under the GNU Public Licence
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
@@ -51,17 +51,17 @@ int main (int argc, char **argv)
 	GMT_LONG	n_args;
 	GMT_LONG     n_rec = 0;
 
-	BOOLEAN	outline = FALSE;
-	BOOLEAN	error = FALSE, nofile = TRUE, polygon = FALSE;
-	BOOLEAN shade_uncert = FALSE;
-	BOOLEAN rescale_sigma = FALSE;
-	BOOLEAN done, no_size_needed, greenwich;
-	BOOLEAN read_ellipse = FALSE, read_rotated_ellipse = FALSE;
-	BOOLEAN des_ellipse = TRUE, des_arrow = TRUE;
-	BOOLEAN read_anisotropy = FALSE;
-	BOOLEAN read_wedge = FALSE;
-	BOOLEAN read_cross = FALSE;
-	BOOLEAN old_GMT_world_map, skip_if_outside = TRUE;
+	GMT_LONG	outline = FALSE;
+	GMT_LONG	error = FALSE, nofile = TRUE, polygon = FALSE;
+	GMT_LONG shade_uncert = FALSE;
+	GMT_LONG rescale_sigma = FALSE;
+	GMT_LONG done, no_size_needed, greenwich;
+	GMT_LONG read_ellipse = FALSE, read_rotated_ellipse = FALSE;
+	GMT_LONG des_ellipse = TRUE, des_arrow = TRUE;
+	GMT_LONG read_anisotropy = FALSE;
+	GMT_LONG read_wedge = FALSE;
+	GMT_LONG read_cross = FALSE;
+	GMT_LONG old_GMT_world_map, skip_if_outside = TRUE;
 
 	double xy[2], west = 0.0, east = 0.0, south = 0.0, north = 0.0;
 	double plot_x, plot_y, scale = 0.0;
@@ -87,7 +87,7 @@ int main (int argc, char **argv)
 
 	GMT_LONG justify;
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	GMT_init_pen (&pen, GMT_PENWIDTH);
 	GMT_init_fill (&fill, 0, 0, 0);
@@ -377,7 +377,7 @@ int main (int argc, char **argv)
                         }
 
 			GMT_map_outside (xy[0], xy[1]);
-			if ( abs (GMT_x_status_new) > 1 || abs (GMT_y_status_new) > 1) continue;
+			if (GMT_abs (GMT_x_status_new) > 1 || GMT_abs (GMT_y_status_new) > 1) continue;
 
 			GMT_geo_to_xy (xy[0], xy[1], &plot_x, &plot_y);
 
