@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77convert.c,v 1.46 2010/01/05 01:15:48 guru Exp $
+ *	$Id: mgd77convert.c,v 1.50 2011/01/02 20:09:36 guru Exp $
  *
- *    Copyright (c) 2005-2010 by P. Wessel
+ *    Copyright (c) 2005-2011 by P. Wessel
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -27,7 +27,7 @@ int main (int argc, char **argv)
 {
 	int code_pos, i, in_out, argno, n_cruises = 0, n_paths, format[2] = {MGD77_NOT_SET, MGD77_NOT_SET};
 		
-	BOOLEAN error = FALSE, force = FALSE, high_resolution = FALSE, original = FALSE;
+	GMT_LONG error = FALSE, force = FALSE, high_resolution = FALSE, original = FALSE;
 	
 	char file[BUFSIZ], **list, *fcode = "act";
 	char *format_name[MGD77_N_FORMATS] = {"MGD77 ASCII", "MGD77+ netCDF", "ASCII table"};
@@ -35,7 +35,7 @@ int main (int argc, char **argv)
 	struct MGD77_CONTROL M;
 	struct MGD77_DATASET *D;
 	
-	argc = GMT_begin (argc, argv);		/* Initialize GMT Machinery */
+	argc = (int)GMT_begin (argc, argv);		/* Initialize GMT Machinery */
 	
 	/* Initialize MGD77 output order and other parameters*/
 	
@@ -195,7 +195,7 @@ int main (int argc, char **argv)
 		MGD77_Verify_Header (&M, &(D->H), NULL);	/* Verify the header */
 	
 		if (format[GMT_IN] == MGD77_FORMAT_CDF && format[GMT_OUT] != MGD77_FORMAT_CDF && (D->H.info[MGD77_CDF_SET].n_col || D->flags[0] || D->flags[1])) {
-			fprintf(stderr, "\n%s: Warning: Mput file contains enhanced material that the output file format cannot represent\n", GMT_program);
+			fprintf(stderr, "\n%s: Warning: Input file contains enhanced material that the output file format cannot represent\n", GMT_program);
 		}
 
 		/* OK, ready to write out converted file */
