@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77info.c,v 1.67 2010/01/05 01:15:48 guru Exp $
+ *	$Id: mgd77info.c,v 1.73 2011/01/02 20:09:36 guru Exp $
  *
- *    Copyright (c) 2004-2010 by P. Wessel
+ *    Copyright (c) 2004-2011 by P. Wessel
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -29,23 +29,23 @@ int main (int argc, char **argv)
 	GMT_LONG i, id, rec, argno, col_listing = 3, length, id_col, t_col, x_col, y_col, saved_range, use;
 	GMT_LONG header_flag = 0, n_paths, counter[MGD77_MAX_COLS], agency_listing = 1, quad_no, n_quad;
 	
-	BOOLEAN error = FALSE, greenwich = FALSE, quick_summary = FALSE, dump_raw_header = FALSE;
-	BOOLEAN first = TRUE, col_summary = FALSE, read_file, dump_formatted_header = FALSE;
-	BOOLEAN quick_agencies = FALSE, dump_e77_header = FALSE, dump_hist_header = FALSE;
-	BOOLEAN quad[4] = {FALSE, FALSE, FALSE, FALSE};
+	GMT_LONG error = FALSE, greenwich = FALSE, quick_summary = FALSE, dump_raw_header = FALSE;
+	GMT_LONG first = TRUE, col_summary = FALSE, read_file, dump_formatted_header = FALSE;
+	GMT_LONG quick_agencies = FALSE, dump_e77_header = FALSE, dump_hist_header = FALSE;
+	GMT_LONG quad[4] = {FALSE, FALSE, FALSE, FALSE};
 	
 	double this_dist, this_lon, this_lat, last_lon, last_lat, dx, dy, dlon, ds, lon_w;
 	double xmin, xmax, xmin1, xmin2, xmax1, xmax2, ymin, ymax, this_time, tmin, tmax;
 	double *dvalue[MGD77_MAX_COLS];
 	
-	char *tvalue[MGD77_MAX_COLS], **list;
+	char *tvalue[MGD77_MAX_COLS], buffer[BUFSIZ], **list;
 	
 	GMT_cal_rd rata_die;
 	
 	struct MGD77_CONTROL M, Out;
 	struct MGD77_DATASET *D;
 		
-	argc = GMT_begin (argc, argv);		/* Initialize GMT Machinery */
+	argc = (int)GMT_begin (argc, argv);		/* Initialize GMT Machinery */
 	GMT_get_time_system ("unix", &(gmtdefs.time_system));						/* MGD77+ uses GMT's Unix time epoch */
 	GMT_init_time_system_structure (&(gmtdefs.time_system));
 	
@@ -207,9 +207,12 @@ int main (int argc, char **argv)
 	saved_range = GMT_io.geo.range;	/* We may have to reset thisso keep a copy */
 	GMT_io.out_col_type[0] = GMT_IS_LON;	GMT_io.out_col_type[1] = GMT_IS_LAT;
 	GMT_io.out_col_type[2] = M.time_format;	
-	if (quick_summary) fprintf (GMT_stdout, "#Cruise %sID      %sWest    %sEast    %sSouth   %sNorth   %sStartTime%s%sEndTime%s%s%sDist%snRec",
+	if (quick_summary) {
+		sprintf (buffer, "#Cruise %sID      %sWest    %sEast    %sSouth   %sNorth   %sStartTime%s%sEndTime%s%s%sDist%snRec",
 		gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter,
 		gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter);
+		GMT_fputs (buffer, GMT_stdout);
+	}	
 
 	use = (M.original || M.format != MGD77_FORMAT_CDF) ? MGD77_ORIG : MGD77_REVISED;
 	
@@ -231,16 +234,21 @@ int main (int argc, char **argv)
 		}
 
 		if (dump_hist_header) {	/* Dump of MGD77+ history */
-			fprintf (GMT_stdout, "%s: %s", list[argno], D->H.history);
+			sprintf (buffer, "%s: %s", list[argno], D->H.history);
+			GMT_fputs (buffer, GMT_stdout);
 			MGD77_Close_File (&M);
 			MGD77_Free (D);
 			continue;
 		}
 		if (dump_e77_header) {	/* Dump of e77 header status */
-			if (D->H.E77 && strlen(D->H.E77) > 0)
-				fprintf (GMT_stdout, "%s: %s\n", list[argno], D->H.E77);
-			else
-				fprintf (GMT_stdout, "%s: E77 not applied\n", list[argno]);
+			if (D->H.E77 && strlen(D->H.E77) > 0) {
+				sprintf (buffer, "%s: %s\n", list[argno], D->H.E77);
+				GMT_fputs (buffer, GMT_stdout);
+			}
+			else {
+				sprintf (buffer, "%s: E77 not applied\n", list[argno]);
+				GMT_fputs (buffer, GMT_stdout);
+			}
 			MGD77_Close_File (&M);
 			MGD77_Free (D);
 			continue;
@@ -259,46 +267,49 @@ int main (int argc, char **argv)
 		if (first && quick_summary) {	/* Output all column headers */
 			for (i = 0; i < M.n_out_columns; i++) {
 				if (i == id_col || i == t_col || i == x_col || i == y_col) continue;
-				fprintf (GMT_stdout,"%s%s", gmtdefs.field_delimiter, D->H.info[M.order[i].set].col[M.order[i].item].abbrev);
+				sprintf (buffer,"%s%s", gmtdefs.field_delimiter, D->H.info[M.order[i].set].col[M.order[i].item].abbrev);
+				GMT_fputs (buffer, GMT_stdout);
 			}
-			fprintf (GMT_stdout,"\n");
+			GMT_fputs ("\n", GMT_stdout);
 		}
 		
 		if (col_summary) {	/* Just list names and info for any extra columns */
 			for (i = 0, first = TRUE; i < M.n_out_columns; i++) {
 				if (i == id_col || i == t_col || i == x_col || i == y_col) continue;
-				if (!first) fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
+				if (!first) GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);
 				if (((col_listing & 1) && M.order[i].set == 0) || ((col_listing & 2) && M.order[i].set == 1)) {
-					fprintf (GMT_stdout, "%s", D->H.info[M.order[i].set].col[M.order[i].item].abbrev);
+					GMT_fputs (D->H.info[M.order[i].set].col[M.order[i].item].abbrev, GMT_stdout);
 					first = FALSE;
 				}
 			}
-			if (first) fprintf (GMT_stdout, "No columns matching selection found!");
-			fprintf (GMT_stdout, "\n");
+			if (first) GMT_fputs ("No columns matching selection found!", GMT_stdout);
+			GMT_fputs ("\n", GMT_stdout);
 			MGD77_Close_File (&M);
 			MGD77_Free (D);
 			continue;
 		}
 			
 		if (dump_raw_header) {	/* Write entire MGD77 header */
-			fprintf (GMT_stdout, "-------------------------------");
-			fprintf (GMT_stdout, " Cruise: %8s ", M.NGDC_id);
-			fprintf (GMT_stdout, "-------------------------------\n");
+			GMT_fputs ("-------------------------------", GMT_stdout);
+			sprintf (buffer, " Cruise: %8s ", M.NGDC_id);	GMT_fputs (buffer, GMT_stdout);
+			GMT_fputs ("-------------------------------\n", GMT_stdout);
 			MGD77_Write_Header_Record_m77 ("", &Out, &D->H);
-			fprintf (GMT_stdout, "----------------------------------------");
-			fprintf (GMT_stdout, "----------------------------------------\n");
+			GMT_fputs ("----------------------------------------", GMT_stdout);
+			sprintf (buffer, "----------------------------------------\n");	GMT_fputs (buffer, GMT_stdout);
 			if (M.format == MGD77_FORMAT_CDF) {
-				fprintf (GMT_stdout, "%s\n", D->H.history);
+				sprintf (buffer, "%s\n", D->H.history);
+				GMT_fputs (buffer, GMT_stdout);
 				for (i = 0; i < M.n_out_columns; i++) {
 					if ((M.order[i].set == MGD77_CDF_SET)) {
-						fprintf (GMT_stdout, "> %s%s%s%s%s%s%s", D->H.info[MGD77_CDF_SET].col[M.order[i].item].abbrev, gmtdefs.field_delimiter,
+						sprintf (buffer, "> %s%s%s%s%s%s%s", D->H.info[MGD77_CDF_SET].col[M.order[i].item].abbrev, gmtdefs.field_delimiter,
 						D->H.info[MGD77_CDF_SET].col[M.order[i].item].name, gmtdefs.field_delimiter,
 						D->H.info[MGD77_CDF_SET].col[M.order[i].item].units, gmtdefs.field_delimiter,
 						D->H.info[MGD77_CDF_SET].col[M.order[i].item].comment);
+						GMT_fputs ("\n", GMT_stdout);
 					}
 				}
 			}
-			fprintf (GMT_stdout, "\n");
+			GMT_fputs ("\n", GMT_stdout);
 		}
 		
 		GMT_make_dnan (tmin);
@@ -308,7 +319,7 @@ int main (int argc, char **argv)
 		xmax1 = xmax2 = -360.0;
 		ymin = 180.0;
 		ymax = -180.0;
-		memset ((void *)quad, 0, 4*sizeof(BOOLEAN));	/* Set al to FALSE */
+		memset ((void *)quad, 0, 4*sizeof(GMT_LONG));	/* Set al to FALSE */
 		greenwich = FALSE;
 		memset ((void *) counter, 0, (size_t)(MGD77_MAX_COLS * sizeof (GMT_LONG)));
 	
@@ -417,31 +428,36 @@ int main (int argc, char **argv)
 			}
 		}			
 		if (quick_summary) {
-			fprintf (GMT_stdout,"%8s%s%8s%s", M.NGDC_id, gmtdefs.field_delimiter, D->H.mgd77[use]->Survey_Identifier, gmtdefs.field_delimiter);
-			GMT_ascii_output_one (GMT_stdout, xmin, 0);	fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
-			GMT_ascii_output_one (GMT_stdout, xmax, 0);	fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
-			GMT_ascii_output_one (GMT_stdout, ymin, 1);	fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
-			GMT_ascii_output_one (GMT_stdout, ymax, 1);	fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
+			sprintf (buffer,"%8s%s%8s%s", M.NGDC_id, gmtdefs.field_delimiter, D->H.mgd77[use]->Survey_Identifier, gmtdefs.field_delimiter);
+			GMT_fputs (buffer, GMT_stdout);
+			GMT_ascii_output_one (GMT_stdout, xmin, 0);	GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);
+			GMT_ascii_output_one (GMT_stdout, xmax, 0);	GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);
+			GMT_ascii_output_one (GMT_stdout, ymin, 1);	GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);
+			GMT_ascii_output_one (GMT_stdout, ymax, 1);	GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);
 			if (!GMT_is_dnan(tmin) && !GMT_is_dnan(tmax)) {
-				GMT_ascii_output_one (GMT_stdout, tmin, 2);	fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
-				GMT_ascii_output_one (GMT_stdout, tmax, 2);	fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);						
+				GMT_ascii_output_one (GMT_stdout, tmin, 2);	GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);
+				GMT_ascii_output_one (GMT_stdout, tmax, 2);	GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);						
 			} else {
-				fprintf (GMT_stdout, "%4s-%2s-%2s%s%4s-%2s-%2s%s",
+				sprintf (buffer, "%4s-%2s-%2s%s%4s-%2s-%2s%s",
 				D->H.mgd77[use]->Survey_Departure_Year, D->H.mgd77[use]->Survey_Departure_Month, D->H.mgd77[use]->Survey_Departure_Day, gmtdefs.field_delimiter,
 				D->H.mgd77[use]->Survey_Arrival_Year, D->H.mgd77[use]->Survey_Arrival_Month, D->H.mgd77[use]->Survey_Arrival_Day, gmtdefs.field_delimiter);
+				GMT_fputs (buffer, GMT_stdout);
 			}
-			fprintf (GMT_stdout, "%ld%s%ld", (GMT_LONG)irint (this_dist), gmtdefs.field_delimiter, D->H.n_records);
+			sprintf (buffer, "%ld%s%ld", (GMT_LONG)irint (this_dist), gmtdefs.field_delimiter, D->H.n_records);
+			GMT_fputs (buffer, GMT_stdout);
 			for (i = 1; i < M.n_out_columns; i++) {
 				if (i == id_col || i == t_col || i == x_col || i == y_col) continue;
-				if (((col_listing & 1) && M.order[i].set == 0) || ((col_listing & 2) && M.order[i].set == 1))
-					fprintf (GMT_stdout,"%s%ld",	gmtdefs.field_delimiter, counter[i]);
+				if (((col_listing & 1) && M.order[i].set == 0) || ((col_listing & 2) && M.order[i].set == 1)) {
+					sprintf (buffer,"%s%ld",	gmtdefs.field_delimiter, counter[i]);
+					GMT_fputs (buffer, GMT_stdout);
+				}
 			}
-			fprintf (GMT_stdout,"\n");
+			GMT_fputs ("\n", GMT_stdout);
 		}
 		MGD77_Free (D);
 	}
 		
-	MGD77_Path_Free (n_paths, list);
+	MGD77_Path_Free ((int)n_paths, list);
 	MGD77_end (&M);
 
 	exit (EXIT_SUCCESS);
