@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77list.c,v 1.110 2010/01/05 01:15:48 guru Exp $
+ *	$Id: mgd77list.c,v 1.118 2011/01/02 20:09:36 guru Exp $
  *
- *    Copyright (c) 2004-2010 by P. Wessel
+ *    Copyright (c) 2004-2011 by P. Wessel
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -52,14 +52,15 @@ int main (int argc, char **argv)
 	
 	GMT_LONG rec, prevrec, n_out = 0, start_rec = 0, stop_rec;
 	
-	BOOLEAN error = FALSE, exact = FALSE, string_output = FALSE, limit_institution = FALSE, need_depth = FALSE, fake_times = FALSE;
-	BOOLEAN negative_depth = FALSE,  negative_msd = FALSE, need_distances, need_time, limit_on_time = FALSE, limit_on_recs = FALSE;
-	BOOLEAN limit_on_dist = FALSE, limit_on_wesn = FALSE, need_lonlat = FALSE, first_cruise = TRUE, need_twt = FALSE, this_limit_on_time;
-	BOOLEAN need_date, need_sound = FALSE, apply_corrections = FALSE, adj_force = FALSE, PDR_wrap, skip_if_time_is_NaN = FALSE;
-	BOOLEAN limit_on_azimuth = FALSE, limit_on_velocity = FALSE, lonlat_not_NaN, first_warning = TRUE, has_prev_twt = FALSE;
+	GMT_LONG error = FALSE, exact = FALSE, string_output = FALSE, limit_institution = FALSE, need_depth = FALSE, fake_times = FALSE;
+	GMT_LONG negative_depth = FALSE,  negative_msd = FALSE, need_distances, need_time, limit_on_time = FALSE, limit_on_recs = FALSE;
+	GMT_LONG limit_on_dist = FALSE, limit_on_wesn = FALSE, need_lonlat = FALSE, first_cruise = TRUE, need_twt = FALSE, this_limit_on_time;
+	GMT_LONG need_date, need_sound = FALSE, apply_corrections = FALSE, adj_force = FALSE, PDR_wrap, skip_if_time_is_NaN = FALSE;
+	GMT_LONG limit_on_azimuth = FALSE, limit_on_velocity = FALSE, lonlat_not_NaN, first_warning = TRUE, has_prev_twt = FALSE;
 	
 	char *start_date = CNULL, *stop_date = CNULL, f_setting[BUFSIZ], fx_setting[BUFSIZ], **list = NULL, **item_names = NULL;
 	char *tvalue[MGD77_MAX_COLS], institution[3], s_unit[2], d_unit[2], *aux_tvalue[N_MGD77_AUX], *correction_table = CNULL;
+	char buffer[BUFSIZ];
 	
 	double west, east, south, north, start_time, stop_time, start_dist, IGRF[7], correction, min_vel = 0.0, max_vel = DBL_MAX;
 	double stop_dist, dist_scale, vel_scale, ds, dt, cumulative_dist, aux_dvalue[N_MGD77_AUX], *out = VNULL;
@@ -100,7 +101,7 @@ int main (int argc, char **argv)
 	GMT_LONG separate_aux_columns (struct MGD77_CONTROL *F, char *fx_setting, struct MGD77_AUX_INFO *aux, struct MGD77_AUXLIST *A);
 	GMT_LONG augment_aux_columns (int n_items, char **item_name, struct MGD77_AUX_INFO *aux, struct MGD77_AUXLIST *auxlist, int n_aux);
 
-	argc = GMT_begin (argc, argv);		/* Initialize GMT Machinery */
+	argc = (int)GMT_begin (argc, argv);		/* Initialize GMT Machinery */
 	
 	/* Initialize MGD77 output order and other parameters*/
 	
@@ -240,13 +241,13 @@ int main (int argc, char **argv)
 				if (!strcmp (f_setting, "all")) strcpy (f_setting, MGD77_ALL);
 				if (!strcmp (f_setting, "all+")) {
 					strcpy (f_setting, MGD77_ALL);
-					strcpy (f_setting, ",");
+					strcat (f_setting, ",");
 					strcat (f_setting, MGD77_AUX);
 				}
 				if (!strcmp (f_setting, "mgd77")) strcpy (f_setting, MGD77_GEO);
 				if (!strcmp (f_setting, "mgd77+")) {
 					strcpy (f_setting, MGD77_GEO);
-					strcpy (f_setting, ",");
+					strcat (f_setting, ",");
 					strcat (f_setting, MGD77_AUX);
 				}
 				break;
@@ -418,7 +419,7 @@ int main (int argc, char **argv)
 	if (GMT_give_synopsis_and_exit || argc == 1) {	/* Display usage */
 		fprintf(stderr,"mgd77list %s - Extract data from MGD77 files\n\n", MGD77_VERSION);
 		fprintf (stderr,"usage: mgd77list <cruise(s)> -F<dataflags>[,<tests>] [-A[+]c|d|f|m|t[code]] [-Cf|g|e] [-Da<startdate>] [-Db<stopdate>] [-E]\n");
-		fprintf (stderr, "\t[-H] [-I<code>] [-L[<corrtable.txt>]] [-N[s|p][e|k|n|m]]] [-Qa|v<min>/<max>] [%s]\n", GMT_Rgeo_OPT);
+		fprintf (stderr, "\t[-Ga<startrec>] [-Gb<stoprec>] [-H] [-I<code>] [-L[<corrtable.txt>]] [-N[s|p][e|k|n|m]]] [-Qa|v<min>/<max>] [%s]\n", GMT_Rgeo_OPT);
 		fprintf (stderr, "\t[-Sa<startdist>[unit]] [-Sb<stopdist>[unit]] [-T[m|e]] [-V] [-W<Weight>] [-Z[+|-] [%s] [%s]\n\n", GMT_bo_OPT, GMT_mo_OPT);
          
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
@@ -537,6 +538,8 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t  If A|B is used instead or a|b then records with no time are excluded from output\n");
 		fprintf (stderr, "\t-E Only records that exactly matches the requested geophysical information in -F will be used.\n");
 		fprintf (stderr, "\t   [Default will output all record that matches at least one column]\n");
+		fprintf (stderr, "\t-Ga<rec> lists from given record [Start of cruise]\n");
+		fprintf (stderr, "\t  b<rec> lists up to given record [End of cruise]\n");
 		fprintf (stderr, "\t-H Write one header record with column names\n");
 		fprintf (stderr, "\t-I Ignore certain data file formats from consideration. Append combination of act to ignore\n");
 		fprintf (stderr, "\t   (a) MGD77 ASCII, (c) MGD77+ netCDF, or (t) plain table files. [Default ignores none]\n");
@@ -595,9 +598,9 @@ int main (int argc, char **argv)
 	n_out_columns = M.n_out_columns;				/* This is the total number of columns in the final output */
 	if (MGD77_Get_Column ("depth", &M) == MGD77_NOT_SET) negative_depth = FALSE;	/* Just so we don't accidently access dvalue[z_col] further down in the loop */
 	if (MGD77_Get_Column ("msd", &M) == MGD77_NOT_SET) negative_msd = FALSE;	/* Just so we don't accidently access dvalue[m_col] further down in the loop */
-	n_aux = separate_aux_columns (&M, fx_setting, aux, auxlist);				/* Determine which auxillary columns are requested (if any) */
+	n_aux = (int)separate_aux_columns (&M, fx_setting, aux, auxlist);				/* Determine which auxillary columns are requested (if any) */
 	if (apply_corrections) {
-		n_aux = augment_aux_columns (n_items, item_names, aux, auxlist, n_aux);		/* Determine which auxillary columns are needed by -L */
+		n_aux = (int)augment_aux_columns (n_items, item_names, aux, auxlist, n_aux);		/* Determine which auxillary columns are needed by -L */
 		for (i = 0; i < n_items; i++) GMT_free ((void *)item_names[i]);
 		if (n_items) GMT_free ((void *)item_names);
 	}
@@ -800,20 +803,21 @@ int main (int argc, char **argv)
 		}
 		
 		if (!GMT_io.binary[GMT_OUT] && GMT_io.io_header[GMT_OUT]) {	/* Write out header record */
-			fprintf (GMT_stdout, "# ");
+			GMT_fputs ("# ", GMT_stdout);
 			for (i = kx = pos = 0; pos < n_out_columns; i++, pos++) {
 				while (kx < n_aux && aux[kx].pos == i) {	/* Insert auxillary column */
-					fprintf (GMT_stdout, "%s", auxlist[aux[kx].type].header);
-					if ((pos+1) < n_out_columns) fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
+					GMT_fputs (auxlist[aux[kx].type].header, GMT_stdout);
+					if ((pos+1) < n_out_columns) GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);
 					pos++, kx++;
 				}
 				if (i >= n_cols_to_process) continue;
 				c  = M.order[i].set;
 				id = M.order[i].item;
-				fprintf (GMT_stdout, "%7s", D->H.info[c].col[id].abbrev);
-				if ((pos+1) < n_out_columns) fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
+				sprintf (buffer, "%7s", D->H.info[c].col[id].abbrev);
+				GMT_fputs (buffer, GMT_stdout);
+				if ((pos+1) < n_out_columns) GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);
 			}
-			fprintf (GMT_stdout, "\n");
+			GMT_fputs ("\n", GMT_stdout);
 		}
 
 		if (GMT_io.multi_segments[GMT_OUT]) {	/* Write multisegment header between each cruise */
@@ -851,7 +855,7 @@ int main (int argc, char **argv)
 
 		this_limit_on_time = limit_on_time;	/* Since we might change it below */
 		if (time_column != MGD77_NOT_SET && D->H.no_time) {	/* Cannot know if ASCII MGD77 dont have time until after reading */
-			BOOLEAN faked = FALSE;
+			GMT_LONG faked = FALSE;
 			if (fake_times) {	/* Try to make fake times based on duration and distances */
 				faked = MGD77_fake_times (&M, &(D->H), dvalue[x_col], dvalue[y_col], dvalue[t_col], D->H.n_records);
 				if (faked && gmtdefs.verbose) fprintf (stderr, "%s: Warning: Time column for cruise %s created from distances and duration\n", GMT_program, list[argno]);
@@ -940,11 +944,11 @@ int main (int argc, char **argv)
 		
 			if (need_time) {	/* Need auxillary time columns such as year, days etc, hence we get the calendar first, then use MGD77_cal_to_fyear */
 				MGD77_gcal_from_dt (&M, dvalue[t_col][rec], &cal);	/* No adjust for TZ; this is GMT UTC time */
-				aux_dvalue[MGD77_AUX_YR] = cal.year;
-				aux_dvalue[MGD77_AUX_MO] = cal.month;
-				aux_dvalue[MGD77_AUX_DY] = cal.day_m;
-				aux_dvalue[MGD77_AUX_HR] = cal.hour;
-				aux_dvalue[MGD77_AUX_MI] = cal.min;
+				aux_dvalue[MGD77_AUX_YR] = (double)cal.year;
+				aux_dvalue[MGD77_AUX_MO] = (double)cal.month;
+				aux_dvalue[MGD77_AUX_DY] = (double)cal.day_m;
+				aux_dvalue[MGD77_AUX_HR] = (double)cal.hour;
+				aux_dvalue[MGD77_AUX_MI] = (double)cal.min;
 				aux_dvalue[MGD77_AUX_SC] = cal.sec;
 				date = MGD77_cal_to_fyear (&cal);	/* Get date as decimal year */
 				need_date = FALSE;
@@ -1084,17 +1088,17 @@ int main (int argc, char **argv)
 				for (i = kx = pos = 0; pos < n_out_columns; i++, pos++) {
 					while (kx < n_aux && aux[kx].pos == i) {	/* Insert auxillary column */
 						if (aux[kx].text)
-							fprintf (GMT_stdout, "%s", aux_tvalue[aux[kx].type]);
+							GMT_fputs (aux_tvalue[aux[kx].type], GMT_stdout);
 						else
 							GMT_ascii_output_one (GMT_stdout, aux_dvalue[aux[kx].type], pos);
-						if ((pos+1) < n_out_columns) fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
+						if ((pos+1) < n_out_columns) GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);
 						kx++, pos++;
 					}
 					if (i >= n_cols_to_process) continue;
 					c  = M.order[i].set;
 					id = M.order[i].item;
 					if (D->H.info[c].col[id].text)
-						for (k = 0; k < D->H.info[c].col[id].text && tvalue[i][rec*D->H.info[c].col[id].text+k]; k++) fputc ((int)tvalue[i][rec*D->H.info[c].col[id].text+k], GMT_stdout);
+						for (k = 0; k < D->H.info[c].col[id].text && tvalue[i][rec*D->H.info[c].col[id].text+k]; k++) GMT_fputc ((int)tvalue[i][rec*D->H.info[c].col[id].text+k], GMT_stdout);
 					else if (id == time_column) {	/* Time */
 						if (GMT_io.out_col_type[pos] == GMT_IS_FLOAT) {	/* fractional year */
 							if (need_date) {	/* Did not get computed already */
@@ -1112,9 +1116,9 @@ int main (int argc, char **argv)
 						correction = (apply_corrections) ? MGD77_Correction (CORR[argno][i].term, dvalue, aux_dvalue, rec) : 0.0;
 						GMT_ascii_output_one (GMT_stdout, dvalue[i][rec] - correction, pos);
 					}
-					if ((pos+1) < n_out_columns) fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
+					if ((pos+1) < n_out_columns) GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);
 				}
-				fprintf (GMT_stdout, "\n");
+				GMT_fputs ("\n", GMT_stdout);
 			}
 			else {	/* Use GMT output machinery which can handle binary output, if requested */
 				for (i = kx = pos = 0; pos < n_out_columns; i++, pos++) {
