@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77magref.c,v 1.23 2010/01/05 01:15:48 guru Exp $
+ *	$Id: mgd77magref.c,v 1.30 2011/03/06 02:09:56 guru Exp $
  *
- *    Copyright (c) 2009-2010 by J. Luis and P. Wessel
+ *    Copyright (c) 2009-2011 by J. Luis and P. Wessel
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -18,13 +18,12 @@
 
 int main (int argc, char **argv) {
 
-	int i, j, s, pos_slash = 0, nval = 0, nfval = 0, fno, n_files = 0, error = 0, n_args, t_col = 3, n_out = 0;
-	int lval = 0, lfval = 0, n_field_components, this_i;
-	GMT_LONG pos;
-	BOOLEAN nofile = TRUE, copy_input = FALSE, time_in_years = FALSE, fixed_alt = FALSE, fixed_time = FALSE;
-	BOOLEAN do_CM4 = TRUE, joint_IGRF_CM4 = FALSE, do_IGRF = FALSE, cm4_igrf_T = FALSE, done;
+	GMT_LONG i, j, s, pos_slash = 0, nval = 0, nfval = 0, fno, n_files = 0, n_args, t_col = 3, n_out = 0;
+	GMT_LONG lval = 0, lfval = 0, n_field_components, this_i, pos, error = 0;
+	GMT_LONG nofile = TRUE, copy_input = FALSE, time_in_years = FALSE, fixed_alt = FALSE, fixed_time = FALSE;
+	GMT_LONG do_CM4 = TRUE, joint_IGRF_CM4 = FALSE, do_IGRF = FALSE, cm4_igrf_T = FALSE, done;
 	size_t n_alloc = 0, need = 0;
-	double	the_altitude, the_time, *time_array = NULL, *alt_array = NULL, *time_years = NULL, IGRF[7], out[BUFSIZ];
+	double	the_altitude, the_time, *time_array = NULL, *alt_array = NULL, *time_years = NULL, IGRF[7], out[GMT_MAX_COLUMNS];
 	double	*igrf_xyz = NULL;	/* Temporary storage for the joint_IGRF_CM4 case */
 	char p[GMT_LONG_TEXT], txt[GMT_LONG_TEXT];
 	FILE *fp;
@@ -35,7 +34,7 @@ int main (int argc, char **argv) {
 
 	Ctrl = (struct MGD77_CM4 *)New_CM4_Ctrl ();	/* Allocate and initialize a new control structure */
 
-	argc = GMT_begin (argc, argv);		/* Initialize GMT Machinery */
+	argc = (int) GMT_begin (argc, argv);		/* Initialize GMT Machinery */
 	
 	GMT_get_time_system ("unix", &(gmtdefs.time_system));						/* MGD77+ uses GMT's Unix time epoch */
 	GMT_init_time_system_structure (&(gmtdefs.time_system));
@@ -75,6 +74,7 @@ int main (int argc, char **argv) {
 							case 't':
 								fixed_time = TRUE;
 								the_time = atof (&p[1]);
+								GMT_io.out_col_type[3] = GMT_IS_FLOAT;
 								break;
 							case 'y':
 								time_in_years = TRUE;
@@ -90,10 +90,10 @@ int main (int argc, char **argv) {
 					Ctrl->M.path = strdup (&argv[i][2]);
 					break;
 				case 'D':
-					this_i = i;
+					this_i = 2;
 					if (argv[i][2] == '-') this_i++;
-					if ((argv[this_i][2] > 47) && (argv[this_i][2] < 58)) {	/* arg is numeric -> Dst Index */
-						Ctrl->D.dst[0] = atof(&argv[this_i][2]);
+					if ((argv[i][this_i] > 47) && (argv[i][this_i] < 58)) {	/* arg is numeric -> Dst Index */
+						Ctrl->D.dst[0] = atof(&argv[i][2]);
 						Ctrl->D.index = FALSE; 
 					}
 					else {
@@ -149,7 +149,7 @@ int main (int argc, char **argv) {
 								break;
 						}
 					}
-					Ctrl->F.n_field_components = nval; 
+					Ctrl->F.n_field_components = (int)nval; 
 
 					if (pos_slash) {
 						for (j = pos_slash; argv[i][j]; j++) {
@@ -187,7 +187,7 @@ int main (int argc, char **argv) {
 									break;
 							}
 						}
-						Ctrl->F.n_field_sources = nfval; 
+						Ctrl->F.n_field_sources = (int)nfval; 
 					}
 					break;
 				case 'G':
@@ -220,7 +220,7 @@ int main (int argc, char **argv) {
 								break;
 						}
 					}
-					Ctrl->L.n_curr_components = lval; 
+					Ctrl->L.n_curr_components = (int)lval; 
 
 					if (pos_slash) {
 						for (j = pos_slash; argv[i][j]; j++) {
@@ -239,7 +239,7 @@ int main (int argc, char **argv) {
 									break;
 							}
 						}
-						Ctrl->L.n_curr_sources = lfval; 
+						Ctrl->L.n_curr_sources = (int)lfval; 
 					}
 					break;
 				case 'S':
@@ -348,7 +348,7 @@ int main (int argc, char **argv) {
 	n_out = 4 - (int)(fixed_alt + fixed_time);	/* Minimum input columns (could be more) */
 	if (GMT_io.binary[GMT_IN] && GMT_io.ncol[GMT_IN] == 0) GMT_io.ncol[GMT_IN] = n_out;
 	if (GMT_io.binary[GMT_IN] && GMT_io.ncol[GMT_IN] < n_out) {
-		fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data (-bi) must have at least %d columns\n", GMT_program, n_out);
+		fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data (-bi) must have at least %ld columns\n", GMT_program, n_out);
 		error++;
 	}
 
@@ -370,7 +370,7 @@ int main (int argc, char **argv) {
 		else {
 			cm4_igrf_T = FALSE;
 			if ( (nval == 1) && (Ctrl->F.field_components[0] == 0) ) {
-				for (i = 0; i < 3; i++) Ctrl->F.field_components[i] = i+2;	/* Force the x,y,z request */
+				for (i = 0; i < 3; i++) Ctrl->F.field_components[i] = (int)(i+2);	/* Force the x,y,z request */
 				cm4_igrf_T = TRUE;
 			}
 			else if ( !((nval == 3) && 
@@ -380,7 +380,7 @@ int main (int argc, char **argv) {
 			}
 
 			nval = 3;
-			Ctrl->F.n_field_components = nval; 
+			Ctrl->F.n_field_components = (int)nval; 
 		}
 	}
 	/* ----------------------------------------------------------------------------------------------------- */
@@ -394,7 +394,7 @@ int main (int argc, char **argv) {
 		if (nval == 0) {		/* No components selected, default used */
 			copy_input = TRUE;
 			Ctrl->F.n_field_components = 7;
-			for (i = 0; i < 7; i++) Ctrl->F.field_components[i] = i;
+			for (i = 0; i < 7; i++) Ctrl->F.field_components[i] = (int)i;
 		}
 		if (nfval == 0 && !joint_IGRF_CM4) {		/* No sources selected, retain only the main field */
 			Ctrl->F.field_sources[0] = 0; 
@@ -460,7 +460,7 @@ int main (int argc, char **argv) {
 		
 		n_out = n_field_components + ((copy_input) ? T->segment[0]->n_columns : 0);
 		if (GMT_io.binary[GMT_OUT] && GMT_io.ncol[GMT_OUT] > 0 && n_out > GMT_io.ncol[GMT_OUT]) {
-			fprintf (stderr, "%s: Binary output must have at least %d columns (your -bo option only set %ld)\n", 
+			fprintf (stderr, "%s: Binary output must have at least %ld columns (your -bo option only set %ld)\n", 
 				GMT_program, n_out, GMT_io.ncol[GMT_OUT]);
 			exit (EXIT_FAILURE);
 		}
@@ -485,11 +485,11 @@ int main (int argc, char **argv) {
 
 			if (!fixed_alt) {	/* Assign the alt_array to the provided altitude array */
 				alt_array = T->segment[s]->coord[GMT_Z];
-				Ctrl->DATA.n_altitudes = T->segment[s]->n_rows;
+				Ctrl->DATA.n_altitudes = (int)T->segment[s]->n_rows;
 			}
 
 			if (!fixed_time) {	/* Assign the time_array to the provided time array */
-				Ctrl->DATA.n_times = T->segment[s]->n_rows;
+				Ctrl->DATA.n_times = (int)T->segment[s]->n_rows;
 				if (time_in_years)
 					time_array = T->segment[s]->coord[t_col];
 				else {	/* Must convert internal GMT time to decimal years first */
@@ -504,7 +504,7 @@ int main (int argc, char **argv) {
 				fprintf (stderr, "\tThough extended here to 2009 the secular variation estimation will be unreliable.\n");
 			}
 
-			Ctrl->DATA.n_pts = T->segment[s]->n_rows;
+			Ctrl->DATA.n_pts = (int)T->segment[s]->n_rows;
 			if (do_IGRF || joint_IGRF_CM4) {
 				int type;
 				type = (Ctrl->G.geodetic) ? 1 : 2;
