@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77manage.c,v 1.137 2010/01/14 07:15:20 guru Exp $
+ *	$Id: mgd77manage.c,v 1.143 2011/01/02 20:09:36 guru Exp $
  *
- *    Copyright (c) 2005-2010 by P. Wessel
+ *    Copyright (c) 2005-2011 by P. Wessel
  * mgd77manage is used to (1) remove data columns from mgd77+ files
  * or (2) add a new data column to mgd77+ files.  Data can be added
  * from data tables, created from reference field formulas, or by
@@ -64,10 +64,10 @@ int main (int argc, char **argv)
 	
 	nc_type c_nc_type;
 	
-	BOOLEAN got_c = FALSE, got_a = FALSE, got_d = FALSE, got_g = FALSE, got_i = FALSE, got_n = FALSE, got_t = FALSE;
-	BOOLEAN error = FALSE, replace = FALSE, delete = FALSE, interpolate = FALSE, transform, verified, force = FALSE;
-	BOOLEAN strings = FALSE, got_grid, got_table, two_cols = FALSE, constant, ok_to_read = TRUE, got_e = FALSE;
-	BOOLEAN ignore_verify = FALSE, e77_skip_mode[N_E77_MODES];
+	GMT_LONG got_c = FALSE, got_a = FALSE, got_d = FALSE, got_g = FALSE, got_i = FALSE, got_n = FALSE, got_t = FALSE;
+	GMT_LONG error = FALSE, replace = FALSE, delete = FALSE, interpolate = FALSE, transform, verified, force = FALSE;
+	GMT_LONG strings = FALSE, got_grid, got_table, two_cols = FALSE, constant, ok_to_read = TRUE, got_e = FALSE;
+	GMT_LONG ignore_verify = FALSE, e77_skip_mode[N_E77_MODES];
 	
 	char line[BUFSIZ], file[BUFSIZ], *d_list = CNULL, p[BUFSIZ], history[BUFSIZ], c_size = 0, **list;
 	char c_abbrev[GMT_TEXT_LEN], c_units[GMT_TEXT_LEN], c_name[MGD77_COL_NAME_LEN], c_comment[MGD77_COL_COMMENT_LEN];
@@ -93,7 +93,7 @@ int main (int argc, char **argv)
 	GMT_LONG skip_if_missing (char *name, char *file, struct MGD77_CONTROL *F, struct MGD77_DATASET *D);
 	GMT_LONG got_default_answer (char *line, char *answer);
 
-	argc = GMT_begin (argc, argv);		/* Initialize GMT Machinery */
+	argc = (int)GMT_begin (argc, argv);		/* Initialize GMT Machinery */
 	GMT_get_time_system ("unix", &(gmtdefs.time_system));						/* MGD77+ uses GMT's Unix time epoch */
 	GMT_init_time_system_structure (&(gmtdefs.time_system));
 	
@@ -107,7 +107,7 @@ int main (int argc, char **argv)
 	parameters[COL_TYPE]    = 0;	/* netCDF type */
 	GMT_pad[0] = GMT_pad[1] = GMT_pad[2] = GMT_pad[3] = 2;
 	d_unit[0] = d_unit[1] = '\0';
-	memset ((void *)e77_skip_mode, 0, (size_t)(N_E77_MODES * sizeof (BOOLEAN)));
+	memset ((void *)e77_skip_mode, 0, (size_t)(N_E77_MODES * sizeof (GMT_LONG)));
 	/* Default e77_skip_mode will apply header and fix corrections if prefix is Y and set all data bits */
 	
 	MGD77_Init (&In);			/* Initialize MGD77 Machinery */
@@ -215,6 +215,7 @@ int main (int argc, char **argv)
 
 				case 'F':	/* Force mode */
 					force = TRUE;
+					break;
 
 				case 'I':	/* Column attribute information */
 					error += decode_I_options (&argv[i][2], c_abbrev, c_name, c_units, &c_size, c_comment, parameters);
@@ -503,7 +504,7 @@ int main (int argc, char **argv)
 		two_cols = (got_d || got_n || got_t);
 		n = (two_cols) ? -1 : 0;
 		n_alloc = GMT_CHUNK;
-		n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : BUFSIZ;
+		n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : GMT_MAX_COLUMNS;
 		colvalue = (double *) GMT_memory (VNULL, n_alloc, sizeof (double), GMT_program);
 		if (two_cols) {	/* Got an abscissae column as well (dnt: d = dist, n = rec number, t = time) */
 			coldnt = (double *) GMT_memory (VNULL, n_alloc, sizeof (double), GMT_program);
@@ -796,7 +797,7 @@ int main (int argc, char **argv)
 			yvar = (double *)D->values[iy];
 			colvalue = (double *)GMT_memory (VNULL, (size_t)D->H.n_records, sizeof (double), GMT_program);
 			
-			for (i = 0; i < D->H.n_records; i++) colvalue[i] = MGD77_Theoretical_Gravity (xvar[i], yvar[i], GF_version);
+			for (i = 0; i < D->H.n_records; i++) colvalue[i] = MGD77_Theoretical_Gravity (xvar[i], yvar[i], (int)GF_version);
 			if (gmtdefs.verbose) fprintf (stderr, "%s: Estimated IGRF at %ld locations out of %ld for cruise %s\n", GMT_program, D->H.n_records, D->H.n_records, list[argno]);
 		}
 		else if (got_c == ADD_CARTER) {	/* Append Carter correction column */
@@ -965,7 +966,7 @@ int main (int argc, char **argv)
 			GMT_LONG n_E77_headers, n_E77_scales, n_E77_offsets, n_E77_recalcs, n_tz_corr, n_unprocessed, e_error = 0;
 			unsigned int *flags, pattern;
 			size_t length;
-			BOOLEAN has_time, old_flags, tz_errors = FALSE;
+			GMT_LONG has_time, old_flags, tz_errors = FALSE;
 			short *tz_corr = NULL;
 			struct MGD77_HEADER_PARAMS *P;
 			double rec_time, del_t, value, *tvar = VNULL;
@@ -995,7 +996,7 @@ int main (int argc, char **argv)
 				fprintf(stderr, "%s: ERROR: Could not read record #1 from %s.e77 - aborting\n", GMT_program, list[argno]);
 				e_error++;
 			}
-			sscanf (&line[1], "%*s %s %*s %*s %*s %*s %*s %s %*s %ld", ID, date, &n_recs);
+			sscanf (&line[1], "%*s %s %*s %*s %*s %*s %*s %s %*s %" GMT_LL "d", ID, date, &n_recs);
 			if (strcmp (In.NGDC_id, ID)) {
 				fprintf(stderr, "%s: ERROR: E77 Conflict %s : ID = %s versus %s - aborting\n", GMT_program, efile, ID, In.NGDC_id);
 				e_error++;
@@ -1047,10 +1048,10 @@ int main (int argc, char **argv)
 						if (line[0] == '?') n_unprocessed++;
 						e_error++;
 					}
-					sscanf (line, "%c-%c-%[^-]-%[^-]-%ld", &YorN, &kind, ID, field, &item);
+					sscanf (line, "%c-%c-%[^-]-%[^-]-%" GMT_LL "d", &YorN, &kind, ID, field, &item);
 				}
 				else				/* Data record */
-					sscanf (line, "%c %s %s %ld %s", &YorN, ID, timestamp, &rec, code);
+					sscanf (line, "%c %s %s %" GMT_LL "d %s", &YorN, ID, timestamp, &rec, code);
 				if (strcmp (In.NGDC_id, ID)) {
 					fprintf(stderr, "%s: ERROR: E77 Conflict %s : ID = %s versus %s in header records!\n", GMT_program, efile, ID, In.NGDC_id);
 					e_error++;
@@ -1087,7 +1088,7 @@ int main (int argc, char **argv)
 				/* Example of expected line:  
 				   Y-E-06050010-H15-01: Invalid Gravity Departure Base Station Value: (0000000) [1000009]
 				*/
-				sscanf (line, "%c-%c-%[^-]-%[^-]-%ld", &YorN, &kind, ID, field, &item);
+				sscanf (line, "%c-%c-%[^-]-%[^-]-%" GMT_LL "d", &YorN, &kind, ID, field, &item);
 				if (strcmp (In.NGDC_id, ID)) {
 					fprintf(stderr, "%s: ERROR: E77 Conflict %s : ID = %s versus %s in header records - skipped\n", GMT_program, efile, ID, In.NGDC_id);
 					e_error++;
@@ -1113,7 +1114,7 @@ int main (int argc, char **argv)
 				
 				if (type == E77_HEADER_MODE) {	/* Header meta data fixes */
 				
-					key = MGD77_Param_Key (number, item);	/* Returns -ve if sequence not found or item not found, >=0 otherwise */
+					key = MGD77_Param_Key ((int)number, (int)item);	/* Returns -ve if sequence not found or item not found, >=0 otherwise */
 					
 					switch (key) {
 						case MGD77_BAD_HEADER_RECNO:
@@ -1184,7 +1185,7 @@ int main (int argc, char **argv)
 								break;
 							case E77_HDR_GRID_OFFSET:	/* Range of bad values - set flags to BAD  */
 							case E77_HDR_FLAGRANGE:		/* Range of bad values - set flags to BAD  */
-								sscanf (answer, "%ld-%ld", &from, &to);
+								sscanf (answer, "%" GMT_LL "d-%" GMT_LL "d", &from, &to);
 								if (from < 1 || from > D->H.n_records || to < 1 || to > D->H.n_records || to < from) {
 									fprintf (stderr, "%s: Error: Record range %s is invalid.  Correction skipped\n", GMT_program, answer);
 									break;
@@ -1207,7 +1208,7 @@ int main (int argc, char **argv)
 				for (rec = 0, has_time = FALSE; !has_time && rec < D->H.n_records; rec++) if (!GMT_is_dnan (tvar[rec])) has_time = TRUE;
 			}
 			while (GMT_fgets (line, BUFSIZ, fp_e)) {	/* Read until EOF */
-				sscanf (line, "%c %s %s %ld %s", &YorN, ID, timestamp, &rec, code);
+				sscanf (line, "%c %s %s %" GMT_LL "d %s", &YorN, ID, timestamp, &rec, code);
 				if (strcmp (In.NGDC_id, ID)) {
 					fprintf(stderr, "%s: ERROR: E77 Conflict %s : ID = %s versus %s in data records - skipped\n", GMT_program, efile, ID, In.NGDC_id);
 					e_error++;
@@ -1275,7 +1276,7 @@ int main (int argc, char **argv)
 										tz_corr = (short *)GMT_memory (VNULL, (size_t)D->H.n_records, sizeof (short), GMT_program);
 										tz_errors = TRUE;
 									}
-									sscanf (line, "%*c %*s %*s %*s %*s %*s %*s %*s %ld", &tz);
+									sscanf (line, "%*c %*s %*s %*s %*s %*s %*s %*s %" GMT_LL "d", &tz);
 									tz_corr[rec] = (short)tz;
 									n_tz_corr++;
 									break;
@@ -1495,7 +1496,7 @@ int main (int argc, char **argv)
 			fprintf (stderr, "%s: Sampled data for %ld MGD77 files\n", GMT_program, n_changed);
 	}
 	
-	MGD77_Path_Free (n_paths, list);
+	MGD77_Path_Free ((int)n_paths, list);
 	MGD77_end (&In);
 
 	exit (EXIT_SUCCESS);
