@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77path.c,v 1.24 2010/01/05 01:15:48 guru Exp $
+ *	$Id: mgd77path.c,v 1.27 2011/01/02 20:09:36 guru Exp $
  *
- *    Copyright (c) 2004-2010 by P. Wessel
+ *    Copyright (c) 2004-2011 by P. Wessel
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -21,13 +21,13 @@ int main (int argc, char **argv)
 {
 	GMT_LONG i, n_cruises = 0, n_paths;
 	
-	BOOLEAN error = FALSE, dirs = FALSE, strip = FALSE;
+	GMT_LONG error = FALSE, dirs = FALSE, strip = FALSE;
 	
 	char path[BUFSIZ], **list;
 	
 	struct MGD77_CONTROL M;
 
-	argc = GMT_begin (argc, argv);		/* Initialize GMT Machinery */
+	argc = (int)GMT_begin (argc, argv);		/* Initialize GMT Machinery */
 	
 	MGD77_Init (&M);			/* Initialize MGD77 Machinery */
 
@@ -103,7 +103,7 @@ int main (int argc, char **argv)
 	
 	if (gmtdefs.verbose) fprintf (stderr, "%s: Found %ld cruises\n", GMT_program, n_cruises);
 	
-	MGD77_Path_Free (n_paths, list);
+	MGD77_Path_Free ((int)n_paths, list);
 	MGD77_end (&M);
 	GMT_end (argc, argv);
 	
