@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77track.c,v 1.68 2010/01/05 01:15:48 guru Exp $
+ *	$Id: mgd77track.c,v 1.74 2011/03/06 02:09:56 guru Exp $
  *
- *    Copyright (c) 2004-2010 by P. Wessel
+ *    Copyright (c) 2004-2011 by P. Wessel
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -49,24 +49,24 @@ struct MGD77TRACK_LEG_ANNOT {	/* Structure used to annotate legs after clipping
 struct MGD77TRACK_MARKER {
 	double marker_size, font_size;
 	struct GMT_FILL f, s;	/* Font and symbol colors */
-	int font_no;
+	GMT_LONG font_no;
 };
 
 int main (int argc, char **argv)
 {
-	GMT_LONG rec, first_rec, last_rec, n_alloc_c = GMT_SMALL_CHUNK;
 	int i, j, n_id = 0, mrk = 0, annot_name = 0, dist_flag = 2, use, n_paths;
-	int this_julian = 0, last_julian, argno, n_cruises = 0;
 	
-	BOOLEAN error = FALSE, first, both = FALSE, no_clip = FALSE;
-	BOOLEAN  annot_tick[2] = {0, 0}, draw_tick[2] = {0, 0}, dist_gap = FALSE, time_gap = FALSE;
+	GMT_LONG rec, first_rec, last_rec, n_alloc_c = GMT_SMALL_CHUNK;
+	GMT_LONG this_julian = 0, last_julian, argno, n_cruises = 0;
+	GMT_LONG error = FALSE, first, both = FALSE, no_clip = FALSE;
+	GMT_LONG  annot_tick[2] = {0, 0}, draw_tick[2] = {0, 0}, dist_gap = FALSE, time_gap = FALSE;
 	
 	char *start_date = CNULL, *stop_date = CNULL, ms[GMT_TEXT_LEN], mc[GMT_TEXT_LEN];
        	char label[GMT_LONG_TEXT], date[GMT_TEXT_LEN], clock[GMT_TEXT_LEN], comment[BUFSIZ];
 	char mfs[GMT_TEXT_LEN], mf[GMT_TEXT_LEN], mfc[GMT_TEXT_LEN], name[GMT_TEXT_LEN], **list, *p;
 
 	double west, east, south, north, start_time, stop_time, start_dist, gap_d = 0.0, gap_t = 0.0;
-	double stop_dist, dist_scale, x, y, annot_dist[2] = {0, 0}, tick_dist[2] = {0, 0}, annot_time[2] = {0, 0}, tick_time[2] = {0, 0};
+	double stop_dist, x, y, annot_dist[2] = {0, 0}, tick_dist[2] = {0, 0}, annot_time[2] = {0, 0}, tick_time[2] = {0, 0};
 	double *track_dist = NULL, angle, plot_x, plot_y, *lon, *lat, *track_time;
 	double annotsize = MGD77TRACK_ANSIZE, factor = 0.001, scale = 1.0, c_angle;
 	
@@ -81,9 +81,9 @@ int main (int argc, char **argv)
 	int get_annotinfo (char *args, struct MGD77TRACK_ANNOT *info);
 	void annot_legname (double x, double y, double lon, double lat, double angle, char *text, double size);
 	double heading (GMT_LONG rec, double *lon, double *lat, GMT_LONG n_records);
-	BOOLEAN bad_coordinates (double lon, double lat);
+	GMT_LONG bad_coordinates (double lon, double lat);
 
-	argc = GMT_begin (argc, argv);		/* Initialize GMT Machinery */
+	argc = (int)GMT_begin (argc, argv);		/* Initialize GMT Machinery */
 	
 	GMT_init_pen (&pen, GMT_PENWIDTH);
 	GMT_init_fill (&marker[MGD77TRACK_MARK_NEWDAY].s, 0, 0, 0);	/* Black color for new Julian day marker */
@@ -335,9 +335,9 @@ int main (int argc, char **argv)
 		fprintf (stderr, "	   day marker, and d for distance marker.  Then, append 5 comma-separated items:\n");
 		fprintf (stderr, "	   <markersize>[unit],<markercolor>,<markerfontsize,<markerfont>,<markerfontcolor>\n");
 		fprintf (stderr, "	   Default settings for the three marker types are:\n");
-		fprintf (stderr, "	     -TT%g,black,%g,%d,black\n", marker[MGD77TRACK_MARK_NEWDAY].marker_size, marker[MGD77TRACK_MARK_NEWDAY].font_size, marker[MGD77TRACK_MARK_NEWDAY].font_no);
-		fprintf (stderr, "	     -Tt%g,white,%g,%d,black\n", marker[MGD77TRACK_MARK_SAMEDAY].marker_size, marker[MGD77TRACK_MARK_SAMEDAY].font_size, marker[MGD77TRACK_MARK_SAMEDAY].font_no);
-		fprintf (stderr, "	     -Td%g,black,%g,%d,black\n", marker[MGD77TRACK_MARK_DIST].marker_size, marker[MGD77TRACK_MARK_DIST].font_size, marker[MGD77TRACK_MARK_DIST].font_no);
+		fprintf (stderr, "	     -TT%g,black,%g,%ld,black\n", marker[MGD77TRACK_MARK_NEWDAY].marker_size, marker[MGD77TRACK_MARK_NEWDAY].font_size, marker[MGD77TRACK_MARK_NEWDAY].font_no);
+		fprintf (stderr, "	     -Tt%g,white,%g,%ld,black\n", marker[MGD77TRACK_MARK_SAMEDAY].marker_size, marker[MGD77TRACK_MARK_SAMEDAY].font_size, marker[MGD77TRACK_MARK_SAMEDAY].font_no);
+		fprintf (stderr, "	     -Td%g,black,%g,%ld,black\n", marker[MGD77TRACK_MARK_DIST].marker_size, marker[MGD77TRACK_MARK_DIST].font_size, marker[MGD77TRACK_MARK_DIST].font_no);
 		GMT_explain_option ('U');
 		GMT_explain_option ('V');
 		fprintf (stderr, "	-W sets track pen attributes [width = %gp, color = (%d/%d/%d), texture = solid line].\n", 
@@ -355,7 +355,6 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
-	dist_scale = 1000.0 * project_info.M_PR_DEG;	/* Work internally in meters */
 	use = (M.original) ? MGD77_ORIG : MGD77_REVISED;
 
 	if (east < west) west -= 360.0;
@@ -383,10 +382,6 @@ int main (int argc, char **argv)
 			fprintf (stderr, "%s: Error reading header sequence for cruise %s\n", GMT_program, list[argno]);
 			exit (EXIT_FAILURE);
 		}
-		if (GMT_io.multi_segments[GMT_OUT]) {	/* Write multisegment header between each cruise */
-			sprintf (GMT_io.segment_header, "%c %s\n", GMT_io.EOF_flag[GMT_OUT], list[argno]);
-			GMT_write_segmentheader (GMT_stdout, M.n_out_columns);
-		}
 		rec = 0;
 		last_julian = -1;
 		
@@ -578,7 +573,7 @@ int main (int argc, char **argv)
 
 	GMT_plotend ();
 	
-	if (gmtdefs.verbose) fprintf (stderr, "%s: Plotted %d cruises\n", GMT_program, n_cruises);
+	if (gmtdefs.verbose) fprintf (stderr, "%s: Plotted %ld cruises\n", GMT_program, n_cruises);
 
 	MGD77_Path_Free (n_paths, list);
 	MGD77_end (&M);
@@ -708,6 +703,6 @@ void annot_legname (double x, double y, double lon, double lat, double angle, ch
 	ps_text (x, y, size, text, angle, just, 0);
 }
 
-BOOLEAN bad_coordinates (double lon, double lat) {
+GMT_LONG bad_coordinates (double lon, double lat) {
 	return (GMT_is_dnan (lon) || GMT_is_dnan (lat));
 }
