@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: binlegs.c,v 1.19 2010/01/05 01:15:48 guru Exp $
+ *	$Id: binlegs.c,v 1.22 2011/03/05 21:24:29 guru Exp $
  *
- *    Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *    Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -14,7 +14,7 @@
  * as Brown-book LOC, but now all the legs listed are really
  * inside the area).  The list of legs given to binlegs will have
  * the .bix suffix appended before opening the index file
- * 
+ *
  * Author:	Paul Wessel
  * Date:	21-MAY-1987
  * Revised:	13-SEP-1989	Added option to remove legs and specify path
@@ -23,9 +23,9 @@
  * Version:	2.0 21-Jun-1991
  *		3.1 15-OCT-1998 POSIX compliant
  *		3.2 10-MAR-1999 New GMT_SHAREDIR/mgg directory place for data
- * 
+ *
  */
- 
+
 #include "gmt.h"
 
 #ifdef WIN32
@@ -36,18 +36,18 @@ extern int _chmod (const char *path, int mode);
 #endif
 
 #define S_RDONLY 0000444
- 
+
 struct GRID {
 	int bix;
 	int n_legs;
 	struct LEG *first_leg, *last_leg;
 };
-	
+
 struct LEG {
 	int leg_id;		/* Low 4 bytes carries gmt-flag, rest has id_no << 4 */
 	struct LEG *next_leg;
 };
-	
+
 struct INFO {
 	char legname[16];
 	int leg_id;
@@ -60,19 +60,19 @@ int main (int argc, char **argv)
 
 	struct INFO *info_head, *this_info, *new_info, *make_info(char *name, int id_no, int flag);
 	struct LEG *this_leg, *make_leg(int id, int flag);
-	
+
 	char file[BUFSIZ], leg[16], lname[16], line[BUFSIZ], *c_unused = NULL;
-	char leg_file[BUFSIZ], index_file[BUFSIZ], old_leg_file[BUFSIZ], old_index_file[BUFSIZ], path[BUFSIZ];
+	char leg_file[BUFSIZ], index_file[BUFSIZ], old_leg_file[BUFSIZ], old_index_file[BUFSIZ];
 	char error = FALSE, replace = FALSE, delete = FALSE, found_it, verbose = FALSE;
-	
+
 	FILE *fp = NULL, *fbin, *fleg, *find;
-	
-	int no_of_legs, index, id, bin, free_id, max, flag, not_used = 0;
+
+	int no_of_legs, index, id, bin, free_id, max, flag, i, j, year, last_id;
+	size_t not_used = 0;
 	int remove_leg(int leg_id, struct GRID *grid);
-	int i, j, year, last_id;
 	struct GRID grid[64800];
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	if (argc == 1) error = TRUE;
 	for (i = 1; i < argc; i++) {
@@ -86,9 +86,6 @@ int main (int argc, char **argv)
 						delete = TRUE;
 						replace = TRUE;
 						break;
-					case 'P':	/* Give path to index files */
-						strcpy (path, &argv[i][2]);
-						break;
 					case 'V':
 						verbose = TRUE;
 						break;
@@ -102,30 +99,22 @@ int main (int argc, char **argv)
 		else
 			fp = fopen(argv[i],"r");
 	}
-	
+
 	if (error || fp == NULL) {
-		fprintf(stderr, "Usage: binlegs leglistfile [-D] [-P<Path>] [-R] [-V]\n");
+		fprintf(stderr, "Usage: binlegs leglistfile [-D] [-R] [-V]\n");
 		fprintf(stderr,"	-D will remove info for the listed legs\n");
-		fprintf(stderr,"	-P gives directory for the index files [Default is %s%cmgg]\n", GMT_SHAREDIR, DIR_DELIM);
 		fprintf(stderr,"	-R will replace old info. [Default is append].\n");
 		fprintf(stderr,"	-V (verbose) will print update-messages. [Default is silent]\n");
 		exit (EXIT_FAILURE);
 	}
-	
+
 	info_head = make_info ("-", 0, 0);
 	this_info = info_head;
 	for (bin = 0; bin < 64800; bin++) grid[bin].n_legs = 0;
-	
-	if (path[0]) {
-		sprintf (leg_file, "%s%cgmt_legs.d", path, DIR_DELIM);
-		sprintf (index_file, "%s%cgmt_index.b", path, DIR_DELIM);
-	}
-	else {
-		sprintf (leg_file, "%s%cmgg%cgmt_legs.d", GMT_SHAREDIR, DIR_DELIM, DIR_DELIM);
-		sprintf (index_file, "%s%cmgg%cgmt_index.b", GMT_SHAREDIR, DIR_DELIM, DIR_DELIM);
-	}
-	
-	
+
+	GMT_getsharepath ("mgg", "gmt_legs", ".d", leg_file);
+	GMT_getsharepath ("mgg", "gmt_index", ".b", index_file);
+
 	if ((fleg = fopen (leg_file,"r")) == NULL) {
 		fprintf (stderr,"Could not find %s\n", leg_file);
 		exit (EXIT_FAILURE);
@@ -134,11 +123,11 @@ int main (int argc, char **argv)
 		fprintf (stderr,"Could not open %s\n", index_file);
 		exit (EXIT_FAILURE);
 	}
-	
+
 	last_id  = -1;
-	
+
 	/* Read existing leg-information from gmt_legs.d file */
-	
+
 	while (fgets (line, BUFSIZ, fleg)) {
 		sscanf (line, "%s %d %d",lname, &id, &flag);
 		this_info->next_info = make_info (lname, id, flag);
@@ -146,9 +135,9 @@ int main (int argc, char **argv)
 		if (id > last_id) last_id = id;
 	}
 	fclose (fleg);
-	
+
 	/* Read geographical leg-info from gmt_index.b file */
-	
+
 	while ((fread ((void *)(&index), (size_t)4, (size_t)1, fbin)) == 1) {
 		not_used = fread ((void *)(&no_of_legs), (size_t)4, (size_t)1, fbin);
 		if (grid[index].n_legs == 0) {
@@ -165,12 +154,12 @@ int main (int argc, char **argv)
 		}
 	}
 	fclose (fbin);
-	
+
 	/* Ok, now we can start reading new info */
-	
+
 	while (fgets (line, BUFSIZ, fp)) {
 		sscanf (line, "%s", leg);
-		for (this_info = info_head; this_info->next_info && 
+		for (this_info = info_head; this_info->next_info &&
 			strcmp (this_info->next_info->legname, leg) < 0;
 			this_info = this_info->next_info);
 		free_id = 0;
@@ -193,9 +182,9 @@ int main (int argc, char **argv)
 				fprintf (stderr, "binlegs: Leg %s not in system!\n", leg);
 			continue;
 		}
-			
+
 		/* Open the bix file */
-		
+
 		sprintf (file, "%s.bix", leg);
 		if ((find = fopen (file,"r")) == NULL) {
 			fprintf (stderr, "Could not find file: %s\n",file);
@@ -204,9 +193,9 @@ int main (int argc, char **argv)
 		if (verbose) fprintf (stderr, "binlegs: Adding leg: %s\n",leg);
 		c_unused = fgets (line, BUFSIZ, find);
 		sscanf (line, "%d %d", &year, &max);
-		
+
 		/* If a leg is replaced, then use the same id_no, else increment to get a new one */
-		
+
 		id = (free_id) ? free_id : ++last_id;
 		if (!free_id) {
 			new_info = make_info (leg, id, 0);
@@ -234,12 +223,12 @@ int main (int argc, char **argv)
 		this_info->gmt = max;
 	}
 	fclose (fp);
-	
+
 	/* Done, now we must rewrite the gmt_index.b and gmt_legs.d files */
-	
+
 	sprintf (old_leg_file, "%s_old", leg_file);
 	sprintf (old_index_file, "%s_old", index_file);
-	
+
 	if (rename (leg_file, old_leg_file)) {
 		fprintf (stderr, "binlegs: Rename failed for %s. Aborts!\n", leg_file);
 		exit (EXIT_FAILURE);
@@ -248,7 +237,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "binlegs: Rename failed for %s. Aborts!\n", index_file);
 		exit (EXIT_FAILURE);
 	}
-	
+
 	if ((fleg = fopen (leg_file, "w")) == NULL) {
 		fprintf (stderr, "binlegs: Failed to create %s. Aborts!\n", leg_file);
 		exit (EXIT_FAILURE);
@@ -257,14 +246,14 @@ int main (int argc, char **argv)
 		fprintf (stderr, "binlegs: Failed to create %s. Aborts!\n", index_file);
 		exit (EXIT_FAILURE);
 	}
-	for (this_info = info_head->next_info; this_info; 
+	for (this_info = info_head->next_info; this_info;
 		this_info = this_info->next_info)
 		fprintf (fleg,"%s %d %d\n",this_info->legname,
 					  this_info->leg_id,
 					  this_info->gmt);
 	fclose (fleg);
 	chmod (leg_file, (mode_t)S_RDONLY);
-	
+
 	for (bin = 0; bin < 64800; bin++) {
 		if (grid[bin].n_legs > 0) {
 			not_used = fwrite ((void *)(&bin), (size_t)4, (size_t)1, fbin);
@@ -306,10 +295,10 @@ int remove_leg (int leg_id, struct GRID *grid)
 	/* Remove all traces of the leg with id leg_id from structures */
 	struct LEG *leg, *skip_leg;
 	int bin;
-	
+
 	for (bin = 0; bin < 64800; bin++) {
 		if (grid[bin].n_legs == 0) continue;	/* No legs crossed this bin */
-		
+
 		for (leg = grid[bin].first_leg; leg->next_leg && leg->next_leg->leg_id == leg_id; leg = leg->next_leg);	/* Finds the leg or end-of-list */
 
 		if (leg->next_leg) {	/* Ok, found it. Lets remove it from the list */
