@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: dat2gmt.c,v 1.19 2010/01/05 01:15:48 guru Exp $
+ *	$Id: dat2gmt.c,v 1.21 2011/03/05 21:24:29 guru Exp $
  *
- *    Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *    Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -32,7 +32,7 @@ int main (int argc, char **argv)
 	struct GMTMGG_TIME *gmt;
 	struct GMTMGG_REC *record;
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 	
 	if (argc != 3 || ((fpi = fopen(argv[1], "r")) == NULL) || ((fpo = fopen(argv[2], "wb")) == NULL)) {
 		fprintf(stderr, "usage: dat2gmt asciifile file.gmt\n");
