@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmtpath.c,v 1.14 2010/01/05 01:15:48 guru Exp $
+ *	$Id: gmtpath.c,v 1.17 2011/03/05 21:24:29 guru Exp $
  *
- *    Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *    Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -20,9 +20,9 @@ int main (int argc, char **argv)
 	char path[BUFSIZ];
 	int i, error = FALSE;
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 	
-	gmtmggpath_init(GMT_SHAREDIR);
+	gmtmggpath_init();
 
 	for (i = 1; !error && i < argc; i++) {
 		if (argv[i][0] == '-') {
