@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmttrack.c,v 1.36 2010/01/05 01:15:48 guru Exp $
+ *	$Id: gmttrack.c,v 1.39 2011/03/06 02:09:56 guru Exp $
  *
- *    Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *    Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -78,7 +78,7 @@ int main (int argc, char **argv)
 	GMT_init_pen (&pen, GMT_PENWIDTH);
 	for (i = 0; i < 3; i++) black[i] = 0, white[i] = 255;
 	
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
@@ -97,7 +97,7 @@ int main (int argc, char **argv)
 				case 'y':
 				case 'c':
 				case '\0':
-					error += GMT_parse_common_options (argv[i], &west, &east, &south, &north);
+					error += (int)GMT_parse_common_options (argv[i], &west, &east, &south, &north);
 					break;
 				case 'W':
 					GMT_getpen (&argv[i][2], &pen);
@@ -175,7 +175,7 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 	
-	gmtmggpath_init(GMT_SHAREDIR);
+	gmtmggpath_init();
 
 	if (east < west) west -= 360.0;
 		
