@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77togmt.c,v 1.26 2010/01/05 01:15:48 guru Exp $
+ *	$Id: mgd77togmt.c,v 1.31 2011/03/05 21:24:29 guru Exp $
  *
- *    Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *    Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -45,18 +45,18 @@ int main (int argc, char **argv) {
 	int n_records, *year, k;
 	int i, rec, n_read, n_files = 0, n_alloc = GMT_CHUNK, leg_year = 0, len;
 	int T_INC = 60, fake_running_time = 0;
-	int anom_offset = 0;
-	BOOLEAN use_list = FALSE, set_agency = FALSE, mag_rewind = FALSE, greenwich = FALSE;
-	int t_flag = FALSE, error = FALSE;
+	int t_flag = FALSE, anom_offset = 0;
+	GMT_LONG use_list = FALSE, set_agency = FALSE, mag_rewind = FALSE, greenwich = FALSE, give_synopsis_and_exit = FALSE;
+	GMT_LONG error = FALSE;
 	double cable_len = 0;
 	char file[80], *mfile, *list, agency[10], *legfname, line[BUFSIZ], **mgd77, **prefix;
 	struct GMTMGG_TIME *gmt;
 	struct GMTMGG_REC *record;
 	FILE *fp = NULL, *fpo;
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
-	gmtmggpath_init(GMT_SHAREDIR);
+	gmtmggpath_init();
 
 	legfname = list = mfile = CNULL;
 	memset ((void *)agency, 0, (size_t)10);
@@ -64,6 +64,9 @@ int main (int argc, char **argv) {
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
 			switch (argv[i][1]) {
+				case '\0':
+					error = give_synopsis_and_exit = TRUE;
+					break;
 				case 'Y':
 					leg_year = atoi (&argv[i][2]);
 					break;
@@ -110,41 +113,47 @@ int main (int argc, char **argv) {
 			mfile = argv[i];
 	}
 	
-	if (use_list && !list) {
-		fprintf (stderr, "SYNTAX ERROR -L option:  Must specify list file\n");
-		error = TRUE;
-	}
-	if (use_list && (legfname || leg_year != 0)) {
-		fprintf (stderr, "SYNTAX ERROR -L option:  Specify -L or the combination -F, -Y\n");
-		error = TRUE;
-	}
-	if (!use_list && !mfile && !legfname) {
-		fprintf (stderr, "SYNTAX ERROR -F option:  When using standard input you must use -F option.\n");
-		error = TRUE;
+	if (!give_synopsis_and_exit) {
+		if (use_list && !list) {
+			fprintf (stderr, "SYNTAX ERROR -L option:  Must specify list file\n");
+			error = TRUE;
+		}
+		if (use_list && (legfname || leg_year != 0)) {
+			fprintf (stderr, "SYNTAX ERROR -L option:  Specify -L or the combination -F, -Y\n");
+			error = TRUE;
+		}
+		if (!use_list && !mfile && !legfname) {
+			fprintf (stderr, "SYNTAX ERROR -F option:  When using standard input you must use -F option.\n");
+			error = TRUE;
+		}
 	}
 	
 	if (argc == 1 || error) {
-		fprintf (stderr, "usage: mgd77togmt [mgd77file] [-F<filename>] -Y<leg_year> OR -L<leglist> [-A<10 char agency name>] [-G] [NGDC-file -I<time_increment>] [-V] [-T[<offset>]] [-W[<cable_length>]]\n");
-		fprintf (stderr, "	-Y sets start year. If not provided and -L option not used, it tries to get\n");
-		fprintf (stderr, "	   it from header file. The header file must be in the same directory of the\n");
-		fprintf (stderr, "	   main file and must have a name equal to the main but with a .h77 extension.\n");
-		fprintf (stderr, "	-L gives name of a list with several records of <mgd77file> <gmtprefix> <leg_year>\n");
+		fprintf (stderr, "usage: mgd77togmt [mgd77file] [-F<filename>] -Y<leg_year> OR -L<leglist> [-A<10 char agency name>]\n");
+		fprintf (stderr, "\t[-G] [NGDC-file -I<time_increment>] [-V] [-T[<offset>]] [-W[<cable_length>]]\n\n");
+		
+		if (give_synopsis_and_exit) exit (EXIT_FAILURE);
+		
+		fprintf (stderr, "\t-Y sets start year. If not provided and -L option not used, it tries to get\n");
+		fprintf (stderr, "\t   it from header file. The header file must be in the same directory of the\n");
+		fprintf (stderr, "\t   main file and must have a name equal to the main but with a .h77 extension.\n");
+		fprintf (stderr, "\t-L gives name of a list with several records of <mgd77file> <gmtprefix> <leg_year>\n");
 		fprintf (stderr, "\n\tOPTIONS:\n");
-		fprintf (stderr, "	-A sets optional 10 char info for gmt header.\n");
-		fprintf (stderr, "	-F sets gmtfilename prefix (e.g., without path or .gmt). If not given, it\n");
-		fprintf (stderr, "	   will be constructed from the mgd77file name plus the .gmt extension.\n");
-		fprintf(stderr,"	-G force geographical longitudes (-180/+180) [Default is 0-360]\n");
-		fprintf (stderr, "	-I sets fake timeincrement for files without time information\n");
-		fprintf (stderr, "	-T Extracts Total field instead of anomaly. Since F does not hold in a 2 byte int var\n");
-		fprintf (stderr, "	   we subtract a constant [default = 40000] but you can provide another value in <offset>.\n");
-		fprintf (stderr, "	-W Take into account that the magnetometer is not at ship's position.\n");
-		fprintf (stderr, "	   <cable> is magnetometer tow distance [default = 200 meters].\n");
-		fprintf (stderr, "	   If -W only is given (e.g. no <cable>) and like with the -Y option, we try\n");
-		fprintf (stderr, "	   to get the tow distance from the header file. Failing, defaults to 200 meters.\n");
-		fprintf (stderr, "	   Note that this option will throw away the first points whose accumulated.\n");
-		fprintf (stderr, "	   distance since the start of magnetic acquisition is less than cable.\n");
-		fprintf (stderr, "	   length, and likewise for the end of the mag profile.\n");
-		fprintf (stderr, "	-V runs in verbose mode.\n");
+		fprintf (stderr, "\t-A sets optional 10 char info for gmt header.\n");
+		fprintf (stderr, "\t-F sets gmtfilename prefix (e.g., without path or .gmt). If not given, it\n");
+		fprintf (stderr, "\t   will be constructed from the mgd77file name plus the .gmt extension.\n");
+		fprintf (stderr, "\t-G force geographical longitudes (-180/+180) [Default is 0-360]\n");
+		fprintf (stderr, "\t-I sets fake timeincrement for files without time information\n");
+		fprintf (stderr, "\t-T Extracts Total field instead of anomaly. Since F does not hold in a 2 byte int var\n");
+		fprintf (stderr, "\t   we subtract a constant [default = 40000] but you can provide another value in <offset>.\n");
+		fprintf (stderr, "\t-W Take into account that the magnetometer is not at ship's position.\n");
+		fprintf (stderr, "\t   <cable> is magnetometer tow distance [default = 200 meters].\n");
+		fprintf (stderr, "\t   If -W only is given (e.g. no <cable>) and like with the -Y option, we try\n");
+		fprintf (stderr, "\t   to get the tow distance from the header file. Failing, defaults to 200 meters.\n");
+		fprintf (stderr, "\t   Note that this option will throw away the first points whose accumulated.\n");
+		fprintf (stderr, "\t   distance since the start of magnetic acquisition is less than cable.\n");
+		fprintf (stderr, "\t   length, and likewise for the end of the mag profile.\n");
+		fprintf (stderr, "\t-V runs in verbose mode.\n");
 		
 		exit (EXIT_FAILURE);
 	}
