@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *    $Id: minmax.c,v 1.64 2010/01/05 01:15:46 guru Exp $
+ *    $Id: minmax.c,v 1.74 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -31,25 +31,25 @@
 struct MINMAX_CTRL {	/* All control options for this program (except common args) */
 	/* active is TRUE if the option has been activated */
 	struct C {	/* -C */
-		BOOLEAN active;
+		GMT_LONG active;
 	} C;
 	struct E {	/* -E<L|l|H|h><col> */
-		BOOLEAN active;
-		BOOLEAN abs;
+		GMT_LONG active;
+		GMT_LONG abs;
 		GMT_LONG mode;
 		GMT_LONG col;
 	} E;
 	struct I {	/* -Idx[/dy[/<dz>..] */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG ncol;
-		double inc[BUFSIZ];
+		double inc[GMT_MAX_COLUMNS];
 	} I;
 	struct S {	/* -S[x|y] */
-		BOOLEAN active;
-		BOOLEAN xbar, ybar;
+		GMT_LONG active;
+		GMT_LONG xbar, ybar;
 	} S;
 	struct T {	/* -T<dz>[/<col>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double inc;
 		GMT_LONG col;
 	} T;
@@ -57,12 +57,12 @@ struct MINMAX_CTRL {	/* All control options for this program (except common args
 
 int main (int argc, char **argv)
 {
-	BOOLEAN  error = FALSE, nofile = TRUE, done = FALSE, got_stuff = FALSE, first, give_r_string = FALSE;
-	BOOLEAN  dateline = FALSE, brackets = FALSE, work_on_abs_value, special = FALSE, quad[4] = {FALSE, FALSE, FALSE, FALSE};
+	GMT_LONG  error = FALSE, nofile = TRUE, done = FALSE, got_stuff = FALSE, first, give_r_string = FALSE;
+	GMT_LONG  dateline = FALSE, brackets = FALSE, work_on_abs_value, special = FALSE, quad[4] = {FALSE, FALSE, FALSE, FALSE};
 
-	char line[BUFSIZ], file[BUFSIZ], chosen[BUFSIZ], *not_used = NULL;
+	char line[BUFSIZ], file[BUFSIZ], chosen[BUFSIZ], buffer[BUFSIZ], *not_used = NULL;
 
-	GMT_LONG i, j, ncol, n_files = 0, fno, n_args, n_fields, n_expected_fields, quad_no, n;
+	GMT_LONG i, j, ncol, n_files = 0, fno, n_args, n_read, n_fields, n_expected_fields, quad_no, n;
 	
 	double *xyzmin, *xyzmax, west, east, south, north, low, high, value, e_min = DBL_MAX, e_max = -DBL_MAX, *in;
 	double xmin1 = 360.0, xmin2 = 360.0, xmax1 = -360.0, xmax2 = -360.0;
@@ -74,7 +74,7 @@ int main (int argc, char **argv)
 	GMT_LONG strip_blanks_and_output (double x, GMT_LONG col);
 	void *New_minmax_Ctrl (), Free_minmax_Ctrl (struct MINMAX_CTRL *C);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct MINMAX_CTRL *) New_minmax_Ctrl ();		/* Allocate and initialize defaults in a new control structure */
 	
@@ -125,7 +125,7 @@ int main (int argc, char **argv)
 					Ctrl->I.active = TRUE;
 					if (argv[i][2] == 'p') special = TRUE;
 					j = (special) ? 3 : 2;
-					Ctrl->I.ncol = GMT_getincn (&argv[i][j], Ctrl->I.inc, BUFSIZ);
+					Ctrl->I.ncol = GMT_getincn (&argv[i][j], Ctrl->I.inc, GMT_MAX_COLUMNS);
 					break;
 				case 'L':	/* Obsolete, but backward compatibility prevails [use -f instead] */
 					GMT_io.in_col_type[0] = GMT_io.out_col_type[0] = GMT_IS_LON;
@@ -134,7 +134,7 @@ int main (int argc, char **argv)
 					break;
 				case 'T':
 					Ctrl->T.active = TRUE;
-					j = sscanf (&argv[i][2], "%lf/%ld", &Ctrl->T.inc, &Ctrl->T.col);
+					j = sscanf (&argv[i][2], "%lf/%" GMT_LL "d", &Ctrl->T.inc, &Ctrl->T.col);
 					if (j == 1) Ctrl->T.col = 0;
 					break;
 				case 'S':
@@ -269,7 +269,7 @@ int main (int argc, char **argv)
 		}
 	}
 
-	n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : BUFSIZ;
+	n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : GMT_MAX_COLUMNS;
 
 	for (fno = 1; !done && fno < n_args; fno++) {     /* Loop over input files, if any */
 		if (!nofile && argv[fno][0] == '-') continue;
@@ -294,22 +294,24 @@ int main (int argc, char **argv)
 
 		if (GMT_io.io_header[GMT_IN]) for (i = 0; i < GMT_io.n_header_recs; i++) not_used = GMT_fgets (line, BUFSIZ, fp);
 
-		n = ncol = 0;
-		n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : BUFSIZ;
+		n = ncol = n_read = 0;
+		n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : GMT_MAX_COLUMNS;
 		first = TRUE;
 
 		n_fields = GMT_input (fp, &n_expected_fields, &in);
 
 		while (! (GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
 
+			n_read++;
+
 			while ((GMT_io.status & GMT_IO_SEGMENT_HEADER) && !(GMT_io.status & GMT_IO_EOF)) {
 					n_fields = GMT_input (fp, &n_expected_fields, &in);
 			}
 			if ((GMT_io.status & GMT_IO_EOF)) continue;	/* At EOF */
 
 			if (GMT_io.status & GMT_IO_MISMATCH) {
-				fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields, n_expected_fields, n);
-				exit (EXIT_FAILURE);
+				fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld (skipped)\n", GMT_program, n_fields, n_expected_fields, n_read);
+				continue;
 			}
 
 			if (first) {	/* First time, allocate # of columns */
@@ -398,7 +400,7 @@ int main (int argc, char **argv)
 
 		if (GMT_io.in_col_type[0] == GMT_IS_LON) {	/* Now determine longitude range */
 			int n_quad;
-			n_quad = quad[0] + quad[1] + quad[2] + quad[3];	/* How many quadrants had data */
+			n_quad = (int)(quad[0] + quad[1] + quad[2] + quad[3]);	/* How many quadrants had data */
 			if (quad[0] && quad[3]) {	/* Longitudes on either side of Greenwich only, must use -180/+180 notation */
 				xyzmin[0] = xmin2;
 				xyzmax[0] = xmax2;
@@ -439,7 +441,7 @@ int main (int argc, char **argv)
 			east  = MAX (east, xyzmax[Ctrl->T.col]);
 		}
 		else if (!Ctrl->E.active && n > 0) {
-			if (!Ctrl->C.active) fprintf (GMT_stdout, "%s: N = %ld\t", file, n);
+			if (!Ctrl->C.active) {sprintf (buffer, "%s: N = %ld\t", file, n);	GMT_fputs (buffer, GMT_stdout);}
 			for (i = 0; i < ncol; i++) {
 				if (xyzmin[i] == DBL_MAX) {
 					low = high = GMT_d_NaN;
@@ -452,14 +454,14 @@ int main (int argc, char **argv)
 					low = xyzmin[i];
 					high = xyzmax[i];
 				}
-				if (brackets) fputc ('<', GMT_stdout);
+				if (brackets) GMT_fputs ("<", GMT_stdout);
 				GMT_ascii_output_one (GMT_stdout, low, i);
-				(Ctrl->C.active) ? fputc ('\t', GMT_stdout) : fputc ('/', GMT_stdout);
+				(Ctrl->C.active) ? GMT_fputs ("\t", GMT_stdout) : GMT_fputs ("/", GMT_stdout);
 				GMT_ascii_output_one (GMT_stdout, high, i);
-				if (brackets) fputc ('>', GMT_stdout);
-				if (i < (ncol - 1)) fputc ('\t', GMT_stdout);
+				if (brackets) GMT_fputs (">", GMT_stdout);
+				if (i < (ncol - 1)) GMT_fputs ("\t", GMT_stdout);
 			}
-			fprintf (GMT_stdout, "\n");
+			GMT_fputs ("\n", GMT_stdout);
 		}
 	}
 	if (got_stuff) {
@@ -469,22 +471,23 @@ int main (int argc, char **argv)
 			south = floor (south / Ctrl->I.inc[1]) * Ctrl->I.inc[1];
 			north = ceil (north / Ctrl->I.inc[1]) * Ctrl->I.inc[1];
 			if (east < west) east += 360.0;
-			fprintf (GMT_stdout, "-R");
-			strip_blanks_and_output (west, 0);	fputc ('/', GMT_stdout);
-			strip_blanks_and_output (east, 0);	fputc ('/', GMT_stdout);
-			strip_blanks_and_output (south, 1);	fputc ('/', GMT_stdout);
-			strip_blanks_and_output (north, 1);	fputc ('\n', GMT_stdout);
+			if (GMT_IS_ZERO (east - 360.0) && west > 180.0) GMT_io.geo.range = 2;	/* Override this setting explicitly to get negative lons since 360 otherwise will become 0 */
+			GMT_fputs ("-R", GMT_stdout);
+			strip_blanks_and_output (west, 0);	GMT_fputs ("/", GMT_stdout);
+			strip_blanks_and_output (east, 0);	GMT_fputs ("/", GMT_stdout);
+			strip_blanks_and_output (south, 1);	GMT_fputs ("/", GMT_stdout);
+			strip_blanks_and_output (north, 1);	GMT_fputs ("\n", GMT_stdout);
 		}
 		else if (Ctrl->T.active) {	/* -T option */
 			west  = floor (west / Ctrl->T.inc) * Ctrl->T.inc;
 			east  = ceil (east / Ctrl->T.inc) * Ctrl->T.inc;
-			fprintf (GMT_stdout, "-T");
-			strip_blanks_and_output (west, 0);	fputc ('/', GMT_stdout);
-			strip_blanks_and_output (east, 0);	fputc ('/', GMT_stdout);
-			strip_blanks_and_output (Ctrl->T.inc, 0);	fputc ('\n', GMT_stdout);
+			GMT_fputs ("-T", GMT_stdout);
+			strip_blanks_and_output (west, 0);	GMT_fputs ("/", GMT_stdout);
+			strip_blanks_and_output (east, 0);	GMT_fputs ("/", GMT_stdout);
+			strip_blanks_and_output (Ctrl->T.inc, 0);	GMT_fputs ("\n", GMT_stdout);
 		}
 		else if (Ctrl->E.active)
-			fprintf (GMT_stdout, "%s", chosen);
+			GMT_fputs (chosen, GMT_stdout);
 	}
 	else if (!got_stuff)
 		fprintf (stderr, "%s: No input data found!\n", GMT_program);
@@ -508,7 +511,7 @@ GMT_LONG strip_blanks_and_output (double x, GMT_LONG col)
 
 	GMT_ascii_format_one (text, x, GMT_io.out_col_type[col]);
 	for (k = 0; text[k] && text[k] == ' '; k++);
-	return (fprintf (GMT_stdout, "%s", &text[k]));
+	return (GMT_fputs (&text[k], GMT_stdout));
 }
 
 void *New_minmax_Ctrl () {	/* Allocate and initialize a new control structure */
