@@ -1,6 +1,6 @@
 /*
- *	$Id: gmtstitch.c,v 1.57 2010/01/05 01:15:48 guru Exp $
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	$Id: gmtstitch.c,v 1.63 2011/01/02 20:09:36 guru Exp $
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  */
 /* gmtstitch will combine pieces of coastlines or similar segments into a
  * continuous line, polygon, or group of lines/polygons so that the jump
@@ -46,8 +46,8 @@ int main (int argc, char **argv)
 	GMT_LONG i, j, k, np, distance_flag = 0, n_files = 0, ns, n_args, id, pos, start_id, done, end_order;
 	GMT_LONG n_new, n, chain = 0, n_islands = 0, n_trouble = 0, n_closed = 0, id2, L, G, error = 0, mode = 0;
 	GMT_LONG n_alloc = GMT_SMALL_CHUNK, n_id_alloc = GMT_CHUNK, out_seg, match = 0, n_steps, n_points = 0;	
-	BOOLEAN individual_file = FALSE, save_type = FALSE, write_links = FALSE, do_lists = FALSE, first, *skip;
-	BOOLEAN nn_check = FALSE, separate = FALSE;
+	GMT_LONG individual_file = FALSE, save_type = FALSE, write_links = FALSE, do_lists = FALSE, first, *skip;
+	GMT_LONG nn_check = FALSE, separate = FALSE;
 	struct GMT_DATASET *D;
 	double dd[2][2], p_dummy_x, p_dummy_y, p_last_x, p_last_y, p_first_x, p_first_y, distance;
 	double cutoff = 0.0, nn_dist = 0.0, scl = 1.0, closed_dist = 0.0;
@@ -56,9 +56,9 @@ int main (int argc, char **argv)
 	FILE *fp = NULL, *fp3 = NULL, *fpl[2] = {NULL, NULL}, *fp_closed = NULL;
 
 	void Write_This_Segment (FILE *fp, struct GMT_LINE_SEGMENT *line, GMT_LONG start, GMT_LONG end);
-	BOOLEAN connect (struct LINK *S, int id, int order, double cutoff, BOOLEAN nn_check, double nn_dist);
+	GMT_LONG connect (struct LINK *S, int id, int order, double cutoff, GMT_LONG nn_check, double nn_dist);
 	
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 	memset ((void *)format, 0, BUFSIZ);
 	memset ((void *)linkfile, 0, BUFSIZ);
 	memset ((void *)lists, 0, BUFSIZ);
@@ -340,20 +340,20 @@ int main (int argc, char **argv)
 			}
 		}
 	}
-	ns = id;
-	if (ns == 0) {	/* All are closed */
-		if (gmtdefs.verbose) fprintf (stderr, "%s: All segments already form closed polygons\n", GMT_program);
-		exit (EXIT_SUCCESS);
-	}
-	if (separate && gmtdefs.verbose) {	/* Report and exit */
-		fprintf (stderr, "%s: Separated %ld closed and %ld open segments\n", GMT_program, n_closed, n_open);
+	if (separate) {	/* Report and exit */
+		if (gmtdefs.verbose) fprintf (stderr, "%s: Separated %ld closed and %ld open segments\n", GMT_program, n_closed, n_open);
 		GMT_free_dataset (D);
-
 		exit (EXIT_SUCCESS);
 	}
+	if (id == -1) {	/* All are closed or we wrote them out as separate */
+		if (gmtdefs.verbose) fprintf (stderr, "%s: All %ld segments already form closed polygons\n", GMT_program, n_closed);
+		GMT_free_dataset (D);
+		exit (EXIT_SUCCESS);
+	}
+	ns = id;
 	
 	if (ns < n_id_alloc) seg = (struct LINK *) GMT_memory ((void *)seg, (size_t)ns, sizeof(struct LINK), GMT_program);
-	skip = (BOOLEAN *) GMT_memory (VNULL, (size_t)ns, sizeof(BOOLEAN), GMT_program);
+	skip = (GMT_LONG *) GMT_memory (VNULL, (size_t)ns, sizeof(GMT_LONG), GMT_program);
 	
 	if (gmtdefs.verbose) fprintf (stderr, "%s: Found %ld closed polygons\n", GMT_program, n_islands);
 	
@@ -484,7 +484,7 @@ int main (int argc, char **argv)
 #if DEBUG2
 		if (gmtdefs.verbose) fprintf (stderr, "%ld\n", seg[id].orig_id);
 #endif
-		while (!done && connect (seg, id, end_order, cutoff, nn_check, nn_dist)) {
+		while (!done && connect (seg, (int)id, (int)end_order, cutoff, nn_check, nn_dist)) {
 			id2 = seg[id].buddy[end_order].id;
 #if DEBUG2
 			if (gmtdefs.verbose) fprintf (stderr, "%ld\n", seg[id2].orig_id);
@@ -626,7 +626,7 @@ int main (int argc, char **argv)
 	exit (EXIT_SUCCESS);
 }
 
-BOOLEAN connect (struct LINK *S, int id, int order, double cutoff, BOOLEAN nn_check, double nn_dist)
+GMT_LONG connect (struct LINK *S, int id, int order, double cutoff, GMT_LONG nn_check, double nn_dist)
 {	/* Checks if OK to connect this segment to its nearest neighbor and returns TRUE if OK */
 
 	if (S[S[id].buddy[order].id].used) return (FALSE);		/* Segment has been used already */
@@ -639,7 +639,7 @@ BOOLEAN connect (struct LINK *S, int id, int order, double cutoff, BOOLEAN nn_ch
 void Write_This_Segment (FILE *fp, struct GMT_LINE_SEGMENT *line, GMT_LONG start, GMT_LONG end)
 {
 	GMT_LONG i, j, inc, done = FALSE;
-	static double out[BUFSIZ];
+	static double out[GMT_MAX_COLUMNS];
 	
 	inc = (start < end) ? +1 : -1;
 	for (i = start; !done; i += inc) {
