@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: makepattern.c,v 1.27 2010/01/05 01:15:48 guru Exp $
+ *	$Id: makepattern.c,v 1.31 2011/03/03 21:02:51 guru Exp $
  *
- *      Copyright (c) 1999-2010 by P. Wessel
+ *      Copyright (c) 1999-2011 by P. Wessel
  *      See LICENSE.TXT file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; version 2 of the License.
+ *      the Free Software Foundation; version 2 or any later version.
  *
  *      This program is distributed in the hope that it will be useful,
  *      but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -38,7 +38,7 @@
 
 int main (int argc, char **argv)
 {
-	BOOLEAN pad = FALSE, icon = FALSE;
+	GMT_LONG pad = FALSE, icon = FALSE;
 
 	int i, j, k, kk, nx, ny, extra, mx, step, error = 0;
 
@@ -63,7 +63,7 @@ int main (int argc, char **argv)
 	GMT_init_fill (&fg, 0, 0, 0);		/* Default foreground is black */
 	GMT_init_fill (&bg, 255, 255, 255);	/* Default background is white */
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
@@ -73,7 +73,7 @@ int main (int argc, char **argv)
 				/* Common parameters */
 
 				case '\0':
-					error += GMT_parse_common_options (argv[i], 0, 0, 0, 0);
+					error += (int)GMT_parse_common_options (argv[i], 0, 0, 0, 0);
 					break;
 
 				/* Supplemental parameters */
