@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: psmegaplot.c,v 1.17 2010/01/05 01:15:48 guru Exp $
+ *	$Id: psmegaplot.c,v 1.20 2011/03/03 21:02:51 guru Exp $
  *
- *      Copyright (c) 1999-2010 by P. Wessel
+ *      Copyright (c) 1999-2011 by P. Wessel
  *      See LICENSE.TXT file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; version 2 of the License.
+ *      the Free Software Foundation; version 2 or any later version.
  *
  *      This program is distributed in the hope that it will be useful,
  *      but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -36,7 +36,7 @@ int main (int argc, char **argv)
 	GMT_LONG x0, y0, i, j, nx, ny, page;
 	double scale = 0.0;
 	FILE *fp;
-	BOOLEAN first, crop_marks = FALSE, error = FALSE, done;
+	GMT_LONG first, crop_marks = FALSE, error = FALSE, done;
 	char ifile[100], buffer[BUFSIZ];
 
 	for (i = 1; i < argc; i++) {
