@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: nearneighbor.c,v 1.66 2010/01/05 01:15:46 guru Exp $
+ *	$Id: nearneighbor.c,v 1.75 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -33,38 +33,41 @@
  
 #include "gmt.h"
 
+#define NN_DEF_SECTORS	4
+#define NN_MIN_SECTORS	2
+
 struct NEARNEIGHBOR_CTRL {	/* All control options for this program (except common args) */
 	/* active is TRUE if the option has been activated */
 	struct I {	/* -Idx[/dy] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double xinc, yinc;
 	} I;
 	struct E {	/* -E<empty> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double value;
 	} E;
 	struct F {	/* -F */
-		BOOLEAN active;
+		GMT_LONG active;
 	} F;
 	struct G {	/* -G<grdfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} G;
 	struct L {	/* -L<flag> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char mode[4];
 	} L;
 	struct N {	/* -N<sectors> */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG sectors, min_sectors;
 	} N;
 	struct S {	/* -S<radius>[m|c|k|K] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double radius;
 		char unit;
 	} S;
 	struct W {	/* -W */
-		BOOLEAN active;
+		GMT_LONG active;
 	} W;
 };
 
@@ -80,12 +83,12 @@ struct NEARNEIGHBOR_POINT {	/* Structure with input data constraints */
 int main (int argc, char **argv)
 {
 	GMT_LONG i, j, k, i0, j0, ij, n, nm, n_alloc = GMT_CHUNK, n_set, n_filled, n_almost, n_none;
-	GMT_LONG *di, dj, sector, n_fields, ii, jj;
+	GMT_LONG *di, dj, sector, n_read, n_fields, ii, jj;
 	GMT_LONG n_files = 0, n_args, fno, n_expected_fields, distance_flag = 0;
 	GMT_LONG max_di, actual_max_di, n_req, x_wrap, y_wrap;
 
-	BOOLEAN error = FALSE, done = FALSE, nofile = TRUE;
-	BOOLEAN wrap_180, replicate_x, replicate_y;
+	GMT_LONG error = FALSE, done = FALSE, nofile = TRUE;
+	GMT_LONG wrap_180, replicate_x, replicate_y;
 
 	double weight, weight_sum, grd_sum, *x0, *y0, dx, dy, delta, distance = 0.0, factor;
 	double *in, *shrink, x_left, x_right, y_top, y_bottom, xinc2, yinc2, idx, idy;
@@ -107,7 +110,7 @@ int main (int argc, char **argv)
 	void free_node (struct NEARNEIGHBOR_NODE *node);
 	void *New_nearneighbor_Ctrl (), Free_nearneighbor_Ctrl (struct NEARNEIGHBOR_CTRL *C);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct NEARNEIGHBOR_CTRL *) New_nearneighbor_Ctrl ();	/* Allocate and initialize a new control structure */
 
@@ -168,9 +171,9 @@ int main (int argc, char **argv)
 					break;
 				case 'N':
 					Ctrl->N.active = TRUE;
-					n = sscanf (&argv[i][2], "%ld/%ld", &Ctrl->N.sectors, &Ctrl->N.min_sectors);
-					if (n < 1) Ctrl->N.sectors = 4;
-					if (n < 2) Ctrl->N.min_sectors = Ctrl->N.sectors;
+					n = sscanf (&argv[i][2], "%" GMT_LL "d/%" GMT_LL "d", &Ctrl->N.sectors, &Ctrl->N.min_sectors);
+					if (n < 1) Ctrl->N.sectors = NN_DEF_SECTORS;
+					if (n < 2) Ctrl->N.min_sectors = NN_MIN_SECTORS;
 					break;
 				case 'S':
 					Ctrl->S.active = TRUE;
@@ -198,7 +201,8 @@ int main (int argc, char **argv)
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 		fprintf(stderr, "\t-G name of output grid.\n");
 		GMT_inc_syntax ('I', 0);
-		fprintf(stderr, "\t-N sets number of sectors and minimum number to be filled.\n\t   Default is quadrant search [4], requiring all to be filled.\n");
+		fprintf(stderr, "\t-N sets number of sectors and minimum number to be filled.\n");
+		fprintf(stderr, "\t   Default is quadrant search [%d], requiring at least %d to be filled.\n", NN_DEF_SECTORS, NN_MIN_SECTORS);
 		GMT_explain_option ('R');
 		fprintf(stderr, "\t-S sets search radius in -R, -I units; append m or c for minutes or seconds.\n");
 		fprintf(stderr, "\t   Append k for km (implies -R,-I in degrees), use flat Earth approximation.\n");
@@ -238,8 +242,8 @@ int main (int argc, char **argv)
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -N option:  Must specify a positive number of sectors\n", GMT_program);
 		error++;
 	}
-	if (Ctrl->S.active && (Ctrl->S.radius <= 0.0 || GMT_is_dnan (Ctrl->S.radius))) {
-		fprintf (stderr, "%s: GMT SYNTAX ERROR.  Radius is NaN or negative\n", GMT_program);
+	if (Ctrl->S.radius <= 0.0 || GMT_is_dnan (Ctrl->S.radius)) {
+		fprintf (stderr, "%s: GMT SYNTAX ERROR.  Radius is NaN, zero or negative\n", GMT_program);
 		error++;
 	}
 	if (Ctrl->I.xinc <= 0.0 || Ctrl->I.yinc <= 0.0) {
@@ -269,7 +273,7 @@ int main (int argc, char **argv)
 
 	header.x_inc = Ctrl->I.xinc;
 	header.y_inc = Ctrl->I.yinc;
-	header.node_offset = Ctrl->F.active;
+	header.node_offset = (int)Ctrl->F.active;
 	GMT_RI_prepare (&header);	/* Ensure -R -I consistency and set nx, ny */
 	GMT_err_fail (GMT_grd_RI_verify (&header, 1), Ctrl->G.file);
 
@@ -342,7 +346,7 @@ int main (int argc, char **argv)
 	y_top = header.y_max + dj * header.y_inc;	y_bottom = header.y_min - dj * header.y_inc;
 	x_width = header.x_max - header.x_min;		y_width = header.y_max - header.y_min;
 	half_x_width = 0.5 * x_width;			half_y_width = 0.5 * y_width;
-	n = 0;
+	n = n_read = 0;
 	replicate_x = (edgeinfo.nxp && !header.node_offset);	/* Gridline registration has duplicate column */
 	replicate_y = (edgeinfo.nyp && !header.node_offset);	/* Gridline registration has duplicate row */
 	x_wrap = header.nx - 1;			/* Add to node index to go to right column */
@@ -369,13 +373,16 @@ int main (int argc, char **argv)
 
 		while ((n_fields = GMT_input (fp, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
 
+			n_read++;
+
 			if (GMT_io.status & GMT_IO_MISMATCH) {
-				fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields, n_expected_fields, n);
-				exit (EXIT_FAILURE);
+				fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld (skipped)\n", GMT_program, n_fields, n_expected_fields, n_read);
+				continue;
 			}
 
-			if (in[GMT_X] < x_left || in[GMT_X] > x_right) continue;
-			if (in[GMT_Y] < y_bottom || in[GMT_Y] > y_top) continue;
+			if (GMT_is_dnan (in[GMT_Z])) continue;					/* Skip if z = NaN */
+			if (GMT_y_is_outside (in[GMT_Y], y_bottom, y_top)) continue;		/* Outside y-range */
+			if (GMT_x_is_outside (&in[GMT_X], x_left, x_right)) continue;	/* Outside x-range (or longitude) */
 
 			point[n].x = (float)in[GMT_X];
 			point[n].y = (float)in[GMT_Y];
