@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: project.c,v 1.71 2010/01/05 01:15:46 guru Exp $
+ *	$Id: project.c,v 1.82 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -42,49 +42,49 @@
 struct PROJECT_CTRL {	/* All control options for this program (except common args) */
 	/* active is TRUE if the option has been activated */
 	struct A {	/* -A<azimuth> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double azimuth;
 	} A;
 	struct C {	/* -C<ox>/<oy> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double x, y;
 	} C;
 	struct D {	/* -D<d_or_g> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char set;
 	} D;
 	struct E {	/* -E<bx>/<by> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double x, y;
 	} E;
 	struct F {	/* -F<flags> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char col[PROJECT_N_FARGS];	/* Character codes for desired output in the right order */
 	} F;
 	struct G {	/* -G<inc> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double inc;
 	} G;
 	struct L {	/* -L[w][<l_min>/<l_max>] */
-		BOOLEAN active;
-		BOOLEAN constrain;
+		GMT_LONG active;
+		GMT_LONG constrain;
 		double min, max;
 	} L;
 	struct N {	/* -N */
-		BOOLEAN active;
+		GMT_LONG active;
 	} N;
 	struct Q {	/* -Q */
-		BOOLEAN active;
+		GMT_LONG active;
 	} Q;
 	struct S {	/* -S */
-		BOOLEAN active;
+		GMT_LONG active;
 	} S;
 	struct T {	/* -T<px>/<py> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double x, y;
 	} T;
 	struct W {	/* -W<w_min>/<w_max> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double min, max;
 	} W;
 };
@@ -107,12 +107,12 @@ int main (int argc, char **argv)
 
 	double	a[3], b[3], x[3], xt[3], pole[3], center[3], e[9];
 
-	BOOLEAN	dateline = FALSE, error = FALSE, find_new_point = FALSE, first = TRUE, z_first = TRUE, pure_ascii, skip;
-	BOOLEAN greenwich = FALSE, nofile = TRUE, done = FALSE, want_z_output = FALSE;
+	GMT_LONG	dateline = FALSE, error = FALSE, find_new_point = FALSE, first = TRUE, z_first = TRUE, pure_ascii, skip;
+	GMT_LONG greenwich = FALSE, nofile = TRUE, done = FALSE, want_z_output = FALSE;
 
 	FILE *fp = NULL;
 
-	char	modifier, record_str[BUFSIZ], heading[PROJECT_N_FARGS][GMT_TEXT_LEN];
+	char	modifier, record_str[BUFSIZ], heading[PROJECT_N_FARGS][GMT_TEXT_LEN], buffer[GMT_TEXT_LEN];
 	char	txt_a[GMT_LONG_TEXT], txt_b[GMT_LONG_TEXT], *not_used = NULL;
 
 	struct PROJECT_DATA *p_data;
@@ -125,11 +125,11 @@ int main (int argc, char **argv)
 	void	matrix_3v (double *a, double *x, double *b);
 	void	matrix_2v (double *a, double *x, double *b);
 	void	sphere_project_setup (double alat, double alon, double *a, double blat, double blon, double *b, double azim, double *p, double *c, GMT_LONG two_pts);
-	void	flat_project_setup (double alat, double alon, double blat, double blon, double plat, double plon, double *azim, double *e, GMT_LONG two_pts, BOOLEAN pole_set);
+	void	flat_project_setup (double alat, double alon, double blat, double blon, double plat, double plon, double *azim, double *e, GMT_LONG two_pts, GMT_LONG pole_set);
 	void	copy_text_from_col3 (char *line, char *z_cols);
 	void	*New_project_Ctrl (), Free_project_Ctrl (struct PROJECT_CTRL *C);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct PROJECT_CTRL *) New_project_Ctrl ();		/* Allocate and initialize defaults in a new control structure */
 
@@ -262,7 +262,7 @@ int main (int argc, char **argv)
 	}
 
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
-		fprintf (stderr, "project %s - project data onto line or great circle, generate track, or translate coordinates\n\n", GMT_VERSION);
+		fprintf (stderr, "project %s - Project data onto line or great circle, generate track, or translate coordinates\n\n", GMT_VERSION);
 		fprintf(stderr,"usage:	project [files] -C<ox>/<oy> [-A<azimuth>] [-D<d_or_g>] [-E<bx>/<by>]\n");
 		fprintf(stderr,"\t[-F<flags>] [-G<dist>] [%s] [-L[w][<l_min>/<l_max>]]\n", GMT_H_OPT);
 		fprintf(stderr,"\t[-N] [-Q] [-S] [-T<px>/<py>] [-V] [-W<w_min>/<w_max>]\n");
@@ -542,7 +542,7 @@ int main (int argc, char **argv)
 		/* Now output generated track */
 
 		if (!GMT_io.binary[GMT_OUT]) {
-			if (GMT_io.io_header[GMT_OUT]) fprintf (GMT_stdout, "lon\tlat\tdist\n");
+			if (GMT_io.io_header[GMT_OUT]) {sprintf (buffer, "lon\tlat\tdist\n");	GMT_fputs(buffer, GMT_stdout);}
 
 			for (i = 0; i < n_used; i++) {
 				for (j = 0; j < n_outputs; j++) out[j] = p_data[i].a[output_choice[j]];
@@ -553,7 +553,7 @@ int main (int argc, char **argv)
 
 	else {	/* Must read input file */
 
-		n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : BUFSIZ;
+		n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : GMT_MAX_COLUMNS;
 
 		if (n_files > 0)
 			nofile = FALSE;
@@ -609,16 +609,16 @@ int main (int argc, char **argv)
 				}
 
 				while (! (GMT_io.status & (GMT_IO_SEGMENT_HEADER | GMT_IO_EOF))) {	/* Keep going until FALSE or = 2 segment header */
+
+					n_total_read ++;
 					if (GMT_io.status & GMT_IO_MISMATCH) {
-						fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields, n_expected_fields, n_total_read);
-						exit (EXIT_FAILURE);
+						fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld (skipped)\n", GMT_program, n_fields, n_expected_fields, n_total_read);
+						continue;
 					}
 
 					xx = in[GMT_X];
 					yy = in[GMT_Y];
 
-					n_total_read ++;
-
 					if (Ctrl->N.active) {
 						x[0] = xx - Ctrl->C.x;
 						x[1] = yy - Ctrl->C.y;
@@ -642,6 +642,9 @@ int main (int argc, char **argv)
 					p_data[n_used].t = NULL;	/* Initialize since that is not done by realloc */
 					p_data[n_used].z = NULL;	/* Initialize since that is not done by realloc */
 					if (n_z) {	/* Copy over z column(s) */
+#ifdef DEBUG
+						GMT_memtrack_off (GMT_mem_keeper);	/* Because it gives way too many pointers to search through */
+#endif
 						if (pure_ascii) {	/* Must store all text beyond x,y columns */
 							p_data[n_used].t = (char *) GMT_memory (VNULL, strlen (GMT_io.current_record), sizeof (char), GMT_program);
 							copy_text_from_col3 (GMT_io.current_record, p_data[n_used].t);
@@ -650,6 +653,9 @@ int main (int argc, char **argv)
 							p_data[n_used].z = (double *) GMT_memory (VNULL, (size_t)n_z, sizeof (double), GMT_program);
 							memcpy ((void *)p_data[n_used].z, (void *)&in[GMT_Z], (size_t)(n_z * sizeof(double)));
 						}
+#ifdef DEBUG
+						GMT_memtrack_on (GMT_mem_keeper);
+#endif
 					}
 					n_used++;
 					if (n_used == n_alloc) {
@@ -702,10 +708,10 @@ int main (int argc, char **argv)
 					if (first && GMT_io.io_header[GMT_OUT]) {
 						for (j = 0; j < n_outputs; j++) {
 							if (output_choice[j] == -1)
-								fprintf (GMT_stdout, "%s", heading[6]);
+								GMT_fputs (heading[6], GMT_stdout);
 							else
-								fprintf (GMT_stdout, "%s", heading[output_choice[j]]);
-							(j == (n_outputs - 1)) ? fprintf (GMT_stdout, "\n") : fprintf (GMT_stdout, "\t");
+								GMT_fputs (heading[output_choice[j]], GMT_stdout);
+							(j == (n_outputs - 1)) ? GMT_fputs ("\n", GMT_stdout) : GMT_fputs ("\t", GMT_stdout);
 						}
 						first = FALSE;
 					}
@@ -720,10 +726,12 @@ int main (int argc, char **argv)
 					for (i = 0; i < n_used; i++) {
 						for (j = 0; j < n_outputs; j++) {
 							if (output_choice[j] == -1)	/* Output all z columns as one string */
-								fprintf (GMT_stdout, "%s", p_data[i].t);
-							else
-								fprintf (GMT_stdout, gmtdefs.d_format, p_data[i].a[output_choice[j]]);
-							(j == (n_outputs - 1)) ? fprintf (GMT_stdout, "\n") : fprintf (GMT_stdout, "\t");
+								GMT_fputs (p_data[i].t, GMT_stdout);
+							else {
+								sprintf (buffer, gmtdefs.d_format, p_data[i].a[output_choice[j]]);
+								GMT_fputs (buffer, GMT_stdout);
+							}
+							(j == (n_outputs - 1)) ? GMT_fputs ("\n", GMT_stdout) : GMT_fputs ("\t", GMT_stdout);
 						}
 					}
 				}
@@ -752,10 +760,16 @@ int main (int argc, char **argv)
 
 	if (gmtdefs.verbose) fprintf(stderr, "%s: %ld read, %ld used\n", GMT_program, n_total_read, n_total_used);
 
+#ifdef DEBUG
+	if (n_z) GMT_memtrack_off (GMT_mem_keeper);
+#endif
 	for (i = 0; i < n_alloc; i++) {
 		if (p_data[i].t) GMT_free ((void *)p_data[i].t);
 		if (p_data[i].z) GMT_free ((void *)p_data[i].z);
 	}
+#ifdef DEBUG
+	if (n_z) GMT_memtrack_on (GMT_mem_keeper);
+#endif
 	GMT_free ((void *)p_data);
 	GMT_free ((void *)out);
 
@@ -947,7 +961,7 @@ void sphere_project_setup (double alat, double alon, double *a, double blat, dou
 	GMT_normalize3v(c);
 }
 
-void flat_project_setup (double alat, double alon, double blat, double blon, double plat, double plon, double *azim, double *e, GMT_LONG two_pts, BOOLEAN pole_set)
+void flat_project_setup (double alat, double alon, double blat, double blon, double plat, double plon, double *azim, double *e, GMT_LONG two_pts, GMT_LONG pole_set)
 {
 	/* Sets up stuff for rotation of cartesian 2-vectors, analogous
 	   to the spherical three vector stuff above.
