@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: ps2raster.c,v 1.69 2010/01/05 01:15:46 guru Exp $
+ *	$Id: ps2raster.c,v 1.84 2011/01/11 10:38:23 remko Exp $
  *
- *	Copyright (c) 2006-2010 by J. Luis
+ *	Copyright (c) 2006-2011 by J. Luis
  *	See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -69,59 +69,59 @@
 
 struct PS2RASTER_CTRL {
 	struct A {	/* -A[u][-] [Adjust boundingbox] */
-		BOOLEAN active;
-		BOOLEAN strip;	/* Remove the -U time-stamp */
-		BOOLEAN reset;	/* The -A- turns -A off, overriding any automode in effect */
+		GMT_LONG active;
+		GMT_LONG strip;	/* Remove the -U time-stamp */
+		GMT_LONG reset;	/* The -A- turns -A off, overriding any automode in effect */
 	} A;
 	struct C {	/* -C<option> */
-		BOOLEAN active;
+		GMT_LONG active;
 	} C;
 	struct D {	/* -D<dir> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *dir;
 	} D;
 	struct E {	/* -E<resolution> */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG dpi;
 	} E;
 	struct F {	/* -F<out_name> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} F;
 	struct G {	/* -G<GSpath> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} G;
 	struct L {	/* -L<listfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} L;
 	struct N {	/* -N */
-		BOOLEAN active;
+		GMT_LONG active;
 	} N;
 	struct P2 {	/* -P */
-		BOOLEAN active;
+		GMT_LONG active;
 	} P;
 	struct Q {	/* -Q[g|t]<bits> */
-		BOOLEAN active;
-		BOOLEAN on[2];	/* [0] for graphics, [1] for text antialiasing */
+		GMT_LONG active;
+		GMT_LONG on[2];	/* [0] for graphics, [1] for text antialiasing */
 		GMT_LONG bits[2];
 	} Q;
 	struct S {	/* -S */
-		BOOLEAN active;
+		GMT_LONG active;
 	} S;
 	struct T {	/* -T */
-		BOOLEAN active;
-		BOOLEAN eps;	/* TRUE if we want to make EPS (possibly in addition to another format) */
+		GMT_LONG active;
+		GMT_LONG eps;	/* TRUE if we want to make EPS (possibly in addition to another format) */
 		GMT_LONG device;
 	} T;
 	struct V2 {	/* -V */
-		BOOLEAN active;
+		GMT_LONG active;
 	} V;
 	struct W {	/* -W -- for world file production */
-		BOOLEAN active;
-		BOOLEAN warp;
-		BOOLEAN kml;
+		GMT_LONG active;
+		GMT_LONG warp;
+		GMT_LONG kml;
 		GMT_LONG mode;	/* 0 = clamp at ground, 1 is relative to ground, 2 is absolute 3 is relative to seafloor, 4 is clamp at seafloor */
 		GMT_LONG min_lod, max_lod;	/* minLodPixels and maxLodPixels settings */
 		GMT_LONG min_fade, max_fade;	/* minFadeExtent and maxFadeExtent settings */
@@ -132,11 +132,23 @@ struct PS2RASTER_CTRL {
 	} W;
 };
 
-int main (int argc, char **argv) {
-	BOOLEAN error = FALSE, grayscale = FALSE, found_proj = FALSE;
+char * fgets2 (char *s, int n, FILE *stream)
+{	/* Like fgets but breaks for either \r or \n */
+	int c, k = 0, done = FALSE;
+	n--;	/* Max chars to read */
+	while (!done && (c = fgetc (stream)) != EOF) {
+		if (c == '\r') c = '\n';	/* Replace ugly \r with nice \n */
+		s[k++] = c;			/* Add to the growing buffer */
+		if (c == '\n' || k == n) s[k] = '\0', done = TRUE;	/* Get \n or ran out of space */
+	}
+	return ((k == 0) ? NULL : s);
+}
 
-	GMT_LONG i, j, k, len, r, n_files = 0, pos_file, pos_ext, nr, nl, pix_w = 0, pix_h = 0, mode;
-	GMT_LONG got_BB, got_HRBB, got_BBatend, file_has_HRBB, got_orient, landscape, setup, i_unused = 0;
+int main (int argc, char **argv) {
+	GMT_LONG error = FALSE, grayscale = FALSE, found_proj = FALSE;
+
+	GMT_LONG i, j, k, len, r, n_files = 0, pos_file, pos_ext, pix_w = 0, pix_h = 0, mode;
+	GMT_LONG got_BB, got_HRBB, got_BBatend, file_has_HRBB, got_end, landscape, setup, i_unused = 0;
 	double xt, yt, w, h, x0 = 0.0, x1 = 612.0, y0 = 0.0, y1 = 828.0;
 	double	west = 0.0, east = 0.0, south = 0.0, north = 0.0;
 	double	west_prj, south_prj, east_prj, north_prj;
@@ -146,7 +158,7 @@ int main (int argc, char **argv) {
 	char ps_file[BUFSIZ];
 	char **ps_names, *no_U_file = NULL, *clean_PS_file = NULL, *tmp_file = NULL, out_file[BUFSIZ], *BB_file = NULL;
 	char line[BUFSIZ], c[BUFSIZ], *p, c1[20], c2[20], c3[20], c4[20], cmd[BUFSIZ], proj4_name[20], *quiet = NULL;
-	char *gs_params = NULL, *gs_BB = NULL, *anti = NULL, text[BUFSIZ], gs_extra[BUFSIZ], *proj4_cmd = NULL, *not_used = NULL;
+	char *gs_params = NULL, *gs_BB = NULL, *anti = NULL, text[BUFSIZ], gs_extra[BUFSIZ], *proj4_cmd = NULL;
 	char *device[N_GS_DEVICES] = {"", "pdfwrite", "jpeg", "png16m", "ppmraw", "tiff24nc", "bmp16m", "pngalpha", "jpeggray", "pnggray", "tiffgray", "bmpgray"};
 	char *ext[N_GS_DEVICES] = {".eps", ".pdf", ".jpg", ".png", ".ppm", ".tif", ".bmp", ".png", ".jpg", ".png", ".tif", ".bmp"};
 	char *RefLevel[5] = {"clampToGround", "relativeToGround", "absolute", "relativeToSeaFloor", "clampToSeaFloor"};
@@ -166,14 +178,14 @@ int main (int argc, char **argv) {
 	struct PS2RASTER_CTRL *Ctrl;
 
 	void *New_ps2raster_Ctrl (), Free_ps2raster_Ctrl (struct PS2RASTER_CTRL *C);
-	BOOLEAN parse_GE_settings (char *arg, struct PS2RASTER_CTRL *C);
+	GMT_LONG parse_GE_settings (char *arg, struct PS2RASTER_CTRL *C);
 	
 	Ctrl = (struct PS2RASTER_CTRL *)New_ps2raster_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	/* Parameters for all the formats available */
 
-	gs_params = "-q -dNOPAUSE -dBATCH -dUseFlateCompression=true -dPDFSETTINGS=/prepress -dEmbedAllFonts=true -dMonoImageFilter=/FlateEncode -dAutoFilterGrayImages=false -dGrayImageFilter=/FlateEncode -dAutoFilterColorImages=false -dColorImageFilter=/FlateEncode";
-	gs_BB = "-q -dNOPAUSE -dBATCH -sDEVICE=bbox -r720";
+	gs_params = "-q -dSAFER -dNOPAUSE -dBATCH -dUseFlateCompression=true -dPDFSETTINGS=/prepress -dEmbedAllFonts=true -dSubsetFonts=true -dMonoImageFilter=/FlateEncode -dAutoFilterGrayImages=false -dGrayImageFilter=/FlateEncode -dAutoFilterColorImages=false -dColorImageFilter=/FlateEncode";
+	gs_BB = "-q -dSAFER -dNOPAUSE -dBATCH -sDEVICE=bbox"; /* -r defaults to 4000, see http://pages.cs.wisc.edu/~ghost/doc/cvs/Devices.htm#Test */
 	memset ((void *)gs_extra, 0, BUFSIZ);
 	
 	/* Check and interpret the command line arguments */
@@ -212,7 +224,7 @@ int main (int argc, char **argv) {
 				case 'F':	/* Set explicitly the output file name */
 					Ctrl->F.active = TRUE;
 					Ctrl->F.file = strdup (&argv[i][2]);
-					GMT_chop_ext(Ctrl->F.file);	/* Make sure file name has no extension */
+					GMT_chop_ext (Ctrl->F.file);	/* Make sure file name has no extension */
 					break;
 				case 'L':	/* Give list of files to convert */
 					Ctrl->L.active = TRUE;
@@ -305,8 +317,9 @@ int main (int argc, char **argv) {
 
 	if (argc == 1 || GMT_give_synopsis_and_exit || error) {
 		fprintf (stderr,"ps2raster %s - Converts one or several [E]PS file(s) to raster formats using GhostScript.\n\n", GMT_VERSION);
-		fprintf(stderr,"usage: ps2raster <psfile1> <psfile2> <...> [-A[u][-]] [-D<dir>] [-E<resolution>] [-F<out_name>]\n");
-		fprintf(stderr,"       [-G<ghost_path>] [-L<listfile>] [-N] [-P] [-Q[g|t]1|2|4] [-Tb|e|f|g|G|j|m|t] [-V]\n");
+		fprintf(stderr,"usage: ps2raster <psfile1> <psfile2> <...> [-A[u][-]] [-C<gs_command>] [-D<dir>]\n");
+		fprintf(stderr,"       [-E<resolution>] [-F<out_name>] [-G<ghost_path>] [-L<listfile>] [-N] [-P]\n");
+		fprintf(stderr,"       [-Q[g|t]1|2|4] [-S] [-Tb|e|f|g|G|j|m|t] [-V]\n");
 		fprintf(stderr,"       [-W[+g][+k][+t<title>][+n<name>][+a<mode>[<alt]][+l<lodmin>/<lodmax>][+f<minfade>/<maxfade>][+<URL>]]\n\n");
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
@@ -314,10 +327,12 @@ int main (int argc, char **argv) {
 		fprintf (stderr,"image will have the size specified by the BoundingBox.\n");
 		fprintf (stderr,"As an option, a tight BoundingBox may be computed.\n\n");
 		fprintf (stderr,"	<psfile(s)> postscript file(s) to be converted.\n");
-		fprintf(stderr,"\n\tOPTIONS:\n");
+		fprintf (stderr,"\n\tOPTIONS:\n");
 		fprintf (stderr,"\t-A Adjust the BoundingBox to the minimum required by the image contents\n");
 		fprintf (stderr,"\t   Append u to strip out time-stamps (produced by GMT -U options)\n");
 		fprintf (stderr,"\t   Append - to make sure -A is NOT activated by -W\n");
+		fprintf (stderr,"\t-C Specify a single, custom option that will be passed on to GhostScript\n");
+		fprintf (stderr,"\t   as is. Repeat to add several options [none].\n");
 		fprintf (stderr,"\t-D Sets an alternative output directory (which must exist) [Default is same directory as PS files]\n");
 		fprintf (stderr,"\t   Use -D. to place the output in the current directory.\n");
 		fprintf (stderr,"\t-E Set raster resolution in dpi [default = 720 for PDF, 300 for others]\n");
@@ -434,8 +449,8 @@ int main (int argc, char **argv) {
 	}
 
 	if (Ctrl->W.active) {	/* Implies -P and -A (unless -A- is set ) */
-		Ctrl->P.active = TRUE;
-		if (!Ctrl->A.reset) Ctrl->A.active = TRUE;
+		Ctrl->P.active = Ctrl->A.active = TRUE;
+		if (Ctrl->A.reset) Ctrl->A.active = FALSE;
 	}
 
 	/* Use default DPI if not already set */
@@ -444,9 +459,9 @@ int main (int argc, char **argv) {
 	/* Multiple files in a file with their names */
 	if (Ctrl->L.active) {
 		ps_names = (char **) GMT_memory (VNULL, n_alloc, sizeof (char *), GMT_program);
-		while (fgets (line, BUFSIZ, fpl) != NULL) {
+		while (fgets2 (line, BUFSIZ, fpl) != NULL) {
 			ps_names[n_files] = (char *) GMT_memory (VNULL, (size_t)BUFSIZ, sizeof (char), GMT_program);
-			if (line[0] == '#' || line[0] == '\n' || line[0] == '\r') continue;
+			if (line[0] == '#' || line[0] == '\n') continue;
 			sscanf (line, "%s", ps_names[n_files]);
 			n_files++;
 			if (n_files > (int)n_alloc) {
@@ -487,35 +502,11 @@ int main (int argc, char **argv) {
 			fprintf (stderr, "%s: Cannot to open file %s\n", GMT_program, ps_file);
 			continue;
 		}
+
 		if (Ctrl->V.active) fprintf (stderr, "%s: Processing %s:", GMT_program, ps_file);
 
-		/* Check for JUNKY Illustrator EPS crap with mix of \r and \n */
-		not_used = fgets (line, BUFSIZ, fp);	/* Get a single line - this will be a full buffer if crap */
-		for (j = nr = nl = 0; j < (int)strlen (line); j++) {
-			if (line[j] == '\r') nr++;	/* Number of CR found */
-			if (line[j] == '\n') nl++;	/* Number of LF found */
-		}
-		rewind (fp);	/* Go back to beginning */
-		if (nl == 0 && nr) {	/* Must create temporary file without the \r shit */
-			int byte;
-			if (Ctrl->V.active) fprintf (stderr, " Clean EPS...");
-			clean_PS_file = (char *) GMT_memory (VNULL, (size_t)BUFSIZ, sizeof(char), GMT_program);
-			sprintf (clean_PS_file, "%s%cps2raster_%da.eps", Ctrl->D.dir, DIR_DELIM, (int)getpid());
-			if ((fp2 = fopen (clean_PS_file, "w+")) == NULL) {
-				fprintf (stderr, "%s: Unable to create a temporary file\n", GMT_program);
-				exit (EXIT_FAILURE);
-			}
-			while ((byte = fgetc (fp)) != EOF) {
-				if (byte == '\r') byte = '\n';	/* Replace the CR with LF */
-				fputc (byte, fp2);
-			}
-			fclose (fp);	/* Close original PS file */
-			rewind (fp2);	/* Rewind new clean PS file */
-			fp = fp2;	/* Set original file pointer to this file instead */
-		}
-
 		if (Ctrl->A.strip) {	/* Must strip off the GMT timestamp stuff */
-			BOOLEAN dump = TRUE;
+			GMT_LONG dump = TRUE;
 			if (Ctrl->V.active) fprintf (stderr, " Strip GMT time-stamp...");
 			no_U_file = (char *) GMT_memory (VNULL, (size_t)BUFSIZ, sizeof(char), GMT_program);
 			sprintf (no_U_file, "%s%cps2raster_%db.eps", Ctrl->D.dir, DIR_DELIM, (int)getpid());
@@ -523,7 +514,7 @@ int main (int argc, char **argv) {
 				fprintf (stderr, "%s: Unable to create a temporary file\n", GMT_program);
 				exit (EXIT_FAILURE);
 			}
-			while (fgets (line, BUFSIZ, fp) != NULL) {
+			while (fgets2 (line, BUFSIZ, fp) != NULL) {
 				if (!strncmp (line, "% Begin GMT time-stamp", (size_t)22)) dump = FALSE;
 				if (dump) fprintf (fp2, "%s", line);
 				if (!strncmp (line, "% End GMT time-stamp", (size_t)20)) dump = TRUE;
@@ -533,7 +524,7 @@ int main (int argc, char **argv) {
 			fp = fp2;	/* Set original file pointer to this file instead */
 		}
 
-		got_BB = got_HRBB = file_has_HRBB = got_BBatend = got_orient = landscape = setup = FALSE;
+		got_BB = got_HRBB = file_has_HRBB = got_BBatend = got_end = landscape = setup = FALSE;
 
 		len = (GMT_LONG)strlen(ps_file);
 		j = len - 1;
@@ -554,20 +545,33 @@ int main (int argc, char **argv) {
 			BB_file = (char *) GMT_memory (VNULL, (size_t)BUFSIZ, sizeof(char), GMT_program);
 			sprintf (BB_file, "%s%cps2raster_%ldc.bb", Ctrl->D.dir, DIR_DELIM, (GMT_LONG)getpid());
 			psfile_to_use = (Ctrl->A.strip) ? no_U_file : ((clean_PS_file) ? clean_PS_file : ps_file);
-			sprintf (cmd, "%s%s %s %s 2> %s", at_sign, Ctrl->G.file, gs_BB, psfile_to_use, BB_file);
+			sprintf (cmd, "%s%s %s %s %s 2> %s", at_sign, Ctrl->G.file, gs_BB, gs_extra, psfile_to_use, BB_file);
 			i_unused = system (cmd);		/* Execute the command that computes the tight BB */
 			if ((fpb = fopen (BB_file, "r")) == NULL) {
 				fprintf (stderr, "%s: Unable to open file %s\n", GMT_program, BB_file);
 				exit (EXIT_FAILURE);
 			}
-			while (fgets (line, BUFSIZ, fpb) != NULL && !got_BB) {	/* We only use the High resolution BB */
+			while (fgets2 (line, BUFSIZ, fpb) != NULL && !got_BB) {	/* We only use the High resolution BB */
 				if ((p = strstr (line,"%%HiResBoundingBox:"))) {
 					sscanf (&p[19], "%s %s %s %s", c1, c2, c3, c4);
 					x0 = atof (c1);		y0 = atof (c2);
 					x1 = atof (c3);		y1 = atof (c4);
 					if (x1 <= x0 || y1 <= y0) {
 						fprintf (stderr, "%s: Unable to decode BoundingBox file %s\n", GMT_program, BB_file);
-						exit (EXIT_FAILURE);
+						fclose (fpb);
+						remove (BB_file);	/* Remove the file */
+						tmp_file = (char *) GMT_memory (VNULL, (size_t)BUFSIZ, sizeof(char), GMT_program);
+						sprintf (tmp_file, "%s%c", Ctrl->D.dir, DIR_DELIM);
+						strncat (tmp_file, &ps_file[pos_file], (size_t)(pos_ext - pos_file));
+						strcat (tmp_file, ext[Ctrl->T.device]);
+						sprintf (cmd, "%s%s %s %s -sDEVICE=%s -g1x1 -r%ld -sOutputFile=%s -f%s", 
+							at_sign, Ctrl->G.file, gs_params, gs_extra, device[Ctrl->T.device],
+							Ctrl->E.dpi, tmp_file, ps_file);
+						i_unused = system (cmd);		/* Execute the GhostScript command */
+						if (Ctrl->S.active) fprintf (stdout, "%s\n", cmd);
+
+						GMT_free((void *) tmp_file);
+						continue;
 					}
 					got_BB = got_HRBB = TRUE;
 				}
@@ -584,18 +588,21 @@ int main (int argc, char **argv) {
 		tmp_file = (char *) GMT_memory (VNULL, (size_t)BUFSIZ, sizeof(char), GMT_program);
 		if (Ctrl->T.eps) {
 			if (Ctrl->D.active) sprintf (tmp_file, "%s%c", Ctrl->D.dir, DIR_DELIM);	/* Use specified output directory */
-			strncat (tmp_file, &ps_file[pos_file], (size_t)(pos_ext - pos_file));
+			if (!Ctrl->F.active)
+				strncat (tmp_file, &ps_file[pos_file], (size_t)(pos_ext - pos_file));
+			else
+				strcat (tmp_file, Ctrl->F.file);
 			strcat (tmp_file, ext[GS_DEV_EPS]);
 			if ((fpo = fopen (tmp_file, "w")) == NULL) {
 				fprintf (stderr, "%s: Unable to open file %s for writing\n", GMT_program, tmp_file);
-				exit (EXIT_FAILURE);
+				continue;
 			}
 		}
 		else {
 			sprintf (tmp_file, "%s%cps2raster_%ldd.eps", Ctrl->D.dir, DIR_DELIM, (GMT_LONG)getpid());
 			if ((fpo = fopen (tmp_file, "w+")) == NULL) {
 				fprintf (stderr, "%s: Unable to create a temporary file\n", GMT_program);
-				exit (EXIT_FAILURE);
+				continue;
 			}
 		}
 
@@ -603,10 +610,11 @@ int main (int argc, char **argv) {
 		 * Since we prefer the HiResBB over BB we must continue to read until both are found or 20 lines have past */
 
 		i = 0;
-		while ((fgets (line, BUFSIZ, fp) != NULL) && i < 20 && !(got_BB && got_HRBB && got_orient)) {
+		while ((fgets2 (line, BUFSIZ, fp) != NULL) && i < 20 && !(got_BB && got_HRBB && got_end)) {
 			i++;
-			if (!line[0] || line[0] != '%') continue;/* Skip empty and non-comment lines */
-			if (!got_BB && (p = strstr (line, "%%BoundingBox:"))) {
+			if (!line[0] || line[0] != '%') 
+				{ /* Skip empty and non-comment lines */ }
+			else if (!got_BB && (p = strstr (line, "%%BoundingBox:"))) {
 				sscanf (&p[14], "%s %s %s %s",c1,c2,c3,c4);
 				if (strncmp (c1, "(atend)", (size_t)7)) {	/* Got actual numbers */
 					if (!got_HRBB) {	/* Only assign values if we havent seen the high-res version yet */
@@ -629,22 +637,23 @@ int main (int argc, char **argv) {
 					}
 				}
 			}
-			else if (!got_orient && (p = strstr (line, "%%Orientation:"))) {
+			else if ((p = strstr (line, "%%Orientation:"))) {
 				sscanf (&p[14], "%s", c1);
 				if (!strncmp (c1, "Landscape", (size_t)9)) landscape = TRUE;
-				got_orient = TRUE;
 			}
-			if (got_BBatend == 1 && got_orient) {	/* Now is the time to look at the end of the file */
+			else if ((p = strstr (line, "%%EndComments")))
+				got_end = TRUE;
+			if (got_BBatend == 1 && (got_end || i == 19)) {	/* Now is the time to look at the end of the file */
 				got_BBatend++;			/* Avoid jumping more than once to the end */
 				if (!fseek (fp, (long)-256, SEEK_END)) i = -30;
 			}
 		}
 
-		/* Can not proceed without knowing the BoundingBox */
+		/* Cannot proceed without knowing the BoundingBox */
 
 		if (!got_BB) {
 			fprintf (stderr, "%s: GMT FATAL ERROR: The file %s has no BoundingBox in the first 20 lines or last 256 bytes. Use -A option.\n", GMT_program, ps_file);
-			exit (EXIT_FAILURE);
+			continue;
 		}
 
 		/* Do the math on the BoundingBox and translation coordinates */
@@ -657,7 +666,7 @@ int main (int argc, char **argv) {
 		/* Rewind the input file and start copying and replacing */
 
 		rewind (fp);
-		while (fgets (line, BUFSIZ, fp) != NULL) {
+		while (fgets2 (line, BUFSIZ, fp) != NULL) {
 			if (line[0] != '%') {	/* Copy any non-comment line, except one containing /PageSize in the Setup block */
 				if (setup && strstr(line,"/PageSize") != NULL) continue;
 				fprintf (fpo, "%s", line);
@@ -737,7 +746,7 @@ int main (int argc, char **argv) {
 			}
 #ifdef USE_GDAL
 			else if (!strncmp(c, "%%PageTrailer", (size_t)13) && found_proj) {
-				fgets (line, BUFSIZ, fp);
+				fgets2 (line, BUFSIZ, fp);
 				fprintf (fpo, "%%%%PageTrailer\n");
 				fprintf (fpo, "%s", line);
 
@@ -825,6 +834,8 @@ int main (int argc, char **argv) {
 				at_sign, Ctrl->G.file, gs_params, gs_extra, device[Ctrl->T.device],
 				pix_w, pix_h, Ctrl->E.dpi, out_file, tmp_file);
 			i_unused = system (cmd);		/* Execute the GhostScript command */
+			if ((i_unused = access (out_file, R_OK)) != 0)
+				fprintf(stderr, "\nPS2RASTER WARNING: file\n\t%s\nwas not created. Maybe you forgot to close the PS file (a -K in excess?)\n", out_file);
 			if (Ctrl->S.active) fprintf (stdout, "%s\n", cmd);
 		}
 		if (Ctrl->V.active) fprintf (stderr, " Done.\n");
@@ -1003,11 +1014,11 @@ int main (int argc, char **argv) {
 	exit (EXIT_SUCCESS);
 }
 
-BOOLEAN parse_GE_settings (char *arg, struct PS2RASTER_CTRL *C)
+GMT_LONG parse_GE_settings (char *arg, struct PS2RASTER_CTRL *C)
 {
 	/* Syntax: -W[+g][+k][+t<doctitle>][+n<layername>][+a<altmode>][+l<lodmin>/<lodmax>] */
 	
-	BOOLEAN error = FALSE;
+	GMT_LONG error = FALSE;
 	GMT_LONG pos = 0;
 	char txt[BUFSIZ], p[BUFSIZ];
 	
@@ -1042,7 +1053,7 @@ BOOLEAN parse_GE_settings (char *arg, struct PS2RASTER_CTRL *C)
 				}
 				break;
 			case 'f':	/* Set fading options in KML */
-				sscanf (&p[1], "%ld/%ld", &C->W.min_fade, &C->W.max_fade);
+				sscanf (&p[1], "%" GMT_LL "d/%" GMT_LL "d", &C->W.min_fade, &C->W.max_fade);
 				break;
 			case 'g':	/* Use gdal to make geotiff */
 				C->W.warp = TRUE;
@@ -1051,7 +1062,7 @@ BOOLEAN parse_GE_settings (char *arg, struct PS2RASTER_CTRL *C)
 				C->W.kml = TRUE;
 				break;
 			case 'l':	/* Set KML level of detail for image */
-				sscanf (&p[1], "%ld/%ld", &C->W.min_lod, &C->W.max_lod);
+				sscanf (&p[1], "%" GMT_LL "d/%" GMT_LL "d", &C->W.min_lod, &C->W.max_lod);
 				break;
 			case 'n':	/* Set KML document layer name */
 				if (C->W.overlayname) free (C->W.overlayname);	/* Already set, free then reset */
