@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: psclip.c,v 1.59 2010/01/05 01:15:47 guru Exp $
+ *	$Id: psclip.c,v 1.64 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -32,20 +32,20 @@
 
 struct PSCLIP_CTRL {
 	struct C {	/* -C */
-		BOOLEAN active;
+		GMT_LONG active;
 	} C;
 	struct E {	/* -Eazim/elev */
-		BOOLEAN active;
+		GMT_LONG active;
 		double azimuth, elevation;
 	} E;
 	struct N {	/* -N */
-		BOOLEAN active;
+		GMT_LONG active;
 	} N;
 	struct T {	/* -T */
-		BOOLEAN active;
+		GMT_LONG active;
 	} T;
 	struct Z {	/* -Z<z_level> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double level;
 	} Z;
 };
@@ -53,9 +53,9 @@ struct PSCLIP_CTRL {
 int main (int argc, char **argv)
 {
 	GMT_LONG i, n, n_alloc;
-	GMT_LONG fno, n_args, n_files = 0, n_fields, n_expected_fields = 0;
+	GMT_LONG fno, n_args, n_files = 0, n_read, n_fields, n_expected_fields = 0;
 
-	BOOLEAN error = FALSE, nofile, done, first;
+	GMT_LONG error = FALSE, nofile, done, first;
 
 	char line[BUFSIZ], *not_used = NULL;
 
@@ -67,7 +67,7 @@ int main (int argc, char **argv)
 
 	void *New_psclip_Ctrl (), Free_psclip_Ctrl (struct PSCLIP_CTRL *C);
 	
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct PSCLIP_CTRL *)New_psclip_Ctrl ();	/* Allocate and initialize a new control structure */
 
@@ -297,12 +297,13 @@ int main (int argc, char **argv)
 
 				/* Start a new segment path */
 
-				n = 0;
+				n_read = n = 0;
 
 				while (! (GMT_io.status & (GMT_IO_SEGMENT_HEADER | GMT_IO_EOF))) {	/* Keep going until FALSE */
+					n_read++;
 					if (GMT_io.status & GMT_IO_MISMATCH) {
-						fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%d) fields near line %ld\n", GMT_program, n_fields, 2, n);
-						exit (EXIT_FAILURE);
+						fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%d) fields near line %ld (skipped)\n", GMT_program, n_fields, 2, n_read);
+						continue;
 					}
 
 					xx[n] = in[GMT_X];	yy[n] = in[GMT_Y];
