@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: pscoast.c,v 1.101 2010/01/05 01:15:47 guru Exp $
+ *	$Id: pscoast.c,v 1.108 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -59,65 +59,65 @@
 
 struct PSCOAST_CTRL {
 	struct A {	/* -A<min_area>[/<min_level>/<max_level>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		struct GMT_SHORE_SELECT info;
 	} A;
 	struct C {	/* -C<fill> */
-		BOOLEAN active;
+		GMT_LONG active;
 		struct GMT_FILL fill[2];	/* lake and riverlake fill */
 	} C;
 	struct D {	/* -D<resolution> */
-		BOOLEAN active;
-		BOOLEAN force;	/* if TRUE, select next highest level if current set is not avaialble */
+		GMT_LONG active;
+		GMT_LONG force;	/* if TRUE, select next highest level if current set is not avaialble */
 		char set;	/* One of f, h, i, l, c */
 	} D;
 	struct E {	/* -Eazim/elev */
-		BOOLEAN active;
+		GMT_LONG active;
 		double azimuth, elevation;
 	} E;
 	struct G {	/* -G<fill> */
-		BOOLEAN active;
-		BOOLEAN clip;
+		GMT_LONG active;
+		GMT_LONG clip;
 		struct GMT_FILL fill;
 	} G;
 	struct I {	/* -I<feature>[/<pen>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG use[GMT_N_RLEVELS];
 		struct GMT_PEN pen[GMT_N_RLEVELS];
 	} I;
 	struct L {	/* -L */
-		BOOLEAN active;
+		GMT_LONG active;
 		struct GMT_MAP_SCALE item;
 	} L;
 	struct N {	/* -N<feature>[/<pen>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG use[GMT_N_BLEVELS];
 		struct GMT_PEN pen[GMT_N_BLEVELS];
 	} N;
 	struct Q {	/* -Q */
-		BOOLEAN active;
+		GMT_LONG active;
 	} Q;
 	struct S {	/* -S<fill> */
-		BOOLEAN active;
-		BOOLEAN clip;
+		GMT_LONG active;
+		GMT_LONG clip;
 		struct GMT_FILL fill;
 	} S;
 	struct T {	/* -L */
-		BOOLEAN active;
+		GMT_LONG active;
 		struct GMT_MAP_ROSE item;
 	} T;
 	struct W {	/* -W[<feature>/]<pen> */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG use[GMT_MAX_GSHHS_LEVEL];
 		struct GMT_PEN pen[GMT_MAX_GSHHS_LEVEL];
 	} W;
 	struct Z {	/* -Z<z_level> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double level;
 	} Z;
 #ifdef DEBUG
 	struct DBG {	/* -+<bin> */
-		BOOLEAN active;
+		GMT_LONG active;
 		int bin;
 	} debug;
 #endif
@@ -131,10 +131,10 @@ int main (int argc, char **argv)
 
 	GMT_LONG n;
 	
-	BOOLEAN	error = FALSE, shift = FALSE, need_coast_base, recursive, fill_ocean, fill_land;
-	BOOLEAN	greenwich = FALSE, possibly_donut_hell = FALSE, fill_in_use = FALSE;
-	BOOLEAN clobber_background, paint_polygons = FALSE, donut, dumping = FALSE;
-	BOOLEAN donut_hell = FALSE, world_map_save, clipping = FALSE;
+	GMT_LONG	error = FALSE, shift = FALSE, need_coast_base, recursive, fill_ocean, fill_land;
+	GMT_LONG	greenwich = FALSE, possibly_donut_hell = FALSE, fill_in_use = FALSE;
+	GMT_LONG clobber_background, paint_polygons = FALSE, donut, dumping = FALSE;
+	GMT_LONG donut_hell = FALSE, world_map_save, clipping = FALSE;
 
 	double	west = 0.0, east = 0.0, south = 0.0, north = 0.0, bin_x[5], bin_y[5], out[2];
 	double west_border, east_border, anti_lon = 0.0, anti_lat = -90.0, edge = 720.0;
@@ -154,7 +154,7 @@ int main (int argc, char **argv)
 	void recursive_clipping (int k0, int np, struct GMT_GSHHS_POL *p, int level, int start_level, int *n_pieces);
 	void *New_pscoast_Ctrl (), Free_pscoast_Ctrl (struct PSCOAST_CTRL *C);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct PSCOAST_CTRL *) New_pscoast_Ctrl ();		/* Allocate and initialize defaults in a new control structure */
 
@@ -379,6 +379,8 @@ int main (int argc, char **argv)
 					break;
 			}
 		}
+		else
+			fprintf (stderr, "%s: Warning: Ignoring filename %s\n", GMT_program, argv[i]);
 	}
 
 	if (argc == 1 || GMT_give_synopsis_and_exit) {	/* Display usage */
@@ -559,7 +561,7 @@ int main (int argc, char **argv)
 	if (error) exit (EXIT_FAILURE);
 
 	if (Ctrl->D.force) Ctrl->D.set = GMT_shore_adjust_res (Ctrl->D.set);
-	base = GMT_set_resolution (&Ctrl->D.set, 'D');
+	base = (int)GMT_set_resolution (&Ctrl->D.set, 'D');
 	z_project.view_azimuth = Ctrl->E.azimuth;
 	z_project.view_elevation = Ctrl->E.elevation;
 	fill[0] = Ctrl->S.fill;
@@ -614,7 +616,10 @@ int main (int argc, char **argv)
 #ifdef SET_IO_MODE
 		GMT_setmode (GMT_OUT);
 #endif
-		if (!GMT_io.binary[1]) fprintf (GMT_stdout, "# Data from the %s resolution GMT shoreline, borders, and rivers database\n", shore_resolution[base]);
+		if (!GMT_io.binary[1]) {
+			sprintf (comment, "# Data from the %s resolution GMT shoreline, borders, and rivers database\n", shore_resolution[base]);
+			GMT_fputs (comment, GMT_stdout);
+		}
 	}
 	else {
 		if (Ctrl->Q.active)
@@ -740,11 +745,11 @@ int main (int argc, char **argv)
 
 	for (ind = 0; need_coast_base && ind < c.nb; ind++) {	/* Loop over necessary bins only */
 
-		bin = c.bins[ind];
+		bin = (int)c.bins[ind];
 #ifdef DEBUG
 		if (Ctrl->debug.active && bin != Ctrl->debug.bin) continue;
 #endif
-		if ((err = GMT_get_shore_bin (ind, &c))) {
+		if ((err = (int)GMT_get_shore_bin (ind, &c))) {
 			fprintf (stderr, "%s: %s [%s resolution shoreline]\n", GMT_program, GMT_strerror(err), shore_resolution[base]);
 			exit (EXIT_FAILURE);
 		}
@@ -777,11 +782,11 @@ int main (int argc, char **argv)
 
 			/* Assemble one or more segments into polygons */
 
-			if ((np = GMT_assemble_shore (&c, direction, TRUE, shift, west_border, east_border, &p)) == 0) continue;
+			if ((np = (int)GMT_assemble_shore (&c, direction, TRUE, shift, west_border, east_border, &p)) == 0) continue;
 
 			/* Get clipped polygons in x,y inches that can be plotted */
 
-			np_new = GMT_prep_polygons (&p, np, donut_hell, step, bin_trouble);
+			np_new = (int)GMT_prep_polygons (&p, np, donut_hell, step, bin_trouble);
 
 			if (clipping) {
 				for (k = level_to_be_painted; k < GMT_MAX_GSHHS_LEVEL - 1; k++) recursive_clipping (-1, np_new, p, k, k, &n_pieces);
@@ -798,7 +803,7 @@ int main (int argc, char **argv)
 			else if (!recursive) {	/* Simply paints all polygons as is */
 				for (k = 0; k < np_new; k++) {
 					if (p[k].n == 0 || p[k].level < lowest_level) continue;
-					level = p[k].level;
+					level = (int)p[k].level;
 					if (donut_hell && GMT_non_zero_winding (anti_x, anti_y, p[k].lon, p[k].lat, p[k].n)) {	/* Antipode inside polygon, must do donut */
 						n = GMT_map_clip_path (&xtmp, &ytmp, &donut);
 						ps_line (xtmp, ytmp, n, 1, TRUE);
@@ -830,7 +835,7 @@ int main (int argc, char **argv)
 		}
 
 		if (Ctrl->W.active && c.ns) {	/* Draw or dump shorelines, no need to assemble polygons */
-			if ((np = GMT_assemble_shore (&c, direction, FALSE, shift, west_border, east_border, &p)) == 0) continue;
+			if ((np = (int)GMT_assemble_shore (&c, direction, FALSE, shift, west_border, east_border, &p)) == 0) continue;
 
 			for (i = 0; i < np; i++) {
 				if (dumping) {
@@ -845,7 +850,7 @@ int main (int argc, char **argv)
 				else if (Ctrl->W.use[p[i].level-1]) {
 					if (donut_hell) p[i].n = GMT_fix_up_path (&p[i].lon, &p[i].lat, p[i].n, step, 0);
 					GMT_n_plot = GMT_geo_to_xy_line (p[i].lon, p[i].lat, p[i].n);
-					k = p[i].level - 1;
+					k = (int)(p[i].level - 1);
 					if (k != last_pen_level) {
 						GMT_setpen (&Ctrl->W.pen[k]);
 						last_pen_level = k;
@@ -878,7 +883,7 @@ int main (int argc, char **argv)
 
 		for (ind = 0; ind < r.nb; ind++) {	/* Loop over necessary bins only */
 
-			bin = r.bins[ind];
+			bin = (int)r.bins[ind];
 			GMT_get_br_bin (ind, &r, Ctrl->I.use, n_rlevels);
 
 			if (r.ns == 0) continue;
@@ -888,7 +893,7 @@ int main (int argc, char **argv)
 				shift = ((left - edge) <= 180.0 && (right - edge) > 180.0);
 			}
 
-			if ((np = GMT_assemble_br (&r, shift, edge, &p)) == 0) {
+			if ((np = (int)GMT_assemble_br (&r, shift, edge, &p)) == 0) {
 				GMT_free_br (&r);
 				continue;
 			}
@@ -907,7 +912,7 @@ int main (int argc, char **argv)
 					GMT_n_plot = GMT_geo_to_xy_line (p[i].lon, p[i].lat, p[i].n);
 					if (!GMT_n_plot) continue;
 
-					k = p[i].level;
+					k = (int)p[i].level;
 					if (k != last_k) {
 						GMT_setpen (&Ctrl->I.pen[k]);
 						last_k = k;
@@ -940,7 +945,7 @@ int main (int argc, char **argv)
 
 		for (ind = 0; ind < b.nb; ind++) {	/* Loop over necessary bins only */
 
-			bin = b.bins[ind];
+			bin = (int)b.bins[ind];
 			GMT_get_br_bin (ind, &b, Ctrl->N.use, n_blevels);
 
 			if (b.ns == 0) continue;
@@ -950,7 +955,7 @@ int main (int argc, char **argv)
 				shift = ((left - edge) <= 180.0 && (right - edge) > 180.0);
 			}
 
-			if ((np = GMT_assemble_br (&b, shift, edge, &p)) == 0) {
+			if ((np = (int)GMT_assemble_br (&b, shift, edge, &p)) == 0) {
 				GMT_free_br (&b);
 				continue;
 			}
@@ -970,7 +975,7 @@ int main (int argc, char **argv)
 					GMT_n_plot = GMT_geo_to_xy_line (p[i].lon, p[i].lat, p[i].n);
 					if (!GMT_n_plot) continue;
 
-					k = p[i].level - 1;
+					k = (int)(p[i].level - 1);
 					if (k != last_k) {
 						GMT_setpen (&Ctrl->N.pen[k]);
 						last_k = k;
@@ -1021,7 +1026,7 @@ void recursive_painting (int k0, int np, struct GMT_GSHHS_POL p[], int level, in
 
 	int k, flag;
 	char text[GMT_TEXT_LEN];
-	BOOLEAN add_this_polygon_to_path (int k0, struct GMT_GSHHS_POL *p, int level, int k);
+	GMT_LONG add_this_polygon_to_path (int k0, struct GMT_GSHHS_POL *p, int level, int k);
 	if (level > GMT_MAX_GSHHS_LEVEL) return;
 	flag = (level == start_level) ? 1 : 0;
 	for (k = k0 + 1; k < np; k++) {
@@ -1049,7 +1054,7 @@ void recursive_clipping (int k0, int np, struct GMT_GSHHS_POL *p, int level, int
 {
 	int k, flag;
 	char text[GMT_TEXT_LEN];
-	BOOLEAN add_this_polygon_to_path (int k0, struct GMT_GSHHS_POL *p, int level, int k);
+	GMT_LONG add_this_polygon_to_path (int k0, struct GMT_GSHHS_POL *p, int level, int k);
 	if (level > GMT_MAX_GSHHS_LEVEL) return;
 	for (k = k0 + 1; k < np; k++) {
 		if (p[k].n == 0 || p[k].level < level) continue;
@@ -1065,7 +1070,7 @@ void recursive_clipping (int k0, int np, struct GMT_GSHHS_POL *p, int level, int
 	}
 }
 
-BOOLEAN add_this_polygon_to_path (int k0, struct GMT_GSHHS_POL *p, int level, int k)
+GMT_LONG add_this_polygon_to_path (int k0, struct GMT_GSHHS_POL *p, int level, int k)
 {
 	/* Determines if we should add the current polygon pol[k] to the growing path we are constructing */
 
