@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: pscontour.c,v 1.115 2010/01/05 01:15:47 guru Exp $
+ *	$Id: pscontour.c,v 1.124 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -31,45 +31,45 @@
 struct PSCONTOUR_CTRL {
 	struct GMT_CONTOUR contour;
 	struct A {	/* -A[-|aint][+a<angle>][+c<dx>[/<dy>]][+f<font>][+g<fill>][+j<just>][+l<label>][+o|O|t][+s<size>][+p<pen>][+u<unit>] */
-		BOOLEAN active;
-		BOOLEAN off;
+		GMT_LONG active;
+		GMT_LONG off;
 		double interval;
 	} A;
 	struct C {	/* -C<cpt> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} C;
 	struct D {	/* -D<dumpfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} D;
 	struct E {	/* -Eazim/elev */
-		BOOLEAN active;
+		GMT_LONG active;
 		double azimuth, elevation;
 	} E;
 	struct G {	/* -G[d|f|n|l|L|x|X]<params> */
-		BOOLEAN active;
+		GMT_LONG active;
 	} G;
 	struct I {	/* -I */
-		BOOLEAN active;
+		GMT_LONG active;
 	} I;
 	struct L {	/* -L<pen> */
-		BOOLEAN active;
+		GMT_LONG active;
 		struct GMT_PEN pen;
 	} L;
 	struct N {	/* -N */
-		BOOLEAN active;
+		GMT_LONG active;
 	} N;
 	struct S {	/* -S */
-		BOOLEAN active;
+		GMT_LONG active;
 	} S;
 	struct T {	/* -T<indexfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} T;
 	struct W {	/* -W[+]<type><pen> */
-		BOOLEAN active;
-		BOOLEAN color;
+		GMT_LONG active;
+		GMT_LONG color;
 		struct GMT_PEN pen;
 	} W;
 };
@@ -105,13 +105,13 @@ struct PSCONTOUR_CHAIN {
 int main(int argc, char **argv)
 {
 	GMT_LONG nx, k2, k3, node1, node2, c, PSCONTOUR_SUM;
-	GMT_LONG n_alloc, section = 0, *vert, *cind, n_fields, n_contours = 0;
-	GMT_LONG add, close, bad, n_expected_fields, last_entry, last_exit;
+	GMT_LONG n_alloc, section = 0, *vert, *cind, n_read, n_fields, n_contours = 0;
+	GMT_LONG add, bad, n_expected_fields, last_entry, last_exit;
 	GMT_LONG ij, n, np, k, i, low, high;
 	
 	int rgb[3], *ind = NULL;
 	
-	BOOLEAN error = FALSE, more, skip = FALSE, advance = FALSE;
+	GMT_LONG error = FALSE, more, skip = FALSE, advance = FALSE, close;
 
 	double xx[3], yy[3], zz[3], xout[5], yout[5], *in, west, east, south, north;
 	double *xc, *yc, *zc, *x, *y, *z, *xp, *yp, current_contour = -DBL_MAX, xyz[2][3];
@@ -132,7 +132,7 @@ int main(int argc, char **argv)
 	void paint_it (double x[], double y[], GMT_LONG n, double z);
 	void *New_pscontour_Ctrl (), Free_pscontour_Ctrl (struct PSCONTOUR_CTRL *C);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct PSCONTOUR_CTRL *)New_pscontour_Ctrl ();	/* Allocate and initialize a new control structure */
 
@@ -387,20 +387,21 @@ int main(int argc, char **argv)
 	if (GMT_io.io_header[GMT_IN]) for (i = 0; i < GMT_io.n_header_recs; i++) not_used = GMT_fgets (line, BUFSIZ, fp);
 
 	xyz[0][2] = DBL_MAX;	xyz[1][2] = -DBL_MAX;
-	n = 0;
+	n_read = n = 0;
 	n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : 3;
 	n_fields = GMT_input (fp, &n_expected_fields, &in);
 
 	while (! (GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
 
+		n_read++;
 		if (GMT_io.status & GMT_IO_MISMATCH) {
-			fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields, n_expected_fields, n);
-			exit (EXIT_FAILURE);
+			fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld (skipped)\n", GMT_program, n_fields, n_expected_fields, n_read);
+			continue;
 		}
 
 		if (Ctrl->S.active) {	/* Must check if points are inside plot region */
 			GMT_map_outside (in[GMT_X], in[GMT_Y]);
-			skip = ( abs (GMT_x_status_new) > 1 || abs (GMT_y_status_new) > 1);
+			skip = (GMT_abs (GMT_x_status_new) > 1 || GMT_abs (GMT_y_status_new) > 1);
 		}
 
 		if (!(skip || GMT_is_dnan (in[GMT_Z]))) {	/* Unless outside or z = NaN */
@@ -854,20 +855,21 @@ GMT_LONG get_triangle_crossings (double *x, double *y, double *z, int *ind, doub
 	 */
 	 
 	GMT_LONG i, j, k, k2, i1, nx, n_alloc, *vout, *cind;
-	double xx[3], yy[3], zz[3], zmin, zmax, dz, frac, *xout, *yout, *zout;
+	double xx[3], yy[3], zz[3], zmin, zmax, dz, frac, small = 1.0e-6, *xout, *yout, *zout;
 
 	xx[0] = x[ind[0]];	yy[0] = y[ind[0]];	zz[0] = z[ind[0]];
 	xx[1] = x[ind[1]];	yy[1] = y[ind[1]];	zz[1] = z[ind[1]];
 	xx[2] = x[ind[2]];	yy[2] = y[ind[2]];	zz[2] = z[ind[2]];
 
 	if (GMT_is_dnan (zz[0]) || GMT_is_dnan (zz[1]) || GMT_is_dnan (zz[2])) return (0);	/* Cannot have crossings if NaNs are present */
+	if (zz[0] == zz[1] && zz[1] == zz[2]) return (0);	/* Cannot have crossings if all nodes are equal */
 
 	zmin = MIN (zz[0], MIN (zz[1], zz[2]));	/* Min z vertex */
 	zmax = MAX (zz[0], MAX (zz[1], zz[2]));	/* Max z vertex */
 
 	i = 0;	j = GMT_n_colors - 1;
-	while (GMT_lut[i].z_low <= zmin && i < GMT_n_colors) i++;
-	while (GMT_lut[j].z_high >= zmax && j > 0) j--;
+	while (GMT_lut[i].z_low < zmin && i < GMT_n_colors) i++;
+	while (GMT_lut[j].z_high > zmax && j > 0) j--;
 
 	nx = j - i + 2;	/* Total number of contours */
 
@@ -895,6 +897,7 @@ GMT_LONG get_triangle_crossings (double *x, double *y, double *z, int *ind, doub
 	/* Loop over the contour levels and determine the line segments */
 
 	for (k = k2 = j = 0; k < nx; k++, k2 += 2) {
+		for (i = 0; i < 3; i++) if (zz[i] == zout[k2]) zz[i] += small;	/* Refuse to go through nodes */
 		for (i = 0; i < 3; i++) {	/* Try each side in turn 0-1, 1-2, 2-0 */
 			i1 = (i == 2) ? 0 : i + 1;
 			if ((zout[k2] >= zz[i] && zout[k2] < zz[i1]) || (zout[k2] <= zz[i] && zout[k2] > zz[i1])) {
