@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: psimage.c,v 1.49 2010/01/05 01:15:47 guru Exp $
+ *	$Id: psimage.c,v 1.55 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -30,37 +30,37 @@
 struct PSIMAGE_CTRL {
 	struct GMT_CONTOUR contour;
 	struct C {	/* -C<xpos>/<ypos>[/<justify>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double x, y;
-		char justify[2];
+		char justify[3];
 	} C;
 	struct E {	/* -E<dpi> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double dpi;
 	} E;
 	struct F {	/* -F<pen> */
-		BOOLEAN active;
+		GMT_LONG active;
 		struct GMT_PEN pen;
 	} F;
 	struct G {	/* -G[f|b|t]<rgb> */
-		BOOLEAN active;
+		GMT_LONG active;
 		int f_rgb[3];
 		int b_rgb[3];
 		int t_rgb[3];
 	} G;
 	struct I {	/* -I */
-		BOOLEAN active;
+		GMT_LONG active;
 	} I;
 	struct M {	/* -M */
-		BOOLEAN active;
+		GMT_LONG active;
 	} M;
 	struct N {	/* -N<nx>/<ny> */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG nx, ny;
 	} N;
 	struct W {	/* -W[-]<width>[/<height>] */
-		BOOLEAN active;
-		BOOLEAN interpolate;
+		GMT_LONG active;
+		GMT_LONG interpolate;
 		double width, height;
 	} W;
 };
@@ -69,7 +69,7 @@ int main (int argc, char **argv)
 {
 	GMT_LONG i, j, n, justify, PS_interpolate = 1, PS_transparent = 1;
 
-	BOOLEAN error = FALSE;
+	GMT_LONG error = FALSE;
 
 	double x, y;
 
@@ -83,7 +83,7 @@ int main (int argc, char **argv)
 
 	void *New_psimage_Ctrl (), Free_psimage_Ctrl (struct PSIMAGE_CTRL *C);
 	
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct PSIMAGE_CTRL *)New_psimage_Ctrl ();	/* Allocate and initialize a new control structure */
 
@@ -114,7 +114,7 @@ int main (int argc, char **argv)
 
 				case 'C':
 					Ctrl->C.active = TRUE;
-					n = sscanf (&argv[i][2], "%[^/]/%[^/]/%s", txt_a, txt_b, Ctrl->C.justify);
+					n = sscanf (&argv[i][2], "%[^/]/%[^/]/%2s", txt_a, txt_b, Ctrl->C.justify);
 					if (n < 2 || n > 3) {
 						fprintf (stderr, "%s ERROR: Syntax is -C<xpos>/<ypos>[/<justify>]\n", GMT_program);
 						error++;
@@ -184,7 +184,7 @@ int main (int argc, char **argv)
 					break;
 				case 'N':
 					Ctrl->N.active = TRUE;
-					n = sscanf (&argv[i][2], "%ld/%ld", &Ctrl->N.nx, &Ctrl->N.ny);
+					n = sscanf (&argv[i][2], "%" GMT_LL "d/%" GMT_LL "d", &Ctrl->N.nx, &Ctrl->N.ny);
 					if (n == 1) Ctrl->N.ny = Ctrl->N.nx;
 					if (n < 1) {
 						error++;
