@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: pslegend.c,v 1.118 2010/01/05 01:15:47 guru Exp $
+ *	$Id: pslegend.c,v 1.125 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -35,35 +35,35 @@
 
 struct PSLEGEND_CTRL {
 	struct C {	/* -C<dx>/<dy> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double dx, dy;
 	} C;
 	struct D {	/* -D[x]<x0>/<y0>/w/h/just */
-		BOOLEAN active;
-		BOOLEAN cartesian;
+		GMT_LONG active;
+		GMT_LONG cartesian;
 		double lon, lat, width, height;
 		char justify[3];
 	} D;
 	struct F {	/* -F */
-		BOOLEAN active;
+		GMT_LONG active;
 	} F;
 	struct G {	/* -G<fill> */
-		BOOLEAN active;
+		GMT_LONG active;
 		struct GMT_FILL fill;
 	} G;
 	struct L {	/* -L<spacing> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double spacing;
 	} L;
 	struct S {	/* -C<script> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} S;
 };
 
 int main (int argc, char **argv)
 {
-	BOOLEAN flush_paragraph = FALSE, draw_vertical_line = FALSE, gave_label, gave_mapscale_options;
+	GMT_LONG flush_paragraph = FALSE, draw_vertical_line = FALSE, gave_label, gave_mapscale_options;
 	
 #ifdef WIN32
 	char *del = "del", *escape = "^", quote = ' ';
@@ -77,7 +77,7 @@ int main (int argc, char **argv)
 	char tw[GMT_LONG_TEXT], jj[GMT_LONG_TEXT], line[BUFSIZ], vpen[GMT_LONG_TEXT], script[GMT_LONG_TEXT], tmptxt[GMT_LONG_TEXT];
 	char sarg[GMT_LONG_TEXT], sparg[BUFSIZ], txtcolor[GMT_LONG_TEXT], psxy[GMT_LONG_TEXT], pstext[GMT_LONG_TEXT];
 	char bar_cpt[GMT_LONG_TEXT], bar_gap[GMT_LONG_TEXT], bar_height[GMT_LONG_TEXT], bar_opts[BUFSIZ], mode, just, *opt;
-	char *barg = CNULL, *jarg = CNULL, *f = CNULL, *u = CNULL;
+	char *barg = CNULL, *jarg = CNULL, *rarg = CNULL, *f = CNULL, *u = CNULL;
 	
 	GMT_LONG i, k, n, justify = 0, n_columns = 1, error = 0, column_number = 0, n_files = 0, n_scan, ifont, not_used = 0;
 	
@@ -110,7 +110,7 @@ int main (int argc, char **argv)
 		}
 	}
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct PSLEGEND_CTRL *)New_pslegend_Ctrl ();	/* Allocate and initialize a new control structure */
 
@@ -123,7 +123,6 @@ int main (int argc, char **argv)
 				/* Common parameters */
 
 				case 'J':
-					jarg = argv[i];	/* Keep this for later */
 				case 'K':
 				case 'O':
 				case 'P':
@@ -135,6 +134,8 @@ int main (int argc, char **argv)
 				case 'y':
 				case 'c':
 				case '\0':
+					if (argv[i][1] == 'R') rarg = argv[i];	/* save original -R option */
+					if (argv[i][1] == 'J') jarg = argv[i];	/* save original -J option */
 					error += GMT_parse_common_options (argv[i], &west, &east, &south, &north);
 					break;
 
@@ -373,6 +374,7 @@ int main (int argc, char **argv)
 				}
 				break;
 			case 'B':	/* Color scale Bar */
+				bar_opts[0] = '\0';
 				sscanf (&line[2], "%s %s %s %[^\n]", bar_cpt, bar_gap, bar_height, bar_opts);
 				x_off = GMT_convert_units (bar_gap, GMT_INCH);
 				fprintf (fpo, "psscale -C%s -O -K -D%gi/%gi/%gi/%sh %s\n", bar_cpt, 0.5 * Ctrl->D.width, Ctrl->D.height-y0, Ctrl->D.width - 2 * x_off, bar_height, bar_opts);
@@ -451,7 +453,7 @@ int main (int argc, char **argv)
 				if (n_scan == 6)	/* Gave specific -R -J on M line */
 					fprintf (fpo, "psbasemap %s %s -O -K -L%s\n", txt_e, txt_f, &mapscale[k]);
 				else	/* Use -R -J supplied to pslegend */
-					fprintf (fpo, "psbasemap -R%g/%g/%g/%g %s -O -K -L%s\n", west, east, south, north, jarg, &mapscale[k]);
+					fprintf (fpo, "psbasemap %s %s -O -K -L%s\n", rarg, jarg, &mapscale[k]);
 				/* Reset -R -J by calling a dummy psxy -T */
 				fprintf (fpo, "psxy -R0/%g/0/%g -JX%gi/-%gi -O -K -T\n", Ctrl->D.width, Ctrl->D.height, Ctrl->D.width, Ctrl->D.height);
 				if (gave_label && just == 'b') y0 += d_off;
@@ -612,7 +614,7 @@ int main (int argc, char **argv)
 
 	if (flush_paragraph) fprintf (fpo, "%s -m %s\n%s %s\n", pstext, tmptxt, del, tmptxt);
 	/* Revert to original region (-R), projection and size (-J) and position (-X, -Y) */
-	fprintf (fpo, "psxy -R%g/%g/%g/%g %s -T -X%c%gi -Y%c%gi -O %s", west, east, south, north, jarg, mode, -Ctrl->D.lon+GMT_ps.x_origin, mode, -Ctrl->D.lat+GMT_ps.y_origin, sparg);
+	fprintf (fpo, "psxy %s %s -T -X%c%gi -Y%c%gi -O %s", rarg, jarg, mode, -Ctrl->D.lon+GMT_ps.x_origin, mode, -Ctrl->D.lat+GMT_ps.y_origin, sparg);
 	if (barg) fprintf (fpo, " %s", barg);
 	if (!GMT_ps.last_page) fprintf (fpo, " -K");
 	fprintf (fpo, "\n");
