@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: psmask.c,v 1.84 2010/01/05 01:15:47 guru Exp $
+ *	$Id: psmask.c,v 1.94 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -42,55 +42,53 @@
 
 struct PSMASK_CTRL {
 	struct C {	/* -C */
-		BOOLEAN active;
+		GMT_LONG active;
 	} C;
 	struct D {	/* -D<dumpfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 		GMT_LONG min_pts;
 	} D;
 	struct E {	/* -Eazim/elev */
-		BOOLEAN active;
+		GMT_LONG active;
 		double azimuth, elevation;
 	} E;
 	struct F {	/* -F */
-		BOOLEAN active;
+		GMT_LONG active;
 	} F;
 	struct G {	/* -G<fill> */
-		BOOLEAN active;
+		GMT_LONG active;
 		struct GMT_FILL fill;
 	} G;
 	struct I {	/* -Idx[/dy] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double xinc, yinc;
 	} I;
 	struct N {	/* -N */
-		BOOLEAN active;
+		GMT_LONG active;
 	} N;
 	struct S {	/* -S<radius>[m|c|k|K] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double radius;
 		char unit;
 	} S;
 	struct T {	/* -T */
-		BOOLEAN active;
+		GMT_LONG active;
 	} T;
 };
 
 struct PSMASK_INFO {
-	BOOLEAN first_dump;
+	GMT_LONG first_dump;
 	GMT_LONG p[5], i_off[5], j_off[5], k_off[5], offset;
 	unsigned int bit[32];
 };
 
 int main (int argc, char **argv)
 {
-	GMT_LONG ij, n, nm;
+	GMT_LONG ij, n, nm, n_read, n_alloc;
 	GMT_LONG i, j, n_edges, di, dj, ii, jj, n_expected_fields, *edge;
 	GMT_LONG section, n_fields, distance_flag = 0, n_plus = 0, k;
-	GMT_LONG n_read, n_alloc;
-	
-	BOOLEAN error = FALSE, first = TRUE, node_only;
+	GMT_LONG error = FALSE, first = TRUE, node_only;
 
 	char line[BUFSIZ], *grd, *not_used = NULL;
 
@@ -104,7 +102,7 @@ int main (int argc, char **argv)
 	struct PSMASK_CTRL *Ctrl;
 
 #ifdef DEBUG
-	BOOLEAN debug = FALSE;
+	GMT_LONG debug = FALSE;
 #endif
 	void draw_clip_contours (double *xx, double *yy, GMT_LONG nn, int rgb[], GMT_LONG id, GMT_LONG flag);
 	void dump_clip_contours (struct PSMASK_INFO *info, double *xx, double *yy, GMT_LONG nn, GMT_LONG id, char *file);
@@ -112,7 +110,7 @@ int main (int argc, char **argv)
 	GMT_LONG clip_contours (struct PSMASK_INFO *info, char *grd, struct GRD_HEADER *h, double xinc2, double yinc2, GMT_LONG *edge, GMT_LONG first, double **x, double **y, GMT_LONG *max);
 	void *New_psmask_Ctrl (), Free_psmask_Ctrl (struct PSMASK_CTRL *C);
 	
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct PSMASK_CTRL *)New_psmask_Ctrl ();	/* Allocate and initialize a new control structure */
 
@@ -294,7 +292,11 @@ int main (int argc, char **argv)
 			fprintf (stderr, "%s: GMT SYNTAX ERROR -T option:  Must also specify a tile color with -G\n", GMT_program);
 			error++;
 		}
-		if (Ctrl->I.xinc <= 0.0 || Ctrl->I.yinc <= 0.0) {
+		if (!Ctrl->I.active) {
+			fprintf (stderr, "%s: GMT SYNTAX ERROR:  Must specify -I option\n", GMT_program);
+			error++;
+		}
+		else if (Ctrl->I.xinc <= 0.0 || Ctrl->I.yinc <= 0.0) {
 			fprintf (stderr, "%s: GMT SYNTAX ERROR -I option:  Must specify positive increments\n", GMT_program);
 			error++;
 		}
@@ -311,7 +313,7 @@ int main (int argc, char **argv)
 			fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data cannot have header -H\n", GMT_program);
 			error++;
 		}
-		h.node_offset = Ctrl->F.active;
+		h.node_offset = (int)Ctrl->F.active;
 		h.x_inc = Ctrl->I.xinc;
 		h.y_inc = Ctrl->I.yinc;
 		h.xy_off = 0.5 * h.node_offset;
@@ -349,6 +351,11 @@ int main (int argc, char **argv)
 	if (!project_info.x_off_supplied && GMT_ps.overlay) GMT_ps.x_origin = 0.0;
 	if (!project_info.y_off_supplied && GMT_ps.overlay) GMT_ps.y_origin = 0.0;
 
+	if (Ctrl->C.active)
+		GMT_ps.clip = -1;	/* Signal that this program terminates clipping that initiated prior to this process */
+	else if (!Ctrl->T.active)
+		GMT_ps.clip = +1;	/* Signal that this program initiates clipping that wil outlive this process */
+		
 	GMT_plotinit (argc, argv);
 
 	if (!Ctrl->C.active) {	/* Start new clip_path */
@@ -407,12 +414,16 @@ int main (int argc, char **argv)
 			}
 			if ((GMT_io.status & GMT_IO_EOF)) continue;	/* At EOF */
 
-			if (GMT_io.status & GMT_IO_MISMATCH) {
-				fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields, n_expected_fields, n_read);
-				exit (EXIT_FAILURE);
-			}
 			n_read++;
 
+			if (GMT_io.status & GMT_IO_MISMATCH) {
+				fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld (skipped)\n", GMT_program, n_fields, n_expected_fields, n_read);
+				continue;
+			}
+
+			if (GMT_y_is_outside (in[GMT_Y], h.y_min, h.y_max)) continue;		/* Outside y-range */
+			if (GMT_x_is_outside (&in[GMT_X], h.x_min, h.x_max)) continue;	/* Outside x-range (or longitude) */
+
 			/* Determine the node closest to the data point */
 
 			i = GMT_x_to_i (in[GMT_X], h.x_min, h.x_inc, h.xy_off, h.nx);
@@ -640,7 +651,7 @@ GMT_LONG clip_contours (struct PSMASK_INFO *info, char *grd, struct GRD_HEADER *
 	static GMT_LONG i0, j0, side;
 	GMT_LONG ij;
 	GMT_LONG i, j, n = 0, n_edges, edge_word, edge_bit;
-	BOOLEAN go_on = TRUE;
+	GMT_LONG go_on = TRUE;
 	GMT_LONG trace_clip_contours (struct PSMASK_INFO *info, char *grd, GMT_LONG *edge, struct GRD_HEADER *h, double xinc2, double yinc2, double **xx, double **yy, GMT_LONG i, GMT_LONG j, GMT_LONG kk, GMT_LONG *max);
 	 
 	 
