@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: psscale.c,v 1.100 2009/09/09 23:27:03 guru Exp $
+ *	$Id: psscale.c,v 1.112 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -43,54 +43,54 @@
 
 struct PSSCALE_CTRL {
 	struct A {	/* -A */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG mode;
 	} A;
 	struct C {	/* -C<cptfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} C;
 	struct D {	/* -D<xpos/ypos/length/width[h]> */
-		BOOLEAN active;
-		BOOLEAN horizontal;
+		GMT_LONG active;
+		GMT_LONG horizontal;
 		double x, y, width, length;
 	} D;
 	struct E {	/* -E[b|f][<length>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG mode;
 		double length;
 	} E;
 	struct I {	/* -I[<intens>|<min_i>/<max_i>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double min, max;
 	} I;
 	struct M {	/* -M */
-		BOOLEAN active;
+		GMT_LONG active;
 	} M;
 	struct N {	/* -N<dpi> */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG dpi;
 	} N;
 	struct L {	/* -L[i][<gap>] */
-		BOOLEAN active;
-		BOOLEAN interval;
+		GMT_LONG active;
+		GMT_LONG interval;
 		double spacing;
 	} L;
 	struct Q {	/* -Q */
-		BOOLEAN active;
+		GMT_LONG active;
 	} Q;
 	struct S {	/* -S */
-		BOOLEAN active;
+		GMT_LONG active;
 	} S;
 	struct Z {	/* -Z<zfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} Z;
 };
 
 int main(int argc, char **argv)
 {
-	BOOLEAN error = FALSE, save_unix_time, must_shift_back = FALSE, B_set = FALSE;
+	GMT_LONG error = FALSE, save_unix_time, must_shift_back = FALSE, B_set = FALSE;
 
 	char flag, line[BUFSIZ], txt_a[GMT_LONG_TEXT], txt_b[GMT_LONG_TEXT];
 	char txt_c[GMT_LONG_TEXT], txt_d[GMT_LONG_TEXT], text[GMT_LONG_TEXT];
@@ -104,14 +104,14 @@ int main(int argc, char **argv)
 
 	struct PSSCALE_CTRL *Ctrl;
 
-	void GMT_draw_colorbar (double length, double width, double *z_width, GMT_LONG bit_dpi, GMT_LONG flip, BOOLEAN B_set, BOOLEAN equi, 
-	   BOOLEAN horizontal, BOOLEAN logscl, BOOLEAN intens, double *max_intens, BOOLEAN skip_lines, GMT_LONG extend, double e_length, double gap, BOOLEAN interval_annot, BOOLEAN monochrome);
+	void GMT_draw_colorbar (double length, double width, double *z_width, GMT_LONG bit_dpi, GMT_LONG flip, GMT_LONG B_set, GMT_LONG equi, 
+	   GMT_LONG horizontal, GMT_LONG logscl, GMT_LONG intens, double *max_intens, GMT_LONG skip_lines, GMT_LONG extend, double e_length, double gap, GMT_LONG interval_annot, GMT_LONG monochrome);
 
-	void *New_Psscale_Ctrl (), Free_Psscale_Ctrl (struct PSSCALE_CTRL *C);
+	void *New_psscale_Ctrl (), Free_psscale_Ctrl (struct PSSCALE_CTRL *C);
 	
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
-	Ctrl = (struct PSSCALE_CTRL *)New_Psscale_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct PSSCALE_CTRL *)New_psscale_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	/* Check and interpret the command line arguments */
 
@@ -160,13 +160,14 @@ int main(int argc, char **argv)
 					flag = argv[i][n];
 					if (flag == 'h' || flag == 'H') {
 						Ctrl->D.horizontal = TRUE;
-						argv[i][n] = 0;
+						argv[i][n] = 0;	/* Temporarily remove the flag */
 					}
 					sscanf (&argv[i][2], "%[^/]/%[^/]/%[^/]/%s", txt_a, txt_b, txt_c, txt_d);
 					Ctrl->D.x   = GMT_convert_units (txt_a, GMT_INCH);
 					Ctrl->D.y   = GMT_convert_units (txt_b, GMT_INCH);
 					Ctrl->D.length = GMT_convert_units (txt_c, GMT_INCH);
 					Ctrl->D.width  = GMT_convert_units (txt_d, GMT_INCH);
+					if (Ctrl->D.horizontal) argv[i][n] = flag;	/* Restore the flag */
 					break;
 				case 'E':
 					Ctrl->E.active = TRUE;
@@ -229,6 +230,8 @@ int main(int argc, char **argv)
 					break;
 			}
 		}
+		else
+			fprintf (stderr, "%s: Warning: Ignoring filename %s\n", GMT_program, argv[i]);
 	}
 
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
@@ -355,7 +358,8 @@ int main(int argc, char **argv)
 				fprintf (stderr, "%s: -Z file %s has more slices than -C file %s!\n", GMT_program, Ctrl->Z.file, Ctrl->C.file);
 				exit (EXIT_FAILURE);
 			}
-			if (line[0] == '#' || line[0] == '\n') continue;	/* Skip comments and blank lines */
+			GMT_chop (line);					/* Rid the world of CR/LF */
+			if (line[0] == '#' || line[0] == '\0') continue;	/* Skip comments and blank lines */
 			n = sscanf (line, "%lf", &z_width[i++]);
 			if (n != 1) {
 				fprintf (stderr, "%s: Error reading file %s near line %ld\n", GMT_program, Ctrl->Z.file, i);
@@ -445,19 +449,19 @@ int main(int argc, char **argv)
 
 	GMT_free ((void *)z_width);
 
-	Free_Psscale_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_psscale_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
 
-void GMT_draw_colorbar (double length, double width, double *z_width, GMT_LONG bit_dpi, GMT_LONG flip, BOOLEAN B_set, BOOLEAN equi, BOOLEAN horizontal, BOOLEAN logscl, BOOLEAN intens, double *max_intens, BOOLEAN skip_lines, GMT_LONG extend, double e_length, double gap, BOOLEAN interval_annot, BOOLEAN monochrome)
+void GMT_draw_colorbar (double length, double width, double *z_width, GMT_LONG bit_dpi, GMT_LONG flip, GMT_LONG B_set, GMT_LONG equi, GMT_LONG horizontal, GMT_LONG logscl, GMT_LONG intens, double *max_intens, GMT_LONG skip_lines, GMT_LONG extend, double e_length, double gap, GMT_LONG interval_annot, GMT_LONG monochrome)
 {
 	GMT_LONG i, ii, id, j, nb, ndec = -1, dec, p_val, depth;
 	GMT_LONG nx = 0, ny = 0, nm, barmem, k, justify, l_justify, this_just, use_labels = 0, Label_justify;
 	int rgb[3], rrggbb[3];
-	BOOLEAN reverse, all = TRUE, use_image, center = FALSE, const_width = TRUE, do_annot;
+	GMT_LONG reverse, all = TRUE, use_image, center = FALSE, const_width = TRUE, do_annot;
 	char format[GMT_LONG_TEXT], text[GMT_LONG_TEXT], test[GMT_LONG_TEXT], unit[GMT_LONG_TEXT], label[GMT_LONG_TEXT];
 	unsigned char *bar = 0, *tmp = 0;
 	double off, annot_off, label_off, len, len2, size, x0, x1, dx, xx, dir, y_base, y_annot, y_label;
@@ -612,7 +616,7 @@ void GMT_draw_colorbar (double length, double width, double *z_width, GMT_LONG b
 				x1 += z_width[ii];
 				if ((f = GMT_lut[ii].fill)) {	/* Using pattern fills */
 					xp[0] = xp[3] = x0 + gap;	xp[1] = xp[2] = x1 - gap;
-					GMT_fill (xp, yp, (GMT_LONG)4, f, center);	/* Contours drawn separately below if desired */
+					GMT_fill (xp, yp, (GMT_LONG)4, f, center);	/* Outline drawn separately below if desired */
 				}
 				else if (intens) {
 					nb = (GMT_gray || monochrome) ? 1 : 3;
@@ -646,26 +650,24 @@ void GMT_draw_colorbar (double length, double width, double *z_width, GMT_LONG b
 			yp[0] = width;	yp[1] = 0.0;	yp[2] = 0.5 * width;
 			id = (reverse) ? GMT_FGD : GMT_BGD;
 			if ((f = GMT_bfn[id].fill))
-				GMT_fill (xp, yp, (GMT_LONG)3, f, FALSE);	/* Contours drawn separately below if desired */
+				GMT_fill (xp, yp, (GMT_LONG)3, f, TRUE);
 			else {
 				memcpy ((void *)rgb, (void *)GMT_bfn[id].rgb, (size_t)(3 * sizeof (int)));
 				if (monochrome) rgb[0] = rgb[1] = rgb[2] = GMT_YIQ (rgb);
-				ps_polygon (xp, yp, (GMT_LONG)3, rgb, FALSE);
+				ps_polygon (xp, yp, (GMT_LONG)3, rgb, TRUE);
 			}
-			ps_polygon (xp, yp, (GMT_LONG)3, GMT_no_rgb, TRUE);
 		}
 		if (extend & (2 - reverse)) {	/* Add color triangle on right side */
 			xp[0] = xp[1] = xright + gap;	xp[2] = xp[0] + e_length;
 			yp[0] = width;	yp[1] = 0.0;	yp[2] = 0.5 * width;
 			id = (reverse) ? GMT_BGD : GMT_FGD;
 			if ((f = GMT_bfn[id].fill))
-				GMT_fill (xp, yp, (GMT_LONG)3, f, FALSE);	/* Contours drawn separately below if desired */
+				GMT_fill (xp, yp, (GMT_LONG)3, f, TRUE);
 			else {
 				memcpy ((void *)rgb, (void *)GMT_bfn[id].rgb, (size_t)(3 * sizeof (int)));
 				if (monochrome) rgb[0] = rgb[1] = rgb[2] = GMT_YIQ (rgb);
-				ps_polygon (xp, yp, (GMT_LONG)3, rgb, FALSE);
+				ps_polygon (xp, yp, (GMT_LONG)3, rgb, TRUE);
 			}
-			ps_polygon (xp, yp, (GMT_LONG)3, GMT_no_rgb, TRUE);
 		}
 
 		if (gap == 0.0) {
@@ -677,8 +679,10 @@ void GMT_draw_colorbar (double length, double width, double *z_width, GMT_LONG b
 
 		if (B_set) {	/* Used -B */
 			GMT_xy_axis (xleft, y_base, length, start_val, stop_val, &frame_info.axis[0], !(flip & 1), frame_info.side[0]-1);
-			dx =  GMT_get_map_interval (0, GMT_GRID_UPPER); 
-			if (dx > 0.0) GMT_linearx_grid (GMT_lut[0].z_low, GMT_lut[GMT_n_colors-1].z_high, 0.0, width, dx);
+			if ((dx = GMT_get_map_interval (0, GMT_GRID_UPPER)) > 0.0) {
+				GMT_setpen (&gmtdefs.grid_pen[0]);
+				GMT_linearx_grid (GMT_lut[0].z_low, GMT_lut[GMT_n_colors-1].z_high, 0.0, width, dx);
+			}
 		}
 		else {
 			/* First draw gridlines, unless skip_lines is TRUE */
@@ -772,8 +776,12 @@ void GMT_draw_colorbar (double length, double width, double *z_width, GMT_LONG b
 				ii = (reverse) ? GMT_n_colors - i - 1 : i;
 				x1 += z_width[ii];
 				if ((f = GMT_lut[ii].fill)) {	/* Using pattern fills */
-					xp[0] = xp[3] = x0 + gap;	xp[1] = xp[2] = x1 - gap;
-					GMT_fill (xp, yp, (GMT_LONG)4, f, center);	/* Contours drawn separately below if desired */
+					ps_transrotate (x0 + gap, 0.0, -90.0);
+
+					xp[0] = xp[3] = -width;	xp[1] = xp[2] = 0.0;
+					yp[0] = yp[1] = 0.0;	yp[2] = yp[3] = x1 - x0 - 2.0 * gap;
+					GMT_fill (xp, yp, (GMT_LONG)4, f, center);	/* Outline drawn separately below if desired */
+					ps_rotatetrans (-(x0 + gap), 0.0, 90.0);
 				}
 				else if (intens) {
 					nb = (GMT_gray || monochrome) ? 1 : 3;
@@ -823,26 +831,24 @@ void GMT_draw_colorbar (double length, double width, double *z_width, GMT_LONG b
 			yp[0] = width;	yp[1] = 0.0;	yp[2] = 0.5 * width;
 			id = (reverse) ? GMT_FGD : GMT_BGD;
 			if ((f = GMT_bfn[id].fill))
-				GMT_fill (xp, yp, (GMT_LONG)3, f, FALSE);	/* Contours drawn separately below if desired */
+				GMT_fill (xp, yp, (GMT_LONG)3, f, TRUE);
 			else {
 				memcpy ((void *)rgb, (void *)GMT_bfn[id].rgb, (size_t)(3 * sizeof (int)));
 				if (monochrome) rgb[0] = rgb[1] = rgb[2] = GMT_YIQ (rgb);
-				ps_polygon (xp, yp, (GMT_LONG)3, rgb, FALSE);
+				ps_polygon (xp, yp, (GMT_LONG)3, rgb, TRUE);
 			}
-			ps_polygon (xp, yp, (GMT_LONG)3, GMT_no_rgb, TRUE);
 		}
 		if (extend & (2 - reverse)) {	/* Add color triangle at top */
 			xp[0] = xp[1] = xright + gap;	xp[2] = xp[0] + e_length;
 			yp[0] = width;	yp[1] = 0.0;	yp[2] = 0.5 * width;
 			id = (reverse) ? GMT_BGD : GMT_FGD;
 			if ((f = GMT_bfn[id].fill))
-				GMT_fill (xp, yp, (GMT_LONG)3, f, FALSE);	/* Contours drawn separately below if desired */
+				GMT_fill (xp, yp, (GMT_LONG)3, f, TRUE);
 			else {
 				memcpy ((void *)rgb, (void *)GMT_bfn[id].rgb, (size_t)(3 * sizeof (int)));
 				if (monochrome) rgb[0] = rgb[1] = rgb[2] = GMT_YIQ (rgb);
-				ps_polygon (xp, yp, (GMT_LONG)3, rgb, FALSE);
+				ps_polygon (xp, yp, (GMT_LONG)3, rgb, TRUE);
 			}
-			ps_polygon (xp, yp, (GMT_LONG)3, GMT_no_rgb, TRUE);
 		}
 		if (gap == 0.0) {
 			ps_segment (xleft, 0.0, xleft + length, 0.0);
@@ -852,13 +858,15 @@ void GMT_draw_colorbar (double length, double width, double *z_width, GMT_LONG b
 		}
 		if (B_set) {	/* Used -B. Must kludge by copying x-axis and scaling to y since we must use GMT_xy_axis to draw a rotated x-axis... */
 			PFL tmp;
-			dx = GMT_get_map_interval (0, GMT_GRID_UPPER); 
-			if (dx > 0.0) GMT_linearx_grid (GMT_lut[0].z_low, GMT_lut[GMT_n_colors-1].z_high, 0.0, width, dx);
+			if ((dx = GMT_get_map_interval (0, GMT_GRID_UPPER)) > 0.0) {
+				GMT_setpen (&gmtdefs.grid_pen[0]);
+				GMT_linearx_grid (GMT_lut[0].z_low, GMT_lut[GMT_n_colors-1].z_high, 0.0, width, dx);
+			}
 			ps_transrotate (0.0, 0.0, -90.0);
 			memcpy ((void *)&frame_info.axis[1], (void *)&frame_info.axis[0], sizeof (struct GMT_PLOT_AXIS));
 			d_swap (project_info.x_scale, project_info.y_scale);
 			d_swap (project_info.x0, project_info.y0);
-			i_swap (project_info.xyz_projection[0], project_info.xyz_projection[1]);
+			l_swap (project_info.xyz_projection[0], project_info.xyz_projection[1]);
 			tmp = GMT_x_forward; GMT_y_forward = GMT_x_forward; GMT_x_forward = tmp;
 			for (i = 0; i < 5; i++) frame_info.axis[1].item[i].parent = 1;
 			GMT_xy_axis (-y_base, 0.0, length, start_val, stop_val, &frame_info.axis[1], (flip & 1), frame_info.side[0]-1);
@@ -999,10 +1007,10 @@ void fix_format (char *unit, char *format)
 	}
 }
 
-void *New_Psscale_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_psscale_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct PSSCALE_CTRL *C;
 	
-	C = (struct PSSCALE_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSSCALE_CTRL), "New_Psscale_Ctrl");
+	C = (struct PSSCALE_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSSCALE_CTRL), "New_psscale_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->N.dpi = 300;
@@ -1012,7 +1020,7 @@ void *New_Psscale_Ctrl () {	/* Allocate and initialize a new control structure *
 	return ((void *)C);
 }
 
-void Free_Psscale_Ctrl (struct PSSCALE_CTRL *C) {	/* Deallocate control structure */
+void Free_psscale_Ctrl (struct PSSCALE_CTRL *C) {	/* Deallocate control structure */
 	if (C->C.file) free ((void *)C->C.file);
 	if (C->Z.file) free ((void *)C->Z.file);
 	GMT_free ((void *)C);	
