@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: psxyz.c,v 1.169 2010/01/13 02:26:09 guru Exp $
+ *	$Id: psxyz.c,v 1.181 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -36,49 +36,49 @@
 
 struct PSXYZ_CTRL {
 	struct A {	/* -A[step] {NOT IMPLEMENTED YET} */
-		BOOLEAN active;
+		GMT_LONG active;
 		double step;
 	} A;
 	struct C {	/* -C<cpt> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} C;
 	struct D {	/* -D<dx>/<dy>[/<dz>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double dx, dy, dz;
 	} D;
 	struct E {	/* -E<azimuth/elevation> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double azimuth, elevation;
 	} E;
 	struct G {	/* -G<fill> */
-		BOOLEAN active;
+		GMT_LONG active;
 		struct GMT_FILL fill;
 	} G;
 	struct I {	/* -I<intensity> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double value;
 	} I;
 	struct L {	/* -L */
-		BOOLEAN active;
+		GMT_LONG active;
 	} L;
 	struct N {	/* -N */
-		BOOLEAN active;
+		GMT_LONG active;
 	} N;
 	struct Q {	/* -Q */
-		BOOLEAN active;
+		GMT_LONG active;
 	} Q;
 	struct S {	/* -S */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *arg;
 	} S;
 	struct W {	/* -W<pen> */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG mode;	/* 0 = normal, 1 = -C applies to pen color only, 2 = -C applies to symbol fill & pen color */
 		struct GMT_PEN pen;
 	} W;
 	struct Z {	/* -Z<z_level> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double level;
 	} Z;
 };
@@ -91,7 +91,7 @@ struct PSXYZ_DATA1 {
 	double x, y, z, value, dist;
 	struct GMT_FILL f;
 	struct GMT_PEN p;
-	BOOLEAN outline;
+	GMT_LONG outline;
 };
 
 struct PSXYZ_DATA2 {
@@ -100,13 +100,13 @@ struct PSXYZ_DATA2 {
 
 int main (int argc, char **argv)
 {
-	BOOLEAN	error = FALSE, nofile = TRUE, polygon = FALSE, done, penset_OK = TRUE;
-	BOOLEAN	get_rgb = FALSE, read_symbol, clip_set = FALSE, fill_active, bar_clip;
-	BOOLEAN default_outline = FALSE, outline_active;
+	GMT_LONG error = FALSE, nofile = TRUE, polygon = FALSE, done, penset_OK = TRUE;
+	GMT_LONG get_rgb = FALSE, read_symbol, clip_set = FALSE, fill_active, bar_clip;
+	GMT_LONG default_outline = FALSE, outline_active, save_u = FALSE;
 
 	char line[BUFSIZ], txt_a[GMT_LONG_TEXT], txt_b[GMT_LONG_TEXT], txt_c[GMT_LONG_TEXT], *not_used = NULL;
 
-	GMT_LONG i, n, n_alloc = 0, n_total_read = 0, j, n_files = 0;
+	GMT_LONG i, n, n_alloc = 0, n_total_read = 0, j, n_files = 0, pos2x, pos2y;
 	GMT_LONG fno, n_cols_start = 3, n_args, n_fields, this_outline;
 	GMT_LONG three, four, five, n_required = 3, n_expected = 0, change;
 	
@@ -132,7 +132,7 @@ int main (int argc, char **argv)
 	void sort_on_distance (struct PSXYZ_DATA1 *data, GMT_LONG n);
 	void *New_psxyz_Ctrl (), Free_psxyz_Ctrl (struct PSXYZ_CTRL *C);
 	
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct PSXYZ_CTRL *)New_psxyz_Ctrl ();	/* Allocate and initialize a new control structure */
 
@@ -184,7 +184,7 @@ int main (int argc, char **argv)
 				case 'm':
 				case ':':
 				case '\0':
-					error += GMT_parse_common_options (argv[i], &west, &east, &south, &north);
+					error += (GMT_LONG)GMT_parse_common_options (argv[i], &west, &east, &south, &north);
 					break;
 		
 				/* Supplemental parameters */
@@ -207,7 +207,7 @@ int main (int argc, char **argv)
 					break;
 				case 'E':
 					Ctrl->E.active = TRUE;
-					error += GMT_get_proj3D (&argv[i][2], &Ctrl->E.azimuth, &Ctrl->E.elevation);
+					error += (GMT_LONG)GMT_get_proj3D (&argv[i][2], &Ctrl->E.azimuth, &Ctrl->E.elevation);
 					break;
 				case 'G':		/* Set color for symbol or polygon */
 					Ctrl->G.active = TRUE;
@@ -411,8 +411,12 @@ int main (int argc, char **argv)
 	three = (get_rgb) ? 4 : 3;
 	four = (get_rgb) ? 5 : 4;
 	five = (get_rgb) ? 6 : 5;
+	pos2x = three + gmtdefs.xy_toggle[GMT_IN];	/* Column with a 2nd longitude (for VECTORS with two sets of coordinates) */
+	pos2y = four - gmtdefs.xy_toggle[GMT_IN];	/* Column with a 2nd latitude (for VECTORS with two sets of coordinates) */
 	n_required = n_cols_start + S.n_required;
 
+	for (j = n_cols_start; j < 10; j++) GMT_io.in_col_type[j] = GMT_IS_DIMENSION;		/* Since these may have units appended */
+	for (j = 0; j < S.n_nondim; j++) GMT_io.in_col_type[S.nondim_col[j]+get_rgb] = GMT_IS_FLOAT;	/* Since these are angles, not dimensions */
 	n_expected = (GMT_io.binary[GMT_IN]) ? GMT_io.ncol[GMT_IN] : n_required;
 	if (GMT_io.binary[GMT_IN] && GMT_io.ncol[GMT_IN] == 0) GMT_io.ncol[GMT_IN]=  n_required;
 	if (n_expected < n_required) {
@@ -439,6 +443,11 @@ int main (int argc, char **argv)
 
 	GMT_err_fail (GMT_map_setup (west, east, south, north), "");
 
+	if (S.u_set) {	/* When -Sc<unit> is given we temporarily reset the system unit to these units so conversions will work */
+		save_u = gmtdefs.measure_unit;
+		gmtdefs.measure_unit = S.u;
+	}
+
 	lux[0] = fabs (z_project.sin_az * z_project.cos_el);
 	lux[1] = fabs (z_project.cos_az * z_project.cos_el);
 	lux[2] = fabs (z_project.sin_el);
@@ -478,11 +487,11 @@ int main (int argc, char **argv)
 	if (S.convert_angles && GMT_IS_MAPPING) S.convert_angles = 2;
 	if ((S.symbol == GMT_SYMBOL_VECTOR || S.symbol == GMT_SYMBOL_VECTOR) && S.v_just == 3) {
 		/* Reading 2nd coordinate so must set column types */
-		GMT_io.in_col_type[three] = GMT_io.in_col_type[GMT_X];
-		GMT_io.in_col_type[four] = GMT_io.in_col_type[GMT_Y];
+		GMT_io.in_col_type[pos2x] = GMT_io.in_col_type[GMT_X];
+		GMT_io.in_col_type[pos2y] = GMT_io.in_col_type[GMT_Y];
 	}
-	fill_active = Ctrl->G.active;	/* Make copies because we will change the values */
-	outline_active =  Ctrl->W.active;
+	fill_active = (GMT_LONG)Ctrl->G.active;	/* Make copies because we will change the values */
+	outline_active =  (GMT_LONG)Ctrl->W.active;
 	if (S.symbol > 0 && !outline_active && !fill_active && !get_rgb) outline_active = TRUE;		/* If no fill nor outline for symbols then turn outline on */
 	bar_clip = ((S.symbol == GMT_SYMBOL_BARX || S.symbol == GMT_SYMBOL_BARY) && !Ctrl->N.active) ? TRUE : FALSE;
 			/* Bars get clipped instead of skipped */
@@ -524,7 +533,7 @@ int main (int argc, char **argv)
 		if (S.symbol > 0) {	/* symbol part (not counting GMT_SYMBOL_FRONT and GMT_SYMBOL_QUOTED_LINE) */
 
 			GMT_world_map = (S.symbol == GMT_SYMBOL_ELLIPSE && S.convert_angles) ? FALSE : TRUE;
-			if (read_symbol) n_expected = BUFSIZ;
+			if (read_symbol) n_expected = GMT_MAX_COLUMNS;
 
 			n = 0;
 			while ((n_fields = GMT_input (fp, &n_expected, &in)) >= 0 && !GMT_REC_IS_EOF) {
@@ -539,16 +548,16 @@ int main (int argc, char **argv)
 					}
 					if (change & 4) GMT_setpen (&current_pen);
 
-					if (read_symbol) n_expected = BUFSIZ;
+					if (read_symbol) n_expected = GMT_MAX_COLUMNS;
 					n_fields = GMT_input (fp, &n_expected, &in);
 				}
 				if (GMT_REC_IS_EOF) continue;		/* At EOF */
-	
-				if (GMT_REC_IS_ERROR && !read_symbol) {
-					fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields, n_expected, n_total_read);
-					exit (EXIT_FAILURE);
-				}
+
 				n_total_read++;
+				if (GMT_REC_IS_ERROR && !read_symbol) {
+					fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld (skipped)\n", GMT_program, n_fields, n_expected, n_total_read);
+					continue;
+				}
 
 				if (read_symbol) {
 					i = strlen (GMT_io.current_record) - 1;
@@ -557,13 +566,14 @@ int main (int argc, char **argv)
 					GMT_parse_symbol_option (&GMT_io.current_record[i+1], &S, 1, FALSE);
 					n_required = n_cols_start + S.n_required;
 				}
-			/*	else {
-					GMT_parse_symbol_option (Ctrl->S.arg, &S, 1, FALSE);
-					n_required = n_cols_start + S.n_required;
-				} */
+
+				/* If read_symbol is TRUE we must unto the dimension scaling for items that should have no scaling, e.g., angles */
+				
+				if (read_symbol) for (j = 0; j < S.n_nondim; j++) in[S.nondim_col[j]+get_rgb] *= GMT_u2u[GMT_INCH][S.u];	/* Undo scales since these are angles, not dimensions */
+
 				if (S.read_size) {
-					S.size_x = in[three] * GMT_u2u[S.u][GMT_INCH];
-					S.size_y = (S.symbol == GMT_SYMBOL_COLUMN) ? in[four] * GMT_u2u[S.u][GMT_INCH] : S.size_x;
+					S.size_x = in[three];
+					S.size_y = (S.symbol == GMT_SYMBOL_COLUMN) ? in[four] : S.size_x;
 				}
 
 				if (n == n_alloc) n_alloc = GMT_alloc_memory ((void **)&data1, n, n_alloc, sizeof (struct PSXYZ_DATA1), GMT_program);
@@ -573,7 +583,7 @@ int main (int argc, char **argv)
 				data1[n].string = NULL;
 				if (S.read_vector) {
 					data1[n].x_size = (float)in[three];	/* direction */
-					data1[n].y_size = (float)(in[four] * GMT_u2u[S.u][GMT_INCH]);	/* length */
+					data1[n].y_size = (float)in[four];	/* length */
 					data1[n].z_size = (float)S.v_shrink;	/* Normalization shrink (if given) */
 					data1[n].flag = S.convert_angles;	/* Azim vs Dir. */
 					if (data1[n].y_size < S.v_norm) data1[n].flag |= 8;	/* Flag to shrink vector attributes */
@@ -588,10 +598,6 @@ int main (int argc, char **argv)
 						data1[n].z_size *= (float)project_info.x_scale;
 						data1[n].x_size = (float)(90.0 - data1[n].x_size);	/* Cartesian azimuth */
 					}
-					else if (S.convert_angles == 0){	/* Got axes in current plot units, change to inches */
-						data1[n].y_size *= (float)GMT_u2u[S.u][GMT_INCH];
-						data1[n].z_size *= (float)GMT_u2u[S.u][GMT_INCH];
-					}
 				}
 				else if (S.symbol == GMT_SYMBOL_ROTATERECT) {
 					data1[n].x_size = (float)in[three];	/* direction */
@@ -603,16 +609,12 @@ int main (int argc, char **argv)
 						data1[n].z_size *= (float)project_info.x_scale;
 						data1[n].x_size = (float)(90.0 - data1[n].x_size);	/* Cartesian azimuth */
 					}
-					else if (S.convert_angles == 0){	/* Got axes in current plot units, change to inches */
-						data1[n].y_size *= (float)GMT_u2u[S.u][GMT_INCH];
-						data1[n].z_size *= (float)GMT_u2u[S.u][GMT_INCH];
-					}
 				}
 				else if (S.symbol == GMT_SYMBOL_PIE || S.symbol == GMT_SYMBOL_MANGLE) {
 					data1[n].x_size = (float)S.size_x;
-					if (S.convert_angles == 1) {	/* Got azimuths instead */
-						data1[n].y_size = (float)(90.0 - in[three+S.read_size]);	/* Start direction in degrees */
-						data1[n].z_size = (float)(90.0 - in[four+S.read_size]);		/* Stop direction in degrees */
+					if (S.convert_angles == 1) {	/* Got Cartesian azimuths instead */
+						data1[n].z_size = (float)(90.0 - in[three+S.read_size]);	/* Start direction in degrees */
+						data1[n].y_size = (float)(90.0 - in[four+S.read_size]);		/* Stop direction in degrees */
 					}
 					else {
 						data1[n].y_size = (float)in[three+S.read_size];			/* Start direction in degrees */
@@ -620,8 +622,8 @@ int main (int argc, char **argv)
 					}
 				}
 				else if (S.symbol == GMT_SYMBOL_RECT) {
-					data1[n].x_size = (float)(in[three+S.read_size] * GMT_u2u[S.u][GMT_INCH]);	/* x-dim */
-					data1[n].y_size = (float)(in[four+S.read_size] * GMT_u2u[S.u][GMT_INCH]);	/* y-dim */
+					data1[n].x_size = (float)in[three+S.read_size];	/* x-dim */
+					data1[n].y_size = (float)in[four+S.read_size];	/* y-dim */
 				}
 				else {
 					data1[n].x_size = (float)S.size_x;
@@ -662,7 +664,7 @@ int main (int argc, char **argv)
 				else if (!Ctrl->N.active) {
 					if (in[GMT_Z] < project_info.z_bottom || in[GMT_Z] > project_info.z_top) continue;
 					GMT_map_outside (in[GMT_X], in[GMT_Y]);
-					if ( abs (GMT_x_status_new) > 1 || abs (GMT_y_status_new) > 1) continue;
+					if (GMT_abs (GMT_x_status_new) > 1 || GMT_abs (GMT_y_status_new) > 1) continue;
 				}
 
 				GMT_project3D (in[GMT_X], in[GMT_Y], in[GMT_Z], &data1[n].x, &data1[n].y, &data1[n].z);
@@ -703,7 +705,7 @@ int main (int argc, char **argv)
 				data1[n].p = current_pen;
 				data1[n].outline = outline_active;
 				n++;
-				if (read_symbol) n_expected = BUFSIZ;
+				if (read_symbol) n_expected = GMT_MAX_COLUMNS;
 			}
 			n_alloc = GMT_alloc_memory ((void **)&data1, 0, n, sizeof (struct PSXYZ_DATA1), GMT_program);
 	
@@ -858,7 +860,7 @@ int main (int argc, char **argv)
 							data1[i].x_size = (float)(90.0 - data1[i].x_size);
 						}
 						if (S.v_just == 3) {
-							GMT_geo_to_xy (in[three], in[four], &x2, &y2);
+							GMT_geo_to_xy (in[pos2x], in[pos2y], &x2, &y2);
 							if (GMT_is_dnan (x2) || GMT_is_dnan (y2)) {
 								fprintf (stderr, "%s: Warning: Vector head coordinates contain NaNs near line %ld. Skipped\n", GMT_program, n_total_read);
 								continue;
@@ -875,7 +877,7 @@ int main (int argc, char **argv)
 							}
 						}
 						this_outline = (S.v_double_heads) ? data1[i].outline + 8 : data1[i].outline;
-						GMT_vector (data1[i].x, data1[i].y, x2, y2, data1[i].z, S.v_width, S.h_length, S.h_width, gmtdefs.vector_shape, &data1[i].f, this_outline);
+						GMT_vector (data1[i].x, data1[i].y, x2, y2, data1[i].z, S.v_width, S.h_length, S.h_width, gmtdefs.vector_shape, &data1[i].f, (GMT_LONG)this_outline);
 						break;
 					case GMT_SYMBOL_VECTOR2:
 						if (data1[i].flag & 2) {
@@ -886,7 +888,7 @@ int main (int argc, char **argv)
 							data1[i].x_size = (float)(90.0 - data1[i].x_size);
 						}
 						if (S.v_just == 3) {
-							GMT_geo_to_xy (in[three], in[four], &x2, &y2);
+							GMT_geo_to_xy (in[pos2x], in[pos2y], &x2, &y2);
 							if (GMT_is_dnan (x2) || GMT_is_dnan (y2)) {
 								fprintf (stderr, "%s: Warning: Vector head coordinates contain NaNs near line %ld. Skipped\n", GMT_program, n_total_read);
 								continue;
@@ -907,19 +909,20 @@ int main (int argc, char **argv)
 							h_l = S.h_length * data1[i].y_size * data1[i].z_size;
 							h_w = S.h_width * data1[i].y_size * data1[i].z_size;
 							this_outline = (S.v_double_heads) ? data1[i].outline + 8 : data1[i].outline;
-							GMT_vector (data1[i].x, data1[i].y, x2, y2, data1[i].z, v_w, h_l, h_w, gmtdefs.vector_shape, &data1[i].f, this_outline);
+							GMT_vector (data1[i].x, data1[i].y, x2, y2, data1[i].z, v_w, h_l, h_w, gmtdefs.vector_shape, &data1[i].f, (GMT_LONG)this_outline);
 						}
 						else {	/* Leave as specified */
 							this_outline = (S.v_double_heads) ? data1[i].outline + 8 : data1[i].outline;
-							GMT_vector (data1[i].x, data1[i].y, x2, y2, data1[i].z, S.v_width, S.h_length, S.h_width, gmtdefs.vector_shape, &data1[i].f, this_outline);
+							GMT_vector (data1[i].x, data1[i].y, x2, y2, data1[i].z, S.v_width, S.h_length, S.h_width, gmtdefs.vector_shape, &data1[i].f, (GMT_LONG)this_outline);
 						}
 						break;
 					case GMT_SYMBOL_PIE:
 						if (S.convert_angles == 2) {
-							GMT_azim_to_angle (data1[i].lon, data1[i].lat, 0.1, (double)(R2D*data1[i].y_size), &tmp);
-							data1[i].y_size = (float)(D2R*tmp);
-							GMT_azim_to_angle (data1[i].lon, data1[i].lat, 0.1, (double)(R2D*data1[i].z_size), &tmp);
-							data1[i].z_size = (float)(D2R*tmp);
+							GMT_azim_to_angle (data1[i].lon, data1[i].lat, 0.1, (double)(data1[i].y_size), &tmp);
+							data1[i].y_size = (float)(tmp);
+							GMT_azim_to_angle (data1[i].lon, data1[i].lat, 0.1, (double)(data1[i].z_size), &tmp);
+							data1[i].z_size = (float)tmp;
+							f_swap (data1[i].y_size, data1[i].z_size);
 						}
 						dim[0] = 0.5 * data1[i].x_size; dim[1] = data1[i].y_size; dim[2] = data1[i].z_size;
 						GMT_pie (data1[i].x, data1[i].y, data1[i].z, dim, &data1[i].f, data1[i].outline);
@@ -1044,6 +1047,8 @@ int main (int argc, char **argv)
 		GMT_contlabel_free (&S.G);
 	}
 
+	if (S.u_set) gmtdefs.measure_unit = save_u;	/* Reset unit */
+
 	if (Ctrl->D.active) ps_transrotate (-DX, -DY, 0.0);	/* Shift plot a bit */
 
 	if (clip_set) GMT_map_clip_off ();
@@ -1150,7 +1155,7 @@ void bary3D (double x, double y, double z, double base, double size, struct GMT_
 	xp[0] = xp[3] = x - size;	xp[1] = xp[2] = x + size;
 	yp[0] = yp[1] = base;	yp[2] = yp[3] = y;
 	for (i = 0; i < 4; i++) GMT_xyz_to_xy (xp[i], yp[i], z, &plot_x[i], &plot_y[i]);
-	GMT_fill (plot_x, plot_y, (GMT_LONG)4, f, outline);
+	GMT_fill (plot_x, plot_y, (GMT_LONG)4, f, (GMT_LONG)outline);
 }
 
 void barx3D (double x, double y, double z, double base, double size, struct GMT_FILL *f, GMT_LONG outline)
@@ -1162,7 +1167,7 @@ void barx3D (double x, double y, double z, double base, double size, struct GMT_
 	yp[0] = yp[3] = y - size;	yp[1] = yp[2] = y + size;
 	xp[0] = xp[1] = base;	xp[2] = xp[3] = x;
 	for (i = 0; i < 4; i++) GMT_xyz_to_xy (xp[i], yp[i], z, &plot_x[i], &plot_y[i]);
-	GMT_fill (plot_x, plot_y, (GMT_LONG)4, f, outline);
+	GMT_fill (plot_x, plot_y, (GMT_LONG)4, f, (GMT_LONG)outline);
 }
 
 void sort_on_distance (struct PSXYZ_DATA1 *data, GMT_LONG n)
