@@ -1,14 +1,14 @@
 /*--------------------------------------------------------------------
- *	$Id: pssegy.c,v 1.27 2008/05/12 22:35:47 guru Exp $
+ *	$Id: pssegy.c,v 1.33 2011/03/05 21:24:29 guru Exp $
  *
- *    Copyright (c) 1999-2008 by T. Henstock
+ *    Copyright (c) 1999-2011 by T. Henstock
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /* pssegy program to plot segy files in postscript with variable trace spacing option
  * uses the GMT pslib imagemask routines to plot a
  * 1-bit depth bitmap which will not obliterate stuff underneath!
  *
- * Author:	Tim Henstock (then@soc.soton.ac.uk)
+ * Author:	Tim Henstock (then@noc.soton.ac.uk)
  * Date:	1-July-1996
  * Version:	1.0
  *
@@ -22,6 +22,9 @@
  *
  *               2.1 10/4/2001 fix unreduce bug, modify to byte-swap if necessary, make 64-bit safe
  *
+ *                   10/7/2009 fix bug when reading trace locations from arbitrary header locations,
+ *                             8 bytes copied, should be 4 bytes 
+ * 
  * This program is free software and may be copied or redistributed under the terms
  * of the GNU public license.
  */
@@ -45,7 +48,7 @@ int bm_nx, bm_ny;
 
 int main (int argc, char **argv)
 {
-	int error = FALSE;
+	GMT_LONG error = FALSE;
 	int plot_cdp = FALSE, plot_offset = FALSE, byte_x = 0, doclip = FALSE;
 	int normalize = FALSE, do_fill = FALSE, negative = FALSE, plot_wig = FALSE;
 	int no_zero = FALSE, trace_file = FALSE;
@@ -68,7 +71,7 @@ int main (int argc, char **argv)
 	float *data;
 	SEGYHEAD *header;
 	char *head;
-	long *head2;
+	int head2;
 	SEGYREEL binhead;
 
 	FILE *fpi = NULL, *fpt = NULL;
@@ -77,7 +80,7 @@ int main (int argc, char **argv)
 	input[0] = 0;
 	w = e = s = n = 0.0;
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 
 	for (i = 1; i < argc; i++) {
@@ -163,7 +166,7 @@ int main (int argc, char **argv)
 				/* plot traces only at listed locations */
 				case 'T':
 					strcpy (input, &argv[i][2]);
-					if ((trace_file = strlen(input))){
+					if ((trace_file = (int)strlen(input))){
 						if ((fpt = fopen (input, "r")) == NULL){
 							fprintf(stderr, "%s: Cannot find trace list file %s\n", GMT_program, input);
 							error++;
@@ -360,19 +363,18 @@ use a few of these*/
 	while ((ix<n_traces) && (header = get_segy_header(fpi))){   /* read traces one by one */
 
 		if (plot_offset){ /* plot traces by offset, cdp, or input order */
-			long offset = ((swap_bytes)? GMT_swab4(header->sourceToRecDist): header->sourceToRecDist);
+			int32_t offset = ((swap_bytes)? GMT_swab4(header->sourceToRecDist): header->sourceToRecDist);
 			x0 = (double) offset;
 		}
 		else if (plot_cdp){
-			long cdpval = ((swap_bytes)? GMT_swab4(header->cdpEns): header->cdpEns);
+			int32_t cdpval = ((swap_bytes)? GMT_swab4(header->cdpEns): header->cdpEns);
 			x0 = (double) cdpval;
 		}
 		else if (byte_x){ /* ugly code - want to get value starting at byte_x of header into a double... */
-		   	long plot_loc;
 			head = (char *) header;
-			head2 = (long *) &(head[byte_x]);
-			plot_loc = ((swap_bytes)? GMT_swab4(*head2): *head2);
-		  	x0 = (double) plot_loc;
+			memcpy(&head2, &head[byte_x], 4); /* edited to fix bug where 8bytes were copied from head.
+												Caused by casting to a long directly from char array*/ 
+			x0 = (double) ((swap_bytes)? GMT_swab4(head2): head2);
 		}
 		else
 			x0 = (1.0 + (double) ix);
