@@ -1,14 +1,14 @@
 /*--------------------------------------------------------------------
- *	$Id: pssegyz.c,v 1.36 2009/08/28 12:08:32 remko Exp $
+ *	$Id: pssegyz.c,v 1.39 2011/03/05 21:24:29 guru Exp $
  *
- *    Copyright (c) 1999-2009 by T. Henstock
+ *    Copyright (c) 1999-2011 by T. Henstock
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /* pssegyz program to plot segy files in 3d in postscript with variable trace spacing option
  * uses routines from the GMT pslib (the postscript imagemask for plotting a
  * 1-bit depth bitmap which will not obliterate stuff underneath!
  *
- * Author:	Tim Henstock (Timothy.J.Henstock@soc.soton.ac.uk)
+ * Author:	Tim Henstock (then@noc.soton.ac.uk)
  * Date:	17-Nov-97
  * Version:	1.0
  *
@@ -53,7 +53,7 @@ int bm_nx, bm_ny;
 
 int main (int argc, char **argv)
 {
-	int error = FALSE;
+	GMT_LONG error = FALSE;
 	int xplot_cdp = FALSE, xplot_offset = FALSE, fix_x = FALSE, byte_x = 0; /* parameters for location plot */
 	int yplot_cdp = FALSE, yplot_offset = FALSE, fix_y = FALSE, byte_y = 0;
 	int doclip = FALSE;
@@ -92,7 +92,7 @@ int main (int argc, char **argv)
 	input[0] = 0;
 	w = e = s = n = 0.0;
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
