@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: segy2grd.c,v 1.36 2009/09/09 23:27:04 guru Exp $
+ *	$Id: segy2grd.c,v 1.41 2011/03/05 21:24:29 guru Exp $
  *
- *	Copyright (c) 1991-2009 by T. Henstock
+ *	Copyright (c) 1991-2011 by T. Henstock
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,7 +20,7 @@
  * to read a segy file and generate a
  * corresponding grd-file.
  *
- * Author:	Tim Henstock
+ * Author:	Tim Henstock (then@noc.soton.ac.uk)
  * Date:	30-JUN-2002
  * Version:	3.4.1
  */
@@ -38,7 +38,7 @@ int main (int argc, char **argv)
 	GMT_LONG n_empty = 0, n_stuffed = 0, n_bad = 0, n_confused = 0;
 	GMT_LONG check, n_traces=10000, n_samp=0, n_sampr=0, byte_x = 0, ix, isamp, ij0;
 
-	int pixel = FALSE;
+	GMT_LONG pixel = FALSE;
 	double w, e, s, n, dx = 0.0, dy = 0.0, xy_off, idy, no_data_d;
 	double s_int = 0.0, x_coord_scale=1.0, x0, yval;
 
@@ -60,7 +60,7 @@ int main (int argc, char **argv)
 
 
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	grdfile = CNULL;
 	input[0] = 0;
@@ -215,12 +215,12 @@ int main (int argc, char **argv)
 
 	if (got_input) GMT_decode_grd_h_info (input, &grd);
 
-	grd.node_offset = pixel;
+	grd.node_offset = (int)pixel;
 	one_or_zero = 1 - grd.node_offset;
 	xy_off = 0.5 * grd.node_offset;
 
-	grd.nx = irint ((e-w)/dx) + one_or_zero;
-	grd.ny = irint ((n-s)/dy) + one_or_zero;
+	grd.nx = (int)(irint ((e-w)/dx) + one_or_zero);
+	grd.ny = (int)(irint ((n-s)/dy) + one_or_zero);
 	grd.x_min = w;	grd.x_max = e;
 	grd.y_min = s;	grd.y_max = n;
 	grd.x_inc = dx;	grd.y_inc = dy;
