@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: sphdistance.c,v 1.20 2010/01/05 01:15:48 guru Exp $
+ *	$Id: sphdistance.c,v 1.24 2011/03/05 21:24:29 guru Exp $
  *
- *	Copyright (c) 2008-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 2008-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -38,35 +38,35 @@
 
 struct SPHDISTANCE_CTRL {
 	struct C {	/* -C */
-		BOOLEAN active;
+		GMT_LONG active;
 	} C;
 	struct D {	/* -D */
-		BOOLEAN active;
+		GMT_LONG active;
 	} D;
 	struct E {	/* -E */
-		BOOLEAN active;
+		GMT_LONG active;
 	} E;
 	struct F {	/* -F */
-		BOOLEAN active;
+		GMT_LONG active;
 	} F;
 	struct G {	/* -G<maskfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} G;
 	struct I {	/* -Idx[/dy] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double xinc, yinc;
 	} I;
 	struct L {	/* -L<unit>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		char unit;
 	} L;
 	struct N {	/* -N */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} N;
 	struct Q {	/* -Q */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} Q;
 };
@@ -79,7 +79,7 @@ int main (int argc, char **argv)
 	GMT_LONG ij, ii, s_row, n_row, w_col, e_col, side;
 	GMT_LONG n_expected_fields, n_args, n_fields, fno, n_files = 0, proj_type = 0;
 
-	BOOLEAN error = FALSE, nofile = TRUE, done = FALSE, first = FALSE;
+	GMT_LONG error = FALSE, nofile = TRUE, done = FALSE, first = FALSE;
 
 	double sx, sy, cx, cy, first_x = 0.0, first_y = 0.0, *in;
 	double *xx = NULL, *yy = NULL, *zz = NULL, *lon = NULL, *lat = NULL;
@@ -101,7 +101,7 @@ int main (int argc, char **argv)
 	struct STRIPACK_VORONOI *V = NULL;
 	void *New_sphdistance_Ctrl (), Free_sphdistance_Ctrl (struct SPHDISTANCE_CTRL *C);
 	
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct SPHDISTANCE_CTRL *)New_sphdistance_Ctrl ();	/* Allocate and initialize a new control structure */
 	GMT_grd_init (&h, argc, argv, FALSE);
@@ -384,7 +384,7 @@ int main (int argc, char **argv)
 	/* OK, time to work on the distance grid */
 	
 	if (gmtdefs.verbose) fprintf (stderr, "%s: Start processing distance grid\n", GMT_program);
-	h.node_offset = Ctrl->F.active;
+	h.node_offset = (int)Ctrl->F.active;
 	h.x_inc = Ctrl->I.xinc;
 	h.y_inc = Ctrl->I.yinc;
 	GMT_RI_prepare (&h);	/* Ensure -R -I consistency and set nx, ny */
@@ -520,7 +520,7 @@ int main (int argc, char **argv)
 void prepare_polygon (struct GMT_LINE_SEGMENT *P)
 {
 	GMT_LONG i, quad_no, n_quad;
-	BOOLEAN quad[4] = {FALSE, FALSE, FALSE, FALSE};
+	GMT_LONG quad[4] = {FALSE, FALSE, FALSE, FALSE};
 	double lon_sum = 0.0, lat_sum = 0.0, lon, dlon;
 	double xmin1 = 360.0, xmin2 = 360.0, xmax1 = -360.0, xmax2 = -360.0;
 	
