@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: sphinterpolate.c,v 1.25 2010/01/05 01:15:48 guru Exp $
+ *	$Id: sphinterpolate.c,v 1.29 2011/03/05 21:24:29 guru Exp $
  *
- *	Copyright (c) 2008-2010 by P. Wessel
+ *	Copyright (c) 2008-2011 by P. Wessel
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -37,26 +37,26 @@
 
 struct SPHINTERPOLATE_CTRL {
 	struct F {	/* -F */
-		BOOLEAN active;
+		GMT_LONG active;
 	} F;
 	struct G {	/* -G<grdfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} G;
 	struct I {	/* -Idx[/dy] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double xinc, yinc;
 	} I;
 	struct Q {	/* -Q<interpolation> */
-		BOOLEAN active;
+		GMT_LONG active;
 		int mode;
 		double value[2];
 	} Q;
 	struct T {	/* -T for variable tension */
-		BOOLEAN active;
+		GMT_LONG active;
 	} T;
 	struct Z {	/* -Z to scale data */
-		BOOLEAN active;
+		GMT_LONG active;
 	} Z;
 };
 
@@ -66,7 +66,7 @@ int main (int argc, char **argv)
 	GMT_LONG n_expected_fields, n_args, m, n_fields, fno, n_files = 0;
 	size_t n_alloc = GMT_CHUNK, nm;
 
-	BOOLEAN error = FALSE, nofile = TRUE, done = FALSE;
+	GMT_LONG error = FALSE, nofile = TRUE, done = FALSE;
 
 	double sx, sy, cx, cy, w_min, w_max, sf = 1.0;
 	double *xx = NULL, *yy = NULL, *zz = NULL, *ww = NULL, *surfd = NULL, *in;
@@ -80,7 +80,7 @@ int main (int argc, char **argv)
 	void *New_sphinterpolate_Ctrl (), Free_sphinterpolate_Ctrl (struct SPHINTERPOLATE_CTRL *C);
 	GMT_LONG get_args (char *arg, double pars[], char *msg);
 	
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct SPHINTERPOLATE_CTRL *)New_sphinterpolate_Ctrl ();	/* Allocate and initialize a new control structure */
 	GMT_grd_init (&h, argc, argv, FALSE);
@@ -320,7 +320,7 @@ int main (int argc, char **argv)
 	/* Set up output grid */
 	
 	if (gmtdefs.verbose) fprintf (stderr, "%s: Evaluate output grid\n", GMT_program);
-	h.node_offset = Ctrl->F.active;
+	h.node_offset = (int)Ctrl->F.active;
 	h.x_inc = Ctrl->I.xinc;
 	h.y_inc = Ctrl->I.yinc;
 	GMT_RI_prepare (&h);	/* Ensure -R -I consistency and set nx, ny */
