@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: splitxyz.c,v 1.52 2010/01/05 01:15:47 guru Exp $
+ *	$Id: splitxyz.c,v 1.60 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -33,41 +33,41 @@
 
 struct SPLITXYZ_CTRL {
 	struct A {	/* -A<azimuth>/<tolerance> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double azimuth, tolerance;
 	} A;
 	struct C {	/* -C<course_change> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double value;
 	} C;
 	struct D {	/* -D<mindist> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double value;
 	} D;
 	struct F {	/* -F<xy_filter>/<z_filter> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double xy_filter, z_filter;
 	} F;
 	struct G {	/* -D<gap> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double value;
 	} G;
 	struct M {	/* -M */
-		BOOLEAN active;
+		GMT_LONG active;
 	} M;
 	struct N {	/* -N<namestem> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *name;
 	} N;
 	struct Q {	/* -Q[<xyzdg>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		char col[SPLITXYZ_N_OUTPUT_CHOICES];	/* Character codes for desired output in the right order */
 	} Q;
 	struct S {	/* -S */
-		BOOLEAN active;
+		GMT_LONG active;
 	} S;
 	struct Z{	/* -Z */
-		BOOLEAN active;
+		GMT_LONG active;
 	} Z;
 };
 
@@ -79,9 +79,9 @@ struct  DATA    {
 int main(int argc, char **argv)
 {
 	GMT_LONG     i, ndata, n_alloc, nprofiles, begin, end;
-	GMT_LONG	j, k, n_required_fields, output_choice[SPLITXYZ_N_OUTPUT_CHOICES], n_expected_fields, n_outputs = 0, n_fields;
+	GMT_LONG	j, k, n_required_fields, output_choice[SPLITXYZ_N_OUTPUT_CHOICES], n_expected_fields, n_outputs = 0, n_read, n_fields;
 
-	BOOLEAN	error = FALSE, ok, hilow = FALSE, z_selected = FALSE;
+	GMT_LONG	error = FALSE, ok, hilow = FALSE, z_selected = FALSE;
 
 	double	dy, dx, last_d, last_c, last_s, csum, ssum, this_c, this_s, dotprod;
 	double	mean_azim, fwork[SPLITXYZ_F_RES], *in, out[SPLITXYZ_N_OUTPUT_CHOICES];
@@ -96,7 +96,7 @@ int main(int argc, char **argv)
 	void	filterz(struct DATA *data, GMT_LONG ndata, double z_filter, double *fwork, GMT_LONG hilow), filterxy_setup(double *fwork), filterxy(struct DATA *data, GMT_LONG begin, GMT_LONG end, double xy_filter, double *fwork, GMT_LONG hilow);
 	void *New_splitxyz_Ctrl (), Free_splitxyz_Ctrl (struct SPLITXYZ_CTRL *C);
 	
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 	
 	Ctrl = (struct SPLITXYZ_CTRL *)New_splitxyz_Ctrl ();	/* Allocate and initialize a new control structure */
 
@@ -115,7 +115,7 @@ int main(int argc, char **argv)
 				case 'b':
 				case 'f':
 				case '\0':
-					error += GMT_parse_common_options (argv[i], 0, 0, 0, 0);
+					error += (GMT_LONG)GMT_parse_common_options (argv[i], 0, 0, 0, 0);
 					break;
 
 				/* Supplemental parameters */
@@ -203,7 +203,7 @@ int main(int argc, char **argv)
  		fprintf (stderr, "splitxyz %s - Split xyz[dh] files into segments\n\n", GMT_VERSION);
 		fprintf(stderr,"usage:  splitxyz [<xyz[dh]file>] -C<course_change> [-A<azimuth>/<tolerance>]\n");
 		fprintf(stderr,"\t[-D<minimum_distance>] [-F<xy_filter>/<z_filter>] [-G<gap>] [%s] [-M]\n", GMT_H_OPT);
-		fprintf(stderr,"\t[-N<namestem>] [-S] [-V] [-Z] [-:] [%s] [%s]\n\n", GMT_b_OPT, GMT_f_OPT);
+		fprintf(stderr,"\t[-N<namestem>] [-Q<flags>] [-S] [-V] [-Z] [-:] [%s] [%s]\n\n", GMT_b_OPT, GMT_f_OPT);
  
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
@@ -221,10 +221,10 @@ int main(int argc, char **argv)
 		fprintf(stderr,"\t-M Map units TRUE; x,y in degrees, dist units in km.  [Default dist unit = x,y unit].\n");
 		fprintf(stderr,"\t-N Write output to separate files named <namestem>.profile#.\n");
 		fprintf(stderr,"\t     [Default all to stdout, separated by >].\n");
-		fprintf(stderr,"\t-Qflags: Indicate what output you want as one or more of xyzdh in any order;\n");
-		fprintf(stderr,"\t  where x,y,z refer to input data locations and optional values,\n");
-		fprintf(stderr,"\t  d,h are the distance and heading along track.\n");
-		fprintf(stderr,"\t  [Default is all fields, i.e. -Qxyzdh (or -Qxydh if -Z is set)]\n");
+		fprintf(stderr,"\t-Q Indicate what output you want as one or more of xyzdh in any order;\n");
+		fprintf(stderr,"\t  where x,y,z refer to input data locations and optional z-value(s),\n");
+		fprintf(stderr,"\t  and d,h are the distance and heading along track.\n");
+		fprintf(stderr,"\t  [Default is all fields, i.e. -Qxyzdh (or -Qxydh if -Z is set)].\n");
 		fprintf(stderr,"\t-S d,h is supplied.  Input is 5 col x,y,z,d,h with d non-decreasing.\n");
 		fprintf(stderr,"\t     [Default input is 3 col x,y,z only and computes d,h from the data].\n");
 		fprintf(stderr,"\t-Z No z-values.  Input is 2 col x,y only\n");
@@ -345,8 +345,7 @@ int main(int argc, char **argv)
 #endif
 	}
         n_alloc = GMT_CHUNK;
-	ndata = 0;
-	i = 0;
+	ndata = n_read = 0;
 
         data = (struct DATA *) GMT_memory (VNULL, (size_t)n_alloc, sizeof(struct DATA), GMT_program);
 
@@ -354,12 +353,12 @@ int main(int argc, char **argv)
 
 	while ((n_fields = GMT_input (fp, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
 
+		n_read++;
 		if (GMT_io.status & GMT_IO_MISMATCH) {
-			fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields,  n_expected_fields, i);
-			exit (EXIT_FAILURE);
+			fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld (skipped)\n", GMT_program, n_fields,  n_expected_fields, n_read);
+			continue;
 
 		}
-		i++;
                 if (ndata == n_alloc) {
                         n_alloc <<= 1;
                         data = (struct DATA *) GMT_memory ((void *)data, (size_t)n_alloc, sizeof(struct DATA), GMT_program);
@@ -492,8 +491,10 @@ int main(int argc, char **argv)
 							exit (EXIT_FAILURE);
 						}
 					}
-					else
-						fprintf (GMT_stdout, "> Start profile # %ld\n", nprofiles);
+					else {
+						sprintf (buffer, "> Start profile # %ld\n", nprofiles);
+						GMT_fputs (buffer, GMT_stdout);
+					}
 
 					for (i = begin; i < end; i++) {
 						for (j = 0; j < n_outputs; j++) {	/* Remember to convert CCW angles back to azimuths */
