@@ -1,11 +1,11 @@
 /*--------------------------------------------------------------------
- *	$Id: grdspotter.c,v 1.19 2008/04/26 05:45:29 guru Exp $
+ *	$Id: grdspotter.c,v 1.33 2011/03/03 21:02:51 guru Exp $
  *
- *   Copyright (c) 1999-2008 by P. Wessel
+ *   Copyright (c) 1999-2011 by P. Wessel
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; version 2 of the License.
+ *   the Free Software Foundation; version 2 or any later version.
  *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -22,7 +22,7 @@
  * can also calculate the Data Importance (DI) associated with each node's
  * flowline and the predicted age (PA) for each node.  Finally, errors in
  * the location of the CVA maximum can be assessed by running a bootstrap
- * extimation.  The grids are all written out in GMT format and can be
+ * estimation.  The grids are all written out in GMT format and can be
  * processed and plotted with GMT.
  * GRDSPOTTER is part of the SPOTTER supplemental GMT package and should
  * be installed accordingly, see README.spotter.
@@ -96,7 +96,7 @@
  * -> Plate motion models (stage poles):
  *
  * Duncan, R.A., and D. Clague, 1985, Pacific plate motion recorded by linear
- *    volcanic chains, in: A.E.M. Nairn, F. G. stehli, S. Uyeda (eds.), The
+ *    volcanic chains, in: A.E.M. Nairn, F. G. Stehli, S. Uyeda (eds.), The
  *    Ocean Basins and Margins, Vol. 7A, Plenum, New York, pp. 89-121.
  * Wessel and Kroenke, 1997, (see above)
  *
@@ -108,7 +108,7 @@
 #define OUTSIDE -1
 
 GMT_LONG get_flowline (double xx, double yy, double tt, struct EULER *p, GMT_LONG n_stages, double d_km, GMT_LONG step, int forth_flag, double wesn[], double **flow);
-BOOLEAN set_age (double *t_smt, float *age, GMT_LONG node, double upper_age, BOOLEAN truncate, BOOLEAN no_ages);
+GMT_LONG set_age (double *t_smt, float *age, GMT_LONG node, double upper_age, GMT_LONG truncate, GMT_LONG no_ages);
 
 int main (int argc, char **argv)
 {
@@ -119,8 +119,8 @@ int main (int argc, char **argv)
 	GMT_LONG one_or_zero;		/* Will be 1 or 0 depending on grid format (-F) */
 	GMT_LONG n_try = 0;			/* Number of bootstrap estimates required */
 	GMT_LONG try;			/* Number of current bootstrap estimate */
-
-	size_t nm;			/* Number of nodes in the output CVA grid */
+	GMT_LONG nm;			/* Number of nodes in the output CVA grid */
+	GMT_LONG node_offset = 0;
 	size_t n_alloc = 0, inc_alloc = BIG_CHUNK;
 	
 	unsigned short pa = 0;		/* Placeholder for PA along track */
@@ -129,23 +129,23 @@ int main (int argc, char **argv)
 
 	GMT_LONG i, j, k, ij, m, row, col, k_step, np, max_ij = 0, n_flow, mem = 0, n_unique_nodes = 0, Qid;
 
-	BOOLEAN	error = FALSE;		/* TRUE when arguments are wrong */
-	BOOLEAN no_ages = TRUE;		/* TRUE when no age grid is given */
-	BOOLEAN truncate_ages = FALSE;	/* Truncate all nodes ages > upper_age */
-	BOOLEAN finite = FALSE;		/* TRUE if stage pole file contains finite rotation poles instead */
-	BOOLEAN get_DI = FALSE;		/* TRUE if we want to obtain Data Importance using max CVA along flowlines */
-	BOOLEAN get_PA = FALSE;	/* TRUE if we want to use CVA flowlines to predict node age */
-	BOOLEAN blabber = FALSE;	/* TRUE if we want excessive verbosity */
-	BOOLEAN bootstrap = FALSE;	/* TRUE if we want bootstrap estimates */
-	BOOLEAN keep_flowlines = FALSE;	/* TRUE if get_DI, get_PA, or bootstrap is TRUE */
-	BOOLEAN multi_slices = FALSE;	/* TRUE if we want CVAs for many different z-sizes */
-	BOOLEAN check_IDs = FALSE;	/* TRUE if we want to compute CVS for certain ID points only */
-	BOOLEAN forth_flag;		/* Holds the do_time + 10 flag passed to forthtrack */
-	BOOLEAN normalize = FALSE;	/* TRUE if we want CVA in percents */
-	BOOLEAN *ID = NULL;			/* Optional array with IDs for each node */
-	BOOLEAN slow_and_painful = FALSE;	/* When we run out of flowline memory */
-	BOOLEAN set_fixed = FALSE;	/* Optional TRUE if we want to set all z[ij]'s to a fixed value */
-	BOOLEAN *processed_node;		/* Pointer to array with TRUE/FALSE values for each grid node */
+	GMT_LONG	error = FALSE;		/* TRUE when arguments are wrong */
+	GMT_LONG no_ages = TRUE;		/* TRUE when no age grid is given */
+	GMT_LONG truncate_ages = FALSE;	/* Truncate all nodes ages > upper_age */
+	GMT_LONG finite = FALSE;		/* TRUE if stage pole file contains finite rotation poles instead */
+	GMT_LONG get_DI = FALSE;		/* TRUE if we want to obtain Data Importance using max CVA along flowlines */
+	GMT_LONG get_PA = FALSE;	/* TRUE if we want to use CVA flowlines to predict node age */
+	GMT_LONG blabber = FALSE;	/* TRUE if we want excessive verbosity */
+	GMT_LONG bootstrap = FALSE;	/* TRUE if we want bootstrap estimates */
+	GMT_LONG keep_flowlines = FALSE;	/* TRUE if get_DI, get_PA, or bootstrap is TRUE */
+	GMT_LONG multi_slices = FALSE;	/* TRUE if we want CVAs for many different z-sizes */
+	GMT_LONG check_IDs = FALSE;	/* TRUE if we want to compute CVS for certain ID points only */
+	GMT_LONG forth_flag;		/* Holds the do_time + 10 flag passed to forthtrack */
+	GMT_LONG normalize = FALSE;	/* TRUE if we want CVA in percents */
+	GMT_LONG *ID = NULL;			/* Optional array with IDs for each node */
+	GMT_LONG slow_and_painful = FALSE;	/* When we run out of flowline memory */
+	GMT_LONG set_fixed = FALSE;	/* Optional TRUE if we want to set all z[ij]'s to a fixed value */
+	GMT_LONG *processed_node;		/* Pointer to array with TRUE/FALSE values for each grid node */
 	
 	float *CVA;			/* The CVA surface we seek to calculate */
 	float *z;			/* The topo or grav input surface */
@@ -165,7 +165,7 @@ int main (int argc, char **argv)
 	double offset, half;		/* 0.0 or 0.5, depending on -F */
 	double z_min = 0.0, z_max = DBL_MAX;		/* Only deal with z-values inside this range [0/Inf] */
 	double CVA_max, wesn[4], cva_contribution;
-	double out[3], scale, z_inc, sdist = 0.0, area;
+	double out[3], scale, z_inc, sdist = 0.0, area, yg;
 	double *lat_area;		/* Area of each dx by dy note in km as function of latitude */
 	double CVA_scale;		/* Used to normalize CVAs to percent */
 	double this_wesn[4];
@@ -193,13 +193,13 @@ int main (int argc, char **argv)
 	
 	struct ID {			/* Information regarding one chain ID */
 		double wesn[4];		/* Do not calculate flowlines outside this box */
-		BOOLEAN ok;		/* TRUE if we want to calculate this CVA */
-		BOOLEAN check_region;	/* TRUE if w, e, s, n is more restrictive than command line -R */
+		GMT_LONG ok;		/* TRUE if we want to calculate this CVA */
+		GMT_LONG check_region;	/* TRUE if w, e, s, n is more restrictive than command line -R */
 	} *ID_info = NULL;
 
 	/* ------------------- END OF DECLARATIONS ------------------------------------------------------------*/
 
-	argc = GMT_begin (argc, argv);			/* Initialize GMT environment */
+	argc = (int)GMT_begin (argc, argv);			/* Initialize GMT environment */
 		
 	GMT_grd_init (&CVA_map, argc, argv, FALSE);	/* Initialize grid structure */
 	
@@ -309,7 +309,7 @@ int main (int argc, char **argv)
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 		
 		fprintf (stderr, "\t<zgrdfile> is the grid with topo or gravity\n");
-		fprintf (stderr, "\t-E Specify the file with rotation parameters\n");
+		fprintf (stderr, "\t-E specifies the rotations to be used (see man page for format)\n\n");
 		fprintf (stderr, "\t-G Specify file name for output CVA convolution grid.\n");
 		fprintf (stderr, "\t-I specifies grid interval(s); Append m [or c] to <dx> and/or <dy> for minutes [or seconds].\n");
 		GMT_explain_option ('R');
@@ -335,6 +335,9 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
+	GMT_check_lattice (&CVA_map.x_inc, &CVA_map.y_inc, &node_offset, NULL);
+	CVA_map.node_offset = (int)node_offset;
+
 	if (!project_info.region_supplied) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR:  Must specify -R option\n", GMT_program);
 		error++;
@@ -363,6 +366,8 @@ int main (int argc, char **argv)
 
 	/* ------------------- END OF PROCESSING COMMAND LINE ARGUMENTS  --------------------------------------*/
 
+	GMT_lat_swap_init ();	/* Initialize auxiliary latitude machinery */
+
 	/* Load in the Euler stage poles */
 
 	n_stages = spotter_init (euler_file, &p, TRUE, finite, FALSE, &upper_age, gmtdefs.verbose);
@@ -381,12 +386,12 @@ int main (int argc, char **argv)
 		offset = 0.5;
 	}
 
-	CVA_map.nx = irint ((CVA_map.x_max - CVA_map.x_min) / CVA_map.x_inc) + one_or_zero;
-	CVA_map.ny = irint ((CVA_map.y_max - CVA_map.y_min) / CVA_map.y_inc) + one_or_zero;
-	nm = CVA_map.nx * CVA_map.ny;
-	CVA = (float *) GMT_memory (VNULL, nm, sizeof(float), GMT_program);
+	CVA_map.nx = (int)(irint ((CVA_map.x_max - CVA_map.x_min) / CVA_map.x_inc) + one_or_zero);
+	CVA_map.ny = (int)(irint ((CVA_map.y_max - CVA_map.y_min) / CVA_map.y_inc) + one_or_zero);
+	nm = GMT_get_nm (CVA_map.nx, CVA_map.ny);
+	CVA = (float *) GMT_memory (VNULL, (size_t)nm, sizeof(float), GMT_program);
 
-	/* Assing grid-region variables in radians to avoid conversions inside convolution loop */
+	/* Assign grid-region variables in radians to avoid conversions inside convolution loop */
 
 	CVA_west_rad   = CVA_map.x_min * D2R;
 	CVA_east_rad   = CVA_map.x_max * D2R;
@@ -397,7 +402,7 @@ int main (int argc, char **argv)
 
 	/* Allocate T/F array */
 
-	processed_node = (BOOLEAN *) GMT_memory (VNULL, nm, sizeof (BOOLEAN), GMT_program);
+	processed_node = (GMT_LONG *) GMT_memory (VNULL, nm, sizeof (GMT_LONG), GMT_program);
 
 	/* Set flowline sampling interval to 1/2 of the shortest distance between x-nodes */
 
@@ -425,7 +430,7 @@ int main (int argc, char **argv)
 	x_smt = (double *) GMT_memory (VNULL, (size_t)zgrid.nx, sizeof(double), GMT_program);
 	for (i = 0; i < zgrid.nx; i++) x_smt[i] = D2R * GMT_i_to_x (i, zgrid.x_min, zgrid.x_max, zgrid.x_inc, half, zgrid.nx);
 	y_smt = (double *) GMT_memory (VNULL, (size_t)zgrid.ny, sizeof(double), GMT_program);
-	for (j = 0; j < zgrid.ny; j++) y_smt[j] = D2R * GMT_j_to_y (j, zgrid.y_min, zgrid.y_max, zgrid.y_inc, half, zgrid.ny);
+	for (j = 0; j < zgrid.ny; j++) y_smt[j] = D2R * GMT_lat_swap (GMT_j_to_y (j, zgrid.y_min, zgrid.y_max, zgrid.y_inc, half, zgrid.ny), GMT_LATSWAP_G2O);	/* Convert to geocentric */
 	lat_area = (double *) GMT_memory (VNULL, (size_t)zgrid.ny, sizeof(double), GMT_program);
 
 	for (j = 0; j < zgrid.ny; j++) lat_area[j] = area * cos (y_smt[j]);
@@ -462,14 +467,14 @@ int main (int argc, char **argv)
 			exit (EXIT_FAILURE);
 		}
 		
-		ID = (BOOLEAN *) GMT_memory (VNULL, (size_t)(idgrid.nx * idgrid.ny), sizeof (BOOLEAN), GMT_program);
+		ID = (GMT_LONG *) GMT_memory (VNULL, (size_t)(idgrid.nx * idgrid.ny), sizeof (GMT_LONG), GMT_program);
 		tmp = (float *) GMT_memory (VNULL, (size_t)(idgrid.nx * idgrid.ny), sizeof(float), GMT_program);
 
 		if (GMT_read_grd (ID_file, &idgrid, tmp, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE)) {
 			fprintf (stderr, "%s: Error reading file %s\n", GMT_program, ID_file);
 			exit (EXIT_FAILURE);
 		}
-		for (i = 0; i < idgrid.nx * idgrid.ny; i++) ID[i] = (BOOLEAN) rint ((double)tmp[i]);
+		for (i = 0; i < idgrid.nx * idgrid.ny; i++) ID[i] = (GMT_LONG) rint ((double)tmp[i]);
 		GMT_free ((void *)tmp);
 		ID_info = (struct ID *) GMT_memory (VNULL, (size_t)(rint (idgrid.z_max) + 1), sizeof (struct ID), GMT_program);
 		if (check_IDs == 1) {	/* Only doing one CVA with no extra restrictions */
@@ -485,8 +490,9 @@ int main (int argc, char **argv)
 				exit (EXIT_FAILURE);
 			}
 			while (fgets (line, BUFSIZ, fp)) {
-				if (line[0] == '#' || line[0] == '\n') continue;
-				k = sscanf (line, "%*s %ld %lf %lf %lf %lf", &Qid, &wq, &eq, &sq, &nq);
+				GMT_chop (line);					/* Rid the world of CR/LF */
+				if (line[0] == '#' || line[0] == '\0') continue;
+				k = sscanf (line, "%*s %" GMT_LL "d %lf %lf %lf %lf", &Qid, &wq, &eq, &sq, &nq);
 				ID_info[Qid].ok = TRUE;
 				if (k == 5) {	/* Got restricted wesn also */
 					ID_info[Qid].check_region = TRUE;
@@ -504,11 +510,11 @@ int main (int argc, char **argv)
 	if (slow_and_painful) {
 		keep_flowlines = FALSE;	/* Do it the hard way to save memory */
 		k_step = 2;		/* Reset back to 3 if needed later */
-		forth_flag = 10;	/* The 10 is used to limit the flowline calculation to only resample track within the rectangular box of interrest */
+		forth_flag = 10;	/* The 10 is used to limit the flowline calculation to only resample track within the rectangular box of interest */
 	}
 	else {
 		keep_flowlines = (get_PA || get_DI || bootstrap);
-		forth_flag = get_PA + 10;	/* The 10 is used to limit the flowline calculation to only resample track within the rectangular box of interrest */
+		forth_flag = get_PA + 10;	/* The 10 is used to limit the flowline calculation to only resample track within the rectangular box of interest */
 		k_step = (get_PA) ? 3 : 2;
 	}
 	if (keep_flowlines) {
@@ -532,7 +538,7 @@ int main (int argc, char **argv)
 				memcpy ((void *)this_wesn, (void *)ID_info[(GMT_LONG)ID[ij]].wesn, 4*sizeof(double));
 			else
 				memcpy ((void *)this_wesn, (void *)wesn, 4*sizeof(double));
-			np = get_flowline (x_smt[col], y_smt[row], t_smt, p, n_stages, sampling_int_in_km, k_step, forth_flag, this_wesn, &c);
+			np = get_flowline (x_smt[col], y_smt[row], t_smt, p, n_stages, sampling_int_in_km, k_step, (int)forth_flag, this_wesn, &c);
 			if (np == 0) continue;	/* No flowline inside this wesn */
 
 			/* STEP 3: Convolve this flowline with node shape and add to CVA grid */
@@ -542,7 +548,7 @@ int main (int argc, char **argv)
 			 * want the nearest distance from each node to the flowline. Later versions may
 			 * improve on this situation */
 
-			memset ((void *)processed_node, FALSE, nm*sizeof(BOOLEAN));	/* Fresh start for this flowline convolution */
+			memset ((void *)processed_node, FALSE, nm*sizeof(GMT_LONG));	/* Fresh start for this flowline convolution */
 			
 			if (keep_flowlines) {
 				flowline[n_nodes].node = (GMT_LONG *) GMT_memory (VNULL, (size_t)np, sizeof (GMT_LONG), GMT_program);
@@ -559,12 +565,10 @@ int main (int argc, char **argv)
 #ifdef DEBUG2
 			printf ("> %ld %ld %ld %ld %g\n", n_nodes, np, row, col, cva_contribution);
 #endif
-			for (m = 0, k = 1; m < np; m++) {	/* Store nearest node indeces only */
-				if (k == 11211) {
-					j = -9;
-				}
+			for (m = 0, k = 1; m < np; m++) {	/* Store nearest node indices only */
 				i = GMT_x_to_i (c[k], CVA_west_rad,  CVA_xinc_rad, offset, CVA_map.nx);	k++;
-				j = GMT_y_to_j (c[k], CVA_south_rad, CVA_yinc_rad, offset, CVA_map.ny);	k++;
+				yg = GMT_lat_swap (R2D*c[k], GMT_LATSWAP_O2G);	/* Convert back to geodetic */
+				j = GMT_y_to_j (yg, CVA_map.y_min, CVA_map.y_inc, offset, CVA_map.ny);	k++;
 				if (i < 0 || i >= CVA_map.nx || j < 0 || j >= CVA_map.ny)	/* Outside the CVA box, flag as outside */
 					node = OUTSIDE;
 				else								/* Inside the CVA box, assign node ij */
@@ -725,7 +729,7 @@ int main (int argc, char **argv)
 		}
 		else {	/* Must recreate flowlines */
 			k_step = 3;	/* FLowlines have (x,y,t) here */
-			forth_flag = get_PA + 10;	/* The 10 is used to limit the flowline calculation to only resample track within the rectangular box of interrest */
+			forth_flag = get_PA + 10;	/* The 10 is used to limit the flowline calculation to only resample track within the rectangular box of interest */
 			for (row = ij = n_flow = n_nodes = 0; row < zgrid.ny; row++) {	/* Loop over all input rows */
 				for (col = 0; col < zgrid.nx; col++, ij++) {	/* Loop over all input columns */
 					/* STEP 1: Determine if z exceeds threshold and if so assign age */
@@ -737,15 +741,16 @@ int main (int argc, char **argv)
 						memcpy ((void *)this_wesn, (void *)ID_info[(GMT_LONG)ID[ij]].wesn, 4*sizeof(double));
 					else
 						memcpy ((void *)this_wesn, (void *)wesn, 4*sizeof(double));
-					np = get_flowline (x_smt[col], y_smt[row], t_smt, p, n_stages, sampling_int_in_km, k_step, forth_flag, this_wesn, &c);
+					np = get_flowline (x_smt[col], y_smt[row], t_smt, p, n_stages, sampling_int_in_km, k_step, (int)forth_flag, this_wesn, &c);
 					if (np == 0) continue;	/* No flowline inside this wesn */
 			 		n_nodes++;
 					/* Fresh start for this flowline convolution */
 					CVA_max = 0.0;
 					this_pa = GMT_d_NaN;
-					for (m = 0, k = 1; m < np; m++) {	/* Store nearest node indeces only */
+					for (m = 0, k = 1; m < np; m++) {	/* Store nearest node indices only */
 						i = GMT_x_to_i (c[k], CVA_west_rad,  CVA_xinc_rad, offset, CVA_map.nx);	k++;
-						j = GMT_y_to_j (c[k], CVA_south_rad, CVA_yinc_rad, offset, CVA_map.ny);	k++;
+						yg = GMT_lat_swap (R2D*c[k], GMT_LATSWAP_O2G);	/* Convert back to geodetic */
+						j = GMT_y_to_j (yg, CVA_map.y_min, CVA_map.y_inc, offset, CVA_map.ny);	k++;
 						if (get_PA) pa_val = c[k++];
 						if (i < 0 || i >= CVA_map.nx || j < 0 || j >= CVA_map.ny) continue;	/* Outside the CVA box, flag as outside */
 						node = j * CVA_map.nx + i;
@@ -803,7 +808,7 @@ int main (int argc, char **argv)
 			if (gmtdefs.verbose) fprintf (stderr, "%s: Bootstrap try %ld\r", GMT_program, try);
 		
 			memset ((void *)CVA, 0, nm * sizeof (float));	/* Start with fresh grid */
-			for (m = 0; m < n_nodes; m++) {	/* Loop over all indeces */
+			for (m = 0; m < n_nodes; m++) {	/* Loop over all indices */
 				ij = (GMT_LONG)floor (rand() * scale);		/* Get a random integer in 0 to n_nodes-1 range */
 				memset ((void *)processed_node, FALSE, nm);		/* Fresh start for this flowline convolution */
 				zz = z[flowline[ij].ij];
@@ -864,8 +869,11 @@ int main (int argc, char **argv)
 GMT_LONG get_flowline (double xx, double yy, double tt, struct EULER *p, GMT_LONG n_stages, double d_km, GMT_LONG step, int flag, double wesn[], double **flow)
 {
 	GMT_LONG n_chunk, n_track, m, kx, ky, first, last, np;
-	double *c, *f;
+	double *c, *f, y_min, y_max;
 	
+	yy = D2R*GMT_lat_swap (R2D*yy, GMT_LATSWAP_G2O);		/* Convert to geocentric */
+	y_min = D2R*GMT_lat_swap (R2D*wesn[2], GMT_LATSWAP_G2O);	/* Convert to geocentric */
+	y_max = D2R*GMT_lat_swap (R2D*wesn[3], GMT_LATSWAP_G2O);	/* Convert to geocentric */
 	/* Get the flowline from this point back to time tt, restricted to the given wesn box */
 	n_chunk = spotter_forthtrack (&xx, &yy, &tt, (GMT_LONG)1, p, n_stages, d_km, 0.0, flag, wesn, &c);
 
@@ -874,7 +882,7 @@ GMT_LONG get_flowline (double xx, double yy, double tt, struct EULER *p, GMT_LON
 	/* Find the first point on the flowline inside the desired CVA region */
 			
 	for (m = 0, ky = 2, first = -1; m < n_track && first == -1; m++, ky += step) {	/* For each point along flowline */
-		if (c[ky] < wesn[2] || c[ky] > wesn[3]) continue;	/* Latitude outside region */
+		if (c[ky] < y_min || c[ky] > y_max) continue;		/* Latitude outside region */
 		kx = ky - 1;						/* Index for the x-coordinate */
 		while (c[kx] > wesn[1]) c[kx] -= TWO_PI;		/* Elaborate W/E test because of 360 periodicity */
 		while (c[kx] < wesn[0]) c[kx] += TWO_PI;
@@ -890,7 +898,7 @@ GMT_LONG get_flowline (double xx, double yy, double tt, struct EULER *p, GMT_LON
 	/* Here we know searching from the end will land inside the grid eventually so last can never exit as -1 */
 			
 	for (m = n_track - 1, ky = step * m + 2, last = -1; m >= 0 && last == -1; m--, ky -= step) {	/* For each point along flowline */
-		if (c[ky] < wesn[2] || c[ky] > wesn[3]) continue;	/* Latitude outside region */
+		if (c[ky] < y_min || c[ky] > y_max) continue;		/* Latitude outside region */
 		kx = ky - 1;						/* Index for the x-coordinate */
 		while (c[kx] > wesn[1]) c[kx] -= TWO_PI;		/* Elaborate W/E test because of 360 periodicity */
 		while (c[kx] < wesn[0]) c[kx] += TWO_PI;
@@ -913,7 +921,7 @@ GMT_LONG get_flowline (double xx, double yy, double tt, struct EULER *p, GMT_LON
 	return (np);
 }
 
-BOOLEAN set_age (double *t_smt, float *age, GMT_LONG node, double upper_age, BOOLEAN truncate, BOOLEAN no_ages)
+GMT_LONG set_age (double *t_smt, float *age, GMT_LONG node, double upper_age, GMT_LONG truncate, GMT_LONG no_ages)
 {
 	/* Returns the age of this node based on either a given seafloor age grid
 	 * or the upper age, truncated if necessary */
