@@ -1,11 +1,11 @@
 /*--------------------------------------------------------------------
- *	$Id: hotspotter.c,v 1.45 2010/01/05 01:15:49 guru Exp $
+ *	$Id: hotspotter.c,v 1.51 2011/03/05 21:24:29 guru Exp $
  *
- *   Copyright (c) 1999-2010 by P. Wessel
+ *   Copyright (c) 1999-2011 by P. Wessel
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; version 2 of the License.
+ *   the Free Software Foundation; version 2 or any later version.
  *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -123,17 +123,18 @@ int main (int argc, char **argv)
 	GMT_LONG n_fields, n_expected_fields;
 	GMT_LONG n_read = 0;		/* Number of records read */
 	GMT_LONG n_nodes;		/* Number of nodes in the output CVA grid */
+	GMT_LONG node_offset = 0;
 
 	/* Misc. counters */
 
 	GMT_LONG i, j, kx, ky, m, ii, jj, i0, j0, k0, dummy[4], fno;
 
-	BOOLEAN	error = FALSE;		/* TRUE when arguments are wrong */
-	BOOLEAN nofile = TRUE;		/* TRUE when data are to be read from stdin */
-	BOOLEAN truncate_ages = FALSE;	/* Truncate all seamounts ages > upper_age */
-	BOOLEAN finite = FALSE;		/* TRUE if stage pole file contains finite rotation poles instead */
-	BOOLEAN normalize = FALSE;	/* TRUE if we want CVA in percents */
-	BOOLEAN done;
+	GMT_LONG	error = FALSE;		/* TRUE when arguments are wrong */
+	GMT_LONG nofile = TRUE;		/* TRUE when data are to be read from stdin */
+	GMT_LONG truncate_ages = FALSE;	/* Truncate all seamounts ages > upper_age */
+	GMT_LONG finite = FALSE;		/* TRUE if stage pole file contains finite rotation poles instead */
+	GMT_LONG normalize = FALSE;	/* TRUE if we want CVA in percents */
+	GMT_LONG done;
 
 	float *CVA;			/* The CVA surface we seek to calculate */
 
@@ -159,6 +160,7 @@ int main (int argc, char **argv)
 	double offset;			/* 0.0 or 0.5, depending onf -F */
 	double half_dx, half_dy;	/* Half grid sizes or 0.0, depending on -F */
 	double *in;			/* GMT read array */
+	double south_c, north_c, yg;	/* Same but geocentric */
 
 	char *CVA_file = CNULL;		/* Output name of CVA grid */
 	char *euler_file = CNULL;	/* Input name of file with stage (Euler) rotations */
@@ -174,7 +176,7 @@ int main (int argc, char **argv)
 
 	/* ------------------- END OF DECLARATIONS ------------------------------------------------------------*/
 
-	argc = GMT_begin (argc, argv);			/* Initialize GMT environment */
+	argc = (int)GMT_begin (argc, argv);			/* Initialize GMT environment */
 
 	GMT_grd_init (&CVA_map, argc, argv, FALSE);	/* Initialize grid structure */
 
@@ -270,7 +272,8 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
-	GMT_check_lattice (&CVA_map.x_inc, &CVA_map.y_inc, &CVA_map.node_offset, NULL);
+	GMT_check_lattice (&CVA_map.x_inc, &CVA_map.y_inc, &node_offset, NULL);
+	CVA_map.node_offset = (int)node_offset;
 
 	if (!project_info.region_supplied) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR:  Must specify -R option\n", GMT_program);
@@ -298,6 +301,8 @@ int main (int argc, char **argv)
 
 	/* ------------------- END OF PROCESSING COMMAND LINE ARGUMENTS  --------------------------------------*/
 
+	GMT_lat_swap_init ();	/* Initialize auxiliary latitude machinery */
+
 	/* Load in the Euler stage poles */
 
 	n_stages = spotter_init (euler_file, &p, TRUE, finite, FALSE, &upper_age, gmtdefs.verbose);
@@ -319,8 +324,8 @@ int main (int argc, char **argv)
 		half_dx = half_dy = 0.0;
 	}
 
-	CVA_map.nx = irint ((CVA_map.x_max - CVA_map.x_min) / CVA_map.x_inc) + one_or_zero;
-	CVA_map.ny = irint ((CVA_map.y_max - CVA_map.y_min) / CVA_map.y_inc) + one_or_zero;
+	CVA_map.nx = (int)(irint ((CVA_map.x_max - CVA_map.x_min) / CVA_map.x_inc) + one_or_zero);
+	CVA_map.ny = (int)(irint ((CVA_map.y_max - CVA_map.y_min) / CVA_map.y_inc) + one_or_zero);
 	n_nodes = GMT_get_nm (CVA_map.nx, CVA_map.ny);
 	CVA = (float *) GMT_memory (VNULL, (size_t)n_nodes, sizeof(float), GMT_program);
 
@@ -330,6 +335,8 @@ int main (int argc, char **argv)
 	east   = CVA_map.x_max * D2R;
 	south  = CVA_map.y_min * D2R;
 	north  = CVA_map.y_max * D2R;
+	south_c  = GMT_lat_swap (CVA_map.y_min, GMT_LATSWAP_G2O) * D2R;	/* Convert to geocentric */ 
+	north_c  = GMT_lat_swap (CVA_map.y_max, GMT_LATSWAP_G2O) * D2R;	/* Convert to geocentric */ 
 	i_xinc_r = 1.0 / xinc_r;
 	i_yinc_r = 1.0 / yinc_r;
 
@@ -407,6 +414,8 @@ int main (int argc, char **argv)
 				continue;
 			}
 
+			in[GMT_Y] = GMT_lat_swap (in[GMT_Y], GMT_LATSWAP_G2O);	/* Convert to geocentric */
+
 			/* STEP 1: Read information about a single seamount from input record */
 
 			x_smt = in[0] * D2R;	/* Seamount positions in RADIANS */
@@ -456,7 +465,7 @@ int main (int argc, char **argv)
 
 				/* First throw out points outside specified grid region */
 
-				if (c[ky] < south || c[ky] > north) continue;	/* Latitude outside region */
+				if (c[ky] < south_c || c[ky] > north_c) continue;	/* Latitude outside region */
 
 				if (c[kx] > east) c[kx] -= TWO_PI;
 				while (c[kx] < west) c[kx] += TWO_PI;
@@ -464,8 +473,9 @@ int main (int argc, char **argv)
 
 				/* OK, this point is within our region, get node index */
 
+				yg = GMT_lat_swap (c[ky], GMT_LATSWAP_O2G);	/* Convert back to geodetic */
 				i = (GMT_LONG) floor (((c[kx] - west)  * i_xinc_r) + offset);
-				j = (GMT_LONG) floor (((north - c[ky]) * i_yinc_r) + offset);
+				j = (GMT_LONG) floor (((north - yg) * i_yinc_r) + offset);
 				node = j * CVA_map.nx + i;
 
 				if (!processed_node[node]) {	/* Have not added to the CVA at this node yet */
