@@ -1,11 +1,11 @@
 /*--------------------------------------------------------------------
- *	$Id: libspotter.c,v 1.58 2009/09/05 01:14:03 guru Exp $
+ *	$Id: libspotter.c,v 1.69 2011/03/05 21:24:29 guru Exp $
  *
- *   Copyright (c) 1999-2009 by P. Wessel
+ *   Copyright (c) 1999-2011 by P. Wessel
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; version 2 of the License.
+ *   the Free Software Foundation; version 2 or any later version.
  *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -43,6 +43,10 @@
  * flowline = TRUE when calling spotter_init and then:
  *	1. Draw FROM a hotspot TO a seamount: Use spotter_backtrack
  *	2. Draw FROM a seamount TO a hotspot (and beyond): Use spotter_forthtrack
+ *
+ * All coordinates herein are assumed to be GEOCENTRIC.  The main programs are
+ * respondible for coverting to/from geodetic data coordinates.  Rotation pole
+ * latitudes are usually implied to be geocentric.
  */
 
 #include "spotter.h"
@@ -52,17 +56,17 @@
 void matrix_to_pole (double T[3][3], double *plon, double *plat, double *w);
 void make_rot_matrix_sub (double E[3], double w, double R[3][3]);
 void reverse_rotation_order (struct EULER *p, GMT_LONG n);
-void xyw_to_struct_euler (struct EULER *p, double lon[], double lat[], double w[], GMT_LONG n, BOOLEAN stages, BOOLEAN convert);
+void xyw_to_struct_euler (struct EULER *p, double lon[], double lat[], double w[], GMT_LONG n, GMT_LONG stages, GMT_LONG convert);
 void set_I_matrix (double R[3][3]);
-BOOLEAN must_do_track (GMT_LONG sideA[], GMT_LONG sideB[]);
+GMT_LONG must_do_track (GMT_LONG sideA[], GMT_LONG sideB[]);
 void set_inout_sides (double x, double y, double wesn[], GMT_LONG sideXY[2]);
 void record_to_covar (struct EULER *e, double K[8]);
 void covar_of_transpose (double A[3][3], double C[3][3], double Ct[3][3]);
 void spotter_set_M (double lon, double lat, double M[3][3]);
 
-void spotter_finite_to_fwstages (struct EULER p[], GMT_LONG n, BOOLEAN finite_rates, BOOLEAN stage_rates);
+void spotter_finite_to_fwstages (struct EULER p[], GMT_LONG n, GMT_LONG finite_rates, GMT_LONG stage_rates);
 
-int spotter_init (char *file, struct EULER **p, int flowline, BOOLEAN finite_in, BOOLEAN finite_out, double *t_max, BOOLEAN verbose)
+int spotter_init (char *file, struct EULER **p, int flowline, GMT_LONG finite_in, GMT_LONG finite_out, double *t_max, GMT_LONG verbose)
 {
 	/* file;	Name of file with backward stage poles */
 	/* p;		Pointer to stage pole array */
@@ -88,7 +92,8 @@ int spotter_init (char *file, struct EULER **p, int flowline, BOOLEAN finite_in,
 	if (flowline) finite_out = TRUE;	/* Override so we get finite poles for conversion to forward stage poles at the end */
 
 	while (GMT_fgets (buffer, 512, fp) != NULL) { /* Expects lon lat t0 t1 ccw-angle */
-		if (buffer[0] == '#' || buffer[0] == '\n') continue;
+		GMT_chop (buffer);					/* Rid the world of CR/LF */
+		if (buffer[0] == '#' || buffer[0] == '\0') continue;
 
 		if (finite_in) {	/* The minimalist record formats is: lon lat t0 [t1] omega [covar] */
 			nf = sscanf (buffer, "%lf %lf %lf %lf %lf %lf %lf %lf %lf %lf %lf %lf %lf %lf",
@@ -114,7 +119,7 @@ int spotter_init (char *file, struct EULER **p, int flowline, BOOLEAN finite_in,
 
 
 		if (e[i].t_stop >= e[i].t_start) {
-			fprintf (stderr, "libspotter: ERROR: Stage rotation %ld has start time younger than stop time\n", i);
+			fprintf (stderr, "libspotter: ERROR: (%s) Stage rotation %ld has start time younger than stop time\n", file, i);
 			GMT_exit (EXIT_FAILURE);
 		}
 		e[i].duration = e[i].t_start - e[i].t_stop;
@@ -152,7 +157,7 @@ int spotter_init (char *file, struct EULER **p, int flowline, BOOLEAN finite_in,
 	/* Extend oldest stage pole back to t_max Ma */
 
 	if ((*t_max) > 0.0 && e[0].t_start < (*t_max)) {
-		if (verbose) fprintf (stderr, "libspotter: Extending oldest stage pole back to %g Ma\n", (*t_max));
+		if (verbose) fprintf (stderr, "libspotter: (%s) Extending oldest stage pole back to %g Ma\n", file, (*t_max));
 
 		e[0].t_start = (*t_max);
 		e[0].duration = e[0].t_start - e[0].t_stop;
@@ -161,7 +166,7 @@ int spotter_init (char *file, struct EULER **p, int flowline, BOOLEAN finite_in,
 		(*t_max) = MAX (e[0].t_start, e[n-1].t_start);
 	*p = e;
 
-	return (n);
+	return ((int)n);
 }
 
 /* Sort functions used to order the rotations */
@@ -215,7 +220,8 @@ int spotter_hotspot_init (char *file, struct HOTSPOT **p)
 	e = (struct HOTSPOT *) GMT_memory (VNULL, n_alloc, sizeof (struct HOTSPOT), "libspotter");
 
 	while (GMT_fgets (buffer, 512, fp) != NULL) {
-		if (buffer[0] == '#' || buffer[0] == '\n') continue;
+		GMT_chop (buffer);					/* Rid the world of CR/LF */
+		if (buffer[0] == '#' || buffer[0] == '\0') continue;
 		n = sscanf (buffer, "%lf %lf %s %d %lf %lf %lf %c %c %c %s", &e[i].lon, &e[i].lat, e[i].abbrev, &e[i].id, &e[i].radius, &e[i].t_off, &e[i].t_on, &create, &fit, &plot, e[i].name);
 		if (n == 3) e[i].id = i;	/* Minimal lon, lat, abbrev */
 		if (n >= 10) {
@@ -245,7 +251,7 @@ int spotter_hotspot_init (char *file, struct HOTSPOT **p)
  *	age t_zero.  For t_zero = 0 this means the hotspot
  */
 
-int spotter_backtrack (double xp[], double yp[], double tp[], GMT_LONG np, struct EULER p[], GMT_LONG ns, double d_km, double t_zero, BOOLEAN do_time, double wesn[], double **c)
+int spotter_backtrack (double xp[], double yp[], double tp[], GMT_LONG np, struct EULER p[], GMT_LONG ns, double d_km, double t_zero, GMT_LONG do_time, double wesn[], double **c)
 /* xp, yp;	Points, in RADIANS */
 /* tp;		Age of feature in m.y. */
 /* np;		# of points */
@@ -258,7 +264,7 @@ int spotter_backtrack (double xp[], double yp[], double tp[], GMT_LONG np, struc
 /* **c;		Pointer to return track vector */
 {
 	GMT_LONG i, j = 0, k, kk = 0, start_k = 0, nd = 1, nn, n_alloc = 2 * GMT_CHUNK, sideA[2], sideB[2];
-	BOOLEAN path, bend, go = FALSE, box_check;
+	GMT_LONG path, bend, go = FALSE, box_check;
 	double t, tt = 0.0, dt, d_lon, tlon, dd = 0.0, i_km = 0.0, xnew, xx, yy, next_x, next_y;
 	double s_lat, c_lat, s_lon, c_lon, cc, ss, cs, i_nd, *track = VNULL;
 
@@ -407,16 +413,16 @@ int spotter_backtrack (double xp[], double yp[], double tp[], GMT_LONG np, struc
 					track = (double *) GMT_memory ((void *)track, (size_t)n_alloc, sizeof (double), "libspotter");
 				}
 			}
-			track[start_k] = nn+1;
+			track[start_k] = (double)(nn+1);
 		}
 	}
 	if (path) {
 		track = (double *) GMT_memory ((void *)track, (size_t)kk, sizeof (double), "libspotter");
 		*c = track;
-		return (kk);
+		return ((int)kk);
 	}
 
-	return (np);
+	return ((int)np);
 }
 
 void set_inout_sides (double x, double y, double wesn[], GMT_LONG sideXY[2]) {
@@ -441,7 +447,7 @@ void set_inout_sides (double x, double y, double wesn[], GMT_LONG sideXY[2]) {
 		sideXY[0] = 0;
 }
 
-BOOLEAN must_do_track (GMT_LONG sideA[], GMT_LONG sideB[]) {
+GMT_LONG must_do_track (GMT_LONG sideA[], GMT_LONG sideB[]) {
 	GMT_LONG dx, dy;
 	/* First check if any of the two points are inside the box */
 	if (sideA[0] == 0 && sideA[1] == 0) return (TRUE);
@@ -459,7 +465,7 @@ BOOLEAN must_do_track (GMT_LONG sideA[], GMT_LONG sideB[]) {
  *	seamount of age tp.  For t_zero = 0 this means from the hotspot.
  */
 
-int spotter_forthtrack (double xp[], double yp[], double tp[], GMT_LONG np, struct EULER p[], GMT_LONG ns, double d_km, double t_zero, BOOLEAN do_time, double wesn[], double **c)
+int spotter_forthtrack (double xp[], double yp[], double tp[], GMT_LONG np, struct EULER p[], GMT_LONG ns, double d_km, double t_zero, GMT_LONG do_time, double wesn[], double **c)
 /* xp, yp;	Points, in RADIANS */
 /* tp;		Age of feature in m.y. */
 /* np;		# of points */
@@ -472,7 +478,7 @@ int spotter_forthtrack (double xp[], double yp[], double tp[], GMT_LONG np, stru
 /* c;		Pointer to return track vector */
 {
 	GMT_LONG i, j = 0, k, kk = 0, start_k = 0, nd = 1, nn, n_alloc = BIG_CHUNK, sideA[2], sideB[2];
-	BOOLEAN path, bend, go = FALSE, box_check;
+	GMT_LONG path, bend, go = FALSE, box_check;
 	double t, tt = 0.0, dt, d_lon, tlon, dd = 0.0, i_km = 0.0, xnew, xx, yy, *track = VNULL;
 	double s_lat, c_lat, s_lon, c_lon, cc, ss, cs, i_nd, next_x, next_y;
 
@@ -621,16 +627,16 @@ int spotter_forthtrack (double xp[], double yp[], double tp[], GMT_LONG np, stru
 					track = (double *) GMT_memory ((void *)track, (size_t)n_alloc, sizeof (double), "libspotter");
 				}
 			}
-			track[start_k] = nn+1;
+			track[start_k] = (double)(nn+1);
 		}
 	}
 	if (path) {
 		track = (double *) GMT_memory ((void *)track, (size_t)kk, sizeof (double), "libspotter");
 		*c = track;
-		return (kk);
+		return ((int)kk);
 	}
 
-	return (np);
+	return ((int)np);
 }
 
 /* Converts a set of total reconstruction poles to forward stage poles for flowlines
@@ -638,7 +644,7 @@ int spotter_forthtrack (double xp[], double yp[], double tp[], GMT_LONG np, stru
  * Based partly on Cox and Hart, 1986
  */
 
-void spotter_finite_to_fwstages (struct EULER p[], GMT_LONG n, BOOLEAN finite_rates, BOOLEAN stage_rates)
+void spotter_finite_to_fwstages (struct EULER p[], GMT_LONG n, GMT_LONG finite_rates, GMT_LONG stage_rates)
 {
 	/* Convert finite rotations to forward stage rotations for flowlines */
 	/* p[]		: Array of structure elements with rotation parameters
@@ -686,7 +692,7 @@ void spotter_finite_to_fwstages (struct EULER p[], GMT_LONG n, BOOLEAN finite_ra
 	reverse_rotation_order (p, n);	/* Flip order since stages go from oldest to youngest */
 }
 
-void spotter_finite_to_stages (struct EULER p[], GMT_LONG n, BOOLEAN finite_rates, BOOLEAN stage_rates)
+void spotter_finite_to_stages (struct EULER p[], GMT_LONG n, GMT_LONG finite_rates, GMT_LONG stage_rates)
 {
 	/* Convert finite rotations to backwards stage rotations for backtracking */
 	/* p[]		: Array of structure elements with rotation parameters
@@ -730,7 +736,7 @@ void spotter_finite_to_stages (struct EULER p[], GMT_LONG n, BOOLEAN finite_rate
 	reverse_rotation_order (p, n);	/* Flip order since stages go from oldest to youngest */
 }
 
-void spotter_stages_to_finite (struct EULER p[], GMT_LONG n, BOOLEAN finite_rates, BOOLEAN stage_rates)
+void spotter_stages_to_finite (struct EULER p[], GMT_LONG n, GMT_LONG finite_rates, GMT_LONG stage_rates)
 {
 	/* Convert stage rotations to finite rotations */
 	/* p[]		: Array of structure elements with rotation parameters
@@ -788,7 +794,7 @@ void spotter_add_rotations (struct EULER a[], GMT_LONG n_a, struct EULER b[], GM
 	double *t, t_min, t_max, Ra[3][3], Rb[3][3], Rab[3][3], lon, lat, w, sign_a, sign_b;
 	double tmp[3][3], RaT[3][3], Ca[3][3], Cb[3][3];
 	GMT_LONG i, j, k, n_k = 0;
-	BOOLEAN a_ok = TRUE, b_ok = TRUE;
+	GMT_LONG a_ok = TRUE, b_ok = TRUE;
 
 	sign_a = (n_a > 0) ? +1.0 : -1.0;
 	sign_b = (n_b > 0) ? +1.0 : -1.0;
@@ -809,9 +815,9 @@ void spotter_add_rotations (struct EULER a[], GMT_LONG n_a, struct EULER b[], GM
 	t_min = MAX (a[n_a-1].t_stop, b[n_b-1].t_stop);
 	t[n_k++] = t_max;
 	i = j = 0;
-	while (i < n_a && a[i].t_stop > t[0]) i++;
+	while (i < n_a && a[i].t_stop >= t[0]) i++;
 	if (i == (n_a - 1)) a_ok = FALSE;
-	while (j < n_b && b[j].t_stop > t[0]) j++;
+	while (j < n_b && b[j].t_stop >= t[0]) j++;
 	if (j == (n_b - 1)) b_ok = FALSE;
 	while (a_ok || b_ok) {
 		if (a_ok && !b_ok) {		/* Only a left */
@@ -1110,7 +1116,7 @@ void reverse_rotation_order (struct EULER *p, GMT_LONG n)
 	}
 }
 
-void xyw_to_struct_euler (struct EULER *p, double lon[], double lat[], double w[], GMT_LONG n, BOOLEAN stages, BOOLEAN convert)
+void xyw_to_struct_euler (struct EULER *p, double lon[], double lat[], double w[], GMT_LONG n, GMT_LONG stages, GMT_LONG convert)
 {	/* Reload the EULER structure from the lon, lat, w arrays.
 	 * stages is TRUE if we are loading stage rotations (FALSE is finite poles).
 	 * convert is TRUE if we must change angles to rates or vice versa */
@@ -1137,7 +1143,7 @@ void set_I_matrix (double R[3][3])
 	R[0][0] = R[1][1] = R[2][2] = 1.0;
 }
 
-int spotter_conf_ellipse (double lon, double lat, double t, struct EULER *p, GMT_LONG np, char flag, BOOLEAN forward, double out[])
+int spotter_conf_ellipse (double lon, double lat, double t, struct EULER *p, GMT_LONG np, char flag, GMT_LONG forward, double out[])
 {
 	/* Given time and rotation parameters, calculate uncertainty in the
 	 * reconstructed point in the form of a confidence ellipse.  To follow
@@ -1149,6 +1155,8 @@ int spotter_conf_ellipse (double lon, double lat, double t, struct EULER *p, GMT
 	 * that rotation, the covariance matrix is R * cov(r) * R^t.
 	 * forward is TRUE if we rotate from past to now and FALSE if we
 	 * rotate from now to the past (e.g., move a hotspot up the chain).
+	 * 2011-02-23 PW: Multiply axes by two to get major & minor (we reported
+	 * SEMI-axes previously; psxy had same problem and now expects full axes)
 	 */
 
 	GMT_LONG matrix_dim = 3L;
@@ -1215,8 +1223,8 @@ int spotter_conf_ellipse (double lon, double lat, double t, struct EULER *p, GMT
 	y_comp = GMT_dot3v (EigenVector, y_in_plane);	/* y-component of major axis in tangent plane */
 	out[kk] = fmod (360.0 + (90.0 - atan2d (y_comp, x_comp)), 360.0);	/* Azimuth of major axis */
 	if (out[kk] > 180.0) out[kk] -= 180.0;
-	out[++kk] = sqrt (EigenValue[0]) * EQ_RAD * SQRT_CHI2;
-	out[++kk] = sqrt (EigenValue[1]) * EQ_RAD * SQRT_CHI2;
+	out[++kk] = 2.0 * sqrt (EigenValue[0]) * EQ_RAD * SQRT_CHI2;	/* Full major axis (not semi) */
+	out[++kk] = 2.0 * sqrt (EigenValue[1]) * EQ_RAD * SQRT_CHI2;	/* Full minor axis (not semi) */
 
 	return (0);
 }
