@@ -1,11 +1,11 @@
 /*--------------------------------------------------------------------
- *	$Id: originator.c,v 1.53 2010/01/05 01:15:49 guru Exp $
+ *	$Id: originator.c,v 1.61 2011/03/06 02:12:42 guru Exp $
  *
- *   Copyright (c) 2000-2010 by P. Wessel
+ *   Copyright (c) 2000-2011 by P. Wessel
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; version 2 of the License.
+ *   the Free Software Foundation; version 2 or any later version.
  *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -98,8 +98,8 @@ struct HOTSPOT_ORIGINATOR {
 	double np_time;		/* Predicted time at nearest point */
 	double np_lon;		/* Longitude of nearest point on the current flowline */
 	double np_lat;		/* Latitude  of nearest point on the current flowline */
-	int nearest;		/* Point id of current flowline node points closest to hotspot */
-	int stage;		/* Stage to which seamount belongs */
+	GMT_LONG nearest;	/* Point id of current flowline node points closest to hotspot */
+	GMT_LONG stage;		/* Stage to which seamount belongs */
 };
 
 int main (int argc, char **argv)
@@ -108,14 +108,14 @@ int main (int argc, char **argv)
 	GMT_LONG n_fields, n_expected_fields, n_best_hs = 1, tdz_output = 0, n_out = 0;
 	GMT_LONG  i, j, k, n, kk, ns, nh, nc, np, n_read, n_skipped = 0;
 
-	BOOLEAN	error = FALSE, done, nofile = TRUE, truncate_ages = FALSE, first = TRUE, better, use_ID = FALSE;
-	BOOLEAN finite = FALSE, degree = FALSE;		/* fitite is TRUE if stage pole file contains finite rotation poles instead */
+	GMT_LONG	error = FALSE, done, nofile = TRUE, truncate_ages = FALSE, first = TRUE, better, use_ID = FALSE;
+	GMT_LONG finite = FALSE, degree = FALSE;		/* fitite is TRUE if stage pole file contains finite rotation poles instead */
 
 	double x_smt, y_smt, z_smt, r_smt, t_smt, *c, *in, d_km = 5.0, upper_age = 180.0, dist, out[5];
 	double max_dist = 1.0e100, hx_dist, hx_dist_km, dist_NA, dist_NX, del_dist, dt = 0.0, A[3], H[3], N[3], X[3];
-	double dlon, fix_r, fix_t;
+	double dlon, fix_r, fix_t, yg, yc;
 
-	char *hsfile = CNULL, *efile = CNULL, age[GMT_TEXT_LEN], *not_used = NULL;
+	char *hsfile = CNULL, *efile = CNULL, age[GMT_TEXT_LEN], buffer[BUFSIZ], *not_used = NULL;
 
 	FILE *fp;
 
@@ -125,7 +125,7 @@ int main (int argc, char **argv)
 
 	int comp_hs (const void *p1, const void *p2);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	GMT_io.in_col_type[0] = GMT_io.out_col_type[0] = GMT_IS_LON;
 	GMT_io.in_col_type[1] = GMT_io.out_col_type[1] = GMT_IS_LAT;
@@ -279,6 +279,8 @@ int main (int argc, char **argv)
 
 	if (error) exit (EXIT_FAILURE);
 
+	GMT_lat_swap_init ();	/* Initialize auxiliary latitude machinery */
+
 	nh = spotter_hotspot_init (hsfile, &orig_hotspot);
 	if (n_best_hs <= 0 || n_best_hs > nh) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -S:  Give value between 1 and %ld\n", GMT_program, nh);
@@ -326,7 +328,7 @@ int main (int argc, char **argv)
 		if (GMT_io.io_header[GMT_IN]) {
 			for (i = 0; i < GMT_io.n_header_recs; i++) {
 				not_used = GMT_fgets (GMT_io.segment_header, BUFSIZ, fp);
-				if (first && !GMT_io.binary[GMT_OUT] && GMT_io.io_header[GMT_OUT]) fprintf (GMT_stdout, "%s", GMT_io.segment_header);
+				if (first && !GMT_io.binary[GMT_OUT] && GMT_io.io_header[GMT_OUT]) GMT_fputs (GMT_io.segment_header, GMT_stdout);
 				n_read++;
 			}
 			first = FALSE;
@@ -345,6 +347,7 @@ int main (int argc, char **argv)
 				fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld (skipped)\n", GMT_program, n_fields, n_expected_fields, n_read);
 				continue;
 			}
+			
 			if (n_input == 3) {	/* set constant r,t values */
 				in[3] = fix_r;
 				in[4] = fix_t;
@@ -368,8 +371,9 @@ int main (int argc, char **argv)
 				n_skipped++;
 				continue;
 			}
+						
 			x_smt = in[0] * D2R;
-			y_smt = in[1] * D2R;
+			y_smt = GMT_lat_swap (in[GMT_Y], GMT_LATSWAP_G2O) * D2R;	/* Convert to geocentric */
 			z_smt = in[2];
 			r_smt = in[3];
 
@@ -382,8 +386,9 @@ int main (int argc, char **argv)
 			memcpy ((void *)hot, (void *)hotspot, nh * sizeof (struct HOTSPOT_ORIGINATOR));
 
 			for (kk = 0, k = 1; kk < np; kk++, k += 3) {	/* For this seamounts track */
+				yg = GMT_lat_swap (R2D*c[k+1], GMT_LATSWAP_O2G);	/* Convert back to geodetic */
 				for (j = 0; j < nh; j++) {	/* For all hotspots */
-					dist = GMT_great_circle_dist (hot[j].h->lon, hot[j].h->lat, R2D * c[k], R2D * c[k+1]);
+					dist = GMT_great_circle_dist (hot[j].h->lon, hot[j].h->lat, R2D * c[k], yg);
 					if (!degree) dist *= KM_PR_DEG;
 					if (dist < hot[j].np_dist) {
 						hot[j].np_dist = dist;
@@ -393,7 +398,8 @@ int main (int argc, char **argv)
 			}
 			for (j = 0; j < nh; j++) {
 
-				GMT_geo_to_cart (hot[j].h->lat, hot[j].h->lon, H, TRUE);	/* 3-D Cartesian vector of this hotspot */
+				yc = GMT_lat_swap (hot[j].h->lat, GMT_LATSWAP_G2O);	/* Convert to geocentric */
+				GMT_geo_to_cart (yc, hot[j].h->lon, H, TRUE);	/* 3-D Cartesian vector of this hotspot */
 
 				/* Fine-tune the nearest point by considering intermediate points along greatcircle between knot points */
 
@@ -435,7 +441,7 @@ int main (int argc, char **argv)
 				}
 				else {	/* Just use node coordinates */
 					hot[j].np_lon  = c[k] * R2D;	/* Longitude of the flowline's closest approach to hotspot */
-					hot[j].np_lat  = c[k+1] * R2D;	/* Latitude  of the flowline's closest approach to hotspot */
+					hot[j].np_lat  = GMT_lat_swap (c[k+1] * R2D, GMT_LATSWAP_O2G);	/* Geodetic latitude  of the flowline's closest approach to hotspot */
 					hot[j].np_time = c[k+2];	/* Predicted time at the flowline's closest approach to hotspot */
 				}
 
@@ -483,12 +489,19 @@ int main (int argc, char **argv)
 						strcpy (age, "NaN");
 					else
 						sprintf (age, "%g", t_smt);
-					fprintf (GMT_stdout, "%g\t%g\t%g\t%g\t%s", in[x], in[y], z_smt, r_smt, age);
+					sprintf (buffer, "%g\t%g\t%g\t%g\t%s", in[x], in[y], z_smt, r_smt, age);
+					GMT_fputs (buffer, GMT_stdout);
 					if (use_ID)
-						for (j = 0; j < n_max_spots; j++) fprintf (GMT_stdout, "\t%d\t%d\t%g\t%g", hot[j].h->id, hot[j].stage, hot[j].np_time, hot[j].np_dist);
+						for (j = 0; j < n_max_spots; j++) {
+							sprintf (buffer, "\t%d\t%ld\t%g\t%g", hot[j].h->id, hot[j].stage, hot[j].np_time, hot[j].np_dist);
+							GMT_fputs (buffer, GMT_stdout);
+						}
 					else
-						for (j = 0; j < n_max_spots; j++) fprintf (GMT_stdout, "\t%s\t%d\t%g\t%g", hot[j].h->abbrev, hot[j].stage, hot[j].np_time, hot[j].np_dist);
-					fprintf (GMT_stdout, "\n");
+						for (j = 0; j < n_max_spots; j++) {
+							sprintf (buffer, "\t%s\t%ld\t%g\t%g", hot[j].h->abbrev, hot[j].stage, hot[j].np_time, hot[j].np_dist);
+							GMT_fputs (buffer, GMT_stdout);
+						}
+					GMT_fputs ("\n", GMT_stdout);
 				}
 			}
 
