@@ -1,11 +1,11 @@
 /*--------------------------------------------------------------------
- *	$Id: rotconverter.c,v 1.29 2010/01/05 01:15:49 guru Exp $
+ *	$Id: rotconverter.c,v 1.35 2011/03/05 21:24:29 guru Exp $
  *
- *   Copyright (c) 1999-2010 by P. Wessel
+ *   Copyright (c) 1999-2011 by P. Wessel
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; version 2 of the License.
+ *   the Free Software Foundation; version 2 or any later version.
  *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -73,18 +73,18 @@ int main (int argc, char **argv)
 	GMT_LONG last_sign, n_slash;
 	GMT_LONG rate_or_rad = 0;		/* Default unit is degrees/My */
 
-	BOOLEAN error = FALSE;		/* Set to TRUE if arguments are inconsistent */
-	BOOLEAN geodetic = TRUE;	/* Want 0-360 range */
-	BOOLEAN finite_in = TRUE;	/* Default format is finite rotation poles for both input and output */
-	BOOLEAN finite_out = TRUE;	/* FALSE gives stage poles */
-	BOOLEAN first = TRUE;		/* TRUE for first input file */
-	BOOLEAN south = FALSE;		/* TRUE if we want to report poles in southern hemisphere */
-	BOOLEAN north = FALSE;		/* TRUE if we want to report poles in northern hemisphere */
-	BOOLEAN online_rot = FALSE;	/* TRUE if we gave a rotation on the commandline rather than file name */
-	BOOLEAN no_time = FALSE;	/* TRUE if we gave a rotation on the commandline as lon/lat/angle only */
-	BOOLEAN header = FALSE;		/* TRUE to write out a header record */
-	BOOLEAN transpose = FALSE;	/* TRUE if we want to change the sign of the final rotation */
-	BOOLEAN reduce_angle = FALSE;	/* TRUE to scale stage pole angles by reduce_fact */
+	GMT_LONG error = FALSE;		/* Set to TRUE if arguments are inconsistent */
+	GMT_LONG geodetic = TRUE;	/* Want 0-360 range */
+	GMT_LONG finite_in = TRUE;	/* Default format is finite rotation poles for both input and output */
+	GMT_LONG finite_out = TRUE;	/* FALSE gives stage poles */
+	GMT_LONG first = TRUE;		/* TRUE for first input file */
+	GMT_LONG south = FALSE;		/* TRUE if we want to report poles in southern hemisphere */
+	GMT_LONG north = FALSE;		/* TRUE if we want to report poles in northern hemisphere */
+	GMT_LONG online_rot = FALSE;	/* TRUE if we gave a rotation on the commandline rather than file name */
+	GMT_LONG no_time = FALSE;	/* TRUE if we gave a rotation on the commandline as lon/lat/angle only */
+	GMT_LONG header = FALSE;		/* TRUE to write out a header record */
+	GMT_LONG transpose = FALSE;	/* TRUE if we want to change the sign of the final rotation */
+	GMT_LONG reduce_angle = FALSE;	/* TRUE to scale stage pole angles by reduce_fact */
 
 	double zero = 0.0;		/* Needed to pass to spotter_init */
 	double lon, lat;		/* Pole location for online rotations */
@@ -96,7 +96,7 @@ int main (int argc, char **argv)
 	char *end_text[2] = {"tend(My)", "aend(deg)"};
 	char *time_text[2] = {"ttime(My)", "tangle(deg)"};
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-' && argv[i][1]) {
@@ -172,8 +172,11 @@ int main (int argc, char **argv)
 				case 'T':	/* Transpose the final result (i.e., change sign of rotation) */
 					transpose = TRUE;
 					break;
-
-				default:
+					
+				case '0': case '1': case '2': case '3': case '4': case '5': case '6':
+					case '7': case '8': case '9': case '.':
+					break;	/* Probably a rotation lon/lat/angle with negative longitude */
+				default:					
 					error = TRUE;
 					GMT_default_error (argv[i][1]);
 					break;
@@ -221,13 +224,15 @@ int main (int argc, char **argv)
 		if (!strncmp (argv[i], "-E", (size_t)2)) continue;
 		if (!strncmp (argv[i], "-V", (size_t)2)) continue;
 		if (!strncmp (argv[i], "-F", (size_t)2)) continue;
+		if (!strncmp (argv[i], "-S", (size_t)2)) continue;
+		if (!strncmp (argv[i], "-N", (size_t)2)) continue;
 		if (!strncmp (argv[i], "-T", (size_t)2)) continue;
 
-		if (argv[i][0] == '-') {
+		if (argv[i][0] == '-' && argv[i][1] == '\0') {
 			last_sign = -1;
 			continue;
 		}
-		if (argv[i][0] == '+') {
+		if (argv[i][0] == '+' && argv[i][1] == '\0') {
 			last_sign = +1;
 			continue;
 		}
