@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: surface.c,v 1.70 2010/01/09 03:29:28 guru Exp $
+ *	$Id: surface.c,v 1.77 2011/03/05 21:24:28 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -88,45 +88,45 @@
 
 struct SURFACE_CTRL {
 	struct A {	/* -A<aspect_ratio> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double value;
 	} A;
 	struct C {	/* -C<converge_limit> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double value;
 	} C;
 	struct G {	/* -G<file> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} G;
 	struct I {	/* -Idx[/dy] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double xinc, yinc;
 	} I;
 	struct L {	/* -Ll|u<limit> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *low, *high;
 		double min, max;
 		GMT_LONG lmode, hmode;
 	} L;
 	struct N {	/* -N<max_iterations> */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG value;
 	} N;
 	struct Q {	/* -Q */
-		BOOLEAN active;
+		GMT_LONG active;
 	} Q;
 	struct S {	/* -S<radius>[m|c] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double radius;
 		char unit;
 	} S;
 	struct T {	/* -T<tension>[i][b] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double b_tension, i_tension;
 	} T;
 	struct Z {	/* -Z<over_relaxation_parameter> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double value;
 	} Z;
 };
@@ -178,7 +178,7 @@ struct SURFACE_INFO {	/* Control structure for surface setup and execution */
 	GMT_LONG total_iterations;
 	GMT_LONG grid_east;
 	GMT_LONG offset[25][12];	/* Indices of 12 nearby points in 25 cases of edge conditions  */
-	BOOLEAN constrained;		/* TRUE if set_low or set_high is TRUE */
+	GMT_LONG constrained;		/* TRUE if set_low or set_high is TRUE */
 	float *lower, *upper;		/* arrays for minmax values, if set */
 	float *u;			/* Pointer to grid array */
 	double low_limit, high_limit;	/* Constrains on range of solution */
@@ -216,7 +216,7 @@ int compare_points (const void *point_1v, const void *point_2v);
 GMT_LONG gcd_euclid (GMT_LONG a, GMT_LONG b);	/* Finds the greatest common divisor  */
 GMT_LONG get_prime_factors (GMT_LONG n, GMT_LONG *f);
 GMT_LONG iterate (struct SURFACE_INFO *C, GMT_LONG mode);
-void load_constraints (struct SURFACE_INFO *C, BOOLEAN transform);
+void load_constraints (struct SURFACE_INFO *C, GMT_LONG transform);
 
 int main (int argc, char **argv)
 {
@@ -248,7 +248,7 @@ int main (int argc, char **argv)
 	void load_parameters (struct SURFACE_INFO *C, struct SURFACE_CTRL *Ctrl);
 	void *New_surface_Ctrl (), Free_surface_Ctrl (struct SURFACE_CTRL *C);
 	
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct SURFACE_CTRL *)New_surface_Ctrl ();	/* Allocate and initialize a new control structure */
 	
@@ -1041,27 +1041,34 @@ void new_initialize_grid (struct SURFACE_INFO *C)
 void read_data (FILE *fp_in, struct SURFACE_INFO *C)
 {
 	GMT_LONG	i, j, k, kmax = 0, kmin = 0;
-	GMT_LONG n_fields, n_expected_fields;
-	double	*in, zmin = DBL_MAX, zmax = -DBL_MAX;
+	GMT_LONG n_read, n_fields, n_expected_fields;
+	double	*in, zmin = DBL_MAX, zmax = -DBL_MAX, wesn_lim[4];
 	char	buffer[BUFSIZ], *not_used = NULL;
 
 	C->data = (struct SURFACE_DATA *) GMT_memory (VNULL, (size_t)C->n_alloc, sizeof(struct SURFACE_DATA), GMT_program);
 
 	/* Read in xyz data and computes index no and store it in a structure */
 
-	k = 0;
+	n_read = k = 0;
 	C->z_mean = 0;
+	/* Initially allow points to be within 1 grid spacing of the grid */
+	wesn_lim[0] = C->h.x_min - C->grid_xinc;	wesn_lim[1] = C->h.x_max + C->grid_xinc;
+	wesn_lim[2] = C->h.y_min - C->grid_yinc;	wesn_lim[3] = C->h.y_max + C->grid_yinc;
+	
 	n_expected_fields = (GMT_io.binary[GMT_IN]) ? GMT_io.ncol[GMT_IN] : 3;
 	if (!GMT_io.binary[GMT_IN] && GMT_io.io_header[GMT_IN]) for (i = 0; i < GMT_io.n_header_recs; i++) not_used = GMT_fgets (buffer, BUFSIZ, fp_in);
 
 	while ((n_fields = GMT_input (fp_in, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
 
+		n_read++;
 		if (GMT_io.status & GMT_IO_MISMATCH) {
-			fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields, n_expected_fields, k);
-			exit (EXIT_FAILURE);
+			fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld (skipped)\n", GMT_program, n_fields, n_expected_fields, n_read);
+			continue;
 		}
 
 		if (GMT_is_dnan (in[GMT_Z])) continue;
+		if (GMT_y_is_outside (in[GMT_Y], wesn_lim[2], wesn_lim[3])) continue;	/* Outside y-range */
+		if (GMT_x_is_outside (&in[GMT_X], wesn_lim[0], wesn_lim[1])) continue;	/* Outside x-range (or longitude) */
 
 		i = (GMT_LONG)floor(((in[GMT_X]-C->h.x_min)*C->r_grid_xinc) + 0.5);
 		if (i < 0 || i >= C->block_nx) continue;
@@ -1666,7 +1673,7 @@ GMT_LONG rescale_z_values (struct SURFACE_INFO *C)
 	return (0);
 }
 
-void load_constraints (struct SURFACE_INFO *C, BOOLEAN transform)
+void load_constraints (struct SURFACE_INFO *C, GMT_LONG transform)
 {
 	GMT_LONG i, j, ij;
 	double yy;
@@ -1778,7 +1785,7 @@ double guess_surface_time (GMT_LONG factors[], GMT_LONG nx, GMT_LONG ny)
 		nxg = nx;
 		nyg = ny;
 	}
-	length = MAX(nxg, nyg);
+	length = (double)MAX(nxg, nyg);
 	t_sum = nxg * (nyg * length);	/* Make it double at each multiply  */
 
 	/* Are there more grid cycles ?  */
@@ -1788,7 +1795,7 @@ double guess_surface_time (GMT_LONG factors[], GMT_LONG nx, GMT_LONG ny)
 		gcd /= factor;
 		nxg *= factor;
 		nyg *= factor;
-		length = factor;
+		length = (double)factor;
 		t_sum += nxg * (nyg * length);
 	}
 	return(t_sum);
@@ -2024,7 +2031,7 @@ void load_parameters (struct SURFACE_INFO *C, struct SURFACE_CTRL *Ctrl)
 {
 	if (Ctrl->S.active) {
 		if (Ctrl->S.unit == 'm' || Ctrl->S.unit == 'M') Ctrl->S.radius /= 60.0;
-		if (Ctrl->S.unit == 'c' || Ctrl->S.unit == 'M') Ctrl->S.radius /= 3600.0;
+		if (Ctrl->S.unit == 'c' || Ctrl->S.unit == 'c') Ctrl->S.radius /= 3600.0;
 	}
 	C->radius = Ctrl->S.radius;
 	C->h.x_inc = Ctrl->I.xinc;
