@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: trend1d.c,v 1.46 2010/01/05 01:15:47 guru Exp $
+ *	$Id: trend1d.c,v 1.51 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -111,25 +111,25 @@
 
 struct TREND1D_CTRL {
 	struct C {	/* -C<condition_#> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double value;
 	} C;
 	struct F {	/* -F<xymrw> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char col[TREND1D_N_OUTPUT_CHOICES];	/* Character codes for desired output in the right order */
 	} F;
 	struct I {	/* -I[<confidence>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double value;
 	} I;
 	struct N {	/* -N[f]<n_model>[r] */
-		BOOLEAN active;
-		BOOLEAN robust;
+		GMT_LONG active;
+		GMT_LONG robust;
 		GMT_LONG mode;
 		GMT_LONG value;
 	} N;
 	struct W {	/* -W */
-		BOOLEAN active;
+		GMT_LONG active;
 	} W;
 };
 
@@ -148,7 +148,7 @@ int main (int argc, char **argv)
 {
 	GMT_LONG i, j, k,n_outputs, n_model, significant, rank, n_req;
 	GMT_LONG  n_data, np;
-	BOOLEAN	error = FALSE, weighted_output = FALSE;
+	GMT_LONG	error = FALSE, weighted_output = FALSE;
 
 	double	*gtg, *v, *gtd, *lambda, *workb, *workz, *c_model, *o_model, *w_model, *work;	/* Arrays  */
 	double	xmin, xmax, c_chisq, o_chisq, w_chisq, scale = 1.0, prob;
@@ -174,7 +174,7 @@ int main (int argc, char **argv)
 	void GMT_cheb_to_pol (double c[], GMT_LONG n, double a, double b);
 	void *New_trend1d_Ctrl (), Free_trend1d_Ctrl (struct TREND1D_CTRL *C);
 	
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct TREND1D_CTRL *)New_trend1d_Ctrl ();	/* Allocate and initialize a new control structure */
 
@@ -190,7 +190,7 @@ int main (int argc, char **argv)
 				case 'b':
 				case 'f':
 				case '\0':
-					error += GMT_parse_common_options (argv[i], 0, 0, 0, 0);
+					error += (GMT_LONG)GMT_parse_common_options (argv[i], 0, 0, 0, 0);
 					break;
 
 				/* Supplemental parameters */
@@ -481,7 +481,7 @@ int main (int argc, char **argv)
 void read_data (struct TREND1D_DATA **data, GMT_LONG *n_data, double *xmin, double *xmax, GMT_LONG weighted_input, double **work, FILE *fp)
 {
 	GMT_LONG	n_alloc = GMT_CHUNK, n_expected_fields, n_fields;
-	GMT_LONG i;
+	GMT_LONG i, n_read;
 	double	*in;
 	char	buffer[BUFSIZ], *not_used = NULL;
 
@@ -494,14 +494,15 @@ void read_data (struct TREND1D_DATA **data, GMT_LONG *n_data, double *xmin, doub
 	(*data) = (struct TREND1D_DATA *) GMT_memory (VNULL, (size_t)n_alloc, sizeof(struct TREND1D_DATA), GMT_program);
 
 	if (GMT_io.io_header[GMT_IN]) for (i = 0; i < GMT_io.n_header_recs; i++) not_used = GMT_fgets (buffer, BUFSIZ, fp);
-	i = 0;
+	i = n_read = 0;
 	n_expected_fields = (GMT_io.binary[GMT_IN]) ? GMT_io.ncol[GMT_IN] : 2 + weighted_input;
 
 	while ((n_fields = GMT_input (fp, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {
 
+		n_read++;
 		if (GMT_io.status & GMT_IO_MISMATCH) {
-			fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields, n_expected_fields, i);
-			exit (EXIT_FAILURE);
+			fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld (skipped)\n", GMT_program, n_fields, n_expected_fields, n_read);
+			continue;
 		}
 
 		(*data)[i].x = in[GMT_X];
