@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: trend2d.c,v 1.47 2010/01/05 01:15:47 guru Exp $
+ *	$Id: trend2d.c,v 1.52 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -71,24 +71,24 @@
 
 struct TREND2D_CTRL {
 	struct C {	/* -C<condition_#> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double value;
 	} C;
 	struct F {	/* -F<xymrw> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char col[TREND2D_N_OUTPUT_CHOICES];	/* Character codes for desired output in the right order */
 	} F;
 	struct I {	/* -I[<confidence>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double value;
 	} I;
 	struct N {	/* -N<n_model>[r] */
-		BOOLEAN active;
-		BOOLEAN robust;
+		GMT_LONG active;
+		GMT_LONG robust;
 		GMT_LONG value;
 	} N;
 	struct W {	/* -W */
-		BOOLEAN active;
+		GMT_LONG active;
 	} W;
 };
 
@@ -106,7 +106,7 @@ int main(int argc, char **argv)
 	GMT_LONG	i, j, k, n_outputs, n_model, significant, rank, n_req, np;
 	GMT_LONG	n_data;
 
-	BOOLEAN	error = FALSE, weighted_output = FALSE;
+	GMT_LONG	error = FALSE, weighted_output = FALSE;
 
 	double	*gtg, *v, *gtd, *lambda, *workb, *workz, *c_model, *o_model, *w_model, *work;	/* Arrays  */
 	double	xmin, xmax, ymin, ymax, c_chisq, o_chisq, w_chisq, scale = 1.0, prob;
@@ -132,7 +132,7 @@ int main(int argc, char **argv)
 	void solve_system(double *gtg, double *gtd, double *model, GMT_LONG n_model, GMT_LONG mp, double *lambda, double *v, double *b, double *z, double c_no, GMT_LONG *ir);
 	void *New_trend2d_Ctrl (), Free_trend2d_Ctrl (struct TREND2D_CTRL *C);
 	
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct TREND2D_CTRL *)New_trend2d_Ctrl ();	/* Allocate and initialize a new control structure */
 
@@ -150,7 +150,7 @@ int main(int argc, char **argv)
 				case 'b':
 				case 'f':
 				case '\0':
-					error += GMT_parse_common_options (argv[i], 0, 0, 0, 0);
+					error += (GMT_LONG)GMT_parse_common_options (argv[i], 0, 0, 0, 0);
 					break;
 
 				/* Supplemental parameters */
@@ -436,7 +436,7 @@ int main(int argc, char **argv)
 void read_data (struct TREND2D_DATA **data, GMT_LONG *n_data, double *xmin, double *xmax, double *ymin, double *ymax, GMT_LONG weighted_input, double **work, FILE *fp)
 {
 
-	GMT_LONG	i, n_alloc = GMT_CHUNK;
+	GMT_LONG	n_read, i, n_alloc = GMT_CHUNK;
 	GMT_LONG n_expected_fields, n_fields;
 	char	buffer[BUFSIZ], *not_used = NULL;
 	double	*in;
@@ -450,14 +450,15 @@ void read_data (struct TREND2D_DATA **data, GMT_LONG *n_data, double *xmin, doub
 	(*data) = (struct TREND2D_DATA *) GMT_memory (VNULL, (size_t)n_alloc, sizeof(struct TREND2D_DATA), GMT_program);
 
 	if (GMT_io.io_header[GMT_IN]) for (i = 0; i < GMT_io.n_header_recs; i++) not_used = GMT_fgets (buffer, BUFSIZ, fp);
-	i = 0;
+	i = n_read = 0;
 	n_expected_fields = (GMT_io.binary[GMT_IN]) ? GMT_io.ncol[GMT_IN] : 3 + weighted_input;
 
 	while ((n_fields = GMT_input (fp, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {
 
+		n_read++;
 		if (GMT_io.status & GMT_IO_MISMATCH) {
-			fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields, n_expected_fields, i);
-			exit (EXIT_FAILURE);
+			fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld (skipped)\n", GMT_program, n_fields, n_expected_fields, n_read);
+			continue;
 		}
 
 		(*data)[i].x = in[GMT_X];
