@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: triangulate.c,v 1.69 2010/01/05 01:15:47 guru Exp $
+ *	$Id: triangulate.c,v 1.78 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -41,26 +41,26 @@
 
 struct TRIANGULATE_CTRL {
 	struct D {	/* -Dx|y */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG dir;
 	} D;
 	struct E {	/* -E<Ctrl->E.value> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double value;
 	} E;
 	struct F {	/* -F */
-		BOOLEAN active;
+		GMT_LONG active;
 	} F;
 	struct G {	/* -G<output_grdfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} G;
 	struct I {	/* -Idx[/dy] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double xinc, yinc;
 	} I;
 	struct Q {	/* -Q */
-		BOOLEAN active;
+		GMT_LONG active;
 	} Q;
 };
 
@@ -73,10 +73,10 @@ int main (int argc, char **argv)
 	int *link, compare_edge(const void *p1, const void *p2);
 	GMT_LONG ij, ij1, ij2, ij3, np, n_alloc, n = 0, i, j, k, n_edge;
 	GMT_LONG i_min, i_max, j_min, j_max, p, nm;
-	GMT_LONG fno, n_files = 0, n_expected_fields, n_args, n_fields;
+	GMT_LONG fno, n_files = 0, n_expected_fields, n_args, n_read, n_fields;
 
-	BOOLEAN error = FALSE, map_them = FALSE;
-	BOOLEAN nofile = TRUE, done = FALSE, do_grid = FALSE;
+	GMT_LONG error = FALSE, map_them = FALSE;
+	GMT_LONG nofile = TRUE, done = FALSE, do_grid = FALSE;
 
 	double zj, zk, zl, zlj, zkj, *in;
 	double *xx, *yy, *zz = VNULL, vx[4], vy[4], xp, yp, a, b, c, f;
@@ -84,7 +84,7 @@ int main (int argc, char **argv)
 
 	float *grd;
 
-	char line[BUFSIZ], *not_used = NULL;
+	char line[BUFSIZ], buffer[BUFSIZ], *not_used = NULL;
 #ifdef TRIANGLE_D
 	char *algorithm = "Shewchuk";
 #else
@@ -99,7 +99,7 @@ int main (int argc, char **argv)
 
 	void *New_triangulate_Ctrl (), Free_triangulate_Ctrl (struct TRIANGULATE_CTRL *C);
 	
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct TRIANGULATE_CTRL *)New_triangulate_Ctrl ();	/* Allocate and initialize a new control structure */
 
@@ -121,7 +121,7 @@ int main (int argc, char **argv)
 				case 'f':
 				case 'm':
 				case '\0':
-					error += GMT_parse_common_options (argv[i], &header.x_min, &header.x_max, &header.y_min, &header.y_max);
+					error += (GMT_LONG)GMT_parse_common_options (argv[i], &header.x_min, &header.x_max, &header.y_min, &header.y_max);
 					break;
         
 				/* Supplemental parameters */
@@ -267,7 +267,7 @@ int main (int argc, char **argv)
 
 	if (do_grid) {
 		do_grid = 1;
-		header.node_offset = Ctrl->F.active;
+		header.node_offset = (int)Ctrl->F.active;
 		header.x_inc = Ctrl->I.xinc;
 		header.y_inc = Ctrl->I.yinc;
 		GMT_RI_prepare (&header);	/* Ensure -R -I consistency and set nx, ny */
@@ -292,7 +292,7 @@ int main (int argc, char **argv)
 	yy = (double *) GMT_memory (VNULL, (size_t)n_alloc, sizeof (double), GMT_program);
 	if (do_grid) zz = (double *) GMT_memory (VNULL, (size_t)n_alloc, sizeof (double), GMT_program);
 
-	n = 0;
+	n = n_read = 0;
 	for (fno = 1; !done && fno < n_args; fno++) {	/* Loop over input files, if any */
 		if (!nofile && argv[fno][0] == '-') continue;
 
@@ -314,9 +314,10 @@ int main (int argc, char **argv)
 
 		while ((n_fields = GMT_input (fp, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
 
+			n_read++;
 			if (GMT_io.status & GMT_IO_MISMATCH) {
-				fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields, n_expected_fields, n);
-				exit (EXIT_FAILURE);
+				fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld (skipped)\n", GMT_program, n_fields, n_expected_fields, n_read);
+				continue;
 			}
 
 			xx[n] = in[GMT_X];
@@ -362,7 +363,7 @@ int main (int argc, char **argv)
 			np = GMT_voronoi (xxp, yyp, (int)n, we, &xe, &ye);
 		}
 		else
-			np = GMT_delaunay (xx, yy, (int)n, &link);
+			np = GMT_delaunay (xxp, yyp, (int)n, &link);
 
 		GMT_free ((void *)xxp);
 		GMT_free ((void *)yyp);
@@ -457,7 +458,8 @@ int main (int argc, char **argv)
 	if (GMT_io.multi_segments[GMT_OUT]) {	/* Must find unique edges to output only once */
 		if (Ctrl->Q.active) {	/* Voronoi edges */
 			for (i = j = 0; i < np; i++) {
-				fprintf (GMT_stdout, "%c Edge %d\n", GMT_io.EOF_flag[GMT_OUT], (int)i);
+				sprintf (buffer, "%c Edge %d\n", GMT_io.EOF_flag[GMT_OUT], (int)i);
+				GMT_fputs (buffer, GMT_stdout);
 				out[GMT_X] = xe[j];	out[GMT_Y] = ye[j++];
 				GMT_output (GMT_stdout, 2, out);
 				out[GMT_X] = xe[j];	out[GMT_Y] = ye[j++];
@@ -474,7 +476,7 @@ int main (int argc, char **argv)
 				edge[ij2].begin = link[ij2];	edge[ij2].end = link[ij3];
 				edge[ij3].begin = link[ij1];	edge[ij3].end = link[ij3];
 			}
-			for (i = 0; i < n_edge; i++) if (edge[i].begin > edge[i].end) i_swap (edge[i].begin, edge[i].end);
+			for (i = 0; i < n_edge; i++) if (edge[i].begin > edge[i].end) l_swap (edge[i].begin, edge[i].end);
 
 			qsort ((void *)edge, (size_t)n_edge, sizeof (struct TRIANGULATE_EDGE), compare_edge);
 			for (i = 1, j = 0; i < n_edge; i++) {
@@ -486,7 +488,8 @@ int main (int argc, char **argv)
 			if (gmtdefs.verbose) fprintf (stderr, "%s: %ld unique triangle edges\n", GMT_program, n_edge);
 
 			for (i = 0; i < n_edge; i++) {
-				fprintf (GMT_stdout, "%c Edge %ld-%ld\n", GMT_io.EOF_flag[GMT_OUT], edge[i].begin, edge[i].end);
+				sprintf (buffer, "%c Edge %ld-%ld\n", GMT_io.EOF_flag[GMT_OUT], edge[i].begin, edge[i].end);
+				GMT_fputs (buffer, GMT_stdout);
 				out[GMT_X] = xx[edge[i].begin];	out[GMT_Y] = yy[edge[i].begin];
 				GMT_output (GMT_stdout, 2, out);
 				out[GMT_X] = xx[edge[i].end];	out[GMT_Y] = yy[edge[i].end];
@@ -498,7 +501,10 @@ int main (int argc, char **argv)
 	else if (GMT_io.binary[GMT_OUT])
 		i = GMT_fwrite ((void *)link, sizeof (int), (size_t)(3*np), GMT_stdout);
 	else
-		for (i = ij = 0; i < np; i++, ij += 3) fprintf (GMT_stdout, "%d\t%d\t%d\n", link[ij], link[ij+1], link[ij+2]);
+		for (i = ij = 0; i < np; i++, ij += 3) {
+			sprintf (buffer, "%d\t%d\t%d\n", link[ij], link[ij+1], link[ij+2]);
+			GMT_fputs (buffer, GMT_stdout);
+		}
 
 	GMT_free ((void *) xx);
 	GMT_free ((void *) yy);
