@@ -1,12 +1,12 @@
 /*-----------------------------------------------------------------
- *	$Id: x2sys.c,v 1.141 2010/01/05 01:15:49 guru Exp $
+ *	$Id: x2sys.c,v 1.150 2011/03/06 02:09:56 guru Exp $
  *
- *      Copyright (c) 1999-2010 by P. Wessel
+ *      Copyright (c) 1999-2011 by P. Wessel
  *      See LICENSE.TXT file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; version 2 of the License.
+ *      the Free Software Foundation; version 2 or any later version.
  *
  *      This program is distributed in the hope that it will be useful,
  *      but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -400,9 +400,9 @@ double *x2sys_dummytimes (GMT_LONG n)
 
 int x2sys_read_record (FILE *fp, double *data, struct X2SYS_INFO *s, struct GMT_IO *G)
 {
-	int j, k, i, n_read = 0;
-	GMT_LONG pos;
-	BOOLEAN error = FALSE;
+	int j, k, i;
+	size_t n_read = 0;
+	GMT_LONG pos, error = FALSE;
 	char line[BUFSIZ], buffer[GMT_TEXT_LEN], p[BUFSIZ], c;
 	unsigned char u;
 	short int h;
@@ -475,7 +475,7 @@ int x2sys_read_record (FILE *fp, double *data, struct X2SYS_INFO *s, struct GMT_
 
 			case 'f':	/* Binary signed 4-byte float */
 				n_read += fread ((void *)&f, sizeof (float), (size_t)1, fp);
-				data[j] = (double)i;
+				data[j] = (double)f;
 				break;
 
 			case 'd':	/* Binary signed 8-byte float */
@@ -504,15 +504,14 @@ int x2sys_read_record (FILE *fp, double *data, struct X2SYS_INFO *s, struct GMT_
  
 int x2sys_read_file (char *fname, double ***data, struct X2SYS_INFO *s, struct X2SYS_FILE_INFO *p, struct GMT_IO *G, GMT_LONG *n_rec)
 {
-	/* Reads the entire contents of the file given and returns the
-	 * number of data records.  The data matrix is return in the
-	 * pointer data.
+	/* Reads the the file given and returns the selected columns (or all)
+	 * from all data records.  The data matrix is return in the pointer data.
 	 */
 
 	GMT_LONG i, j;
 	size_t n_alloc;
 	FILE *fp;
-	double **z, *rec;
+	double **z, *field;
 	char path[BUFSIZ];
 
 	if (x2sys_get_data_path (path, fname, s->suffix)) {
@@ -527,29 +526,30 @@ int x2sys_read_file (char *fname, double ***data, struct X2SYS_INFO *s, struct X
 
 	n_alloc = GMT_CHUNK;
 
-	rec = (double *) GMT_memory (VNULL, (size_t)s->n_fields, sizeof (double), "x2sys_read_file");
-	z = (double **) GMT_memory (VNULL, (size_t)s->n_fields, sizeof (double *), "x2sys_read_file");
-	for (i = 0; i < s->n_fields; i++) z[i] = (double *) GMT_memory (VNULL, n_alloc, sizeof (double), "x2sys_read_file");
+	field = (double *) GMT_memory (VNULL, (size_t)s->n_fields, sizeof (double), "x2sys_read_file");
+	z = (double **) GMT_memory (VNULL, (size_t)s->n_out_columns, sizeof (double *), "x2sys_read_file");
+	for (i = 0; i < s->n_out_columns; i++) z[i] = (double *) GMT_memory (VNULL, n_alloc, sizeof (double), "x2sys_read_file");
 	p->ms_rec = (GMT_LONG *) GMT_memory (VNULL, n_alloc, sizeof (GMT_LONG), "x2sys_read_file");
 	x2sys_skip_header (fp, s);
 	p->n_segments = (s->multi_segment) ? -1 : 0;	/* So that first increment sets it to 0 */
 
 	j = 0;
-	while (!x2sys_read_record (fp, rec, s, G)) {	/* Gets the next data record */
-		for (i = 0; i < s->n_fields; i++) z[i][j] = rec[i];
+	while (!x2sys_read_record (fp, field, s, G)) {	/* Gets the next data record */
+		/* Only copy the requested fields */
+		for (i = 0; i < s->n_out_columns; i++) z[i][j] = field[s->out_order[i]];
 		if (s->multi_segment && s->ms_next) p->n_segments++;
 		p->ms_rec[j] = p->n_segments;
 		j++;
 		if (j == (GMT_LONG)n_alloc) {	/* Get more */
 			n_alloc <<= 1;
-			for (i = 0; i < s->n_fields; i++) z[i] = (double *) GMT_memory ((void *)z[i], n_alloc, sizeof (double), "x2sys_read_file");
+			for (i = 0; i < s->n_out_columns; i++) z[i] = (double *) GMT_memory ((void *)z[i], n_alloc, sizeof (double), "x2sys_read_file");
 			p->ms_rec = (GMT_LONG *) GMT_memory ((void *)p->ms_rec, n_alloc, sizeof (GMT_LONG), "x2sys_read_file");
 		}
 	}
 
 	fclose (fp);
-	GMT_free ((void *)rec);
-	for (i = 0; i < s->n_fields; i++) z[i] = (double *) GMT_memory ((void *)z[i], (size_t)j, sizeof (double), "x2sys_read_file");
+	GMT_free ((void *)field);
+	for (i = 0; i < s->n_out_columns; i++) z[i] = (double *) GMT_memory ((void *)z[i], (size_t)j, sizeof (double), "x2sys_read_file");
 	p->ms_rec = (GMT_LONG *) GMT_memory ((void *)p->ms_rec, (size_t)j, sizeof (GMT_LONG), "x2sys_read_file");
 
 	*data = z;
@@ -570,11 +570,12 @@ int x2sys_read_gmtfile (char *fname, double ***data, struct X2SYS_INFO *s, struc
 	 * MGG format from old Lamont by Wessel and Smith.
 	 */
 
-	int year, n_records, rata_day;
+	int year, n_records;
+	GMT_cal_rd rata_day;
 	GMT_LONG i, j;
 	char path[BUFSIZ];
 	FILE *fp;
-	double **z;
+	double **z, field[6];
 	double NaN, t_off;
 	struct GMTMGG_REC record;
 
@@ -608,7 +609,6 @@ int x2sys_read_gmtfile (char *fname, double ***data, struct X2SYS_INFO *s, struc
 	rata_day = GMT_rd_from_gymd (year, 1, 1);	/* Get the rata day for start of cruise year */
 	t_off = GMT_rdc2dt (rata_day, 0.0);		/* Secs to start of day */
 	
-	
 	if (fread ((void *)&n_records, sizeof (int), (size_t)1, fp) != 1) {
 		fprintf (stderr, "x2sys_read_gmtfile: Could not read n_records from %s\n", path);
 		return (GMT_GRDIO_READ_FAILED);
@@ -621,8 +621,8 @@ int x2sys_read_gmtfile (char *fname, double ***data, struct X2SYS_INFO *s, struc
 		return (GMT_GRDIO_READ_FAILED);
 	}
 
-	z = (double **) GMT_memory (VNULL, (size_t)6, sizeof (double *), "x2sys_read_gmtfile");
-	for (i = 0; i < 6; i++) z[i] = (double *) GMT_memory (VNULL, (size_t)p->n_rows, sizeof (double), "x2sys_read_gmtfile");
+	z = (double **) GMT_memory (VNULL, (size_t)s->n_out_columns, sizeof (double *), "x2sys_read_gmtfile");
+	for (i = 0; i < s->n_out_columns; i++) z[i] = (double *) GMT_memory (VNULL, (size_t)p->n_rows, sizeof (double), "x2sys_read_gmtfile");
 
 	for (j = 0; j < p->n_rows; j++) {
 
@@ -630,14 +630,15 @@ int x2sys_read_gmtfile (char *fname, double ***data, struct X2SYS_INFO *s, struc
 			fprintf (stderr, "x2sys_read_gmtfile: Could not read record %ld from %s\n", j, path);
 			return (GMT_GRDIO_READ_FAILED);
 		}
-
-		z[0][j] = record.time * gmtdefs.time_system.i_scale + t_off;	/* To get GMT time keeping */
-		z[1][j] = record.lat * MDEG2DEG;
-		z[2][j] = record.lon * MDEG2DEG;
-		z[3][j] = (record.gmt[0] == GMTMGG_NODATA) ? NaN : 0.1 * record.gmt[0];
-		z[4][j] = (record.gmt[1] == GMTMGG_NODATA) ? NaN : record.gmt[1];
-		z[5][j] = (record.gmt[2] == GMTMGG_NODATA) ? NaN : record.gmt[2];
-
+		/* Convert the 6 items to doubles */
+		field[0] = record.time * gmtdefs.time_system.i_scale + t_off;	/* To get GMT time keeping */
+		field[1] = record.lat * MDEG2DEG;
+		field[2] = record.lon * MDEG2DEG;
+		field[3] = (record.gmt[0] == GMTMGG_NODATA) ? NaN : 0.1 * record.gmt[0];
+		field[4] = (record.gmt[1] == GMTMGG_NODATA) ? NaN : record.gmt[1];
+		field[5] = (record.gmt[2] == GMTMGG_NODATA) ? NaN : record.gmt[2];
+		/* Only copy the requested fields */
+		for (i = 0; i < s->n_out_columns; i++) z[i][j] = field[s->out_order[i]];
 	}
 
 	fclose (fp);
@@ -722,7 +723,7 @@ int get_first_year (double t)
 	struct GMT_gcal CAL;
 	GMT_dt2rdc (t, &rd, &s);
 	GMT_gcal_from_rd (rd, &CAL);
-	return (CAL.year);
+	return ((int)CAL.year);
 }
 
 int x2sys_read_mgd77ncfile (char *fname, double ***data, struct X2SYS_INFO *s, struct X2SYS_FILE_INFO *p, struct GMT_IO *G, GMT_LONG *n_rec)
@@ -782,7 +783,7 @@ int x2sys_read_mgd77ncfile (char *fname, double ***data, struct X2SYS_INFO *s, s
 
 int x2sys_read_ncfile (char *fname, double ***data, struct X2SYS_INFO *s, struct X2SYS_FILE_INFO *p, struct GMT_IO *G, GMT_LONG *n_rec)
 {
-	int i, n_fields, n_expect = BUFSIZ;
+	GMT_LONG i, n_fields, n_expect = GMT_MAX_COLUMNS;
 	size_t j;
 	char path[BUFSIZ];
 	double **z, *in;
@@ -855,7 +856,7 @@ int x2sys_read_list (char *file, char ***list, int *nf)
 		if (line[0] == '#' || line[0] == '>' || line[0] == '\0') continue;	/* Skip various comments and blank lines */
 		GMT_chop (line);	/* Remove trailing CR or LF */
 		sscanf (line, "%s", name);
-		for (k = strlen(name) - 1, dot = -1; dot == -1 && k >= 0; k--) if (name[k] == '.') dot = k;
+		for (k = (int)strlen(name) - 1, dot = -1; dot == -1 && k >= 0; k--) if (name[k] == '.') dot = k;
 		if (dot > 0) name[dot] = '\0';	/* Chop off extension */
 		p[n] = strdup (name);
 		n++;
@@ -928,7 +929,7 @@ int x2sys_set_system (char *TAG, struct X2SYS_INFO **S, struct X2SYS_BIX *B, str
 	int geodetic = 0, n, k, dist_flag = 0;
 	GMT_LONG pos = 0;
 	double dist;
-	BOOLEAN geographic = FALSE, n_given[2] = {FALSE, FALSE}, c_given = FALSE;
+	GMT_LONG geographic = FALSE, n_given[2] = {FALSE, FALSE}, c_given = FALSE;
 	FILE *fp;
 	struct X2SYS_INFO *s;
 	
@@ -1102,7 +1103,7 @@ int x2sys_set_system (char *TAG, struct X2SYS_INFO **S, struct X2SYS_BIX *B, str
 	return (X2SYS_NOERROR);
 }
 
-void x2sys_bix_init (struct X2SYS_BIX *B, BOOLEAN alloc)
+void x2sys_bix_init (struct X2SYS_BIX *B, GMT_LONG alloc)
 {
 	B->i_bin_x = 1.0 / B->bin_x;
 	B->i_bin_y = 1.0 / B->bin_y;
@@ -1188,7 +1189,7 @@ int x2sys_bix_read_tracks (struct X2SYS_INFO *S, struct X2SYS_BIX *B, int mode,
 	return (X2SYS_NOERROR);
 }
 
-int x2sys_bix_read_index (struct X2SYS_INFO *S, struct X2SYS_BIX *B, BOOLEAN swap)
+int x2sys_bix_read_index (struct X2SYS_INFO *S, struct X2SYS_BIX *B, GMT_LONG swap)
 {
 	/* Reads the binned index file which is native binary and thus swab is an issue */
 	char index_file[BUFSIZ], index_path[BUFSIZ];
@@ -1311,8 +1312,8 @@ void x2sys_path_init (struct X2SYS_INFO *S)
 int x2sys_get_data_path (char *track_path, char *track, char *suffix)
 {
 	int id;
-	BOOLEAN add_suffix;
-	char geo_path[BUFSIZ];
+	GMT_LONG add_suffix = FALSE;
+	char geo_path[BUFSIZ], dotsuffix[GMT_TEXT_LEN];
 
 	if (track[0] == '/' || track[1] == ':') {	/* Full path given, just return it */
 		strcpy(track_path, track);
@@ -1321,7 +1322,8 @@ int x2sys_get_data_path (char *track_path, char *track, char *suffix)
 	
 	/* Check if we need to append suffix */
 	
-	add_suffix = strncmp (&track[strlen(track)-strlen(suffix)], suffix, strlen(suffix));	/* Need to add suffix? */
+	sprintf (dotsuffix, ".%s", suffix);
+	add_suffix = strncmp (&track[strlen(track)-strlen(dotsuffix)], dotsuffix, strlen(dotsuffix));	/* Need to add suffix? */
 
 	/* First look in current directory */
 
@@ -1420,7 +1422,7 @@ GMT_LONG x2sys_read_coe_dbase (struct X2SYS_INFO *S, char *dbase, char *ignorefi
 	char stop[2][GMT_TEXT_LEN], info[2][3*GMT_TEXT_LEN], **trk_list, **ignore = NULL, *t = NULL;
 	GMT_LONG p, n_pairs;
 	int i, k, n_alloc_x, n_alloc_p, n_alloc_t, year[2], id[2], n_ignore = 0, n_tracks = 0, n_items, our_item = -1;
-	BOOLEAN more, skip, two_values = FALSE, check_box, keep = TRUE, no_time = FALSE;
+	GMT_LONG more, skip, two_values = FALSE, check_box, keep = TRUE, no_time = FALSE;
 	double x, m, lon, dist[2], d_val;
 
 	fp = stdin;	/* Default to stdin if dbase is NULL */
@@ -1453,12 +1455,13 @@ GMT_LONG x2sys_read_coe_dbase (struct X2SYS_INFO *S, char *dbase, char *ignorefi
 			sscanf (&line[2], "%*s %*s %s %*s %*s %*s %*s %*s %*s %*s %s", kind, txt);	/* Get first column name after lon/x etc */
 			if (strchr (txt, '_')) {	/* A column name with underscore; we thus assume this is the correct record */
 				char ptr[BUFSIZ];
-				GMT_LONG pos = 0, item = 0;
+				GMT_LONG pos = 0;
+				int item = 0;
 				no_time = !strcmp (kind, "i_1");	/* No time in this database */
 				if (txt[strlen(txt)-1] == '1') two_values = TRUE;	/* Option -2 was used */
 				while (our_item == -1 && (GMT_strtok (&line[2], " \t", &pos, ptr))) {    /* Process all tokens */
 					item++;
-					i = strlen (ptr) - 1;
+					i = (int)strlen (ptr) - 1;
 					while (i >= 0 && ptr[i] != '_') i--;	/* Start at end and find last underscore */
 					if (i < 0) continue;		/* First records 'lon' & 'lat' have no '_' */
 					strncpy (txt, ptr, i);
@@ -1670,7 +1673,7 @@ int x2sys_find_track (char *name, char **list, int n)
 	return (-1);
 }
 
-int x2sys_get_tracknames (int argc, char **argv, char ***filelist, BOOLEAN *cmdline)
+int x2sys_get_tracknames (int argc, char **argv, char ***filelist, GMT_LONG *cmdline)
 {	/* Return list of track names given on command line or via =list mechanism.
 	 * The names do not have the track extension. */
 	int i, A, list = 0, add_chunk, n_alloc;
