@@ -1,12 +1,12 @@
 /*-----------------------------------------------------------------
- *	$Id: x2sys_binlist.c,v 1.64 2010/01/05 01:15:49 guru Exp $
+ *	$Id: x2sys_binlist.c,v 1.70 2011/03/03 21:02:51 guru Exp $
  *
- *      Copyright (c) 1999-2010 by P. Wessel
+ *      Copyright (c) 1999-2011 by P. Wessel
  *      See LICENSE.TXT file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; version 2 of the License.
+ *      the Free Software Foundation; version 2 or any later version.
  *
  *      This program is distributed in the hope that it will be useful,
  *      but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -36,7 +36,7 @@ struct BINCROSS {
 
 int main (int argc, char **argv)
 {
-	char *TAG = CNULL, **trk_name;
+	char *TAG = CNULL, **trk_name, buffer[BUFSIZ];
 
 	GMT_LONG i, j, k, n_tracks, k1, ij, ii, jj, nx, bi, bj, start_i, end_i, jump_180, jump_360;
 	GMT_LONG this_bin_i;	/* This i node for bin */
@@ -48,7 +48,7 @@ int main (int argc, char **argv)
 	unsigned int nav_flag;
 	size_t n_alloc = 0, nx_alloc = GMT_SMALL_CHUNK;
 
-	BOOLEAN error = FALSE, trackline = FALSE, gap, ea_mode = FALSE, cmdline_files;
+	GMT_LONG error = FALSE, trackline = FALSE, gap, ea_mode = FALSE, cmdline_files;
 
 	double **data, *dist_km = NULL, *dist_bin = NULL, dist_scale, x, y, dx, del_x, del_y, y_max = 90.0;
 
@@ -57,11 +57,11 @@ int main (int argc, char **argv)
 	struct X2SYS_BIX B;
 	struct BINCROSS *X;
 
-	int outside (double x, double y, struct X2SYS_BIX *B, BOOLEAN geo);
+	int outside (double x, double y, struct X2SYS_BIX *B, GMT_LONG geo);
 	unsigned int get_data_flag (double *data[], GMT_LONG j, struct X2SYS_INFO *s);
 	int comp_bincross (const void *p1, const void *p2);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 	
 	for (i = strlen(argv[0]); i >= 0 && argv[0][i] != '/'; i--);
 	X2SYS_program = &argv[0][i+1];	/* Name without full path */
@@ -168,7 +168,8 @@ int main (int argc, char **argv)
 		dist_bin = (double *)GMT_memory (VNULL, (size_t)B.nm_bin, sizeof (double), GMT_program);
 	}
 
-	fprintf (GMT_stdout, "# %s\n", TAG);
+	sprintf (buffer, "# %s\n", TAG);
+	GMT_fputs (buffer, GMT_stdout);
 
 	for (i = 0; i < n_tracks; i++) {
 
@@ -308,20 +309,22 @@ int main (int argc, char **argv)
 
 		/* Time for bin index output */
 
-		fprintf (GMT_stdout, "> %s\n", trk_name[i]);
+		sprintf (buffer, "> %s\n", trk_name[i]);
+		GMT_fputs (buffer, GMT_stdout);
 		for (ij = 0; ij < B.nm_bin; ij++) {
 			if (B.binflag[ij] == 0) continue;
 			x = B.x_min + ((ij % B.nx_bin) + 0.5) * B.bin_x;
 			y = B.y_min + ((ij / B.nx_bin) + 0.5) * B.bin_y;
 			GMT_ascii_output_one (GMT_stdout, x, 0);
-			fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
+			GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);
 			GMT_ascii_output_one (GMT_stdout, y, 1);
-			fprintf (GMT_stdout, "%s%ld%s%u", gmtdefs.field_delimiter, ij, gmtdefs.field_delimiter, B.binflag[ij]);
+			sprintf (buffer, "%s%ld%s%u", gmtdefs.field_delimiter, ij, gmtdefs.field_delimiter, B.binflag[ij]);
+			GMT_fputs (buffer, GMT_stdout);
 			if (trackline) {
-				fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
+				GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);
 				GMT_ascii_output_one (GMT_stdout, dist_bin[ij], 2);
 			}
-			fprintf (GMT_stdout, "\n");
+			GMT_fputs ("\n", GMT_stdout);
 		}
 
 		if (trackline) GMT_free ((void *)dist_km);
@@ -331,14 +334,14 @@ int main (int argc, char **argv)
 	x2sys_end (s);
 	GMT_free ((void *)B.binflag);
 	if (trackline) GMT_free ((void *)dist_bin);
-	x2sys_free_list (trk_name, n_tracks);
+	x2sys_free_list (trk_name, (int)n_tracks);
 
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
 
-int outside (double x, double y, struct X2SYS_BIX *B, BOOLEAN geo)
+int outside (double x, double y, struct X2SYS_BIX *B, GMT_LONG geo)
 {
 	if (y < B->y_min || y > B->y_max) return (1);
 	if (geo) {	/* Geographic data with periodic longitudes */
