@@ -1,12 +1,12 @@
 /*-----------------------------------------------------------------
- *	$Id: x2sys_datalist.c,v 1.53 2010/01/05 01:15:49 guru Exp $
+ *	$Id: x2sys_datalist.c,v 1.63 2011/03/07 00:04:35 guru Exp $
  *
- *      Copyright (c) 1999-2010 by P. Wessel
+ *      Copyright (c) 1999-2011 by P. Wessel
  *      See LICENSE.TXT file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; version 2 of the License.
+ *      the Free Software Foundation; version 2 or any later version.
  *
  *      This program is distributed in the hope that it will be useful,
  *      but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -33,18 +33,18 @@ struct X2SYS_ADJUST {
 	double *d, *c;
 };
 
-BOOLEAN x2sys_load_adjustments (char *DIR, char *TAG, char *track, char *column, struct X2SYS_ADJUST **A);
+GMT_LONG x2sys_load_adjustments (char *DIR, char *TAG, char *track, char *column, struct X2SYS_ADJUST **A);
 
 int main (int argc, char **argv)
 {
 	char *sfile, *def = "x2sys", *fflags = CNULL, *TAG = CNULL, *correction_table = CNULL;
-	char **trk_name = NULL;
+	char **trk_name = NULL, buffer[BUFSIZ];
 
-	GMT_LONG i, j, k, bad, trk_no, n_tracks;
-	GMT_LONG n_data_col_out = 0;
+	GMT_LONG i, j, k, bad, trk_no, n_data_col_out = 0;
+	int n_tracks;
 
-	BOOLEAN error = FALSE, suppress = FALSE, apply_corrections = FALSE, t_given, set_r = FALSE;
-	BOOLEAN adjust = FALSE, cmdline_files, special_formatting = FALSE, xy_check, *adj_col = NULL;
+	GMT_LONG error = FALSE, suppress = FALSE, apply_corrections = FALSE, t_given, set_r = FALSE;
+	GMT_LONG adjust = FALSE, cmdline_files, special_formatting = FALSE, xy_check, *adj_col = NULL;
 
 	double **data, west, east, south, north, *out, correction = 0.0, aux_dvalue[N_GENERIC_AUX];
 	double ds = 0.0, cumulative_dist, dist_scale = 1.0, dt, vel_scale = 1.0, adj_amount;
@@ -62,7 +62,7 @@ int main (int argc, char **argv)
 	struct X2SYS_ADJUST **A = NULL;
 	PFD GMT_azimuth_func;
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 	for (i = strlen(argv[0]); i >= 0 && argv[0][i] != '/'; i--);
 	X2SYS_program = &argv[0][i+1];	/* Name without full path */
 	sfile = def;
@@ -147,7 +147,7 @@ int main (int argc, char **argv)
 	if (fflags) x2sys_err_fail (x2sys_pick_fields (fflags, s), "-F");
 
 	s->ascii_out = !GMT_io.binary[1];
-	xy_check = (s->use_column[s->x_col[GMT_IN]] && s->use_column[s->x_col[GMT_IN]]);	/* TRUE means we requested lon,lat so we can check these for inside/outside */
+	xy_check = (s->use_column[s->x_col[GMT_IN]] && s->use_column[s->y_col[GMT_IN]]);	/* TRUE means we requested lon,lat so we can check these for inside/outside */
 
 	if (set_r) {
 		west = B.x_min;		east = B.x_max;
@@ -160,6 +160,7 @@ int main (int argc, char **argv)
 		/* Supply dummy linear proj */
 		project_info.projection = project_info.xyz_projection[0] = project_info.xyz_projection[1] = GMT_LINEAR;
 		project_info.pars[0] = project_info.pars[1] = 1.0;
+		if (s->geographic) project_info.degree[0] = project_info.degree[1] = TRUE;
 		if (west < 0.0 && east < 0.0) {
 			west += 360.0;
 			east += 360.0;
@@ -264,7 +265,7 @@ int main (int argc, char **argv)
 
 	if (adjust) {
 		A = (struct X2SYS_ADJUST **) GMT_memory (VNULL, s->n_out_columns, sizeof (struct X2SYS_ADJUST *), GMT_program);
-		adj_col = (BOOLEAN *) GMT_memory (VNULL, s->n_out_columns, sizeof (BOOLEAN), GMT_program);
+		adj_col = (GMT_LONG *) GMT_memory (VNULL, s->n_out_columns, sizeof (GMT_LONG), GMT_program);
 	}
 	
 	for (trk_no = 0; trk_no < n_tracks; trk_no++) {
@@ -324,12 +325,14 @@ int main (int argc, char **argv)
 					if (s->info[s->out_order[k]].format[0] == '-')
 						GMT_ascii_output_one (GMT_stdout, out[k], k);
 					else {
-						if (!GMT_is_dnan (out[k]))
-							fprintf (GMT_stdout, s->info[s->out_order[k]].format, out[k]);
+						if (!GMT_is_dnan (out[k])) {
+							sprintf (buffer, s->info[s->out_order[k]].format, out[k]);
+							GMT_fputs (buffer, GMT_stdout);
+						}
 						else
-							fprintf (GMT_stdout, "NaN");
+							GMT_fputs ("NaN", GMT_stdout);
 					}
-					(k == (s->n_out_columns - 1)) ? fprintf (GMT_stdout, "\n") : fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
+					(k == (s->n_out_columns - 1)) ? GMT_fputs ("\n", GMT_stdout) : GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);
 				}
 			}
 			else {
@@ -360,9 +363,10 @@ int main (int argc, char **argv)
 	exit (EXIT_SUCCESS);
 }
 
-BOOLEAN x2sys_load_adjustments (char *DIR, char *TAG, char *track, char *column, struct X2SYS_ADJUST **A)
+GMT_LONG x2sys_load_adjustments (char *DIR, char *TAG, char *track, char *column, struct X2SYS_ADJUST **A)
 {
-	GMT_LONG n_fields, n_expected_fields = 2, n = 0, k, type[2] = {GMT_IS_FLOAT, GMT_IS_FLOAT}, n_alloc = GMT_CHUNK;
+	GMT_LONG n_fields, n_expected_fields = 2, n = 0, k, n_alloc = GMT_CHUNK;
+	GMT_LONG type[2] = {GMT_IS_FLOAT, GMT_IS_FLOAT};
 	double *in;
 	char file[BUFSIZ];
 	FILE *fp;
@@ -374,7 +378,7 @@ BOOLEAN x2sys_load_adjustments (char *DIR, char *TAG, char *track, char *column,
 	adj = (struct X2SYS_ADJUST *)GMT_memory (VNULL, 1, sizeof (struct X2SYS_ADJUST), GMT_program);
 	adj->d = (double *)GMT_memory (VNULL, n_alloc, sizeof (double), GMT_program);
 	adj->c = (double *)GMT_memory (VNULL, n_alloc, sizeof (double), GMT_program);
-	for (k = 0; k < 2; k++) i_swap (type[k], GMT_io.in_col_type[k]);	/* Save original input type setting */
+	for (k = 0; k < 2; k++) l_swap (type[k], GMT_io.in_col_type[k]);	/* Save original input type setting */
 	while ((n_fields = GMT_input (fp, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
 		adj->d[n] = in[0];
 		adj->c[n] = in[1];
@@ -388,8 +392,8 @@ BOOLEAN x2sys_load_adjustments (char *DIR, char *TAG, char *track, char *column,
 	GMT_fclose (fp);
 	adj->d = (double *)GMT_memory ((void *)adj->d, n, sizeof (double), GMT_program);
 	adj->c = (double *)GMT_memory ((void *)adj->c, n, sizeof (double), GMT_program);
-	adj->n = n;
+	adj->n = (int)n;
 	*A = adj;
-	for (k = 0; k < 2; k++) i_swap (GMT_io.in_col_type[k], type[k]);	/* Restore original input type setting */
+	for (k = 0; k < 2; k++) l_swap (GMT_io.in_col_type[k], type[k]);	/* Restore original input type setting */
 	return (TRUE);
 }
