@@ -1,12 +1,12 @@
 /*-----------------------------------------------------------------
- *	$Id: x2sys_init.c,v 1.38 2010/01/05 01:15:49 guru Exp $
+ *	$Id: x2sys_init.c,v 1.44 2011/03/06 02:09:57 guru Exp $
  *
- *      Copyright (c) 1999-2010 by P. Wessel
+ *      Copyright (c) 1999-2011 by P. Wessel
  *      See LICENSE.TXT file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; version 2 of the License.
+ *      the Free Software Foundation; version 2 or any later version.
  *
  *      This program is distributed in the hope that it will be useful,
  *      but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -40,20 +40,20 @@ int main (int argc, char **argv)
 	char tag_file[BUFSIZ], track_file[BUFSIZ], bin_file[BUFSIZ], def_file[BUFSIZ];
 	char path_file[BUFSIZ], path[BUFSIZ], line[BUFSIZ];
 
-	BOOLEAN error = FALSE, geographic = FALSE, force = FALSE;
+	GMT_LONG error = FALSE, geographic = FALSE, force = FALSE;
 
 	FILE *fp = NULL, *fp_def = NULL;
 
 	int n_tags = 0, i, n_found = 0, geodetic = 0, r_entry, i_entry, d_entry, d_start;
-	int e_entry,  g_entry, m_entry, wd_entry, wt_entry, n_entry, c_entry;
+	int e_entry,  g_entry, m_entry, wd_entry, wt_entry, n_entry[2], c_entry, n_n = 0;
 
 	double x_min = 0.0, x_max = 0.0, y_min = 0.0, y_max = 0.0, bin_x = 0.0, bin_y = 0.0;
 
-	c_entry = n_entry = r_entry = i_entry = d_entry = e_entry = g_entry = m_entry = wd_entry = wt_entry = 0;
+	c_entry = n_entry[0] = n_entry[1] = r_entry = i_entry = d_entry = e_entry = g_entry = m_entry = wd_entry = wt_entry = 0;
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 	
-	for (i = strlen(argv[0]); i >= 0 && argv[0][i] != '/'; i--);
+	for (i = (int)strlen(argv[0]); i >= 0 && argv[0][i] != '/'; i--);
 	X2SYS_program = &argv[0][i+1];	/* Name without full path */
 
 	for (i = 1; i < argc; i++) {
@@ -117,7 +117,12 @@ int main (int argc, char **argv)
 							error++;
 							break;
 					}
-					n_entry = i;
+					if (n_n >= 2) {
+						fprintf(stderr, "%s: ERROR -N: Can only be given once each for -Nd -Ns\n", GMT_program);
+						error++;
+					}
+					else
+						n_entry[n_n++] = i;
 					break;
 				case 'W':
 					switch (argv[i][2]) {
@@ -199,8 +204,8 @@ int main (int argc, char **argv)
 		fprintf (stderr, "%s: -Idx/dy must be positive!\n", GMT_program);
 		exit (EXIT_FAILURE);
 	}
-
-	sprintf (def_file, "%s.def", ((d_entry) ? sfile : TAG));
+	if (!sfile) sfile = TAG;	/* Default def file */
+	sprintf (def_file, "%s.def", sfile);
 	if (access (def_file, R_OK)) {	/* No such local *.def file */
 		fprintf (stderr,"%s: Unable to find local definition file : %s\n", GMT_program, def_file);
 		exit (EXIT_FAILURE);
@@ -209,7 +214,7 @@ int main (int argc, char **argv)
 		fprintf (stderr,"%s: Unable to open local definition file : %s\n", GMT_program, def_file);
 		exit (EXIT_FAILURE);
 	}
-	for (d_start = strlen (sfile)-1; d_start >= 0 && sfile[d_start] != DIR_DELIM; d_start--);	/* Find pos of last slash */
+	for (d_start = (int)strlen (sfile)-1; d_start >= 0 && sfile[d_start] != DIR_DELIM; d_start--);	/* Find pos of last slash */
 	d_start++;		/* Find start of file name */
 	
 	/* Determine the TAG directory */
@@ -321,7 +326,8 @@ int main (int argc, char **argv)
 	if (e_entry) fprintf (fp, " %s", argv[e_entry]);
 	if (g_entry) fprintf (fp, " %s", argv[g_entry]);
 	if (m_entry) fprintf (fp, " -m%s", &argv[m_entry][2]);
-	if (n_entry) fprintf (fp, " %s", argv[n_entry]);
+	if (n_entry[0]) fprintf (fp, " %s", argv[n_entry[0]]);
+	if (n_entry[1]) fprintf (fp, " %s", argv[n_entry[1]]);
 	if (wt_entry) fprintf (fp, " %s", argv[wt_entry]);
 	if (wd_entry) fprintf (fp, " %s", argv[wd_entry]);
 	(i_entry) ? fprintf (fp, " %s", argv[i_entry]) : fprintf (fp, " -I1/1");
