@@ -1,12 +1,12 @@
 /*-----------------------------------------------------------------
- *	$Id: x2sys_list.c,v 1.24 2010/01/05 01:15:49 guru Exp $
+ *	$Id: x2sys_list.c,v 1.37 2011/03/06 02:09:57 guru Exp $
  *
- *      Copyright (c) 1999-2010 by P. Wessel
+ *      Copyright (c) 1999-2011 by P. Wessel
  *      See LICENSE.TXT file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; version 2 of the License.
+ *      the Free Software Foundation; version 2 or any later version.
  *
  *      This program is distributed in the hope that it will be useful,
  *      but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -30,31 +30,32 @@
 #define GMT_T	3	/* Just used to indicate abs time formatting */
 #define LETTERS "acdhiInNtTvwxyz"
 
-void dump_ascii_cols (double *val, int col, int n, BOOLEAN first);
+void dump_ascii_cols (double *val, int col, int n, GMT_LONG first);
 
 int main (int argc, char **argv)
 {
 	char *TAG = CNULL, *column = CNULL, *fflags = CNULL, *track = CNULL, *ignorelist = CNULL;
 	char *dbase = NULL, *correction_table = CNULL, *weight_list = NULL, **trk_name = NULL, **weight_name = NULL;
+	char buffer[BUFSIZ];
 	struct X2SYS_INFO *s;
 	struct X2SYS_BIX B;
 	struct X2SYS_COE_PAIR *P;
-	BOOLEAN error = FALSE, mixed = FALSE, check_for_NaN = FALSE, both, first, z_is_requested = FALSE;
-	BOOLEAN internal = TRUE;	/* FALSE if only external xovers are needed */
-	BOOLEAN external = TRUE;	/* FALSE if only internal xovers are needed */
-	BOOLEAN single = FALSE;		/* TRUE if a single track is specified -S */
-	BOOLEAN symm_check = FALSE;	/* TRUE if -Y is used */
-	BOOLEAN nx_check = FALSE;	/* TRUE if -N is used */
-	BOOLEAN apply_corrections = FALSE;	/* TRUE if -L is used */
+	GMT_LONG error = FALSE, mixed = FALSE, check_for_NaN = FALSE, both = FALSE, first, z_is_requested = FALSE;
+	GMT_LONG internal = TRUE;	/* FALSE if only external xovers are needed */
+	GMT_LONG external = TRUE;	/* FALSE if only internal xovers are needed */
+	GMT_LONG single = FALSE;		/* TRUE if a single track is specified -S */
+	GMT_LONG symm_check = FALSE;	/* TRUE if -Y is used */
+	GMT_LONG nx_check = FALSE;	/* TRUE if -N is used */
+	GMT_LONG apply_corrections = FALSE;	/* TRUE if -L is used */
 	int i, j, k, coe_kind, one, two, n_items, n_out, nx_min = 0, n_tracks, n_weights = 0, *trk_nx;
 	GMT_LONG p, np_use = 0, nx_use = 0, np, m, nx, id;
 	double wesn[4], val[2], out[128], corr[2] = {0.0, 0.0}, sec_2_unit = 1.0, w_k, w;
 	double fixed_weight = 1.0, *weights = NULL, asymm_max = 1.0, *trk_symm = NULL;
 	struct MGD77_CORRTABLE **CORR;
 	
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 	
-	for (i = strlen(argv[0]); i >= 0 && argv[0][i] != '/'; i--);
+	for (i = (int)strlen(argv[0]); i >= 0 && argv[0][i] != '/'; i--);
 	X2SYS_program = &argv[0][i+1];	/* Name without full path */
 	memset ((void *)wesn, 0, 4*sizeof(double));	/* 0 means no box specified */
 	
@@ -96,7 +97,12 @@ int main (int argc, char **argv)
 					if (argv[i][2] == 'i') external = FALSE;
 					break;
 				case 'S':
-					track = &argv[i][2];
+					if (argv[i][2] == '+') {	/* Print info relative to both cruises */
+						both  = TRUE;
+						track = &argv[i][3];
+					}
+					else
+						track = &argv[i][2];
 					single = TRUE;
 					break;
 				case 'T':
@@ -118,7 +124,7 @@ int main (int argc, char **argv)
 	if (argc == 1 || error || GMT_give_synopsis_and_exit) {
 		fprintf (stderr, "x2sys_list %s - Extract subset from crossover data base\n\n", X2SYS_VERSION);
 		fprintf (stderr, "usage: x2sys_list -C<column> -T<TAG> [<COEdbase>] [-A<asymm_max] [-F<flags>] [-I<ignorelist>] [-L[<corrtable.txt>]]\n");
-		fprintf (stderr, "\t [-N<nx_min>] [-Qe|i] [-S<track>] [%s] [-V] [-W<weight>] [%s]\n\n", GMT_Rgeo_OPT, GMT_mo_OPT);
+		fprintf (stderr, "\t [-N<nx_min>] [-Qe|i] [-S[+]<track>] [%s] [-V] [-W<weight>] [%s]\n\n", GMT_Rgeo_OPT, GMT_mo_OPT);
 
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
@@ -154,6 +160,7 @@ int main (int argc, char **argv)
 		GMT_explain_option ('R');
 		fprintf (stderr, "\t   [Default region is the entire data domain].\n");
 		fprintf (stderr, "\t-S Return only crossovers involving this track [Use all tracks].\n");
+		fprintf (stderr, "\t   Prepend a '+' to make it print info relative to both tracks [Default is selected track].\n");
 		GMT_explain_option ('V');
 		fprintf (stderr, "\t-W If argument can be opened as a file then we expect a List of tracks and their\n");
 		fprintf (stderr, "\t   relative weights; otherwise the argument is the constant weight for all tracks [1].\n");
@@ -174,7 +181,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "%s: ERROR: Must use -F to specify output items.\n", GMT_program);
 		exit (EXIT_FAILURE);
 	}
-	n_items = strlen (fflags);
+	n_items = (int)strlen (fflags);
 	for (i = 0; i < n_items; i++) {
 		if (!strchr (LETTERS, (int)fflags[i])) {
 			fprintf (stderr, "%s: ERROR -F: Unknown item %c.\n", GMT_program, fflags[i]);
@@ -239,8 +246,9 @@ int main (int argc, char **argv)
 	/* Initialize column output types */
 	
 	one = 0;	two = 1;	/* Normal track order */
-	both = !single;			/* Two columns for many output choices */
-	n_out = 1 + both;		/* Number of column output for some cols if single is not specified */
+	if (!both)			/* It may already been set by -S+ */
+		both = !single;		/* Two columns for many output choices */
+	n_out = 1 + (int)both;		/* Number of column output for some cols if single is not specified */
 
 	GMT_io.out_col_type[GMT_X] = (s->geographic) ? GMT_IS_LON : GMT_IS_FLOAT;
 	GMT_io.out_col_type[GMT_Y] = (s->geographic) ? GMT_IS_LAT : GMT_IS_FLOAT;
@@ -339,62 +347,76 @@ int main (int argc, char **argv)
 	/* Time to issue output */
 	
 	if (!GMT_io.binary[GMT_OUT]) {	/* Write 3 header records */
-		fprintf (GMT_stdout, "# Tag: %s %s\n", TAG, column);
-		fprintf (GMT_stdout, "# Command: %s", GMT_program);
-		if (!dbase) fprintf (GMT_stdout, " [stdin]");
-		for (k = 1; k < argc; k++) fprintf (GMT_stdout, " %s", argv[k]);
-		fprintf (GMT_stdout, "\n#");
+		sprintf (buffer, "# Tag: %s %s\n", TAG, column);	GMT_fputs (buffer, GMT_stdout);
+		sprintf (buffer, "# Command: %s ", GMT_program);	GMT_fputs (buffer, GMT_stdout);
+		if (!dbase) GMT_fputs (" [stdin]", GMT_stdout);
+		for (k = 1; k < argc; k++) {GMT_fputs (" ", GMT_stdout);	GMT_fputs (argv[k], GMT_stdout);}
+		sprintf (buffer, "\n#");
+		GMT_fputs (buffer, GMT_stdout);
 		for (i = j = 0; i < n_items; i++, j++) {	/* Overwrite the above settings */
-			if (i > 0) fprintf (GMT_stdout, "\t");
+			if (i > 0) GMT_fputs ("\t", GMT_stdout);
 			switch (fflags[i]) {	/* acdhintTvxyz */
 				case 'a':	/* Angle between tracks */
-					fprintf (GMT_stdout, "angle");
+					GMT_fputs ("angle", GMT_stdout);
 					break;
 				case 'c':	/* Crossover value */
-					fprintf (GMT_stdout, "%s_x", column);
+					sprintf (buffer, "%s_x", column);
+					GMT_fputs (buffer, GMT_stdout);
 					break;
 				case 'd':	/* Distance along track */
-					(both) ? fprintf (GMT_stdout, "dist_1\tdist_2") : fprintf (GMT_stdout, "dist");
+					(both) ? sprintf (buffer, "dist_1\tdist_2") : sprintf (buffer, "dist");
+					GMT_fputs (buffer, GMT_stdout);
 					break;
 				case 'h':	/* Heading along track */
-					(both) ? fprintf (GMT_stdout, "head_1\thead_2") : fprintf (GMT_stdout, "head");
+					(both) ? sprintf (buffer, "head_1\thead_2") : sprintf (buffer, "head");
+					GMT_fputs (buffer, GMT_stdout);
 					break;
 				case 'I':	/* Time interval (unsigned) */
-					fprintf (GMT_stdout, "u_tint");
+					GMT_fputs ("u_tint", GMT_stdout);
 					break;
 				case 'i':	/* Time interval (signed) */
-					fprintf (GMT_stdout, "s_tint");
+					GMT_fputs ("s_tint", GMT_stdout);
 					break;
 				case 'n':	/* Names of the track(s) [need this case to fall through] */
-					(both) ? fprintf (GMT_stdout, "track_1\ttrack_2") : fprintf (GMT_stdout, "track");
+					(both) ? sprintf (buffer, "track_1\ttrack_2") : sprintf (buffer, "track");
+					GMT_fputs (buffer, GMT_stdout);
 					break;
 				case 'N':	/* ID numbers of tracks */
-					(both) ? fprintf (GMT_stdout, "ID_1\tID_2") : fprintf (GMT_stdout, "ID");
+					(both) ? sprintf (buffer, "ID_1\tID_2") : sprintf (buffer, "ID");
+					GMT_fputs (buffer, GMT_stdout);
 					break;
 				case 't':	/* Time along track */
-					(both) ? fprintf (GMT_stdout, "t_1\tt_2") : fprintf (GMT_stdout, "t");
+					(both) ? sprintf (buffer, "t_1\tt_2") : sprintf (buffer, "t");
+					GMT_fputs (buffer, GMT_stdout);
 					break;
 				case 'T':	/* Time along track since beginning of the first year of the track */
-					(both) ? fprintf (GMT_stdout, "T_1\tT_2\n") : fprintf (GMT_stdout, "T");
+					(both) ? sprintf (buffer, "T_1\tT_2\n") : sprintf (buffer, "T");
+					GMT_fputs (buffer, GMT_stdout);
 					break;
 				case 'v':	/* Speed along track */
-					(both) ? fprintf (GMT_stdout, "vel_1\tvel_2") : fprintf (GMT_stdout, "vel");
+					(both) ? sprintf (buffer, "vel_1\tvel_2") : sprintf (buffer, "vel");
+					GMT_fputs (buffer, GMT_stdout);
 					break;
 				case 'w':	/* Composite weight of crossover */
-					fprintf (GMT_stdout, "weight");
+					GMT_fputs ("weight", GMT_stdout);
 					break;
 				case 'x':	/* x coordinate of crossover */
-					(s->geographic) ? fprintf (GMT_stdout, "lon") : fprintf (GMT_stdout, "x");
+					(s->geographic) ? GMT_fputs ("lon", GMT_stdout) : GMT_fputs ("x", GMT_stdout);
 					break;
 				case 'y':	/* y coordinate of crossover */
-					(s->geographic) ? fprintf (GMT_stdout, "lat") : fprintf (GMT_stdout, "y");
+					(s->geographic) ? GMT_fputs ("lat", GMT_stdout) : GMT_fputs ("y", GMT_stdout);
 					break;
 				case 'z':	/* Observed value along track */
-					(both) ? fprintf (GMT_stdout, "%s_1\t%s_2", column, column) : fprintf (GMT_stdout, "%s", column);
+					if (both) {
+						sprintf (buffer, "%s_1\t%s_2", column, column);
+						GMT_fputs (buffer, GMT_stdout);
+					}
+					else
+						GMT_fputs (column, GMT_stdout);
 					break;
 			}
 		}
-		fprintf (GMT_stdout, "\n");
+		GMT_fputs ("\n", GMT_stdout);
 	}
 	
 	for (p = 0; p < np; p++) {	/* For each pair of tracks that generated crossovers */
@@ -402,7 +424,10 @@ int main (int argc, char **argv)
 		if (symm_check && (fabs( trk_symm[P[p].id[0]]) > asymm_max || fabs( trk_symm[P[p].id[1]]) > asymm_max)) continue;	/* COEs not distributed symmatrically */
 		np_use++;
 		nx_use += P[p].nx;
-		if (GMT_io.multi_segments[GMT_OUT]) fprintf (GMT_stdout, "%c %s - %s nx = %d\n", GMT_io.EOF_flag[GMT_OUT], P[p].trk[0], P[p].trk[1], P[p].nx);
+		if (GMT_io.multi_segments[GMT_OUT]) {
+			sprintf (buffer, "%c %s - %s nx = %d\n", GMT_io.EOF_flag[GMT_OUT], P[p].trk[0], P[p].trk[1], P[p].nx);
+			GMT_fputs (buffer, GMT_stdout);
+		}
 		if (gmtdefs.verbose) fprintf (stderr, "%s: Crossovers from %s minus %s [%d].\n", GMT_program, P[p].trk[0], P[p].trk[1], P[p].nx);
 		if (single) {	/* May have to flip which is track one and two */
 			two = !strcmp (track, P[p].trk[0]);
@@ -449,14 +474,19 @@ int main (int argc, char **argv)
 						break;
 					case 'n':	/* Names of the track(s) */
 						if (both) {
-							if (!first) fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
-							fprintf (GMT_stdout, "%s", P[p].trk[0]);
-							fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
-							fprintf (GMT_stdout, "%s", P[p].trk[1]);
+							if (!first) GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);
+							GMT_fputs (P[p].trk[0], GMT_stdout);
+							GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);
+							GMT_fputs (P[p].trk[1], GMT_stdout);
 						}
 						else {
-							if (!first) fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
-							fprintf (GMT_stdout, "%s", P[p].trk[0]);
+							if (!first) GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);
+							if (!track)	/* Can we have a single and not track??? */
+								GMT_fputs (P[p].trk[0], GMT_stdout);
+							else if (strcmp(track, P[p].trk[0]))	/* Print name of other cruise */
+								GMT_fputs (P[p].trk[0], GMT_stdout);
+							else
+								GMT_fputs (P[p].trk[1], GMT_stdout);
 						}
 						break;
 					case 'N':	/* ID numbers of tracks */
@@ -480,7 +510,7 @@ int main (int argc, char **argv)
 						if (mixed) dump_ascii_cols (val, GMT_Z, n_out, first);
 						break;
 					case 'w':	/* Weight for this crossover */
-						if (weights) {	/* Weightfile wsa given; compute composite weight for this COE */
+						if (weights) {	/* Weightfile was given; compute composite weight for this COE */
 							for (m = 0, w_k = 0.0; m < 2; m++) {
 								if ((id = x2sys_find_track (P[p].trk[m], weight_name, n_weights)) == -1) {
 									fprintf (stderr, "%s: No weights found for track %s - using weight = 1.\n", GMT_program, P[p].trk[m]);
@@ -490,7 +520,7 @@ int main (int argc, char **argv)
 									w = weights[id];
 								w_k += 1.0 / (w*w);
 							}
-							out[j] = sqrt (1.0/w_k);
+							out[j] = sqrt (2.0/w_k);
 						}
 						else
 							out[j] = fixed_weight;
@@ -517,7 +547,7 @@ int main (int argc, char **argv)
 				first = FALSE;
 			}
 			if (mixed)
-				fputc ('\n', GMT_stdout);
+				GMT_fputs ("\n", GMT_stdout);
 			else
 				GMT_output (GMT_stdout, j, out);
 		}
@@ -539,13 +569,13 @@ int main (int argc, char **argv)
 	exit (EXIT_SUCCESS);
 }
 
-void dump_ascii_cols (double *val, int col, int n, BOOLEAN first)
+void dump_ascii_cols (double *val, int col, int n, GMT_LONG first)
 {	/* Short-hand to dump n = 1 or 2 numerical values in chosen format.
 	 * col is used to set the format, and first is TRUE for first item per record.
 	 */
 	int i;
 	for (i = 0; i < n; i++) {
-		if (!first) fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
+		if (!first) GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);
 		GMT_ascii_output_one (GMT_stdout, val[i], col);
 		first = FALSE;
 	}
