@@ -1,12 +1,12 @@
 /*-----------------------------------------------------------------
- *	$Id: x2sys_put.c,v 1.41 2010/01/05 01:15:49 guru Exp $
+ *	$Id: x2sys_put.c,v 1.45 2011/03/06 02:09:57 guru Exp $
  *
- *      Copyright (c) 1999-2010 by P. Wessel
+ *      Copyright (c) 1999-2011 by P. Wessel
  *      See LICENSE.TXT file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; version 2 of the License.
+ *      the Free Software Foundation; version 2 or any later version.
  *
  *      This program is distributed in the hope that it will be useful,
  *      but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -45,7 +45,7 @@ int main (int argc, char **argv)
 	char track_file[BUFSIZ], index_file[BUFSIZ], old_track_file[BUFSIZ], old_index_file[BUFSIZ];
 	char track_path[BUFSIZ], index_path[BUFSIZ], old_track_path[BUFSIZ], old_index_path[BUFSIZ];
 
-	BOOLEAN error = FALSE, replace = FALSE, delete = FALSE, found_it, skip, swap = FALSE;
+	GMT_LONG error = FALSE, replace = FALSE, delete = FALSE, found_it, skip, swap = FALSE;
 
 	FILE *fp = NULL, *fbin, *ftrack;
 
@@ -54,11 +54,11 @@ int main (int argc, char **argv)
 	size_t s_unused = 0;
 
 	int x2sys_bix_remove_track (int track_id, struct X2SYS_BIX *B);
-	struct X2SYS_BIX_TRACK_INFO * x2sys_bix_find_track (char *track, BOOLEAN *found_it, struct X2SYS_BIX *B);
+	struct X2SYS_BIX_TRACK_INFO * x2sys_bix_find_track (char *track, GMT_LONG *found_it, struct X2SYS_BIX *B);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 	
-	for (i = strlen(argv[0]); i >= 0 && argv[0][i] != '/'; i--);
+	for (i = (int)strlen(argv[0]); i >= 0 && argv[0][i] != '/'; i--);
 	X2SYS_program = &argv[0][i+1];	/* Name without full path */
 
 	for (i = 1; i < argc; i++) {
@@ -313,7 +313,7 @@ int x2sys_bix_remove_track (int track_id, struct X2SYS_BIX *B)
 	return (track_id);
 }
 
-struct X2SYS_BIX_TRACK_INFO * x2sys_bix_find_track (char *track, BOOLEAN *found_it, struct X2SYS_BIX *B)
+struct X2SYS_BIX_TRACK_INFO * x2sys_bix_find_track (char *track, GMT_LONG *found_it, struct X2SYS_BIX *B)
 {	/* Looks for given track in data base and if found returns pointer to the track before it and sets found_it to TRUE.
 	 * I.e., the track is actually this_info->next_info.  If not found set found_it to FALSE and return pointer where
 	 * this track should be inserted */
