@@ -1,12 +1,12 @@
 /*-----------------------------------------------------------------
- *	$Id: x2sys_solve.c,v 1.42 2010/01/14 07:15:20 guru Exp $
+ *	$Id: x2sys_solve.c,v 1.46 2011/03/03 21:02:51 guru Exp $
  *
- *      Copyright (c) 1999-2010 by P. Wessel
+ *      Copyright (c) 1999-2011 by P. Wessel
  *      See LICENSE.TXT file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; version 2 of the License.
+ *      the Free Software Foundation; version 2 or any later version.
  *
  *      This program is distributed in the hope that it will be useful,
  *      but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -125,22 +125,25 @@ int main (int argc, char **argv)
 {
 	char *TAG = CNULL, *column = CNULL, **trk_list = NULL, *dbase = CNULL;
 	char  trk[2][GMT_TEXT_LEN], t_txt[2][GMT_TEXT_LEN], z_txt[GMT_TEXT_LEN], w_txt[GMT_TEXT_LEN], line[BUFSIZ];
-	BOOLEAN error = FALSE, grow_list = FALSE, normalize = FALSE, use_weights = FALSE, active_col[N_COE_PARS], reset_zero = FALSE;
+	GMT_LONG error = FALSE, grow_list = FALSE, normalize = FALSE, use_weights = FALSE, active_col[N_COE_PARS], reset_zero = FALSE;
+	GMT_LONG write_mat_eq = FALSE, scale_range = FALSE;
 	int *ID[2];
+	int	it, n_iterations = 1;
 	GMT_LONG n_par = 0, n, m, t, n_tracks = 0, mode = 0, n_active;
 	GMT_LONG i, p, j, k, r, s, off, row, n_COE = 0, n_alloc = GMT_CHUNK, n_alloc_t = GMT_CHUNK, ierror;
 	double *N, *a, *b, *data[N_COE_PARS], sgn, zero_test = 1.0e-08, old_mean, new_mean, sw2;
 	double old_stdev, new_stdev, e_k, Sw, Sx, Sxx, range = 0.0, *start = NULL;
+	double sc_range = 1;
 	struct X2SYS_INFO *S;
 	struct X2SYS_BIX B;
 	FILE *fp;
 	PFD basis[N_BASIS];
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 	
 	for (i = strlen(argv[0]); i >= 0 && argv[0][i] != '/'; i--);
 	X2SYS_program = &argv[0][i+1];	/* Name without full path */
-	memset ((void *)active_col, FALSE, N_COE_PARS * sizeof (BOOLEAN));
+	memset ((void *)active_col, FALSE, N_COE_PARS * sizeof (GMT_LONG));
 
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
@@ -175,6 +178,13 @@ int main (int argc, char **argv)
 							break;
 					}
 					break;
+				case 'M':
+					write_mat_eq = TRUE;
+					break;
+				case 'S':
+					scale_range = TRUE;
+					sc_range = atof(&argv[i][2]);
+					break;
 				case 'T':
 					TAG = &argv[i][2];
 					break;
@@ -388,35 +398,49 @@ int main (int argc, char **argv)
 			switch (mode) {	/* Handle input differently depending on what is expected */
 				case F_IS_CONSTANT:
 					sscanf (line, "%s %s %s %s", trk[0], trk[1], z_txt, w_txt);
-					if (GMT_scanf (z_txt, GMT_IS_FLOAT, &data[COL_COE][n_COE]) == GMT_IS_NAN) data[COL_COE][n_COE] = GMT_d_NaN;
+					if (GMT_scanf (z_txt, GMT_IS_FLOAT, &data[COL_COE][n_COE]) == GMT_IS_NAN) 
+						data[COL_COE][n_COE] = GMT_d_NaN;
 					break;
 				case F_IS_DRIFT_T:
 					sscanf (line, "%s %s %s %s %s %s", trk[0], trk[1], t_txt[0], t_txt[1], z_txt, w_txt);
-					if (GMT_scanf (t_txt[0], GMT_IS_ABSTIME, &data[COL_T1][n_COE]) == GMT_IS_NAN) data[COL_T1][n_COE] = GMT_d_NaN;
-					if (GMT_scanf (t_txt[1], GMT_IS_ABSTIME, &data[COL_T2][n_COE]) == GMT_IS_NAN) data[COL_T2][n_COE] = GMT_d_NaN;
-					if (GMT_scanf (z_txt, GMT_IS_FLOAT, &data[COL_COE][n_COE]) == GMT_IS_NAN) data[COL_COE][n_COE] = GMT_d_NaN;
+					if (GMT_scanf (t_txt[0], GMT_IS_ABSTIME, &data[COL_T1][n_COE]) == GMT_IS_NAN) 
+						data[COL_T1][n_COE] = GMT_d_NaN;
+					if (GMT_scanf (t_txt[1], GMT_IS_ABSTIME, &data[COL_T2][n_COE]) == GMT_IS_NAN) 
+						data[COL_T2][n_COE] = GMT_d_NaN;
+					if (GMT_scanf (z_txt, GMT_IS_FLOAT, &data[COL_COE][n_COE]) == GMT_IS_NAN) 
+						data[COL_COE][n_COE] = GMT_d_NaN;
 					break;
 				case F_IS_DRIFT_D:
 					sscanf (line, "%s %s %s %s %s %s", trk[0], trk[1], t_txt[0], t_txt[1], z_txt, w_txt);
-					if (GMT_scanf (t_txt[0], GMT_IS_FLOAT, &data[COL_D1][n_COE]) == GMT_IS_NAN) data[COL_D1][n_COE] = GMT_d_NaN;
-					if (GMT_scanf (t_txt[1], GMT_IS_FLOAT, &data[COL_D2][n_COE]) == GMT_IS_NAN) data[COL_D2][n_COE] = GMT_d_NaN;
-					if (GMT_scanf (z_txt, GMT_IS_FLOAT, &data[COL_COE][n_COE]) == GMT_IS_NAN) data[COL_COE][n_COE] = GMT_d_NaN;
+					if (GMT_scanf (t_txt[0], GMT_IS_FLOAT, &data[COL_D1][n_COE]) == GMT_IS_NAN) 
+						data[COL_D1][n_COE] = GMT_d_NaN;
+					if (GMT_scanf (t_txt[1], GMT_IS_FLOAT, &data[COL_D2][n_COE]) == GMT_IS_NAN) 
+						data[COL_D2][n_COE] = GMT_d_NaN;
+					if (GMT_scanf (z_txt, GMT_IS_FLOAT, &data[COL_COE][n_COE]) == GMT_IS_NAN) 
+						data[COL_COE][n_COE] = GMT_d_NaN;
 					break;
 				case F_IS_GRAV1930:
 					sscanf (line, "%s %s %s %s %s", trk[0], trk[1], t_txt[0], z_txt, w_txt);
-					if (GMT_scanf (t_txt[0], GMT_IS_LAT, &data[COL_YY][n_COE]) == GMT_IS_NAN) data[COL_YY][n_COE] = GMT_d_NaN;
-					if (GMT_scanf (z_txt, GMT_IS_FLOAT, &data[COL_COE][n_COE]) == GMT_IS_NAN) data[COL_COE][n_COE] = GMT_d_NaN;
+					if (GMT_scanf (t_txt[0], GMT_IS_LAT, &data[COL_YY][n_COE]) == GMT_IS_NAN) 
+						data[COL_YY][n_COE] = GMT_d_NaN;
+					if (GMT_scanf (z_txt, GMT_IS_FLOAT, &data[COL_COE][n_COE]) == GMT_IS_NAN) 
+						data[COL_COE][n_COE] = GMT_d_NaN;
 					break;
 				case F_IS_HEADING:
 					sscanf (line, "%s %s %s %s %s %s", trk[0], trk[1], t_txt[0], t_txt[1], z_txt, w_txt);
-					if (GMT_scanf (t_txt[0], GMT_IS_FLOAT, &data[COL_H1][n_COE]) == GMT_IS_NAN) data[COL_H1][n_COE] = GMT_d_NaN;
-					if (GMT_scanf (t_txt[1], GMT_IS_FLOAT, &data[COL_H2][n_COE]) == GMT_IS_NAN) data[COL_H2][n_COE] = GMT_d_NaN;
-					if (GMT_scanf (z_txt, GMT_IS_FLOAT, &data[COL_COE][n_COE]) == GMT_IS_NAN) data[COL_COE][n_COE] = GMT_d_NaN;
+					if (GMT_scanf (t_txt[0], GMT_IS_FLOAT, &data[COL_H1][n_COE]) == GMT_IS_NAN) 
+						data[COL_H1][n_COE] = GMT_d_NaN;
+					if (GMT_scanf (t_txt[1], GMT_IS_FLOAT, &data[COL_H2][n_COE]) == GMT_IS_NAN) 
+						data[COL_H2][n_COE] = GMT_d_NaN;
+					if (GMT_scanf (z_txt, GMT_IS_FLOAT, &data[COL_COE][n_COE]) == GMT_IS_NAN) 
+						data[COL_COE][n_COE] = GMT_d_NaN;
 					break;
 				case F_IS_SCALE:
 					sscanf (line, "%s %s %s %s %s", trk[0], trk[1], t_txt[0], t_txt[1], w_txt);
-					if (GMT_scanf (t_txt[0], GMT_IS_FLOAT, &data[COL_Z1][n_COE]) == GMT_IS_NAN) data[COL_Z1][n_COE] = GMT_d_NaN;
-					if (GMT_scanf (t_txt[1], GMT_IS_FLOAT, &data[COL_Z2][n_COE]) == GMT_IS_NAN) data[COL_Z2][n_COE] = GMT_d_NaN;
+					if (GMT_scanf (t_txt[0], GMT_IS_FLOAT, &data[COL_Z1][n_COE]) == GMT_IS_NAN) 
+						data[COL_Z1][n_COE] = GMT_d_NaN;
+					if (GMT_scanf (t_txt[1], GMT_IS_FLOAT, &data[COL_Z2][n_COE]) == GMT_IS_NAN) 
+						data[COL_Z2][n_COE] = GMT_d_NaN;
 					break;
 			}
 			if (use_weights) {
@@ -430,11 +454,11 @@ int main (int argc, char **argv)
 			}
 			
 			for (i = 0; i < 2; i++) {	/* Look up track IDs */
-				ID[i][n_COE] = x2sys_find_track (trk[i], trk_list, n_tracks);	/* Return track id # for this leg */
+				ID[i][n_COE] = x2sys_find_track (trk[i], trk_list, (int)n_tracks);	/* Return track id # for this leg */
 				if (ID[i][n_COE] == -1) {	/* Leg not in the data base yet */
 					if (grow_list) {	/* Add it */
 						trk_list[n_tracks] = strdup (trk[i]);
-						ID[i][n_COE] = n_tracks++;
+						ID[i][n_COE] = (int)n_tracks++;
 						if (n_tracks == n_alloc_t) {
 							n_alloc_t <<= 1;
 							trk_list = (char **) GMT_memory ((void *)trk_list, (size_t)n_alloc_t, sizeof (char *), GMT_program);
@@ -446,15 +470,19 @@ int main (int argc, char **argv)
 			n_COE++;
 			if (n_COE == n_alloc) {
 				n_alloc <<= 1;
-				for (i = 0; i < N_COE_PARS; i++) if (active_col[i]) data[i] = (double *) GMT_memory ((void *)data[i], (size_t)n_alloc, sizeof (double), GMT_program);
+				for (i = 0; i < N_COE_PARS; i++) 
+					if (active_col[i]) 
+						data[i] = (double *) GMT_memory ((void *)data[i], (size_t)n_alloc, sizeof (double), GMT_program);
 				data[COL_WW] = (double *) GMT_memory ((void *)data[COL_WW], (size_t)n_alloc, sizeof (double), GMT_program);
-				for (i = 0; i < 2; i++) ID[i] = (int *) GMT_memory ((void *)ID[i], (size_t)n_alloc, sizeof (int), GMT_program);
+				for (i = 0; i < 2; i++) 
+					ID[i] = (int *) GMT_memory ((void *)ID[i], (size_t)n_alloc, sizeof (int), GMT_program);
 			}
 		}
 	}
 	if (fp != GMT_stdin) GMT_fclose(fp);
 	if (gmtdefs.verbose) fprintf (stderr, "%s: Found %ld COE records\n", GMT_program, n_COE);
-	for (i = 0; i < N_COE_PARS; i++) if (active_col[i]) data[i] = (double *) GMT_memory ((void *)data[i], (size_t)n_COE, sizeof (double), GMT_program);
+	for (i = 0; i < N_COE_PARS; i++) 
+		if (active_col[i]) data[i] = (double *) GMT_memory ((void *)data[i], (size_t)n_COE, sizeof (double), GMT_program);
 	data[COL_WW] = (double *) GMT_memory ((void *)data[COL_WW], (size_t)n_COE, sizeof (double), GMT_program);
 	
 	normalize = (mode == F_IS_DRIFT_T || mode == F_IS_DRIFT_D);
@@ -481,6 +509,7 @@ int main (int argc, char **argv)
 			}
 		}
 		range = max_extent - min_extent;
+		if (scale_range) range /= sc_range;
 		for (k = 0; k < n_COE; k++) for (i = 0; i < 2; i++) data[j+i][k] /= range;
 	}
 	
@@ -504,7 +533,13 @@ int main (int argc, char **argv)
 	/* Build A'A and A'b ==> N*x = b normal equation matrices directly since A may be too big to do A'A by multiplication.
 	 * For all corrections that involve a constant shift we must add the constraint that such shifts sum to zero; this
 	 * is implemented by adding an extra row/column with the appropriate 0s and 1s and a Lagrange multiplier. */
-	
+
+	for (it = 0; it < n_iterations; it++) {
+		if (it > 0) {
+			memset((void *)N, 0, m*m*sizeof(double));
+			memset((void *)b, 0, m*sizeof(double));
+		}
+
 	for (p = row = 0; p < n_tracks; p++) {	/* For each track */
 		for (s = 0; s < n_par; s++, row++) {	/* For each track's unknown parameter  */
 			for (k = 0; k < n_COE; k++) {	/* For each crossover */
@@ -525,6 +560,7 @@ int main (int argc, char **argv)
 			if (mode != F_IS_SCALE && s == 0) N[m*row+m-1] = 1.0;	/* Augmented column entry for Lagrange multiplier */
 		}
 	}
+
 	if (mode != F_IS_SCALE) {	/* Augmented row for Lagrange multiplier for constants */
 		for (i = 0, off = m*n; i < n; i += n_par) N[off+i] = 1.0;
 	}
@@ -537,10 +573,27 @@ int main (int argc, char **argv)
 	}
 #endif
 
+	if (write_mat_eq) {
+		char *Na, *B;
+		FILE *fp;
+		Na = "Na.dat";		B = "b.dat";
+		fp = fopen(Na, "w");
+		for (i = 0; i < m; i++) {
+			for (j = 0; j < m; j++) fprintf (fp, "%f\t", N[i*m+j]);
+			fprintf (fp, "\n");
+		}
+		fclose(fp);
+
+		fp = fopen(B, "w");
+		for (i = 0; i < m; i++)
+			fprintf (fp, "%f\n", b[i]);
+		fclose(fp);
+	}
+
 	/* Get LS solution */
 
 	GMT_gauss (N, b, m, m, zero_test, &ierror, 1);
-	GMT_free ((void *)N);
+	if (it == n_iterations-1) GMT_free ((void *)N);
 	a = b;	/* Convenience since the solution is called a in the notes */
 
 	/* Estimate new st.dev. */
@@ -558,11 +611,26 @@ int main (int argc, char **argv)
 #ifdef DEBUGX	
 		fprintf (stderr, "COE # %ld: Was %g Is %g\n", k, data[COL_COE][k], e_k);
 #endif
+		if (it > 0) {
+			data[COL_COE][k] = e_k;
+		}
 	}
 	new_mean = Sx / Sw;
 	new_stdev = sqrt ((n_COE * Sxx - Sx * Sx) / (Sw*Sw*(n_COE - 1.0)/n_COE));
 	
-	if (gmtdefs.verbose) fprintf (stderr, "%s: Old mean and st.dev.: %g %g New mean and st.dev.: %g %g\n", GMT_program, old_mean, old_stdev, new_mean, new_stdev);
+		if (gmtdefs.verbose)
+			fprintf (stderr, "%s: Iteration %d:\tOld mean and st.dev.: %g %g New mean and st.dev.: %g %g\n", 
+				GMT_program, it+1, old_mean, old_stdev, new_mean, new_stdev);
+
+		old_mean  = new_mean;
+		old_stdev = new_stdev;
+
+		if (it > 0) {
+			for (p = 0; p < n_tracks; p++)		/* For each track */ 
+				for (r = 0; r < n_par; r++) 	/* For each track's parameter in f(p)  */
+					a[p*n_par + r] += a[p*n_par + r];
+		}
+	}	/* end iteration loop */
 	
 	/* Write correction table */
 	
@@ -605,7 +673,7 @@ int main (int argc, char **argv)
 	for (i = 0; i < 2; i++) GMT_free ((void *)ID[i]);
 	GMT_free ((void *)b);
 	if (reset_zero) GMT_free ((void *)start);
-	x2sys_free_list (trk_list, n_tracks);
+	x2sys_free_list (trk_list, (int)n_tracks);
 
 	x2sys_end (S);
 	GMT_end (argc, argv);
