@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: xyz2grd.c,v 1.92 2010/01/14 07:15:19 guru Exp $
+ *	$Id: xyz2grd.c,v 1.102 2011/03/05 19:48:58 guru Exp $
  *
- *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -39,35 +39,35 @@
 
 struct XYZ2GRD_CTRL {
 	struct A {	/* -A[n|z|u|l] */
-		BOOLEAN active;
+		GMT_LONG active;
 		char mode;
 	} A;
 	struct D {	/* -D<xname>/<yname>/<zname>/<scale>/<offset>/<title>/<remark> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *information;
 	} D;
 	struct E {	/* -E[<nodata>] */
-		BOOLEAN active;
-		BOOLEAN set;
+		GMT_LONG active;
+		GMT_LONG set;
 		double nodata;
 	} E;
 	struct F {	/* -F */
-		BOOLEAN active;
+		GMT_LONG active;
 	} F;
 	struct G {	/* -G<output_grdfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} G;
 	struct I {	/* -Idx[/dy] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double xinc, yinc;
 	} I;
 	struct N {	/* -N<nodata> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double value;
 	} N;
 	struct S {	/* -S */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} S;
 	struct Z Z;
@@ -75,8 +75,8 @@ struct XYZ2GRD_CTRL {
 
 int main (int argc, char **argv)
 {
-	BOOLEAN error = FALSE, do_grid = FALSE, count = FALSE, average = TRUE;
-	BOOLEAN b_only = FALSE, done = FALSE, nofile = TRUE;
+	GMT_LONG error = FALSE, do_grid = FALSE, count = FALSE, average = TRUE;
+	GMT_LONG b_only = FALSE, done = FALSE, nofile = TRUE;
 	
 	GMT_LONG z = 2, fno, n_args, *flag = VNULL;
 	GMT_LONG n_expected_fields, n_fields, n_files = 0, high_low = 0;
@@ -98,7 +98,7 @@ int main (int argc, char **argv)
 	
 	void *New_xyz2grd_Ctrl (), Free_xyz2grd_Ctrl (struct XYZ2GRD_CTRL *C);
 	
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct XYZ2GRD_CTRL *)New_xyz2grd_Ctrl ();	/* Allocate and initialize a new control structure */
 
@@ -117,7 +117,7 @@ int main (int argc, char **argv)
 				case ':':
 				case 'f':
 				case '\0':
-					error += GMT_parse_common_options (argv[i], &grd.x_min, &grd.x_max, &grd.y_min, &grd.y_max);
+					error += (GMT_LONG)GMT_parse_common_options (argv[i], &grd.x_min, &grd.x_max, &grd.y_min, &grd.y_max);
 					break;
 
 				case 'A':
@@ -176,7 +176,7 @@ int main (int argc, char **argv)
 					break;
 				case 'Z':
 					Ctrl->Z.active = TRUE;
-					error += (BOOLEAN)GMT_parse_z_io (&argv[i][2], &Ctrl->Z);
+					error += (GMT_LONG)GMT_parse_z_io (&argv[i][2], &Ctrl->Z);
 					break;
 				default:
 					error = TRUE;
@@ -208,7 +208,8 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   [Default (no -A option) will compute mean values]\n");
 		fprintf (stderr, "\t-D to enter header information.  Specify '=' to get default value\n");
 		fprintf (stderr, "\t-E input is an ESRI ArcInfo interchange ASCII grid.  Optionally,\n");
-		fprintf (stderr, "\t   append the nodata value that represents NaNs [obtain from ESRI grid]\n");
+		fprintf (stderr, "\t   append the nodata value that represents nodes that should be NaN\n");
+		fprintf (stderr, "\t   [Normally, a nodata_value declaration may be found in the ESRI grid].\n");
 		fprintf (stderr, "\t   Information for -R , -I, and -F are obtained from the ESRI file.\n");
 		fprintf (stderr, "\t-F will force pixel registration [Default is grid registration]\n");
 		GMT_explain_option ('H');
@@ -303,7 +304,7 @@ int main (int argc, char **argv)
 	if (do_grid) {
 		grd.x_inc = Ctrl->I.xinc;
 		grd.y_inc = Ctrl->I.yinc;
-		grd.node_offset = Ctrl->F.active;
+		grd.node_offset = (int)Ctrl->F.active;
 		GMT_RI_prepare (&grd);	/* Ensure -R -I consistency and set nx, ny */
 	}
 	
@@ -462,14 +463,14 @@ int main (int argc, char **argv)
 				fprintf (stderr, "%s: Error decoding ncols record\n", GMT_program);
 				exit (EXIT_FAILURE);
 			}
-			not_used = fgets (line, BUFSIZ, fp);
+			not_used = fgets (line, BUFSIZ, fp);	GMT_str_tolower (line);
 			GMT_chop (line);					/* Rid the world of CR/LF */
 			if (sscanf (line, "%*s %lf", &grd.x_min) != 1) {
 				fprintf (stderr, "%s: Error decoding xll record\n", GMT_program);
 				exit (EXIT_FAILURE);
 			}
 			if (!strncmp (line, "xllcorner", (size_t)9)) grd.node_offset = 1;	/* Pixel grid */
-			not_used = fgets (line, BUFSIZ, fp);
+			not_used = fgets (line, BUFSIZ, fp);	GMT_str_tolower (line);
 			GMT_chop (line);					/* Rid the world of CR/LF */
 			if (sscanf (line, "%*s %lf", &grd.y_min) != 1) {
 				fprintf (stderr, "%s: Error decoding yll record\n", GMT_program);
@@ -482,14 +483,6 @@ int main (int argc, char **argv)
 				fprintf (stderr, "%s: Error decoding cellsize record\n", GMT_program);
 				exit (EXIT_FAILURE);
 			}
-			if (!Ctrl->E.set) {	/* Only read if not specified in -E */
-				not_used = fgets (line, BUFSIZ, fp);
-				GMT_chop (line);					/* Rid the world of CR/LF */
-				if (sscanf (line, "%*s %lf", &Ctrl->E.nodata) != 1) {
-					fprintf (stderr, "%s: Error decoding nodata_value record\n", GMT_program);
-					exit (EXIT_FAILURE);
-				}
-			}
 			grd.y_inc = grd.x_inc;
 			grd.xy_off = 0.5 * grd.node_offset;
 			grd.x_max = grd.x_min + (grd.nx - 1 + grd.node_offset) * grd.x_inc;
@@ -501,13 +494,35 @@ int main (int argc, char **argv)
 			nm = n_left = GMT_get_nm (grd.nx, grd.ny);
 
 			a = (float *) GMT_memory (VNULL, (size_t)nm, sizeof (float), GMT_program);
-			/* ESRI grids are scanline oriented (top to bottom) as are GMT grids */
+			if (!Ctrl->E.set) {	/* Only read if not specified in -E */
+				not_used = fgets (line, BUFSIZ, fp);
+				GMT_chop (line);					/* Rid the world of CR/LF */
+				if (sscanf (line, "%*s %lf", &Ctrl->E.nodata) != 1) {
+					fprintf (stderr, "%s: Error decoding nodata_value record\n", GMT_program);
+					exit (EXIT_FAILURE);
+				}
+			}
 			i = j = 0;
+			fscanf (fp, "%s", line);	GMT_str_tolower (line);
+			if (!strcmp (line, "nodata_value")) {	/* Found the optional nodata word */
+				fscanf (fp, "%f", &value);
+				if (Ctrl->E.set && !GMT_IS_ZERO (value - Ctrl->E.nodata)) {
+					fprintf (stderr, "%s: Your -E%g overrides the nodata_value of %g found in the ESRI file\n", GMT_program, Ctrl->E.nodata, value);
+				}
+				else
+					Ctrl->E.nodata = value;
+			}
+			else {	/* Instead got the very first data value */
+				value = (float) atof (line);
+				a[0] = ((double)value == Ctrl->E.nodata) ? GMT_f_NaN : value;
+				if (++i == grd.nx) i = 0, j++;
+				n_left--;
+			}
+			/* ESRI grids are scanline oriented (top to bottom) as are GMT grids */
 			while (fscanf (fp, "%f", &value) == 1 && n_left) {
 				ij = j * grd.nx + i;
 				a[ij] = (value == Ctrl->E.nodata) ? GMT_f_NaN : (float) value;
-				i++;
-				if (i == grd.nx) i = 0, j++;
+				if (++i == grd.nx) i = 0, j++;
 				n_left--;
 			}
 			if (n_left) {
@@ -516,14 +531,14 @@ int main (int argc, char **argv)
 			}
 		}
 		else {	/* Get x, y, z */
-
+			gmtdefs.nan_is_gap = FALSE;	/* Here, all x,y matters */
 			while ((n_fields = GMT_input (fp, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
 
-				if (GMT_io.status & GMT_IO_MISMATCH) {
-					fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields, n_expected_fields, n_read);
-					exit (EXIT_FAILURE);
-				}
 				n_read++;
+				if (GMT_io.status & GMT_IO_MISMATCH) {
+					fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld (skipped)\n", GMT_program, n_fields, n_expected_fields, n_read);
+					continue;
+				}
 
 				if (GMT_y_is_outside (in[GMT_Y],  wesn[2], wesn[3])) continue;	/* Outside y-range */
 				if (GMT_x_is_outside (&in[GMT_X], wesn[0], wesn[1])) continue;	/* Outside x-range */
